from aws_resource_validator.models import Service, APIRegistry, APIObject

class Accessanalyzer(Service):
    def __init__(self):
        super().__init__('Accessanalyzer')
        self.AccessPointArn = APIObject('AccessPointArn', 'string', r'arn:[^:]*:s3:[^:]*:[^:]*:accesspoint/.*', None, None)
        self.add_api_object('AccessPointArn', self.AccessPointArn)
        self.AccessPreviewId = APIObject('AccessPreviewId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('AccessPreviewId', self.AccessPreviewId)
        self.AnalyzerArn = APIObject('AnalyzerArn', 'string', r'[^:]*:[^:]*:[^:]*:[^:]*:[^:]*:analyzer/.{1,255}', None, None)
        self.add_api_object('AnalyzerArn', self.AnalyzerArn)
        self.CloudTrailArn = APIObject('CloudTrailArn', 'string', r'arn:[^:]*:cloudtrail:[^:]*:[^:]*:trail/.{1,576}', None, None)
        self.add_api_object('CloudTrailArn', self.CloudTrailArn)
        self.Name = APIObject('Name', 'string', r'[A-Za-z][A-Za-z0-9_.-]*', 1, 255)
        self.add_api_object('Name', self.Name)
        self.PrincipalArn = APIObject('PrincipalArn', 'string', r'arn:[^:]*:iam::[^:]*:(role|user)/.{1,576}', None, None)
        self.add_api_object('PrincipalArn', self.PrincipalArn)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:[^:]*:iam::[^:]*:role/.{1,576}', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-([0-9a-f]){8}(([0-9a-f]){9})?', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Account(Service):
    def __init__(self):
        super().__init__('Account')
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.ContactInformationPhoneNumber = APIObject('ContactInformationPhoneNumber', 'string', r'^[+][\s0-9()-]+$', 1, 20)
        self.add_api_object('ContactInformationPhoneNumber', self.ContactInformationPhoneNumber)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'^[\s]*[\w+=.#|!&-]+@[\w.-]+\.[\w]+[\s]*$', 1, 254)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'^[\s0-9()+-]+$', 1, 25)
        self.add_api_object('PhoneNumber', self.PhoneNumber)

class AcmPca(Service):
    def __init__(self):
        super().__init__('AcmPca')
        self.ASN1PrintableString64 = APIObject('ASN1PrintableString64', 'string', r'[a-zA-Z0-9\'()+-.?:/= ]*', 0, 64)
        self.add_api_object('ASN1PrintableString64', self.ASN1PrintableString64)
        self.AWSPolicy = APIObject('AWSPolicy', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 20480)
        self.add_api_object('AWSPolicy', self.AWSPolicy)
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]+', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.Arn = APIObject('Arn', 'string', r'arn:[\w+=/,.@-]+:acm-pca:[\w+=/,.@-]*:[0-9]*:[\w+=,.@-]+(/[\w+=,.@-]+)*', 5, 200)
        self.add_api_object('Arn', self.Arn)
        self.AuditReportId = APIObject('AuditReportId', 'string', r'[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}', 36, 36)
        self.add_api_object('AuditReportId', self.AuditReportId)
        self.Base64String1To4096 = APIObject('Base64String1To4096', 'string', r'^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$', 1, 4096)
        self.add_api_object('Base64String1To4096', self.Base64String1To4096)
        self.CnameString = APIObject('CnameString', 'string', r'^[-a-zA-Z0-9;/?:@&=+$,%_.!~*()\']*$', 0, 253)
        self.add_api_object('CnameString', self.CnameString)
        self.CountryCodeString = APIObject('CountryCodeString', 'string', r'[A-Za-z]{2}', 2, 2)
        self.add_api_object('CountryCodeString', self.CountryCodeString)
        self.CustomObjectIdentifier = APIObject('CustomObjectIdentifier', 'string', r'^([0-2])\.([0-9]|([0-3][0-9]))((\.([0-9]+)){0,126})$', 0, 64)
        self.add_api_object('CustomObjectIdentifier', self.CustomObjectIdentifier)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]*', 1, 36)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.Principal = APIObject('Principal', 'string', r'^[^*]+$', 0, 128)
        self.add_api_object('Principal', self.Principal)
        self.S3BucketName3To255 = APIObject('S3BucketName3To255', 'string', r'^[-a-zA-Z0-9._/]+$', 3, 255)
        self.add_api_object('S3BucketName3To255', self.S3BucketName3To255)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Acm(Service):
    def __init__(self):
        super().__init__('Acm')
        self.Arn = APIObject('Arn', 'string', r'arn:[\w+=/,.@-]+:acm:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=,.@-]+)*', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.CertificateBody = APIObject('CertificateBody', 'string', r'-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}(\u000D?\u000A)?', 1, 32768)
        self.add_api_object('CertificateBody', self.CertificateBody)
        self.CertificateChain = APIObject('CertificateChain', 'string', r'(-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}\u000D?\u000A)*-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}(\u000D?\u000A)?', 1, 2097152)
        self.add_api_object('CertificateChain', self.CertificateChain)
        self.DomainNameString = APIObject('DomainNameString', 'string', r'^(\*\.)?(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', 1, 253)
        self.add_api_object('DomainNameString', self.DomainNameString)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'\w+', 1, 32)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.NextToken = APIObject('NextToken', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]*', 1, 10000)
        self.add_api_object('NextToken', self.NextToken)
        self.PcaArn = APIObject('PcaArn', 'string', r'arn:[\w+=/,.@-]+:acm-pca:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=,.@-]+)*', 20, 2048)
        self.add_api_object('PcaArn', self.PcaArn)
        self.PrivateKey = APIObject('PrivateKey', 'string', r'-{5}BEGIN PRIVATE KEY-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END PRIVATE KEY-{5}(\u000D?\u000A)?', 1, 524288)
        self.add_api_object('PrivateKey', self.PrivateKey)
        self.TagKey = APIObject('TagKey', 'string', r'[\p{L}\p{Z}\p{N}_.:\/=+\-@]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\p{L}\p{Z}\p{N}_.:\/=+\-@]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Alexaforbusiness(Service):
    def __init__(self):
        super().__init__('Alexaforbusiness')
        self.AddressBookDescription = APIObject('AddressBookDescription', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 200)
        self.add_api_object('AddressBookDescription', self.AddressBookDescription)
        self.AddressBookName = APIObject('AddressBookName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('AddressBookName', self.AddressBookName)
        self.AmazonId = APIObject('AmazonId', 'string', r'[a-zA-Z0-9]{1,18}', None, None)
        self.add_api_object('AmazonId', self.AmazonId)
        self.Arn = APIObject('Arn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', None, None)
        self.add_api_object('Arn', self.Arn)
        self.AudioLocation = APIObject('AudioLocation', 'string', r'https://([A-Za-z0-9_.-]+)?(s3-[A-Za-z0-9-]+|s3\.([A-Za-z0-9-])+|s3|s3.dualstack\.([A-Za-z0-9-])+)+.amazonaws.com/.*', 0, 1200)
        self.add_api_object('AudioLocation', self.AudioLocation)
        self.BusinessReportScheduleName = APIObject('BusinessReportScheduleName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 64)
        self.add_api_object('BusinessReportScheduleName', self.BusinessReportScheduleName)
        self.ClientId = APIObject('ClientId', 'string', r'^\S+{1,256}$', None, None)
        self.add_api_object('ClientId', self.ClientId)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 10, 150)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.ConferenceProviderName = APIObject('ConferenceProviderName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 50)
        self.add_api_object('ConferenceProviderName', self.ConferenceProviderName)
        self.ContactName = APIObject('ContactName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('ContactName', self.ContactName)
        self.CountryCode = APIObject('CountryCode', 'string', r'\d{1,3}', None, None)
        self.add_api_object('CountryCode', self.CountryCode)
        self.CurrentWiFiPassword = APIObject('CurrentWiFiPassword', 'string', r'[\x00-\x7F]*', 5, 128)
        self.add_api_object('CurrentWiFiPassword', self.CurrentWiFiPassword)
        self.CustomerS3BucketName = APIObject('CustomerS3BucketName', 'string', r'[a-z0-9-\.]{3,63}', None, None)
        self.add_api_object('CustomerS3BucketName', self.CustomerS3BucketName)
        self.Date = APIObject('Date', 'string', r'^\d{4}\-(0?[1-9]|1[012])\-(0?[1-9]|[12][0-9]|3[01])$', None, None)
        self.add_api_object('Date', self.Date)
        self.DeviceName = APIObject('DeviceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 2, 100)
        self.add_api_object('DeviceName', self.DeviceName)
        self.DeviceRoomName = APIObject('DeviceRoomName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('DeviceRoomName', self.DeviceRoomName)
        self.DeviceSerialNumber = APIObject('DeviceSerialNumber', 'string', r'[a-zA-Z0-9]{1,200}', None, None)
        self.add_api_object('DeviceSerialNumber', self.DeviceSerialNumber)
        self.DeviceSerialNumberForAVS = APIObject('DeviceSerialNumberForAVS', 'string', r'^[a-zA-Z0-9]{1,50}$', None, None)
        self.add_api_object('DeviceSerialNumberForAVS', self.DeviceSerialNumberForAVS)
        self.DeviceType = APIObject('DeviceType', 'string', r'[a-zA-Z0-9]{1,200}', None, None)
        self.add_api_object('DeviceType', self.DeviceType)
        self.Email = APIObject('Email', 'string', r'\w[+-.\w]*@\w[\w\.\-]+\.[0-9a-zA-Z]{2,24}', 1, 128)
        self.add_api_object('Email', self.Email)
        self.GatewayDescription = APIObject('GatewayDescription', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 200)
        self.add_api_object('GatewayDescription', self.GatewayDescription)
        self.GatewayGroupName = APIObject('GatewayGroupName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('GatewayGroupName', self.GatewayGroupName)
        self.GatewayName = APIObject('GatewayName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 253)
        self.add_api_object('GatewayName', self.GatewayName)
        self.NetworkProfileDescription = APIObject('NetworkProfileDescription', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 200)
        self.add_api_object('NetworkProfileDescription', self.NetworkProfileDescription)
        self.NetworkProfileName = APIObject('NetworkProfileName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('NetworkProfileName', self.NetworkProfileName)
        self.NetworkSsid = APIObject('NetworkSsid', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 32)
        self.add_api_object('NetworkSsid', self.NetworkSsid)
        self.NextWiFiPassword = APIObject('NextWiFiPassword', 'string', r'(^$)|([\x00-\x7F]{5,})', 0, 128)
        self.add_api_object('NextWiFiPassword', self.NextWiFiPassword)
        self.OrganizationName = APIObject('OrganizationName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('OrganizationName', self.OrganizationName)
        self.OutboundPhoneNumber = APIObject('OutboundPhoneNumber', 'string', r'\d{10}', None, None)
        self.add_api_object('OutboundPhoneNumber', self.OutboundPhoneNumber)
        self.ProductId = APIObject('ProductId', 'string', r'^[a-zA-Z0-9_]{1,256}$', None, None)
        self.add_api_object('ProductId', self.ProductId)
        self.ProfileName = APIObject('ProfileName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('ProfileName', self.ProfileName)
        self.RawPhoneNumber = APIObject('RawPhoneNumber', 'string', r'^[\+0-9\#\,\(][\+0-9\-\.\/\(\)\,\#\s]+$', 0, 50)
        self.add_api_object('RawPhoneNumber', self.RawPhoneNumber)
        self.RoomDescription = APIObject('RoomDescription', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 200)
        self.add_api_object('RoomDescription', self.RoomDescription)
        self.RoomName = APIObject('RoomName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('RoomName', self.RoomName)
        self.S3KeyPrefix = APIObject('S3KeyPrefix', 'string', r'[A-Za-z0-9!_\-\.\*\'()/]*', 0, 100)
        self.add_api_object('S3KeyPrefix', self.S3KeyPrefix)
        self.SipUri = APIObject('SipUri', 'string', r'^sip[s]?:([^@:]+)\@([^@]+)$', 1, 256)
        self.add_api_object('SipUri', self.SipUri)
        self.SkillGroupDescription = APIObject('SkillGroupDescription', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 200)
        self.add_api_object('SkillGroupDescription', self.SkillGroupDescription)
        self.SkillGroupName = APIObject('SkillGroupName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('SkillGroupName', self.SkillGroupName)
        self.SkillId = APIObject('SkillId', 'string', r'(^amzn1\.ask\.skill\.[0-9a-f\-]{1,200})|(^amzn1\.echo-sdk-ams\.app\.[0-9a-f\-]{1,200})', None, None)
        self.add_api_object('SkillId', self.SkillId)
        self.SkillName = APIObject('SkillName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 100)
        self.add_api_object('SkillName', self.SkillName)
        self.SkillType = APIObject('SkillType', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('SkillType', self.SkillType)
        self.SsmlValue = APIObject('SsmlValue', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 4096)
        self.add_api_object('SsmlValue', self.SsmlValue)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TextValue = APIObject('TextValue', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 4096)
        self.add_api_object('TextValue', self.TextValue)
        self.TrustAnchor = APIObject('TrustAnchor', 'string', r'-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}(\u000D?\u000A)?', None, None)
        self.add_api_object('TrustAnchor', self.TrustAnchor)
        self.UserId = APIObject('UserId', 'string', r'amzn1\.[A-Za-z0-9+-\/=.]{1,300}', None, None)
        self.add_api_object('UserId', self.UserId)
        self.userFirstName = APIObject('userFirstName', 'string', r'([A-Za-z\-\' 0-9._]|\p{IsLetter})*', 0, 30)
        self.add_api_object('userFirstName', self.userFirstName)
        self.userLastName = APIObject('userLastName', 'string', r'([A-Za-z\-\' 0-9._]|\p{IsLetter})*', 0, 30)
        self.add_api_object('userLastName', self.userLastName)
        self.userUserId = APIObject('userUserId', 'string', r'[a-zA-Z0-9@_+.-]*', 1, 128)
        self.add_api_object('userUserId', self.userUserId)

class Amp(Service):
    def __init__(self):
        super().__init__('Amp')
        self.ClusterArn = APIObject('ClusterArn', 'string', r'^arn:aws[-a-z]*:eks:[-a-z0-9]+:[0-9]{12}:cluster/.+$', None, None)
        self.add_api_object('ClusterArn', self.ClusterArn)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'^[!-~]+$', 1, 64)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws:kms:[a-z0-9\-]+:\d+:key/[a-f0-9\-]+$', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'^arn:aws[a-z0-9-]*:logs:[a-z0-9-]+:\d{12}:log-group:[A-Za-z0-9\.\-\_\#/]{1,512}\:\*$', None, None)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.RuleGroupsNamespaceName = APIObject('RuleGroupsNamespaceName', 'string', r'[0-9A-Za-z][-.0-9A-Z_a-z]*', 1, 64)
        self.add_api_object('RuleGroupsNamespaceName', self.RuleGroupsNamespaceName)
        self.ScraperAlias = APIObject('ScraperAlias', 'string', r'^[0-9A-Za-z][-.0-9A-Z_a-z]*$', 1, 100)
        self.add_api_object('ScraperAlias', self.ScraperAlias)
        self.ScraperId = APIObject('ScraperId', 'string', r'^[0-9A-Za-z][-.0-9A-Z_a-z]*$', 1, 64)
        self.add_api_object('ScraperId', self.ScraperId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-[0-9a-z]+$', 0, 255)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[0-9a-z]+$', 0, 255)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.WorkspaceArn = APIObject('WorkspaceArn', 'string', r'^arn:aws[-a-z]*:aps:[-a-z0-9]+:[0-9]{12}:workspace/.+$', None, None)
        self.add_api_object('WorkspaceArn', self.WorkspaceArn)
        self.WorkspaceId = APIObject('WorkspaceId', 'string', r'[0-9A-Za-z][-.0-9A-Z_a-z]*', 1, 64)
        self.add_api_object('WorkspaceId', self.WorkspaceId)

class Amplify(Service):
    def __init__(self):
        super().__init__('Amplify')
        self.AccessToken = APIObject('AccessToken', 'string', r'(?s).+', 1, 255)
        self.add_api_object('AccessToken', self.AccessToken)
        self.AppId = APIObject('AppId', 'string', r'd[a-z0-9]+', 1, 20)
        self.add_api_object('AppId', self.AppId)
        self.ArtifactId = APIObject('ArtifactId', 'string', r'(?s).*', None, 255)
        self.add_api_object('ArtifactId', self.ArtifactId)
        self.AutoBranchCreationPattern = APIObject('AutoBranchCreationPattern', 'string', r'(?s).+', 1, 2048)
        self.add_api_object('AutoBranchCreationPattern', self.AutoBranchCreationPattern)
        self.AutoSubDomainCreationPattern = APIObject('AutoSubDomainCreationPattern', 'string', r'(?s).+', 1, 2048)
        self.add_api_object('AutoSubDomainCreationPattern', self.AutoSubDomainCreationPattern)
        self.AutoSubDomainIAMRole = APIObject('AutoSubDomainIAMRole', 'string', r'^$|^arn:aws:iam::\d{12}:role.+', None, 1000)
        self.add_api_object('AutoSubDomainIAMRole', self.AutoSubDomainIAMRole)
        self.BackendEnvironmentArn = APIObject('BackendEnvironmentArn', 'string', r'(?s).*', 0, 1000)
        self.add_api_object('BackendEnvironmentArn', self.BackendEnvironmentArn)
        self.BasicAuthCredentials = APIObject('BasicAuthCredentials', 'string', r'(?s).*', None, 2000)
        self.add_api_object('BasicAuthCredentials', self.BasicAuthCredentials)
        self.BranchArn = APIObject('BranchArn', 'string', r'(?s).*', None, 1000)
        self.add_api_object('BranchArn', self.BranchArn)
        self.BranchName = APIObject('BranchName', 'string', r'(?s).+', 1, 255)
        self.add_api_object('BranchName', self.BranchName)
        self.BuildSpec = APIObject('BuildSpec', 'string', r'(?s).+', 1, 25000)
        self.add_api_object('BuildSpec', self.BuildSpec)
        self.CertificateArn = APIObject('CertificateArn', 'string', r'^arn:aws:acm:[a-z0-9-]+:\d{12}:certificate\/.+$', 0, 1000)
        self.add_api_object('CertificateArn', self.CertificateArn)
        self.CommitId = APIObject('CommitId', 'string', r'(?s).*', None, 255)
        self.add_api_object('CommitId', self.CommitId)
        self.CommitMessage = APIObject('CommitMessage', 'string', r'(?s).*', None, 10000)
        self.add_api_object('CommitMessage', self.CommitMessage)
        self.Condition = APIObject('Condition', 'string', r'(?s).*', 0, 2048)
        self.add_api_object('Condition', self.Condition)
        self.CustomHeaders = APIObject('CustomHeaders', 'string', r'(?s).*', 0, 25000)
        self.add_api_object('CustomHeaders', self.CustomHeaders)
        self.DeploymentArtifacts = APIObject('DeploymentArtifacts', 'string', r'(?s).+', 1, 1000)
        self.add_api_object('DeploymentArtifacts', self.DeploymentArtifacts)
        self.Description = APIObject('Description', 'string', r'(?s).*', None, 1000)
        self.add_api_object('Description', self.Description)
        self.DisplayName = APIObject('DisplayName', 'string', r'(?s).*', None, 255)
        self.add_api_object('DisplayName', self.DisplayName)
        self.DomainName = APIObject('DomainName', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])(\.)?$', None, 64)
        self.add_api_object('DomainName', self.DomainName)
        self.DomainPrefix = APIObject('DomainPrefix', 'string', r'(?s).*', None, 255)
        self.add_api_object('DomainPrefix', self.DomainPrefix)
        self.EnvKey = APIObject('EnvKey', 'string', r'(?s).*', None, 255)
        self.add_api_object('EnvKey', self.EnvKey)
        self.EnvValue = APIObject('EnvValue', 'string', r'(?s).*', None, 5500)
        self.add_api_object('EnvValue', self.EnvValue)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'(?s).+', 1, 255)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.FileName = APIObject('FileName', 'string', r'(?s).*', None, 255)
        self.add_api_object('FileName', self.FileName)
        self.Framework = APIObject('Framework', 'string', r'(?s).*', None, 255)
        self.add_api_object('Framework', self.Framework)
        self.JobId = APIObject('JobId', 'string', r'[0-9]+', None, 255)
        self.add_api_object('JobId', self.JobId)
        self.JobReason = APIObject('JobReason', 'string', r'(?s).*', None, 255)
        self.add_api_object('JobReason', self.JobReason)
        self.MD5Hash = APIObject('MD5Hash', 'string', r'(?s).*', None, 32)
        self.add_api_object('MD5Hash', self.MD5Hash)
        self.Name = APIObject('Name', 'string', r'(?s).+', 1, 255)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'(?s).*', None, 2000)
        self.add_api_object('NextToken', self.NextToken)
        self.OauthToken = APIObject('OauthToken', 'string', r'(?s).*', None, 1000)
        self.add_api_object('OauthToken', self.OauthToken)
        self.PullRequestEnvironmentName = APIObject('PullRequestEnvironmentName', 'string', r'(?s).*', None, 20)
        self.add_api_object('PullRequestEnvironmentName', self.PullRequestEnvironmentName)
        self.Repository = APIObject('Repository', 'string', r'(?s).*', None, 1000)
        self.add_api_object('Repository', self.Repository)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:amplify:.*', 0, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ServiceRoleArn = APIObject('ServiceRoleArn', 'string', r'(?s).*', 0, 1000)
        self.add_api_object('ServiceRoleArn', self.ServiceRoleArn)
        self.Source = APIObject('Source', 'string', r'(?s).+', 1, 2048)
        self.add_api_object('Source', self.Source)
        self.SourceUrl = APIObject('SourceUrl', 'string', r'(?s).*', None, 3000)
        self.add_api_object('SourceUrl', self.SourceUrl)
        self.StackArn = APIObject('StackArn', 'string', r'^arn:aws:cloudformation:[a-z0-9-]+:\d{12}:stack/.+/.+$', 20, 2048)
        self.add_api_object('StackArn', self.StackArn)
        self.StackName = APIObject('StackName', 'string', r'(?s).+', 1, 255)
        self.add_api_object('StackName', self.StackName)
        self.Status = APIObject('Status', 'string', r'.{3,7}', 3, 7)
        self.add_api_object('Status', self.Status)
        self.TTL = APIObject('TTL', 'string', r'\d*', 0, 32)
        self.add_api_object('TTL', self.TTL)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Target = APIObject('Target', 'string', r'(?s).+', 1, 2048)
        self.add_api_object('Target', self.Target)
        self.WebhookId = APIObject('WebhookId', 'string', r'(?s).*', None, 255)
        self.add_api_object('WebhookId', self.WebhookId)

class Amplifybackend(Service):
    def __init__(self):
        super().__init__('Amplifybackend')

class Amplifyuibuilder(Service):
    def __init__(self):
        super().__init__('Amplifyuibuilder')
        self.AppId = APIObject('AppId', 'string', r'd[a-z0-9]+', 1, 20)
        self.add_api_object('AppId', self.AppId)
        self.OperandType = APIObject('OperandType', 'string', r'boolean|string|number', None, None)
        self.add_api_object('OperandType', self.OperandType)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Apigateway(Service):
    def __init__(self):
        super().__init__('Apigateway')
        self.DocumentationPartLocationStatusCode = APIObject('DocumentationPartLocationStatusCode', 'string', r'^([1-5]\d\d|\*|\s*)$', None, None)
        self.add_api_object('DocumentationPartLocationStatusCode', self.DocumentationPartLocationStatusCode)
        self.StatusCode = APIObject('StatusCode', 'string', r'[1-5]\d\d', None, None)
        self.add_api_object('StatusCode', self.StatusCode)

class Apigatewaymanagementapi(Service):
    def __init__(self):
        super().__init__('Apigatewaymanagementapi')

class Apigatewayv2(Service):
    def __init__(self):
        super().__init__('Apigatewayv2')

class Appconfig(Service):
    def __init__(self):
        super().__init__('Appconfig')
        self.Arn = APIObject('Arn', 'string', r'arn:(aws[a-zA-Z-]*)?:[a-z]+:([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1})?:(\d{12})?:[a-zA-Z0-9-_/:.]+', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.ConfigurationProfileType = APIObject('ConfigurationProfileType', 'string', r'^[a-zA-Z\.]+', None, None)
        self.add_api_object('ConfigurationProfileType', self.ConfigurationProfileType)
        self.DeploymentStrategyId = APIObject('DeploymentStrategyId', 'string', r'(^[a-z0-9]{4,7}$|^AppConfig\.[A-Za-z0-9]{9,40}$)', None, None)
        self.add_api_object('DeploymentStrategyId', self.DeploymentStrategyId)
        self.DynamicParameterKey = APIObject('DynamicParameterKey', 'string', r'^([^#\n]{1,96})#([^\/#\n]{1,64})$', None, None)
        self.add_api_object('DynamicParameterKey', self.DynamicParameterKey)
        self.ExtensionOrParameterName = APIObject('ExtensionOrParameterName', 'string', r'^[^\/#:\n]{1,64}$', None, None)
        self.add_api_object('ExtensionOrParameterName', self.ExtensionOrParameterName)
        self.Id = APIObject('Id', 'string', r'[a-z0-9]{4,7}', None, None)
        self.add_api_object('Id', self.Id)
        self.RoleArn = APIObject('RoleArn', 'string', r'^((arn):(aws|aws-cn|aws-iso|aws-iso-[a-z]{1}|aws-us-gov):(iam)::\d{12}:role[/].*)$', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.VersionLabel = APIObject('VersionLabel', 'string', r'.*[^0-9].*', 1, 64)
        self.add_api_object('VersionLabel', self.VersionLabel)

class Appconfigdata(Service):
    def __init__(self):
        super().__init__('Appconfigdata')
        self.Token = APIObject('Token', 'string', r'\S{1,8192}', None, None)
        self.add_api_object('Token', self.Token)

class Appfabric(Service):
    def __init__(self):
        super().__init__('Appfabric')
        self.Arn = APIObject('Arn', 'string', r'arn:.+', 1, 1011)
        self.add_api_object('Arn', self.Arn)
        self.Email = APIObject('Email', 'string', r'[a-zA-Z0-9.!#$%&’*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*', 0, 320)
        self.add_api_object('Email', self.Email)
        self.Identifier = APIObject('Identifier', 'string', r'arn:.+$|^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 1, 1011)
        self.add_api_object('Identifier', self.Identifier)
        self.RedirectUri = APIObject('RedirectUri', 'string', r'https://[-a-zA-Z0-9-._~:/?#@!$&\'()*+,;=]+', 0, 1024)
        self.add_api_object('RedirectUri', self.RedirectUri)
        self.UUID = APIObject('UUID', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('UUID', self.UUID)

class Appflow(Service):
    def __init__(self):
        super().__init__('Appflow')
        self.ARN = APIObject('ARN', 'string', r'arn:aws:.*:.*:[0-9]+:.*', None, 512)
        self.add_api_object('ARN', self.ARN)
        self.AccessKeyId = APIObject('AccessKeyId', 'string', r'\S+', None, 256)
        self.add_api_object('AccessKeyId', self.AccessKeyId)
        self.AccessToken = APIObject('AccessToken', 'string', r'\S+', None, 4096)
        self.add_api_object('AccessToken', self.AccessToken)
        self.AccountName = APIObject('AccountName', 'string', r'\S+', None, 512)
        self.add_api_object('AccountName', self.AccountName)
        self.ApiKey = APIObject('ApiKey', 'string', r'\S+', None, 256)
        self.add_api_object('ApiKey', self.ApiKey)
        self.ApiSecretKey = APIObject('ApiSecretKey', 'string', r'\S+', None, 256)
        self.add_api_object('ApiSecretKey', self.ApiSecretKey)
        self.ApiToken = APIObject('ApiToken', 'string', r'\S+', None, 256)
        self.add_api_object('ApiToken', self.ApiToken)
        self.ApiVersion = APIObject('ApiVersion', 'string', r'\S+', None, 256)
        self.add_api_object('ApiVersion', self.ApiVersion)
        self.ApplicationHostUrl = APIObject('ApplicationHostUrl', 'string', r'^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]', None, 256)
        self.add_api_object('ApplicationHostUrl', self.ApplicationHostUrl)
        self.ApplicationKey = APIObject('ApplicationKey', 'string', r'\S+', None, 512)
        self.add_api_object('ApplicationKey', self.ApplicationKey)
        self.ApplicationServicePath = APIObject('ApplicationServicePath', 'string', r'\S+', None, 512)
        self.add_api_object('ApplicationServicePath', self.ApplicationServicePath)
        self.ApplicationType = APIObject('ApplicationType', 'string', r'\S+', None, 512)
        self.add_api_object('ApplicationType', self.ApplicationType)
        self.AuthCode = APIObject('AuthCode', 'string', r'\S+', None, 4096)
        self.add_api_object('AuthCode', self.AuthCode)
        self.AuthCodeUrl = APIObject('AuthCodeUrl', 'string', r'^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]', None, 256)
        self.add_api_object('AuthCodeUrl', self.AuthCodeUrl)
        self.BucketName = APIObject('BucketName', 'string', r'\S+', 3, 63)
        self.add_api_object('BucketName', self.BucketName)
        self.BucketPrefix = APIObject('BucketPrefix', 'string', r'.*', None, 512)
        self.add_api_object('BucketPrefix', self.BucketPrefix)
        self.BusinessUnitId = APIObject('BusinessUnitId', 'string', r'\S+', None, 18)
        self.add_api_object('BusinessUnitId', self.BusinessUnitId)
        self.ClientCredentialsArn = APIObject('ClientCredentialsArn', 'string', r'arn:aws:secretsmanager:.*:[0-9]+:.*', 20, 2048)
        self.add_api_object('ClientCredentialsArn', self.ClientCredentialsArn)
        self.ClientId = APIObject('ClientId', 'string', r'\S+', None, 512)
        self.add_api_object('ClientId', self.ClientId)
        self.ClientNumber = APIObject('ClientNumber', 'string', r'^\d{3}$', 3, 3)
        self.add_api_object('ClientNumber', self.ClientNumber)
        self.ClientSecret = APIObject('ClientSecret', 'string', r'\S+', None, 512)
        self.add_api_object('ClientSecret', self.ClientSecret)
        self.ClientToken = APIObject('ClientToken', 'string', r'[ -~]+', 1, 256)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ClusterIdentifier = APIObject('ClusterIdentifier', 'string', r'\S+', None, 512)
        self.add_api_object('ClusterIdentifier', self.ClusterIdentifier)
        self.ConnectorDescription = APIObject('ConnectorDescription', 'string', r'[\w!@#\-.?,\s]*', None, 2048)
        self.add_api_object('ConnectorDescription', self.ConnectorDescription)
        self.ConnectorLabel = APIObject('ConnectorLabel', 'string', r'[a-zA-Z0-9][\w!@#.-]+', None, 256)
        self.add_api_object('ConnectorLabel', self.ConnectorLabel)
        self.ConnectorMode = APIObject('ConnectorMode', 'string', r'\S+', None, 256)
        self.add_api_object('ConnectorMode', self.ConnectorMode)
        self.ConnectorName = APIObject('ConnectorName', 'string', r'.*', None, 256)
        self.add_api_object('ConnectorName', self.ConnectorName)
        self.ConnectorOwner = APIObject('ConnectorOwner', 'string', r'.*', None, 256)
        self.add_api_object('ConnectorOwner', self.ConnectorOwner)
        self.ConnectorProfileArn = APIObject('ConnectorProfileArn', 'string', r'arn:aws:appflow:.*:[0-9]+:.*', None, 512)
        self.add_api_object('ConnectorProfileArn', self.ConnectorProfileArn)
        self.ConnectorProfileName = APIObject('ConnectorProfileName', 'string', r'[\w/!@#+=.-]+', None, 256)
        self.add_api_object('ConnectorProfileName', self.ConnectorProfileName)
        self.ConnectorRuntimeSettingDataType = APIObject('ConnectorRuntimeSettingDataType', 'string', r'\S+', None, 256)
        self.add_api_object('ConnectorRuntimeSettingDataType', self.ConnectorRuntimeSettingDataType)
        self.ConnectorRuntimeSettingScope = APIObject('ConnectorRuntimeSettingScope', 'string', r'\S+', None, 256)
        self.add_api_object('ConnectorRuntimeSettingScope', self.ConnectorRuntimeSettingScope)
        self.ConnectorSuppliedValue = APIObject('ConnectorSuppliedValue', 'string', r'\S+', None, 256)
        self.add_api_object('ConnectorSuppliedValue', self.ConnectorSuppliedValue)
        self.ConnectorVersion = APIObject('ConnectorVersion', 'string', r'\S+', None, 256)
        self.add_api_object('ConnectorVersion', self.ConnectorVersion)
        self.CreatedBy = APIObject('CreatedBy', 'string', r'\S+', None, 256)
        self.add_api_object('CreatedBy', self.CreatedBy)
        self.CredentialsMapKey = APIObject('CredentialsMapKey', 'string', r'[\w]+', 1, 128)
        self.add_api_object('CredentialsMapKey', self.CredentialsMapKey)
        self.CredentialsMapValue = APIObject('CredentialsMapValue', 'string', r'\S+', None, 2048)
        self.add_api_object('CredentialsMapValue', self.CredentialsMapValue)
        self.CustomAuthenticationType = APIObject('CustomAuthenticationType', 'string', r'\S+', None, 256)
        self.add_api_object('CustomAuthenticationType', self.CustomAuthenticationType)
        self.CustomPropertyKey = APIObject('CustomPropertyKey', 'string', r'[\w]+', 1, 128)
        self.add_api_object('CustomPropertyKey', self.CustomPropertyKey)
        self.CustomPropertyValue = APIObject('CustomPropertyValue', 'string', r'\S+', None, 2048)
        self.add_api_object('CustomPropertyValue', self.CustomPropertyValue)
        self.DataApiRoleArn = APIObject('DataApiRoleArn', 'string', r'arn:aws:iam:.*:[0-9]+:.*', None, 512)
        self.add_api_object('DataApiRoleArn', self.DataApiRoleArn)
        self.DataTransferApiTypeName = APIObject('DataTransferApiTypeName', 'string', r'[\w/-]+', None, 64)
        self.add_api_object('DataTransferApiTypeName', self.DataTransferApiTypeName)
        self.DatabaseName = APIObject('DatabaseName', 'string', r'\S+', None, 512)
        self.add_api_object('DatabaseName', self.DatabaseName)
        self.DatabaseUrl = APIObject('DatabaseUrl', 'string', r'\S+', None, 512)
        self.add_api_object('DatabaseUrl', self.DatabaseUrl)
        self.DatetimeTypeFieldName = APIObject('DatetimeTypeFieldName', 'string', r'.*', None, 256)
        self.add_api_object('DatetimeTypeFieldName', self.DatetimeTypeFieldName)
        self.Description = APIObject('Description', 'string', r'[\s\w/!@#+=.-]*', None, 1024)
        self.add_api_object('Description', self.Description)
        self.DestinationField = APIObject('DestinationField', 'string', r'.*', None, 256)
        self.add_api_object('DestinationField', self.DestinationField)
        self.DocumentType = APIObject('DocumentType', 'string', r'[\s\w_-]+', None, 512)
        self.add_api_object('DocumentType', self.DocumentType)
        self.DomainName = APIObject('DomainName', 'string', r'\S+', None, 64)
        self.add_api_object('DomainName', self.DomainName)
        self.EntitiesPath = APIObject('EntitiesPath', 'string', r'[\s\w/!@#+=,.-]*', None, 256)
        self.add_api_object('EntitiesPath', self.EntitiesPath)
        self.EntityName = APIObject('EntityName', 'string', r'\S+', None, 1024)
        self.add_api_object('EntityName', self.EntityName)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'[\s\w/!@#+=.-]*', None, 2048)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.ExecutionId = APIObject('ExecutionId', 'string', r'\S+', None, 256)
        self.add_api_object('ExecutionId', self.ExecutionId)
        self.ExecutionMessage = APIObject('ExecutionMessage', 'string', r'[\s\w/!@#+=.-]*', None, 2048)
        self.add_api_object('ExecutionMessage', self.ExecutionMessage)
        self.FlowArn = APIObject('FlowArn', 'string', r'arn:aws:appflow:.*:[0-9]+:.*', None, 512)
        self.add_api_object('FlowArn', self.FlowArn)
        self.FlowDescription = APIObject('FlowDescription', 'string', r'[\w!@#\-.?,\s]*', None, 2048)
        self.add_api_object('FlowDescription', self.FlowDescription)
        self.FlowName = APIObject('FlowName', 'string', r'[a-zA-Z0-9][\w!@#.-]+', None, 256)
        self.add_api_object('FlowName', self.FlowName)
        self.FlowStatusMessage = APIObject('FlowStatusMessage', 'string', r'[\s\w/!@#+=.-]*', None, 2048)
        self.add_api_object('FlowStatusMessage', self.FlowStatusMessage)
        self.GlueDataCatalogDatabaseName = APIObject('GlueDataCatalogDatabaseName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', None, 255)
        self.add_api_object('GlueDataCatalogDatabaseName', self.GlueDataCatalogDatabaseName)
        self.GlueDataCatalogIAMRole = APIObject('GlueDataCatalogIAMRole', 'string', r'arn:aws:iam:.*:[0-9]+:.*', None, 512)
        self.add_api_object('GlueDataCatalogIAMRole', self.GlueDataCatalogIAMRole)
        self.GlueDataCatalogTablePrefix = APIObject('GlueDataCatalogTablePrefix', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', None, 128)
        self.add_api_object('GlueDataCatalogTablePrefix', self.GlueDataCatalogTablePrefix)
        self.Group = APIObject('Group', 'string', r'\S+', None, 128)
        self.add_api_object('Group', self.Group)
        self.Identifier = APIObject('Identifier', 'string', r'\S+', None, 128)
        self.add_api_object('Identifier', self.Identifier)
        self.InstanceUrl = APIObject('InstanceUrl', 'string', r'\S+', None, 256)
        self.add_api_object('InstanceUrl', self.InstanceUrl)
        self.JwtToken = APIObject('JwtToken', 'string', r'^([a-zA-Z0-9_=]+)\.([a-zA-Z0-9_=]+)\.([a-zA-Z0-9_\-\+\/=]*)', None, 8000)
        self.add_api_object('JwtToken', self.JwtToken)
        self.KMSArn = APIObject('KMSArn', 'string', r'arn:aws:kms:.*:[0-9]+:.*', 20, 2048)
        self.add_api_object('KMSArn', self.KMSArn)
        self.Key = APIObject('Key', 'string', r'\S+', None, 512)
        self.add_api_object('Key', self.Key)
        self.Label = APIObject('Label', 'string', r'.*', None, 128)
        self.add_api_object('Label', self.Label)
        self.LogoURL = APIObject('LogoURL', 'string', r'^(https?|ftp|file)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]', None, 256)
        self.add_api_object('LogoURL', self.LogoURL)
        self.LogonLanguage = APIObject('LogonLanguage', 'string', r'^[a-zA-Z0-9_]*$', None, 2)
        self.add_api_object('LogonLanguage', self.LogonLanguage)
        self.MostRecentExecutionMessage = APIObject('MostRecentExecutionMessage', 'string', r'[\w!@#\-.?,\s]*', None, 2048)
        self.add_api_object('MostRecentExecutionMessage', self.MostRecentExecutionMessage)
        self.Name = APIObject('Name', 'string', r'\S+', None, 128)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'\S+', None, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.OAuthScope = APIObject('OAuthScope', 'string', r'\S+', None, 128)
        self.add_api_object('OAuthScope', self.OAuthScope)
        self.Object = APIObject('Object', 'string', r'\S+', None, 512)
        self.add_api_object('Object', self.Object)
        self.ObjectTypeName = APIObject('ObjectTypeName', 'string', r'\S+', None, 255)
        self.add_api_object('ObjectTypeName', self.ObjectTypeName)
        self.Password = APIObject('Password', 'string', r'.*', None, 512)
        self.add_api_object('Password', self.Password)
        self.PrivateConnectionProvisioningFailureMessage = APIObject('PrivateConnectionProvisioningFailureMessage', 'string', r'[\s\w/!@#+=.-]*', None, 2048)
        self.add_api_object('PrivateConnectionProvisioningFailureMessage', self.PrivateConnectionProvisioningFailureMessage)
        self.PrivateLinkServiceName = APIObject('PrivateLinkServiceName', 'string', r'^$|com.amazonaws.vpce.[\w/!:@#.\-]+', None, 512)
        self.add_api_object('PrivateLinkServiceName', self.PrivateLinkServiceName)
        self.ProfilePropertyKey = APIObject('ProfilePropertyKey', 'string', r'[\w]+', 1, 128)
        self.add_api_object('ProfilePropertyKey', self.ProfilePropertyKey)
        self.ProfilePropertyValue = APIObject('ProfilePropertyValue', 'string', r'\S+', None, 2048)
        self.add_api_object('ProfilePropertyValue', self.ProfilePropertyValue)
        self.Property = APIObject('Property', 'string', r'.+', None, 2048)
        self.add_api_object('Property', self.Property)
        self.RedirectUri = APIObject('RedirectUri', 'string', r'\S+', None, 512)
        self.add_api_object('RedirectUri', self.RedirectUri)
        self.RefreshToken = APIObject('RefreshToken', 'string', r'\S+', None, 4096)
        self.add_api_object('RefreshToken', self.RefreshToken)
        self.Region = APIObject('Region', 'string', r'\S+', None, 64)
        self.add_api_object('Region', self.Region)
        self.RegisteredBy = APIObject('RegisteredBy', 'string', r'\S+', None, 512)
        self.add_api_object('RegisteredBy', self.RegisteredBy)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam:.*:[0-9]+:.*', None, 512)
        self.add_api_object('RoleArn', self.RoleArn)
        self.ScheduleExpression = APIObject('ScheduleExpression', 'string', r'.*', None, 256)
        self.add_api_object('ScheduleExpression', self.ScheduleExpression)
        self.SecretKey = APIObject('SecretKey', 'string', r'\S+', None, 256)
        self.add_api_object('SecretKey', self.SecretKey)
        self.Stage = APIObject('Stage', 'string', r'\S+', None, 512)
        self.add_api_object('Stage', self.Stage)
        self.String = APIObject('String', 'string', r'.*', None, 2048)
        self.add_api_object('String', self.String)
        self.SupportedApiVersion = APIObject('SupportedApiVersion', 'string', r'\S+', None, 256)
        self.add_api_object('SupportedApiVersion', self.SupportedApiVersion)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\w+-=\.:/@]*', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Timezone = APIObject('Timezone', 'string', r'.*', None, 256)
        self.add_api_object('Timezone', self.Timezone)
        self.TokenUrl = APIObject('TokenUrl', 'string', r'^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]', None, 256)
        self.add_api_object('TokenUrl', self.TokenUrl)
        self.UpdatedBy = APIObject('UpdatedBy', 'string', r'\S+', None, 256)
        self.add_api_object('UpdatedBy', self.UpdatedBy)
        self.UpsolverBucketName = APIObject('UpsolverBucketName', 'string', r'^(upsolver-appflow)\S*', 16, 63)
        self.add_api_object('UpsolverBucketName', self.UpsolverBucketName)
        self.Username = APIObject('Username', 'string', r'\S+', None, 512)
        self.add_api_object('Username', self.Username)
        self.Value = APIObject('Value', 'string', r'\S+', None, 128)
        self.add_api_object('Value', self.Value)
        self.Warehouse = APIObject('Warehouse', 'string', r'[\s\w/!@#+=.-]*', None, 512)
        self.add_api_object('Warehouse', self.Warehouse)
        self.WorkgroupName = APIObject('WorkgroupName', 'string', r'\S+', None, 512)
        self.add_api_object('WorkgroupName', self.WorkgroupName)

class Appintegrations(Service):
    def __init__(self):
        super().__init__('Appintegrations')
        self.ApplicationName = APIObject('ApplicationName', 'string', r'^[a-zA-Z0-9\/\._ \-]+$', 1, 255)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.ApplicationNamespace = APIObject('ApplicationNamespace', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 32)
        self.add_api_object('ApplicationNamespace', self.ApplicationNamespace)
        self.ApplicationTrustedSource = APIObject('ApplicationTrustedSource', 'string', r'^\w+\:\/\/.*$', 1, 128)
        self.add_api_object('ApplicationTrustedSource', self.ApplicationTrustedSource)
        self.Arn = APIObject('Arn', 'string', r'^arn:aws:[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}$', 1, 2048)
        self.add_api_object('Arn', self.Arn)
        self.ArnOrUUID = APIObject('ArnOrUUID', 'string', r'^(arn:aws:[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}|[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})(:[\w\$]+)?$', 1, 2048)
        self.add_api_object('ArnOrUUID', self.ArnOrUUID)
        self.ClientId = APIObject('ClientId', 'string', r'.*', 1, 255)
        self.add_api_object('ClientId', self.ClientId)
        self.Description = APIObject('Description', 'string', r'.*', 0, 1000)
        self.add_api_object('Description', self.Description)
        self.EventBridgeBus = APIObject('EventBridgeBus', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 255)
        self.add_api_object('EventBridgeBus', self.EventBridgeBus)
        self.EventBridgeRuleName = APIObject('EventBridgeRuleName', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 2048)
        self.add_api_object('EventBridgeRuleName', self.EventBridgeRuleName)
        self.EventDefinitionSchema = APIObject('EventDefinitionSchema', 'string', r'^.*$', 1, 10240)
        self.add_api_object('EventDefinitionSchema', self.EventDefinitionSchema)
        self.EventName = APIObject('EventName', 'string', r'^[a-zA-Z0-9\/\._\-]+::[a-zA-Z0-9\/\._\-]+(?:\*)?$', 1, 255)
        self.add_api_object('EventName', self.EventName)
        self.Fields = APIObject('Fields', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 255)
        self.add_api_object('Fields', self.Fields)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'.*', 1, 2048)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.Identifier = APIObject('Identifier', 'string', r'.*\S.*', 1, 255)
        self.add_api_object('Identifier', self.Identifier)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 255)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 1, 1000)
        self.add_api_object('NextToken', self.NextToken)
        self.NonBlankLongString = APIObject('NonBlankLongString', 'string', r'.*\S.*', 1, 200)
        self.add_api_object('NonBlankLongString', self.NonBlankLongString)
        self.NonBlankString = APIObject('NonBlankString', 'string', r'.*\S.*', 1, 255)
        self.add_api_object('NonBlankString', self.NonBlankString)
        self.Object = APIObject('Object', 'string', r'^[a-zA-Z0-9\/\._\-]+$', 1, 255)
        self.add_api_object('Object', self.Object)
        self.Permission = APIObject('Permission', 'string', r'^[a-zA-Z0-9\/\._\-\*]+$', 1, 255)
        self.add_api_object('Permission', self.Permission)
        self.Source = APIObject('Source', 'string', r'^aws\.partner\/.*$', 1, 256)
        self.add_api_object('Source', self.Source)
        self.SourceURI = APIObject('SourceURI', 'string', r'^(\w+\:\/\/[\w.-]+[\w/!@#+=.-]+$)|(\w+\:\/\/[\w.-]+[\w/!@#+=.-]+[\w/!@#+=.-]+[\w/!@#+=.,-]+$)', 1, 1000)
        self.add_api_object('SourceURI', self.SourceURI)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.URL = APIObject('URL', 'string', r'^\w+\:\/\/.*$', 1, 1000)
        self.add_api_object('URL', self.URL)
        self.UUID = APIObject('UUID', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('UUID', self.UUID)

class ApplicationAutoscaling(Service):
    def __init__(self):
        super().__init__('ApplicationAutoscaling')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:.+:application-autoscaling:.+:[0-9]+:scalable-target\/[a-zA-Z0-9-]+$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.Expression = APIObject('Expression', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 2048)
        self.add_api_object('Expression', self.Expression)
        self.Id = APIObject('Id', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 255)
        self.add_api_object('Id', self.Id)
        self.PolicyName = APIObject('PolicyName', 'string', r'\p{Print}+', 1, 256)
        self.add_api_object('PolicyName', self.PolicyName)
        self.ResourceId = APIObject('ResourceId', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceIdMaxLen1600 = APIObject('ResourceIdMaxLen1600', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1600)
        self.add_api_object('ResourceIdMaxLen1600', self.ResourceIdMaxLen1600)
        self.ScheduledActionName = APIObject('ScheduledActionName', 'string', r'(?!((^[ ]+.*)|(.*([\u0000-\u001f]|[\u007f-\u009f]|[:/|])+.*)|(.*[ ]+$))).+', 1, 256)
        self.add_api_object('ScheduledActionName', self.ScheduledActionName)
        self.TargetTrackingMetricDimensionName = APIObject('TargetTrackingMetricDimensionName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 255)
        self.add_api_object('TargetTrackingMetricDimensionName', self.TargetTrackingMetricDimensionName)
        self.TargetTrackingMetricDimensionValue = APIObject('TargetTrackingMetricDimensionValue', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1024)
        self.add_api_object('TargetTrackingMetricDimensionValue', self.TargetTrackingMetricDimensionValue)
        self.TargetTrackingMetricName = APIObject('TargetTrackingMetricName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 255)
        self.add_api_object('TargetTrackingMetricName', self.TargetTrackingMetricName)
        self.TargetTrackingMetricNamespace = APIObject('TargetTrackingMetricNamespace', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 255)
        self.add_api_object('TargetTrackingMetricNamespace', self.TargetTrackingMetricNamespace)
        self.TargetTrackingMetricUnit = APIObject('TargetTrackingMetricUnit', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1023)
        self.add_api_object('TargetTrackingMetricUnit', self.TargetTrackingMetricUnit)
        self.XmlString = APIObject('XmlString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, None)
        self.add_api_object('XmlString', self.XmlString)

class ApplicationInsights(Service):
    def __init__(self):
        super().__init__('ApplicationInsights')
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:aws(-\w+)*:[\w\d-]+:([\w\d-]*)?:[\w\d_-]*([:/].+)*$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.ComponentConfiguration = APIObject('ComponentConfiguration', 'string', r'[\S\s]+', 1, 10000)
        self.add_api_object('ComponentConfiguration', self.ComponentConfiguration)
        self.ComponentName = APIObject('ComponentName', 'string', r'(?:^[\d\w\-_\.+]*$)|(?:^arn:aws(-\w+)*:[\w\d-]+:([\w\d-]*)?:[\w\d_-]*([:/].+)*$)', 1, 1011)
        self.add_api_object('ComponentName', self.ComponentName)
        self.CustomComponentName = APIObject('CustomComponentName', 'string', r'^[\d\w\-_\.+]*$', 1, 128)
        self.add_api_object('CustomComponentName', self.CustomComponentName)
        self.LogPatternName = APIObject('LogPatternName', 'string', r'[a-zA-Z0-9\.\-_]*', 1, 50)
        self.add_api_object('LogPatternName', self.LogPatternName)
        self.LogPatternRegex = APIObject('LogPatternRegex', 'string', r'[\S\s]+', 1, 50)
        self.add_api_object('LogPatternRegex', self.LogPatternRegex)
        self.LogPatternSetName = APIObject('LogPatternSetName', 'string', r'[a-zA-Z0-9\.\-_]*', 1, 30)
        self.add_api_object('LogPatternSetName', self.LogPatternSetName)
        self.ObservationId = APIObject('ObservationId', 'string', r'o-[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}', 38, 38)
        self.add_api_object('ObservationId', self.ObservationId)
        self.OpsItemSNSTopicArn = APIObject('OpsItemSNSTopicArn', 'string', r'^arn:aws(-\w+)*:[\w\d-]+:([\w\d-]*)?:[\w\d_-]*([:/].+)*$', 20, 300)
        self.add_api_object('OpsItemSNSTopicArn', self.OpsItemSNSTopicArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'.+', 1, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ProblemId = APIObject('ProblemId', 'string', r'p-[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}', 38, 38)
        self.add_api_object('ProblemId', self.ProblemId)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'^arn:aws(-\w+)*:[\w\d-]+:([\w\d-]*)?:[\w\d_-]*([:/].+)*$', 1, 1011)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.ResourceGroupName = APIObject('ResourceGroupName', 'string', r'[a-zA-Z0-9\.\-_]*', 1, 256)
        self.add_api_object('ResourceGroupName', self.ResourceGroupName)
        self.ResourceType = APIObject('ResourceType', 'string', r'[0-9a-zA-Z:_]*', 1, 50)
        self.add_api_object('ResourceType', self.ResourceType)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.WorkloadId = APIObject('WorkloadId', 'string', r'w-[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}', 38, 38)
        self.add_api_object('WorkloadId', self.WorkloadId)
        self.WorkloadName = APIObject('WorkloadName', 'string', r'[a-zA-Z0-9\.\-_]*', 1, 8)
        self.add_api_object('WorkloadName', self.WorkloadName)

class Applicationcostprofiler(Service):
    def __init__(self):
        super().__init__('Applicationcostprofiler')
        self.ImportId = APIObject('ImportId', 'string', r'[0-9A-Za-z\.\-_]*', 1, 255)
        self.add_api_object('ImportId', self.ImportId)
        self.ReportDescription = APIObject('ReportDescription', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('ReportDescription', self.ReportDescription)
        self.ReportId = APIObject('ReportId', 'string', r'^[0-9A-Za-z\.\-_]+$', 1, 255)
        self.add_api_object('ReportId', self.ReportId)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'(?=^.{3,63}$)(?!^(\d+\.)+\d+$)(^(([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])\.)*([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])$)', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'.*\S.*', 1, 512)
        self.add_api_object('S3Key', self.S3Key)
        self.S3Prefix = APIObject('S3Prefix', 'string', r'.*\S.*', 1, 512)
        self.add_api_object('S3Prefix', self.S3Prefix)
        self.Token = APIObject('Token', 'string', r'^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$', 1, 102400)
        self.add_api_object('Token', self.Token)

class Appmesh(Service):
    def __init__(self):
        super().__init__('Appmesh')

class Apprunner(Service):
    def __init__(self):
        super().__init__('Apprunner')
        self.AppRunnerResourceArn = APIObject('AppRunnerResourceArn', 'string', r'arn:aws(-[\w]+)*:[a-z0-9-\\.]{0,63}:[a-z0-9-\\.]{0,63}:[0-9]{12}:(\w|\/|-){1,1011}', 1, 1011)
        self.add_api_object('AppRunnerResourceArn', self.AppRunnerResourceArn)
        self.AutoScalingConfigurationName = APIObject('AutoScalingConfigurationName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{3,31}', 4, 32)
        self.add_api_object('AutoScalingConfigurationName', self.AutoScalingConfigurationName)
        self.BuildCommand = APIObject('BuildCommand', 'string', r'[^\x0a\x0d]+', None, None)
        self.add_api_object('BuildCommand', self.BuildCommand)
        self.ConnectionName = APIObject('ConnectionName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{3,31}', 4, 32)
        self.add_api_object('ConnectionName', self.ConnectionName)
        self.Cpu = APIObject('Cpu', 'string', r'256|512|1024|2048|4096|(0.25|0.5|1|2|4) vCPU', 3, 9)
        self.add_api_object('Cpu', self.Cpu)
        self.CustomerAccountId = APIObject('CustomerAccountId', 'string', r'[0-9]{12}', 12, 12)
        self.add_api_object('CustomerAccountId', self.CustomerAccountId)
        self.DomainName = APIObject('DomainName', 'string', r'[A-Za-z0-9*.-]{1,255}', 1, 255)
        self.add_api_object('DomainName', self.DomainName)
        self.ImageIdentifier = APIObject('ImageIdentifier', 'string', r'([0-9]{12}.dkr.ecr.[a-z\-]+-[0-9]{1}.amazonaws.com\/((?:[a-z0-9]+(?:[._-][a-z0-9]+)*\/)*[a-z0-9]+(?:[._-][a-z0-9]+)*)(:([\w\d+\-=._:\/@])+|@([\w\d\:]+))?)|(^public\.ecr\.aws\/.+\/((?:[a-z0-9]+(?:[._-][a-z0-9]+)*\/)*[a-z0-9]+(?:[._-][a-z0-9]+)*)(:([\w\d+\-=._:\/@])+|@([\w\d\:]+))?)', 1, 1024)
        self.add_api_object('ImageIdentifier', self.ImageIdentifier)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws(-[\w]+)*:kms:[a-z\-]+-[0-9]{1}:[0-9]{12}:key\/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 0, 256)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.Memory = APIObject('Memory', 'string', r'512|1024|2048|3072|4096|6144|8192|10240|12288|(0.5|1|2|3|4|6|8|10|12) GB', 3, 6)
        self.add_api_object('Memory', self.Memory)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.ObservabilityConfigurationName = APIObject('ObservabilityConfigurationName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{3,31}', 4, 32)
        self.add_api_object('ObservabilityConfigurationName', self.ObservabilityConfigurationName)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):iam::[0-9]{12}:(role|role\/service-role)\/[\w+=,.@\-/]{1,1000}', 29, 1024)
        self.add_api_object('RoleArn', self.RoleArn)
        self.RuntimeEnvironmentVariablesKey = APIObject('RuntimeEnvironmentVariablesKey', 'string', r'.*', 1, 51200)
        self.add_api_object('RuntimeEnvironmentVariablesKey', self.RuntimeEnvironmentVariablesKey)
        self.RuntimeEnvironmentVariablesValue = APIObject('RuntimeEnvironmentVariablesValue', 'string', r'.*', 0, 51200)
        self.add_api_object('RuntimeEnvironmentVariablesValue', self.RuntimeEnvironmentVariablesValue)
        self.ServiceId = APIObject('ServiceId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}', 32, 32)
        self.add_api_object('ServiceId', self.ServiceId)
        self.ServiceName = APIObject('ServiceName', 'string', r'[A-Za-z0-9][A-Za-z0-9-_]{3,39}', 4, 40)
        self.add_api_object('ServiceName', self.ServiceName)
        self.SourceDirectory = APIObject('SourceDirectory', 'string', r'[^\x00]+', 1, 4096)
        self.add_api_object('SourceDirectory', self.SourceDirectory)
        self.StartCommand = APIObject('StartCommand', 'string', r'[^\x0a\x0d]+', None, None)
        self.add_api_object('StartCommand', self.StartCommand)
        self.String = APIObject('String', 'string', r'.*', 0, 51200)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:).+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UUID = APIObject('UUID', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}', 36, 36)
        self.add_api_object('UUID', self.UUID)
        self.VpcConnectorName = APIObject('VpcConnectorName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{3,39}', 4, 40)
        self.add_api_object('VpcConnectorName', self.VpcConnectorName)
        self.VpcIngressConnectionName = APIObject('VpcIngressConnectionName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{3,39}', 4, 40)
        self.add_api_object('VpcIngressConnectionName', self.VpcIngressConnectionName)

class Appstream(Service):
    def __init__(self):
        super().__init__('Appstream')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws(?:\-cn|\-iso\-b|\-iso|\-us\-gov)?:[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.\\-]{0,1023}$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d+$', None, None)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.EmbedHostDomain = APIObject('EmbedHostDomain', 'string', r'(?:[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]', None, 128)
        self.add_api_object('EmbedHostDomain', self.EmbedHostDomain)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,100}$', None, None)
        self.add_api_object('Name', self.Name)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[0-9a-z\.\-]*(?<!\.)$', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.StreamingUrlUserId = APIObject('StreamingUrlUserId', 'string', r'[\w+=,.@-]*', 2, 32)
        self.add_api_object('StreamingUrlUserId', self.StreamingUrlUserId)
        self.TagKey = APIObject('TagKey', 'string', r'^(^(?!aws:).[\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UsbDeviceFilterString = APIObject('UsbDeviceFilterString', 'string', r'^((\w*)\s*(\w*)\s*\,\s*(\w*)\s*\,\s*\*?(\w*)\s*\,\s*\*?(\w*)\s*\,\s*\*?\d*\s*\,\s*\*?\d*\s*\,\s*[0-1]\s*\,\s*[0-1]\s*)$', 0, 100)
        self.add_api_object('UsbDeviceFilterString', self.UsbDeviceFilterString)
        self.UserAttributeValue = APIObject('UserAttributeValue', 'string', r'^[A-Za-z0-9_\-\s]+$', None, 2048)
        self.add_api_object('UserAttributeValue', self.UserAttributeValue)
        self.Username = APIObject('Username', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 128)
        self.add_api_object('Username', self.Username)

class Appsync(Service):
    def __init__(self):
        super().__init__('Appsync')
        self.CertificateArn = APIObject('CertificateArn', 'string', r'^arn:[a-z-]*:(acm|iam):[a-z0-9-]*:\d{12}:(certificate|server-certificate)/[0-9A-Za-z_/-]*$', 20, 2048)
        self.add_api_object('CertificateArn', self.CertificateArn)
        self.Context = APIObject('Context', 'string', r'^[\s\S]*$', 2, 28000)
        self.add_api_object('Context', self.Context)
        self.Description = APIObject('Description', 'string', r'^.*$', 0, 255)
        self.add_api_object('Description', self.Description)
        self.DomainName = APIObject('DomainName', 'string', r'^(\*[\w\d-]*\.)?([\w\d-]+\.)+[\w\d-]+$', 1, 253)
        self.add_api_object('DomainName', self.DomainName)
        self.EnvironmentVariableKey = APIObject('EnvironmentVariableKey', 'string', r'^[A-Za-z]+\w*$', 2, 64)
        self.add_api_object('EnvironmentVariableKey', self.EnvironmentVariableKey)
        self.EvaluationResult = APIObject('EvaluationResult', 'string', r'^[\s\S]*$', 0, 65536)
        self.add_api_object('EvaluationResult', self.EvaluationResult)
        self.MappingTemplate = APIObject('MappingTemplate', 'string', r'^.*$', 1, 65536)
        self.add_api_object('MappingTemplate', self.MappingTemplate)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[\\S]+', 1, 65536)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.RdsDataApiConfigResourceArn = APIObject('RdsDataApiConfigResourceArn', 'string', r'^arn:[a-z-]*:rds:[a-z0-9-]*:\d{12}:cluster:[0-9A-Za-z_/-]*$', 20, 2048)
        self.add_api_object('RdsDataApiConfigResourceArn', self.RdsDataApiConfigResourceArn)
        self.RdsDataApiConfigSecretArn = APIObject('RdsDataApiConfigSecretArn', 'string', r'^arn:[a-z-]*:secretsmanager:[a-z0-9-]*:\d{12}:secret:[0-9A-Za-z_/+=.@!-]*$', 20, 2048)
        self.add_api_object('RdsDataApiConfigSecretArn', self.RdsDataApiConfigSecretArn)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:appsync:[A-Za-z0-9_/.-]{0,63}:\d{12}:apis/[0-9A-Za-z_-]{26}$', 70, 75)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceName = APIObject('ResourceName', 'string', r'[_A-Za-z][_0-9A-Za-z]*', 1, 65536)
        self.add_api_object('ResourceName', self.ResourceName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[ a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\s\w+-=\.:/@]*$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Template = APIObject('Template', 'string', r'^[\s\S]*$', 2, 65536)
        self.add_api_object('Template', self.Template)

class ArcZonalShift(Service):
    def __init__(self):
        super().__init__('ArcZonalShift')
        self.BlockedDate = APIObject('BlockedDate', 'string', r'^[0-9]{4}-[0-9]{2}-[0-9]{2}$', 10, 10)
        self.add_api_object('BlockedDate', self.BlockedDate)
        self.BlockedWindow = APIObject('BlockedWindow', 'string', r'^(Mon|Tue|Wed|Thu|Fri|Sat|Sun):[0-9]{2}:[0-9]{2}-(Mon|Tue|Wed|Thu|Fri|Sat|Sun):[0-9]{2}:[0-9]{2}$', 19, 19)
        self.add_api_object('BlockedWindow', self.BlockedWindow)
        self.ExpiresIn = APIObject('ExpiresIn', 'string', r'^([1-9][0-9]*)(m|h)$', 2, 5)
        self.add_api_object('ExpiresIn', self.ExpiresIn)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:.*$', 8, 1024)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ZonalShiftId = APIObject('ZonalShiftId', 'string', r'^[A-Za-z0-9-]+$', 6, 36)
        self.add_api_object('ZonalShiftId', self.ZonalShiftId)

class Artifact(Service):
    def __init__(self):
        super().__init__('Artifact')
        self.LongStringAttribute = APIObject('LongStringAttribute', 'string', r'^[^<>]*$', 1, 1024)
        self.add_api_object('LongStringAttribute', self.LongStringAttribute)
        self.ReportId = APIObject('ReportId', 'string', r'^report-[a-zA-Z0-9]{16}$', None, None)
        self.add_api_object('ReportId', self.ReportId)
        self.ShortStringAttribute = APIObject('ShortStringAttribute', 'string', r'^[a-zA-Z0-9_\-\s]*$', 1, 256)
        self.add_api_object('ShortStringAttribute', self.ShortStringAttribute)

class Athena(Service):
    def __init__(self):
        super().__init__('Athena')
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^[0-9]+$', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.CalculationResultType = APIObject('CalculationResultType', 'string', r'\w+\/[-+.\w]+', 1, 256)
        self.add_api_object('CalculationResultType', self.CalculationResultType)
        self.CapacityReservationName = APIObject('CapacityReservationName', 'string', r'[a-zA-Z0-9._-]+', 1, 128)
        self.add_api_object('CapacityReservationName', self.CapacityReservationName)
        self.CatalogNameString = APIObject('CatalogNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 256)
        self.add_api_object('CatalogNameString', self.CatalogNameString)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 1, 36)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.CommentString = APIObject('CommentString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 255)
        self.add_api_object('CommentString', self.CommentString)
        self.ExecutorId = APIObject('ExecutorId', 'string', r'.*', None, 100000)
        self.add_api_object('ExecutorId', self.ExecutorId)
        self.IdentityCenterApplicationArn = APIObject('IdentityCenterApplicationArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16}$', 0, 255)
        self.add_api_object('IdentityCenterApplicationArn', self.IdentityCenterApplicationArn)
        self.IdentityCenterInstanceArn = APIObject('IdentityCenterInstanceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso:::instance/(sso)?ins-[a-zA-Z0-9-.]{16}$', 0, 255)
        self.add_api_object('IdentityCenterInstanceArn', self.IdentityCenterInstanceArn)
        self.KeyString = APIObject('KeyString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('KeyString', self.KeyString)
        self.KmsKey = APIObject('KmsKey', 'string', r'^arn:aws[a-z\-]*:kms:([a-z0-9\-]+):\d{12}:key/?[a-zA-Z_0-9+=,.@\-_/]+$|^arn:aws[a-z\-]*:kms:([a-z0-9\-]+):\d{12}:alias/?[a-zA-Z_0-9+=,.@\-_/]+$|^alias/[a-zA-Z0-9/_-]+$|[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 1, 2048)
        self.add_api_object('KmsKey', self.KmsKey)
        self.NamedQueryId = APIObject('NamedQueryId', 'string', r'\S+', 1, 128)
        self.add_api_object('NamedQueryId', self.NamedQueryId)
        self.NotebookId = APIObject('NotebookId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 1, 36)
        self.add_api_object('NotebookId', self.NotebookId)
        self.NotebookName = APIObject('NotebookName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]+', 1, 255)
        self.add_api_object('NotebookName', self.NotebookName)
        self.QueryExecutionId = APIObject('QueryExecutionId', 'string', r'\S+', 1, 128)
        self.add_api_object('QueryExecutionId', self.QueryExecutionId)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws[a-z\-]*:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Uri = APIObject('S3Uri', 'string', r'^(https|s3|S3)://([^/]+)/?(.*)$', None, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.StatementName = APIObject('StatementName', 'string', r'[a-zA-Z_][a-zA-Z0-9_@:]{1,256}', 1, 256)
        self.add_api_object('StatementName', self.StatementName)
        self.TypeString = APIObject('TypeString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 4096)
        self.add_api_object('TypeString', self.TypeString)
        self.WorkGroupName = APIObject('WorkGroupName', 'string', r'[a-zA-Z0-9._-]{1,128}', None, None)
        self.add_api_object('WorkGroupName', self.WorkGroupName)

class Auditmanager(Service):
    def __init__(self):
        super().__init__('Auditmanager')
        self.AWSServiceName = APIObject('AWSServiceName', 'string', r'^[a-zA-Z0-9-\s().]+$', 1, 40)
        self.add_api_object('AWSServiceName', self.AWSServiceName)
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AccountName = APIObject('AccountName', 'string', r'^[\u0020-\u007E]+$', 1, 50)
        self.add_api_object('AccountName', self.AccountName)
        self.ActionPlanInstructions = APIObject('ActionPlanInstructions', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('ActionPlanInstructions', self.ActionPlanInstructions)
        self.ActionPlanTitle = APIObject('ActionPlanTitle', 'string', r'^[\w\W\s\S]*$', None, 300)
        self.add_api_object('ActionPlanTitle', self.ActionPlanTitle)
        self.AssessmentDescription = APIObject('AssessmentDescription', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('AssessmentDescription', self.AssessmentDescription)
        self.AssessmentEvidenceFolderName = APIObject('AssessmentEvidenceFolderName', 'string', r'^[\w\W\s\S]*$', 1, 300)
        self.add_api_object('AssessmentEvidenceFolderName', self.AssessmentEvidenceFolderName)
        self.AssessmentFrameworkDescription = APIObject('AssessmentFrameworkDescription', 'string', r'^[\w\W\s\S]*$', 1, 200)
        self.add_api_object('AssessmentFrameworkDescription', self.AssessmentFrameworkDescription)
        self.AssessmentName = APIObject('AssessmentName', 'string', r'^[^\\]*$', 1, 300)
        self.add_api_object('AssessmentName', self.AssessmentName)
        self.AssessmentReportDescription = APIObject('AssessmentReportDescription', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('AssessmentReportDescription', self.AssessmentReportDescription)
        self.AssessmentReportName = APIObject('AssessmentReportName', 'string', r'^[a-zA-Z0-9-_\.]+$', 1, 300)
        self.add_api_object('AssessmentReportName', self.AssessmentReportName)
        self.AuditManagerArn = APIObject('AuditManagerArn', 'string', r'^arn:.*:auditmanager:.*', 20, 2048)
        self.add_api_object('AuditManagerArn', self.AuditManagerArn)
        self.CloudTrailArn = APIObject('CloudTrailArn', 'string', r'^arn:.*:cloudtrail:.*', 20, 2048)
        self.add_api_object('CloudTrailArn', self.CloudTrailArn)
        self.ComplianceType = APIObject('ComplianceType', 'string', r'^[\w\W\s\S]*$', None, 100)
        self.add_api_object('ComplianceType', self.ComplianceType)
        self.ControlCommentBody = APIObject('ControlCommentBody', 'string', r'^[\w\W\s\S]*$', None, 500)
        self.add_api_object('ControlCommentBody', self.ControlCommentBody)
        self.ControlDescription = APIObject('ControlDescription', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('ControlDescription', self.ControlDescription)
        self.ControlName = APIObject('ControlName', 'string', r'^[^\\]*$', 1, 300)
        self.add_api_object('ControlName', self.ControlName)
        self.ControlSetId = APIObject('ControlSetId', 'string', r'^[\w\W\s\S]*$', 1, 300)
        self.add_api_object('ControlSetId', self.ControlSetId)
        self.ControlSetName = APIObject('ControlSetName', 'string', r'^[^\\\_]*$', 1, 300)
        self.add_api_object('ControlSetName', self.ControlSetName)
        self.ControlSources = APIObject('ControlSources', 'string', r'^[a-zA-Z_0-9-\s.,]+$', 1, 100)
        self.add_api_object('ControlSources', self.ControlSources)
        self.CreatedBy = APIObject('CreatedBy', 'string', r'^[a-zA-Z0-9\s-_()\[\]]+$', 1, 100)
        self.add_api_object('CreatedBy', self.CreatedBy)
        self.DelegationComment = APIObject('DelegationComment', 'string', r'^[\w\W\s\S]*$', None, 350)
        self.add_api_object('DelegationComment', self.DelegationComment)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'^.*@.*$', 1, 320)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.ErrorCode = APIObject('ErrorCode', 'string', r'[0-9]{3}', 3, 3)
        self.add_api_object('ErrorCode', self.ErrorCode)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^[\w\W\s\S]*$', None, 300)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.EventName = APIObject('EventName', 'string', r'^[\w\W\s\S]*$', None, 100)
        self.add_api_object('EventName', self.EventName)
        self.EvidenceAttributeKey = APIObject('EvidenceAttributeKey', 'string', r'^[\w\W\s\S]*$', None, 100)
        self.add_api_object('EvidenceAttributeKey', self.EvidenceAttributeKey)
        self.EvidenceAttributeValue = APIObject('EvidenceAttributeValue', 'string', r'^[\w\W\s\S]*$', None, 200)
        self.add_api_object('EvidenceAttributeValue', self.EvidenceAttributeValue)
        self.Filename = APIObject('Filename', 'string', r'^[\w,\s-]+\.[A-Za-z]+$', 1, 255)
        self.add_api_object('Filename', self.Filename)
        self.FrameworkDescription = APIObject('FrameworkDescription', 'string', r'^[\w\W\s\S]*$', 1, 1000)
        self.add_api_object('FrameworkDescription', self.FrameworkDescription)
        self.FrameworkName = APIObject('FrameworkName', 'string', r'^[^\\]*$', 1, 300)
        self.add_api_object('FrameworkName', self.FrameworkName)
        self.GenericArn = APIObject('GenericArn', 'string', r'^arn:.*', 20, 2048)
        self.add_api_object('GenericArn', self.GenericArn)
        self.HyperlinkName = APIObject('HyperlinkName', 'string', r'^[\w\W\s\S]*$', 1, 200)
        self.add_api_object('HyperlinkName', self.HyperlinkName)
        self.IamArn = APIObject('IamArn', 'string', r'^arn:.*:iam:.*', 20, 2048)
        self.add_api_object('IamArn', self.IamArn)
        self.KeywordValue = APIObject('KeywordValue', 'string', r'^[a-zA-Z_0-9-\s().]+$', 1, 100)
        self.add_api_object('KeywordValue', self.KeywordValue)
        self.KmsKey = APIObject('KmsKey', 'string', r'^arn:.*:kms:.*|DEFAULT', 7, 2048)
        self.add_api_object('KmsKey', self.KmsKey)
        self.LastUpdatedBy = APIObject('LastUpdatedBy', 'string', r'^[a-zA-Z0-9\s-_()\[\]]+$', 1, 100)
        self.add_api_object('LastUpdatedBy', self.LastUpdatedBy)
        self.ManualEvidenceLocalFileName = APIObject('ManualEvidenceLocalFileName', 'string', r'[^\/]*', 1, 300)
        self.add_api_object('ManualEvidenceLocalFileName', self.ManualEvidenceLocalFileName)
        self.ManualEvidenceTextResponse = APIObject('ManualEvidenceTextResponse', 'string', r'^[\w\W\s\S]*$', 1, 1000)
        self.add_api_object('ManualEvidenceTextResponse', self.ManualEvidenceTextResponse)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.QueryStatement = APIObject('QueryStatement', 'string', r'(?s).*', 1, 10000)
        self.add_api_object('QueryStatement', self.QueryStatement)
        self.Region = APIObject('Region', 'string', r'^[a-z]{2}-[a-z]+-[0-9]{1}$', None, None)
        self.add_api_object('Region', self.Region)
        self.S3Url = APIObject('S3Url', 'string', r'''^(S|s)3:\/\/[a-zA-Z0-9\-\.\(\)\\'\*\_\!\/]+$''', 1, 1024)
        self.add_api_object('S3Url', self.S3Url)
        self.SNSTopic = APIObject('SNSTopic', 'string', r'^[a-zA-Z0-9-_\(\)\[\]]+$', 1, 255)
        self.add_api_object('SNSTopic', self.SNSTopic)
        self.ShareRequestComment = APIObject('ShareRequestComment', 'string', r'^[\w\W\s\S]*$', None, 500)
        self.add_api_object('ShareRequestComment', self.ShareRequestComment)
        self.SnsArn = APIObject('SnsArn', 'string', r'^arn:.*:sns:.*|NONE', 4, 2048)
        self.add_api_object('SnsArn', self.SnsArn)
        self.SourceDescription = APIObject('SourceDescription', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('SourceDescription', self.SourceDescription)
        self.String = APIObject('String', 'string', r'.*', 0, 2048)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.{0,255}', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TestingInformation = APIObject('TestingInformation', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('TestingInformation', self.TestingInformation)
        self.TimestampUUID = APIObject('TimestampUUID', 'string', r'^[0-9]{10,13}_[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 47, 50)
        self.add_api_object('TimestampUUID', self.TimestampUUID)
        self.Token = APIObject('Token', 'string', r'^[A-Za-z0-9+\/=]*$', 1, 1000)
        self.add_api_object('Token', self.Token)
        self.TroubleshootingText = APIObject('TroubleshootingText', 'string', r'^[\w\W\s\S]*$', None, 1000)
        self.add_api_object('TroubleshootingText', self.TroubleshootingText)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 36, 36)
        self.add_api_object('UUID', self.UUID)
        self.UrlLink = APIObject('UrlLink', 'string', r'^(https?:\/\/)?(www\.)?[a-zA-Z0-9-_]+([\.]+[a-zA-Z]+)+[\/\w]*$', 1, 8192)
        self.add_api_object('UrlLink', self.UrlLink)
        self.Username = APIObject('Username', 'string', r'^[a-zA-Z0-9-_()\s\+=,.@]+$', 1, 128)
        self.add_api_object('Username', self.Username)
        self.organizationId = APIObject('organizationId', 'string', r'o-[a-z0-9]{10,32}', 12, 34)
        self.add_api_object('organizationId', self.organizationId)

class AutoscalingPlans(Service):
    def __init__(self):
        super().__init__('AutoscalingPlans')
        self.PolicyName = APIObject('PolicyName', 'string', r'\p{Print}+', 1, 256)
        self.add_api_object('PolicyName', self.PolicyName)
        self.ResourceIdMaxLen1600 = APIObject('ResourceIdMaxLen1600', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1600)
        self.add_api_object('ResourceIdMaxLen1600', self.ResourceIdMaxLen1600)
        self.ScalingPlanName = APIObject('ScalingPlanName', 'string', r'[\p{Print}&&[^|:/]]+', 1, 128)
        self.add_api_object('ScalingPlanName', self.ScalingPlanName)
        self.XmlString = APIObject('XmlString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, None)
        self.add_api_object('XmlString', self.XmlString)
        self.XmlStringMaxLen128 = APIObject('XmlStringMaxLen128', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 128)
        self.add_api_object('XmlStringMaxLen128', self.XmlStringMaxLen128)
        self.XmlStringMaxLen256 = APIObject('XmlStringMaxLen256', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 256)
        self.add_api_object('XmlStringMaxLen256', self.XmlStringMaxLen256)

class Autoscaling(Service):
    def __init__(self):
        super().__init__('Autoscaling')
        self.AllowedInstanceType = APIObject('AllowedInstanceType', 'string', r'[a-zA-Z0-9\.\*\-]+', 1, 30)
        self.add_api_object('AllowedInstanceType', self.AllowedInstanceType)
        self.AnyPrintableAsciiStringMaxLen4000 = APIObject('AnyPrintableAsciiStringMaxLen4000', 'string', r'[\u0009\u000A\u000D\u0020-\u007e]+', 1, 4000)
        self.add_api_object('AnyPrintableAsciiStringMaxLen4000', self.AnyPrintableAsciiStringMaxLen4000)
        self.AsciiStringMaxLen255 = APIObject('AsciiStringMaxLen255', 'string', r'[A-Za-z0-9\-_\/]+', 1, 255)
        self.add_api_object('AsciiStringMaxLen255', self.AsciiStringMaxLen255)
        self.ExcludedInstance = APIObject('ExcludedInstance', 'string', r'[a-zA-Z0-9\.\*\-]+', 1, 30)
        self.add_api_object('ExcludedInstance', self.ExcludedInstance)
        self.LaunchTemplateName = APIObject('LaunchTemplateName', 'string', r'[a-zA-Z0-9\(\)\.\-/_]+', 3, 128)
        self.add_api_object('LaunchTemplateName', self.LaunchTemplateName)
        self.NotificationTargetResourceName = APIObject('NotificationTargetResourceName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 255)
        self.add_api_object('NotificationTargetResourceName', self.NotificationTargetResourceName)
        self.ResourceName = APIObject('ResourceName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1600)
        self.add_api_object('ResourceName', self.ResourceName)
        self.TagKey = APIObject('TagKey', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.XmlString = APIObject('XmlString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, None)
        self.add_api_object('XmlString', self.XmlString)
        self.XmlStringMaxLen1023 = APIObject('XmlStringMaxLen1023', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1023)
        self.add_api_object('XmlStringMaxLen1023', self.XmlStringMaxLen1023)
        self.XmlStringMaxLen1600 = APIObject('XmlStringMaxLen1600', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1600)
        self.add_api_object('XmlStringMaxLen1600', self.XmlStringMaxLen1600)
        self.XmlStringMaxLen19 = APIObject('XmlStringMaxLen19', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 19)
        self.add_api_object('XmlStringMaxLen19', self.XmlStringMaxLen19)
        self.XmlStringMaxLen2047 = APIObject('XmlStringMaxLen2047', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 2047)
        self.add_api_object('XmlStringMaxLen2047', self.XmlStringMaxLen2047)
        self.XmlStringMaxLen255 = APIObject('XmlStringMaxLen255', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 255)
        self.add_api_object('XmlStringMaxLen255', self.XmlStringMaxLen255)
        self.XmlStringMaxLen32 = APIObject('XmlStringMaxLen32', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 32)
        self.add_api_object('XmlStringMaxLen32', self.XmlStringMaxLen32)
        self.XmlStringMaxLen511 = APIObject('XmlStringMaxLen511', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 511)
        self.add_api_object('XmlStringMaxLen511', self.XmlStringMaxLen511)
        self.XmlStringMaxLen64 = APIObject('XmlStringMaxLen64', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 64)
        self.add_api_object('XmlStringMaxLen64', self.XmlStringMaxLen64)
        self.XmlStringMetricLabel = APIObject('XmlStringMetricLabel', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, 2047)
        self.add_api_object('XmlStringMetricLabel', self.XmlStringMetricLabel)
        self.XmlStringMetricStat = APIObject('XmlStringMetricStat', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 100)
        self.add_api_object('XmlStringMetricStat', self.XmlStringMetricStat)
        self.XmlStringUserData = APIObject('XmlStringUserData', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, 21847)
        self.add_api_object('XmlStringUserData', self.XmlStringUserData)

class B2bi(Service):
    def __init__(self):
        super().__init__('B2bi')
        self.CapabilityId = APIObject('CapabilityId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('CapabilityId', self.CapabilityId)
        self.Email = APIObject('Email', 'string', r'[\w\.\-]+@[\w\.\-]+', 5, 254)
        self.add_api_object('Email', self.Email)
        self.PartnershipId = APIObject('PartnershipId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('PartnershipId', self.PartnershipId)
        self.Phone = APIObject('Phone', 'string', r'\+?([0-9 \t\-()\/]{7,})(?:\s*(?:#|x\.?|ext\.?|extension) \t*(\d+))?', 7, 22)
        self.add_api_object('Phone', self.Phone)
        self.ProfileId = APIObject('ProfileId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('ProfileId', self.ProfileId)
        self.TradingPartnerId = APIObject('TradingPartnerId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('TradingPartnerId', self.TradingPartnerId)
        self.TransformerId = APIObject('TransformerId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('TransformerId', self.TransformerId)
        self.TransformerJobId = APIObject('TransformerJobId', 'string', r'[a-zA-Z0-9_-]+', 25, 25)
        self.add_api_object('TransformerJobId', self.TransformerJobId)

class BackupGateway(Service):
    def __init__(self):
        super().__init__('BackupGateway')
        self.ActivationKey = APIObject('ActivationKey', 'string', r'^[0-9a-zA-Z\-]+$', 1, 50)
        self.add_api_object('ActivationKey', self.ActivationKey)
        self.GatewayArn = APIObject('GatewayArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):backup-gateway(:[a-zA-Z-0-9]+){3}\/[a-zA-Z-0-9]+$', 50, 500)
        self.add_api_object('GatewayArn', self.GatewayArn)
        self.Host = APIObject('Host', 'string', r'^.+$', 3, 128)
        self.add_api_object('Host', self.Host)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):iam::([0-9]+):role/(\S+)$', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^(^arn:(aws|aws-cn|aws-us-gov):kms:([a-zA-Z0-9-]+):([0-9]+):(key|alias)/(\S+)$)|(^alias/(\S+)$)$', 50, 500)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'^$|^arn:(aws|aws-cn|aws-us-gov):logs:([a-zA-Z0-9-]+):([0-9]+):log-group:[a-zA-Z0-9_\-\/\.]+:\*$', 0, 2048)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9-]*$', 1, 100)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'^.+$', 1, 1000)
        self.add_api_object('NextToken', self.NextToken)
        self.Password = APIObject('Password', 'string', r'^[ -~]+$', 1, 100)
        self.add_api_object('Password', self.Password)
        self.Path = APIObject('Path', 'string', r'^[^\x00]+$', 1, 4096)
        self.add_api_object('Path', self.Path)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):backup-gateway(:[a-zA-Z-0-9]+){3}\/[a-zA-Z-0-9]+$', 50, 500)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ServerArn = APIObject('ServerArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):backup-gateway(:[a-zA-Z-0-9]+){3}\/[a-zA-Z-0-9]+$', 50, 500)
        self.add_api_object('ServerArn', self.ServerArn)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[^\x00]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Username = APIObject('Username', 'string', r'^[ -\.0-\[\]-~]*[!-\.0-\[\]-~][ -\.0-\[\]-~]*$', 1, 100)
        self.add_api_object('Username', self.Username)

class Backup(Service):
    def __init__(self):
        super().__init__('Backup')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.BackupOptionKey = APIObject('BackupOptionKey', 'string', r'^[a-zA-Z0-9\-\_\.]{1,50}$', None, None)
        self.add_api_object('BackupOptionKey', self.BackupOptionKey)
        self.BackupOptionValue = APIObject('BackupOptionValue', 'string', r'^[a-zA-Z0-9\-\_\.]{1,50}$', None, None)
        self.add_api_object('BackupOptionValue', self.BackupOptionValue)
        self.BackupRuleName = APIObject('BackupRuleName', 'string', r'^[a-zA-Z0-9\-\_\.]{1,50}$', None, None)
        self.add_api_object('BackupRuleName', self.BackupRuleName)
        self.BackupSelectionName = APIObject('BackupSelectionName', 'string', r'^[a-zA-Z0-9\-\_\.]{1,50}$', None, None)
        self.add_api_object('BackupSelectionName', self.BackupSelectionName)
        self.BackupVaultName = APIObject('BackupVaultName', 'string', r'^[a-zA-Z0-9\-\_]{2,50}$', None, None)
        self.add_api_object('BackupVaultName', self.BackupVaultName)
        self.FrameworkDescription = APIObject('FrameworkDescription', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('FrameworkDescription', self.FrameworkDescription)
        self.FrameworkName = APIObject('FrameworkName', 'string', r'[a-zA-Z][_a-zA-Z0-9]*', 1, 256)
        self.add_api_object('FrameworkName', self.FrameworkName)
        self.ReportPlanDescription = APIObject('ReportPlanDescription', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('ReportPlanDescription', self.ReportPlanDescription)
        self.ReportPlanName = APIObject('ReportPlanName', 'string', r'[a-zA-Z][_a-zA-Z0-9]*', 1, 256)
        self.add_api_object('ReportPlanName', self.ReportPlanName)
        self.ResourceType = APIObject('ResourceType', 'string', r'^[a-zA-Z0-9\-\_\.]{1,50}$', None, None)
        self.add_api_object('ResourceType', self.ResourceType)

class Backupstorage(Service):
    def __init__(self):
        super().__init__('Backupstorage')
        self.MetadataString = APIObject('MetadataString', 'string', r'^.{1,256}$', None, None)
        self.add_api_object('MetadataString', self.MetadataString)

class Batch(Service):
    def __init__(self):
        super().__init__('Batch')

class BcmDataExports(Service):
    def __init__(self):
        super().__init__('BcmDataExports')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws[-a-z0-9]*:[-a-z0-9]+:[-a-z0-9]*:[0-9]{12}:[-a-zA-Z0-9/:_]+$', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.ExportName = APIObject('ExportName', 'string', r'''^[0-9A-Za-z!\-_.*\\'()]+$''', 1, 128)
        self.add_api_object('ExportName', self.ExportName)
        self.GenericString = APIObject('GenericString', 'string', r'^[\S\s]*$', 0, 1024)
        self.add_api_object('GenericString', self.GenericString)
        self.NextPageToken = APIObject('NextPageToken', 'string', r'^[\S\s]*$', 0, 8192)
        self.add_api_object('NextPageToken', self.NextPageToken)
        self.QueryStatement = APIObject('QueryStatement', 'string', r'^[\S\s]*$', 1, 36000)
        self.add_api_object('QueryStatement', self.QueryStatement)
        self.TableName = APIObject('TableName', 'string', r'^[\S\s]*$', 0, 1024)
        self.add_api_object('TableName', self.TableName)
        self.TableProperty = APIObject('TableProperty', 'string', r'^[\S\s]*$', 0, 1024)
        self.add_api_object('TableProperty', self.TableProperty)

class BedrockAgentRuntime(Service):
    def __init__(self):
        super().__init__('BedrockAgentRuntime')
        self.AgentAliasId = APIObject('AgentAliasId', 'string', r'^[0-9a-zA-Z]+$', 0, 10)
        self.add_api_object('AgentAliasId', self.AgentAliasId)
        self.AgentId = APIObject('AgentId', 'string', r'^[0-9a-zA-Z]+$', 0, 10)
        self.add_api_object('AgentId', self.AgentId)
        self.AgentVersion = APIObject('AgentVersion', 'string', r'^(DRAFT|[0-9]{0,4}[1-9][0-9]{0,4})$', 1, 5)
        self.add_api_object('AgentVersion', self.AgentVersion)
        self.BedrockModelArn = APIObject('BedrockModelArn', 'string', r'^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}/[a-z0-9]{12})|(:foundation-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}))$', 20, 1011)
        self.add_api_object('BedrockModelArn', self.BedrockModelArn)
        self.ContentType = APIObject('ContentType', 'string', r'[a-z]{1,20}/.{1,20}', None, None)
        self.add_api_object('ContentType', self.ContentType)
        self.GuardrailConfigurationGuardrailIdString = APIObject('GuardrailConfigurationGuardrailIdString', 'string', r'^[a-z0-9]+$', 0, 64)
        self.add_api_object('GuardrailConfigurationGuardrailIdString', self.GuardrailConfigurationGuardrailIdString)
        self.GuardrailConfigurationGuardrailVersionString = APIObject('GuardrailConfigurationGuardrailVersionString', 'string', r'^(([1-9][0-9]{0,7})|(DRAFT))$', 1, 5)
        self.add_api_object('GuardrailConfigurationGuardrailVersionString', self.GuardrailConfigurationGuardrailVersionString)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws(|-cn|-us-gov):kms:[a-zA-Z0-9-]*:[0-9]{12}:key/[a-zA-Z0-9-]{36}$', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.KnowledgeBaseId = APIObject('KnowledgeBaseId', 'string', r'^[0-9a-zA-Z]+$', 0, 10)
        self.add_api_object('KnowledgeBaseId', self.KnowledgeBaseId)
        self.NextToken = APIObject('NextToken', 'string', r'^\S*$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NonBlankString = APIObject('NonBlankString', 'string', r'^[\s\S]*$', None, None)
        self.add_api_object('NonBlankString', self.NonBlankString)
        self.S3Uri = APIObject('S3Uri', 'string', r'^s3://[a-z0-9][a-z0-9.-]{1,61}[a-z0-9]/.{1,1024}$', 1, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SessionId = APIObject('SessionId', 'string', r'^[0-9a-zA-Z._:-]+$', 2, 100)
        self.add_api_object('SessionId', self.SessionId)

class BedrockAgent(Service):
    def __init__(self):
        super().__init__('BedrockAgent')
        self.AgentAliasArn = APIObject('AgentAliasArn', 'string', r'^arn:aws:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:agent-alias/[0-9a-zA-Z]{10}/[0-9a-zA-Z]{10}$', 0, 2048)
        self.add_api_object('AgentAliasArn', self.AgentAliasArn)
        self.AgentAliasId = APIObject('AgentAliasId', 'string', r'^(\bTSTALIASID\b|[0-9a-zA-Z]+)$', 10, 10)
        self.add_api_object('AgentAliasId', self.AgentAliasId)
        self.AgentArn = APIObject('AgentArn', 'string', r'^arn:aws:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:agent/[0-9a-zA-Z]{10}$', 0, 2048)
        self.add_api_object('AgentArn', self.AgentArn)
        self.AgentRoleArn = APIObject('AgentRoleArn', 'string', r'^arn:aws(-[^:]+)?:iam::([0-9]{12})?:role/(service-role/)?AmazonBedrockExecutionRoleForAgents_.+$', 0, 2048)
        self.add_api_object('AgentRoleArn', self.AgentRoleArn)
        self.BedrockEmbeddingModelArn = APIObject('BedrockEmbeddingModelArn', 'string', r'^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}/[a-z0-9]{12})|(:foundation-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}))$', 20, 1011)
        self.add_api_object('BedrockEmbeddingModelArn', self.BedrockEmbeddingModelArn)
        self.BucketOwnerAccountId = APIObject('BucketOwnerAccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('BucketOwnerAccountId', self.BucketOwnerAccountId)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', 33, 256)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ColumnName = APIObject('ColumnName', 'string', r'^[a-zA-Z0-9_\-]+$', 0, 63)
        self.add_api_object('ColumnName', self.ColumnName)
        self.DraftVersion = APIObject('DraftVersion', 'string', r'^DRAFT$', 5, 5)
        self.add_api_object('DraftVersion', self.DraftVersion)
        self.FieldName = APIObject('FieldName', 'string', r'^.*$', 0, 2048)
        self.add_api_object('FieldName', self.FieldName)
        self.Id = APIObject('Id', 'string', r'^[0-9a-zA-Z]{10}$', None, None)
        self.add_api_object('Id', self.Id)
        self.IngestionJobFilterValue = APIObject('IngestionJobFilterValue', 'string', r'^.*$', 0, 100)
        self.add_api_object('IngestionJobFilterValue', self.IngestionJobFilterValue)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws(|-cn|-us-gov):kms:[a-zA-Z0-9-]*:[0-9]{12}:key/[a-zA-Z0-9-]{36}$', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.KnowledgeBaseArn = APIObject('KnowledgeBaseArn', 'string', r'^arn:aws(|-cn|-us-gov):bedrock:[a-zA-Z0-9-]*:[0-9]{12}:knowledge-base/[0-9a-zA-Z]+$', 0, 128)
        self.add_api_object('KnowledgeBaseArn', self.KnowledgeBaseArn)
        self.KnowledgeBaseRoleArn = APIObject('KnowledgeBaseRoleArn', 'string', r'^arn:aws(-[^:]+)?:iam::([0-9]{12})?:role/.+$', 0, 2048)
        self.add_api_object('KnowledgeBaseRoleArn', self.KnowledgeBaseRoleArn)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}(-gov)?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_\.]+(:(\$LATEST|[a-zA-Z0-9-_]+))?$', 0, 2048)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.ModelIdentifier = APIObject('ModelIdentifier', 'string', r'^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}(([:][a-z0-9-]{1,63}){0,2})?/[a-z0-9]{12})|(:foundation-model/([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2})))|(([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2}))|(([0-9a-zA-Z][_-]?)+)$', 1, 2048)
        self.add_api_object('ModelIdentifier', self.ModelIdentifier)
        self.MongoDbAtlasCollectionName = APIObject('MongoDbAtlasCollectionName', 'string', r'^.*$', 0, 63)
        self.add_api_object('MongoDbAtlasCollectionName', self.MongoDbAtlasCollectionName)
        self.MongoDbAtlasDatabaseName = APIObject('MongoDbAtlasDatabaseName', 'string', r'^.*$', 0, 63)
        self.add_api_object('MongoDbAtlasDatabaseName', self.MongoDbAtlasDatabaseName)
        self.MongoDbAtlasEndpoint = APIObject('MongoDbAtlasEndpoint', 'string', r'^.*$', 0, 2048)
        self.add_api_object('MongoDbAtlasEndpoint', self.MongoDbAtlasEndpoint)
        self.MongoDbAtlasEndpointServiceName = APIObject('MongoDbAtlasEndpointServiceName', 'string', r'^(?:arn:aws(?:-us-gov|-cn|-iso|-iso-[a-z])*:.+:.*:\d+:.+/.+$|[a-zA-Z0-9*]+[a-zA-Z0-9._-]*)$', 1, 255)
        self.add_api_object('MongoDbAtlasEndpointServiceName', self.MongoDbAtlasEndpointServiceName)
        self.MongoDbAtlasIndexName = APIObject('MongoDbAtlasIndexName', 'string', r'^.*$', 0, 2048)
        self.add_api_object('MongoDbAtlasIndexName', self.MongoDbAtlasIndexName)
        self.Name = APIObject('Name', 'string', r'^([0-9a-zA-Z][_-]?){1,100}$', None, None)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'^\S*$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NonBlankString = APIObject('NonBlankString', 'string', r'^[\s\S]+$', None, None)
        self.add_api_object('NonBlankString', self.NonBlankString)
        self.NumericalVersion = APIObject('NumericalVersion', 'string', r'^[0-9]{1,5}$', None, None)
        self.add_api_object('NumericalVersion', self.NumericalVersion)
        self.OpenSearchServerlessCollectionArn = APIObject('OpenSearchServerlessCollectionArn', 'string', r'^arn:aws:aoss:[a-z]{2}(-gov)?-[a-z]+-\d{1}:\d{12}:collection/[a-z0-9-]{3,32}$', 0, 2048)
        self.add_api_object('OpenSearchServerlessCollectionArn', self.OpenSearchServerlessCollectionArn)
        self.OpenSearchServerlessIndexName = APIObject('OpenSearchServerlessIndexName', 'string', r'^.*$', 0, 2048)
        self.add_api_object('OpenSearchServerlessIndexName', self.OpenSearchServerlessIndexName)
        self.PineconeConnectionString = APIObject('PineconeConnectionString', 'string', r'^.*$', 0, 2048)
        self.add_api_object('PineconeConnectionString', self.PineconeConnectionString)
        self.PineconeNamespace = APIObject('PineconeNamespace', 'string', r'^.*$', 0, 2048)
        self.add_api_object('PineconeNamespace', self.PineconeNamespace)
        self.ProvisionedModelIdentifier = APIObject('ProvisionedModelIdentifier', 'string', r'^((([0-9a-zA-Z][_-]?){1,63})|(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:provisioned-model/[a-z0-9]{12}))$', 1, 2048)
        self.add_api_object('ProvisionedModelIdentifier', self.ProvisionedModelIdentifier)
        self.RdsArn = APIObject('RdsArn', 'string', r'^arn:aws(|-cn|-us-gov):rds:[a-zA-Z0-9-]*:[0-9]{12}:cluster:[a-zA-Z0-9-]{1,63}$', None, None)
        self.add_api_object('RdsArn', self.RdsArn)
        self.RdsDatabaseName = APIObject('RdsDatabaseName', 'string', r'^[a-zA-Z0-9_\-]+$', 0, 63)
        self.add_api_object('RdsDatabaseName', self.RdsDatabaseName)
        self.RdsTableName = APIObject('RdsTableName', 'string', r'^[a-zA-Z0-9_\.\-]+$', 0, 63)
        self.add_api_object('RdsTableName', self.RdsTableName)
        self.RedisEnterpriseCloudEndpoint = APIObject('RedisEnterpriseCloudEndpoint', 'string', r'^.*$', 0, 2048)
        self.add_api_object('RedisEnterpriseCloudEndpoint', self.RedisEnterpriseCloudEndpoint)
        self.RedisEnterpriseCloudIndexName = APIObject('RedisEnterpriseCloudIndexName', 'string', r'^.*$', 0, 2048)
        self.add_api_object('RedisEnterpriseCloudIndexName', self.RedisEnterpriseCloudIndexName)
        self.S3BucketArn = APIObject('S3BucketArn', 'string', r'^arn:aws(|-cn|-us-gov):s3:::[a-z0-9][a-z0-9.-]{1,61}[a-z0-9]$', 1, 2048)
        self.add_api_object('S3BucketArn', self.S3BucketArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]$', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'''^[\.\-\!\*\_\\'\(\)a-zA-Z0-9][\.\-\!\*\_\\'\(\)\/a-zA-Z0-9]*$''', 1, 1024)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.SecretArn = APIObject('SecretArn', 'string', r'^arn:aws(|-cn|-us-gov):secretsmanager:[a-z0-9-]{1,20}:([0-9]{12}|):secret:[a-zA-Z0-9!/_+=.@-]{1,512}$', None, None)
        self.add_api_object('SecretArn', self.SecretArn)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z0-9\s._:/=+@-]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[a-zA-Z0-9\s._:/=+@-]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaggableResourcesArn = APIObject('TaggableResourcesArn', 'string', r'(^arn:aws:bedrock:[a-zA-Z0-9-]+:/d{12}:(agent|agent-alias|knowledge-base)/[A-Z0-9]{10}(?:/[A-Z0-9]{10})?$)', 20, 1011)
        self.add_api_object('TaggableResourcesArn', self.TaggableResourcesArn)
        self.Version = APIObject('Version', 'string', r'^(DRAFT|[0-9]{0,4}[1-9][0-9]{0,4})$', 1, 5)
        self.add_api_object('Version', self.Version)

class BedrockRuntime(Service):
    def __init__(self):
        super().__init__('BedrockRuntime')
        self.GuardrailIdentifier = APIObject('GuardrailIdentifier', 'string', r'(([a-z0-9]+)|(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:guardrail/[a-z0-9]+))', 0, 2048)
        self.add_api_object('GuardrailIdentifier', self.GuardrailIdentifier)
        self.GuardrailVersion = APIObject('GuardrailVersion', 'string', r'(([1-9][0-9]{0,7})|(DRAFT))', None, None)
        self.add_api_object('GuardrailVersion', self.GuardrailVersion)
        self.InvokeModelIdentifier = APIObject('InvokeModelIdentifier', 'string', r'(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}/[a-z0-9]{12})|(:foundation-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.:]?[a-z0-9-]{1,63}))|([0-9]{12}:provisioned-model/[a-z0-9]{12})))|([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.:]?[a-z0-9-]{1,63}))|(([0-9a-zA-Z][_-]?)+)', 1, 2048)
        self.add_api_object('InvokeModelIdentifier', self.InvokeModelIdentifier)
        self.NonBlankString = APIObject('NonBlankString', 'string', r'[\s\S]*', None, None)
        self.add_api_object('NonBlankString', self.NonBlankString)

class Bedrock(Service):
    def __init__(self):
        super().__init__('Bedrock')
        self.BaseModelIdentifier = APIObject('BaseModelIdentifier', 'string', r'(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2})/[a-z0-9]{12})|(:foundation-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2})))|([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2})|(([0-9a-zA-Z][_-]?)+)', 1, 2048)
        self.add_api_object('BaseModelIdentifier', self.BaseModelIdentifier)
        self.BedrockModelId = APIObject('BedrockModelId', 'string', r'[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}(/[a-z0-9]{12}|)', 0, 140)
        self.add_api_object('BedrockModelId', self.BedrockModelId)
        self.BrandedName = APIObject('BrandedName', 'string', r'.*', 1, 20)
        self.add_api_object('BrandedName', self.BrandedName)
        self.CustomModelArn = APIObject('CustomModelArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}/[a-z0-9]{12}', 20, 1011)
        self.add_api_object('CustomModelArn', self.CustomModelArn)
        self.CustomModelName = APIObject('CustomModelName', 'string', r'([0-9a-zA-Z][_-]?)+', 1, 63)
        self.add_api_object('CustomModelName', self.CustomModelName)
        self.EvaluationDatasetName = APIObject('EvaluationDatasetName', 'string', r'[0-9a-zA-Z-_.]+', 1, 63)
        self.add_api_object('EvaluationDatasetName', self.EvaluationDatasetName)
        self.EvaluationJobArn = APIObject('EvaluationJobArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:evaluation-job/[a-z0-9]{12}', 0, 1011)
        self.add_api_object('EvaluationJobArn', self.EvaluationJobArn)
        self.EvaluationJobDescription = APIObject('EvaluationJobDescription', 'string', r'.+', 1, 200)
        self.add_api_object('EvaluationJobDescription', self.EvaluationJobDescription)
        self.EvaluationJobIdentifier = APIObject('EvaluationJobIdentifier', 'string', r'(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:evaluation-job/[a-z0-9]{12})', 0, 1011)
        self.add_api_object('EvaluationJobIdentifier', self.EvaluationJobIdentifier)
        self.EvaluationJobName = APIObject('EvaluationJobName', 'string', r'[a-z0-9](-*[a-z0-9]){0,62}', 1, 63)
        self.add_api_object('EvaluationJobName', self.EvaluationJobName)
        self.EvaluationMetricDescription = APIObject('EvaluationMetricDescription', 'string', r'.+', 1, 63)
        self.add_api_object('EvaluationMetricDescription', self.EvaluationMetricDescription)
        self.EvaluationMetricName = APIObject('EvaluationMetricName', 'string', r'[0-9a-zA-Z-_.]+', 1, 63)
        self.add_api_object('EvaluationMetricName', self.EvaluationMetricName)
        self.EvaluationModelIdentifier = APIObject('EvaluationModelIdentifier', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}(([:][a-z0-9-]{1,63}){0,2})?/[a-z0-9]{12})|(:foundation-model/([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2})))|(([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2}))|(([0-9a-zA-Z][_-]?)+)', 1, 2048)
        self.add_api_object('EvaluationModelIdentifier', self.EvaluationModelIdentifier)
        self.EvaluationRatingMethod = APIObject('EvaluationRatingMethod', 'string', r'[0-9a-zA-Z-_]+', 1, 100)
        self.add_api_object('EvaluationRatingMethod', self.EvaluationRatingMethod)
        self.EvaluationTaskType = APIObject('EvaluationTaskType', 'string', r'[A-Za-z0-9]+', 1, 63)
        self.add_api_object('EvaluationTaskType', self.EvaluationTaskType)
        self.FoundationModelArn = APIObject('FoundationModelArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}::foundation-model/[a-z0-9-]{1,63}[.]{1}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}', None, None)
        self.add_api_object('FoundationModelArn', self.FoundationModelArn)
        self.GuardrailArn = APIObject('GuardrailArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:guardrail/[a-z0-9]+', 0, 2048)
        self.add_api_object('GuardrailArn', self.GuardrailArn)
        self.GuardrailDraftVersion = APIObject('GuardrailDraftVersion', 'string', r'DRAFT', 5, 5)
        self.add_api_object('GuardrailDraftVersion', self.GuardrailDraftVersion)
        self.GuardrailId = APIObject('GuardrailId', 'string', r'[a-z0-9]+', 0, 64)
        self.add_api_object('GuardrailId', self.GuardrailId)
        self.GuardrailIdentifier = APIObject('GuardrailIdentifier', 'string', r'(([a-z0-9]+)|(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:guardrail/[a-z0-9]+))', 0, 2048)
        self.add_api_object('GuardrailIdentifier', self.GuardrailIdentifier)
        self.GuardrailName = APIObject('GuardrailName', 'string', r'[0-9a-zA-Z-_]+', 1, 50)
        self.add_api_object('GuardrailName', self.GuardrailName)
        self.GuardrailNumericalVersion = APIObject('GuardrailNumericalVersion', 'string', r'[1-9][0-9]{0,7}', None, None)
        self.add_api_object('GuardrailNumericalVersion', self.GuardrailNumericalVersion)
        self.GuardrailTopicName = APIObject('GuardrailTopicName', 'string', r'[0-9a-zA-Z-_ !?.]+', 1, 100)
        self.add_api_object('GuardrailTopicName', self.GuardrailTopicName)
        self.GuardrailVersion = APIObject('GuardrailVersion', 'string', r'(([1-9][0-9]{0,7})|(DRAFT))', None, None)
        self.add_api_object('GuardrailVersion', self.GuardrailVersion)
        self.HumanTaskInstructions = APIObject('HumanTaskInstructions', 'string', r'[\S\s]+', 1, 5000)
        self.add_api_object('HumanTaskInstructions', self.HumanTaskInstructions)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[a-zA-Z0-9](-*[a-zA-Z0-9])*', 1, 256)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.JobName = APIObject('JobName', 'string', r'[a-zA-Z0-9](-*[a-zA-Z0-9\+\-\.])*', 1, 63)
        self.add_api_object('JobName', self.JobName)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws(-[^:]+)?:kms:[a-zA-Z0-9-]*:[0-9]{12}:key/[a-zA-Z0-9-]{36}', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'arn:aws(-[^:]+)?:kms:[a-zA-Z0-9-]*:[0-9]{12}:((key/[a-zA-Z0-9-]{36})|(alias/[a-zA-Z0-9-_/]+))', 1, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.ModelArn = APIObject('ModelArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}/[a-z0-9]{12})|(:foundation-model/[a-z0-9-]{1,63}[.]{1}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}))', 20, 1011)
        self.add_api_object('ModelArn', self.ModelArn)
        self.ModelCustomizationJobArn = APIObject('ModelCustomizationJobArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:model-customization-job/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}/[a-z0-9]{12}', 0, 1011)
        self.add_api_object('ModelCustomizationJobArn', self.ModelCustomizationJobArn)
        self.ModelCustomizationJobIdentifier = APIObject('ModelCustomizationJobIdentifier', 'string', r'(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:model-customization-job/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}/[a-z0-9]{12})|([a-zA-Z0-9](-*[a-zA-Z0-9\+\-\.])*)', 0, 1011)
        self.add_api_object('ModelCustomizationJobIdentifier', self.ModelCustomizationJobIdentifier)
        self.ModelIdentifier = APIObject('ModelIdentifier', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:(([0-9]{12}:custom-model/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}(([:][a-z0-9-]{1,63}){0,2})?/[a-z0-9]{12})|(:foundation-model/([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2})))|(([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([.]?[a-z0-9-]{1,63})([:][a-z0-9-]{1,63}){0,2}))|(([0-9a-zA-Z][_-]?)+)', 1, 2048)
        self.add_api_object('ModelIdentifier', self.ModelIdentifier)
        self.ModelName = APIObject('ModelName', 'string', r'([a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63})', 1, 63)
        self.add_api_object('ModelName', self.ModelName)
        self.NonBlankString = APIObject('NonBlankString', 'string', r'[\s\S]*', None, None)
        self.add_api_object('NonBlankString', self.NonBlankString)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'\S*', 1, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.Provider = APIObject('Provider', 'string', r'[A-Za-z0-9- ]{1,63}', None, None)
        self.add_api_object('Provider', self.Provider)
        self.ProvisionedModelArn = APIObject('ProvisionedModelArn', 'string', r'arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:provisioned-model/[a-z0-9]{12}', None, None)
        self.add_api_object('ProvisionedModelArn', self.ProvisionedModelArn)
        self.ProvisionedModelId = APIObject('ProvisionedModelId', 'string', r'((([0-9a-zA-Z][_-]?)+)|(arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:[0-9]{12}:provisioned-model/[a-z0-9]{12}))', None, None)
        self.add_api_object('ProvisionedModelId', self.ProvisionedModelId)
        self.ProvisionedModelName = APIObject('ProvisionedModelName', 'string', r'([0-9a-zA-Z][_-]?)+', 1, 63)
        self.add_api_object('ProvisionedModelName', self.ProvisionedModelName)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws(-[^:]+)?:iam::([0-9]{12})?:role/.+', 0, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', 1, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SageMakerFlowDefinitionArn = APIObject('SageMakerFlowDefinitionArn', 'string', r'arn:aws(-[^:]+)?:sagemaker:[a-z0-9-]{1,20}:[0-9]{12}:flow-definition/.*', 0, 1024)
        self.add_api_object('SageMakerFlowDefinitionArn', self.SageMakerFlowDefinitionArn)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'[-0-9a-zA-Z]+', 0, 32)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'[-0-9a-zA-Z]+', 0, 32)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'[a-zA-Z0-9\s._:/=+@-]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[a-zA-Z0-9\s._:/=+@-]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaggableResourcesArn = APIObject('TaggableResourcesArn', 'string', r'.*(^[a-zA-Z0-9][a-zA-Z0-9\-]*$)|(^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}:([0-9]{12}|)((:(fine-tuning-job|model-customization-job|custom-model)/[a-z0-9-]{1,63}[.]{1}[a-z0-9-]{1,63}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}(/[a-z0-9]{12})$)|(:provisioned-model/[a-z0-9]{12}$)|(:guardrail/[a-z0-9]+$)|(:evaluation-job/[a-z0-9]{12}$))).*', 20, 1011)
        self.add_api_object('TaggableResourcesArn', self.TaggableResourcesArn)

class Billingconductor(Service):
    def __init__(self):
        super().__init__('Billingconductor')
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.Arn = APIObject('Arn', 'string', r'arn:aws(-cn)?:billingconductor::[0-9]{12}:billinggroup/?[0-9]{12}$|^arn:aws(-cn)?:billingconductor::[0-9]{12}:pricingplan/[a-zA-Z0-9]{10}$|^arn:aws(-cn)?:billingconductor::[0-9]{12}:pricingrule/[a-zA-Z0-9]{10}$|^(arn:aws(-cn)?:billingconductor::[0-9]{12}:customlineitem/)?[a-zA-Z0-9]{10}', 0, 100)
        self.add_api_object('Arn', self.Arn)
        self.Association = APIObject('Association', 'string', r'((arn:aws(-cn)?:billingconductor::[0-9]{12}:billinggroup/)?[0-9]{12}|MONITORED|UNMONITORED)', None, None)
        self.add_api_object('Association', self.Association)
        self.BillingEntity = APIObject('BillingEntity', 'string', r'[a-zA-Z0-9 ]+', None, None)
        self.add_api_object('BillingEntity', self.BillingEntity)
        self.BillingGroupArn = APIObject('BillingGroupArn', 'string', r'(arn:aws(-cn)?:billingconductor::[0-9]{12}:billinggroup/)?[0-9]{12}', None, None)
        self.add_api_object('BillingGroupArn', self.BillingGroupArn)
        self.BillingGroupFullArn = APIObject('BillingGroupFullArn', 'string', r'arn:aws(-cn)?:billingconductor::[0-9]{12}:billinggroup/[0-9]{12}', None, None)
        self.add_api_object('BillingGroupFullArn', self.BillingGroupFullArn)
        self.BillingGroupName = APIObject('BillingGroupName', 'string', r'[a-zA-Z0-9_\+=\.\-@]+', 1, 128)
        self.add_api_object('BillingGroupName', self.BillingGroupName)
        self.BillingPeriod = APIObject('BillingPeriod', 'string', r'\d{4}-(0?[1-9]|1[012])', None, None)
        self.add_api_object('BillingPeriod', self.BillingPeriod)
        self.ClientToken = APIObject('ClientToken', 'string', r'[a-zA-Z0-9-]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CustomLineItemArn = APIObject('CustomLineItemArn', 'string', r'(arn:aws(-cn)?:billingconductor::[0-9]{12}:customlineitem/)?[a-zA-Z0-9]{10}', None, None)
        self.add_api_object('CustomLineItemArn', self.CustomLineItemArn)
        self.CustomLineItemAssociationElement = APIObject('CustomLineItemAssociationElement', 'string', r'(arn:aws(-cn)?:billingconductor::[0-9]{12}:(customlineitem|billinggroup)/)?[a-zA-Z0-9]{10,12}', None, None)
        self.add_api_object('CustomLineItemAssociationElement', self.CustomLineItemAssociationElement)
        self.CustomLineItemName = APIObject('CustomLineItemName', 'string', r'[a-zA-Z0-9_\+=\.\-@]+', 1, 128)
        self.add_api_object('CustomLineItemName', self.CustomLineItemName)
        self.Operation = APIObject('Operation', 'string', r'\S+', 1, 256)
        self.add_api_object('Operation', self.Operation)
        self.PricingPlanArn = APIObject('PricingPlanArn', 'string', r'(arn:aws(-cn)?:billingconductor::[0-9]{12}:pricingplan/)?[a-zA-Z0-9]{10}', None, None)
        self.add_api_object('PricingPlanArn', self.PricingPlanArn)
        self.PricingPlanFullArn = APIObject('PricingPlanFullArn', 'string', r'arn:aws(-cn)?:billingconductor::[0-9]{12}:pricingplan/[a-zA-Z0-9]{10}', None, None)
        self.add_api_object('PricingPlanFullArn', self.PricingPlanFullArn)
        self.PricingPlanName = APIObject('PricingPlanName', 'string', r'[a-zA-Z0-9_\+=\.\-@]+', 1, 128)
        self.add_api_object('PricingPlanName', self.PricingPlanName)
        self.PricingRuleArn = APIObject('PricingRuleArn', 'string', r'(arn:aws(-cn)?:billingconductor::[0-9]{12}:pricingrule/)?[a-zA-Z0-9]{10}', None, None)
        self.add_api_object('PricingRuleArn', self.PricingRuleArn)
        self.PricingRuleName = APIObject('PricingRuleName', 'string', r'[a-zA-Z0-9_\+=\.\-@]+', 1, 128)
        self.add_api_object('PricingRuleName', self.PricingRuleName)
        self.Service = APIObject('Service', 'string', r'[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('Service', self.Service)
        self.UsageType = APIObject('UsageType', 'string', r'\S+', 1, 256)
        self.add_api_object('UsageType', self.UsageType)

class Braket(Service):
    def __init__(self):
        super().__init__('Braket')
        self.BraketResourceArn = APIObject('BraketResourceArn', 'string', r'^arn:aws[a-z\-]*:braket:[a-z0-9\-]*:[0-9]{12}:.*$', None, None)
        self.add_api_object('BraketResourceArn', self.BraketResourceArn)
        self.CreateJobRequestJobNameString = APIObject('CreateJobRequestJobNameString', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9]){0,50}$', 1, 50)
        self.add_api_object('CreateJobRequestJobNameString', self.CreateJobRequestJobNameString)
        self.GetJobResponseJobNameString = APIObject('GetJobResponseJobNameString', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9]){0,50}$', 1, 50)
        self.add_api_object('GetJobResponseJobNameString', self.GetJobResponseJobNameString)
        self.HyperParametersValueString = APIObject('HyperParametersValueString', 'string', r'^.*$', 1, 2500)
        self.add_api_object('HyperParametersValueString', self.HyperParametersValueString)
        self.InputFileConfigChannelNameString = APIObject('InputFileConfigChannelNameString', 'string', r'^[A-Za-z0-9\.\-_]+$', 1, 64)
        self.add_api_object('InputFileConfigChannelNameString', self.InputFileConfigChannelNameString)
        self.JobArn = APIObject('JobArn', 'string', r'^arn:aws[a-z\-]*:braket:[a-z0-9\-]+:[0-9]{12}:job/.*$', None, None)
        self.add_api_object('JobArn', self.JobArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws[a-z\-]*:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Path = APIObject('S3Path', 'string', r'^(https|s3)://([^/]+)/?(.*)$', 0, 1024)
        self.add_api_object('S3Path', self.S3Path)
        self.Uri = APIObject('Uri', 'string', r'\d{10,14}\.dkr\.ecr.[a-z0-9-]+\.amazonaws\.com\/.+(@sha256)?:.+', 1, 255)
        self.add_api_object('Uri', self.Uri)

class Budgets(Service):
    def __init__(self):
        super().__init__('Budgets')
        self.AccountId = APIObject('AccountId', 'string', r'\d{12}', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.ActionId = APIObject('ActionId', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('ActionId', self.ActionId)
        self.BudgetName = APIObject('BudgetName', 'string', r'^(?![^:\\]*/action/|(?i).*<script>.*</script>.*)[^:\\]+$', 1, 100)
        self.add_api_object('BudgetName', self.BudgetName)
        self.DimensionValue = APIObject('DimensionValue', 'string', r'[\S\s]*', 0, 2147483647)
        self.add_api_object('DimensionValue', self.DimensionValue)
        self.GenericString = APIObject('GenericString', 'string', r'.*', 0, 2147483647)
        self.add_api_object('GenericString', self.GenericString)
        self.Group = APIObject('Group', 'string', r'^([\u0021-\u007F]+\u002F)?[\w+=,.@-]+$', 1, 640)
        self.add_api_object('Group', self.Group)
        self.InstanceId = APIObject('InstanceId', 'string', r'^i-(\w{8}|\w{17})$|^[a-zA-Z]([\w-]{0,61}\w)?$', 1, 63)
        self.add_api_object('InstanceId', self.InstanceId)
        self.NumericValue = APIObject('NumericValue', 'string', r'([0-9]*\.)?[0-9]+', 1, 2147483647)
        self.add_api_object('NumericValue', self.NumericValue)
        self.PolicyArn = APIObject('PolicyArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|us-iso-east-1|us-isob-east-1):iam::(\d{12}|aws):policy(\u002F[\u0021-\u007F]+\u002F|\u002F)[\w+=,.@-]+$', 25, 684)
        self.add_api_object('PolicyArn', self.PolicyArn)
        self.PolicyId = APIObject('PolicyId', 'string', r'^p-[0-9a-zA-Z_]{8,128}$', 10, 130)
        self.add_api_object('PolicyId', self.PolicyId)
        self.Region = APIObject('Region', 'string', r'^\w{2}-\w+(-\w+)?-\d$', 9, 20)
        self.add_api_object('Region', self.Region)
        self.Role = APIObject('Role', 'string', r'^([\u0021-\u007F]+\u002F)?[\w+=,.@-]+$', 1, 576)
        self.add_api_object('Role', self.Role)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|us-iso-east-1|us-isob-east-1):iam::\d{12}:role(\u002F[\u0021-\u007F]+\u002F|\u002F)[\w+=,.@-]+$', 32, 618)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SubscriberAddress = APIObject('SubscriberAddress', 'string', r'(.*[\n\r\t\f\ ]?)*', 1, 2147483647)
        self.add_api_object('SubscriberAddress', self.SubscriberAddress)
        self.TargetId = APIObject('TargetId', 'string', r'^(ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$)|(\d{12})', 12, 68)
        self.add_api_object('TargetId', self.TargetId)
        self.UnitValue = APIObject('UnitValue', 'string', r'.*', 1, 2147483647)
        self.add_api_object('UnitValue', self.UnitValue)
        self.User = APIObject('User', 'string', r'^([\u0021-\u007F]+\u002F)?[\w+=,.@-]+$', 1, 576)
        self.add_api_object('User', self.User)

class Ce(Service):
    def __init__(self):
        super().__init__('Ce')
        self.Arn = APIObject('Arn', 'string', r'arn:aws[-a-z0-9]*:[a-z0-9]+:[-a-z0-9]*:[0-9]{12}:[-a-zA-Z0-9/:_]+', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.CostCategoryName = APIObject('CostCategoryName', 'string', r'^(?! )[\p{L}\p{N}\p{Z}-_]*(?<! )$', 1, 50)
        self.add_api_object('CostCategoryName', self.CostCategoryName)
        self.CostCategoryValue = APIObject('CostCategoryValue', 'string', r'^(?! )[\p{L}\p{N}\p{Z}-_]*(?<! )$', 1, 50)
        self.add_api_object('CostCategoryValue', self.CostCategoryValue)
        self.GenericString = APIObject('GenericString', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('GenericString', self.GenericString)
        self.GroupDefinitionKey = APIObject('GroupDefinitionKey', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('GroupDefinitionKey', self.GroupDefinitionKey)
        self.MetricName = APIObject('MetricName', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('MetricName', self.MetricName)
        self.NextPageToken = APIObject('NextPageToken', 'string', r'[\S\s]*', 0, 8192)
        self.add_api_object('NextPageToken', self.NextPageToken)
        self.RecommendationDetailId = APIObject('RecommendationDetailId', 'string', r'^[\S\s]{8}-[\S\s]{4}-[\S\s]{4}-[\S\s]{4}-[\S\s]{12}$', 36, 36)
        self.add_api_object('RecommendationDetailId', self.RecommendationDetailId)
        self.RecommendationId = APIObject('RecommendationId', 'string', r'^[\S\s]{8}-[\S\s]{4}-[\S\s]{4}-[\S\s]{4}-[\S\s]{12}$', 36, 36)
        self.add_api_object('RecommendationId', self.RecommendationId)
        self.ResourceTagKey = APIObject('ResourceTagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('ResourceTagKey', self.ResourceTagKey)
        self.ResourceTagValue = APIObject('ResourceTagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('ResourceTagValue', self.ResourceTagValue)
        self.SearchString = APIObject('SearchString', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('SearchString', self.SearchString)
        self.SortDefinitionKey = APIObject('SortDefinitionKey', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('SortDefinitionKey', self.SortDefinitionKey)
        self.SubscriberAddress = APIObject('SubscriberAddress', 'string', r'(^[a-zA-Z0-9.!#$%&\'*+=?^_‘{|}~-]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$)|(^arn:(aws[a-zA-Z-]*):sns:[a-zA-Z0-9-]+:[0-9]{12}:[a-zA-Z0-9_-]+(\.fifo)?$)', 6, 302)
        self.add_api_object('SubscriberAddress', self.SubscriberAddress)
        self.TagKey = APIObject('TagKey', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('TagKey', self.TagKey)
        self.Value = APIObject('Value', 'string', r'[\S\s]*', 0, 1024)
        self.add_api_object('Value', self.Value)
        self.YearMonthDay = APIObject('YearMonthDay', 'string', r'(\d{4}-\d{2}-\d{2})(T\d{2}:\d{2}:\d{2}Z)?', 0, 40)
        self.add_api_object('YearMonthDay', self.YearMonthDay)
        self.ZonedDateTime = APIObject('ZonedDateTime', 'string', r'^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d(([+-]\d\d:\d\d)|Z)$', 20, 25)
        self.add_api_object('ZonedDateTime', self.ZonedDateTime)

class Chatbot(Service):
    def __init__(self):
        super().__init__('Chatbot')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws:[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}$', 12, 1224)
        self.add_api_object('Arn', self.Arn)
        self.AwsUserIdentity = APIObject('AwsUserIdentity', 'string', r'^arn:aws:(iam|sts)::[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}$', 15, 1101)
        self.add_api_object('AwsUserIdentity', self.AwsUserIdentity)
        self.ChatConfigurationArn = APIObject('ChatConfigurationArn', 'string', r'^arn:aws:(wheatley|chatbot):[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}$', 19, 1169)
        self.add_api_object('ChatConfigurationArn', self.ChatConfigurationArn)
        self.ChimeWebhookUrl = APIObject('ChimeWebhookUrl', 'string', r'^https://hooks\.chime\.aws/incomingwebhooks/[A-Za-z0-9\-]+?\?token=[A-Za-z0-9\-]+$', 1, 255)
        self.add_api_object('ChimeWebhookUrl', self.ChimeWebhookUrl)
        self.ConfigurationName = APIObject('ConfigurationName', 'string', r'^[A-Za-z0-9-_]+$', 1, 128)
        self.add_api_object('ConfigurationName', self.ConfigurationName)
        self.CustomerCwLogLevel = APIObject('CustomerCwLogLevel', 'string', r'^(ERROR|INFO|NONE)$', 4, 5)
        self.add_api_object('CustomerCwLogLevel', self.CustomerCwLogLevel)
        self.GuardrailPolicyArn = APIObject('GuardrailPolicyArn', 'string', r'^(^$|(?!.*\/aws-service-role\/.*)arn:aws:iam:[A-Za-z0-9_\/.-]{0,63}:[A-Za-z0-9_\/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_\/+=,@.-]{0,1023})$', 11, 1163)
        self.add_api_object('GuardrailPolicyArn', self.GuardrailPolicyArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[a-zA-Z0-9=\/+_.\-,#:\\"{}]{4,1276}$', 1, 1276)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.SlackChannelId = APIObject('SlackChannelId', 'string', r'^[A-Za-z0-9]+$', 1, 255)
        self.add_api_object('SlackChannelId', self.SlackChannelId)
        self.SlackTeamId = APIObject('SlackTeamId', 'string', r'^[0-9A-Z]{1,255}$', 1, 255)
        self.add_api_object('SlackTeamId', self.SlackTeamId)
        self.SlackUserId = APIObject('SlackUserId', 'string', r'^(.*)$', 1, 255)
        self.add_api_object('SlackUserId', self.SlackUserId)
        self.TeamName = APIObject('TeamName', 'string', r'^(.*)$', 1, 255)
        self.add_api_object('TeamName', self.TeamName)
        self.TeamsChannelId = APIObject('TeamsChannelId', 'string', r'^([a-zA-Z0-9-_=+\/.,])*%3[aA]([a-zA-Z0-9-_=+\/.,])*%40([a-zA-Z0-9-_=+\/.,])*$', 1, 255)
        self.add_api_object('TeamsChannelId', self.TeamsChannelId)
        self.TeamsChannelName = APIObject('TeamsChannelName', 'string', r'^(.*)$', 1, 1000)
        self.add_api_object('TeamsChannelName', self.TeamsChannelName)
        self.UUID = APIObject('UUID', 'string', r'^[0-9A-Fa-f]{8}(?:-[0-9A-Fa-f]{4}){3}-[0-9A-Fa-f]{12}$', 36, 36)
        self.add_api_object('UUID', self.UUID)

class ChimeSdkIdentity(Service):
    def __init__(self):
        super().__init__('ChimeSdkIdentity')
        self.ChimeArn = APIObject('ChimeArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 5, 1600)
        self.add_api_object('ChimeArn', self.ChimeArn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[-_a-zA-Z0-9]*', 2, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.LexBotAliasArn = APIObject('LexBotAliasArn', 'string', r'arn:aws:lex:[a-z]{2}-[a-z]+-\d{1}:\d{12}:bot-alias/[A-Z0-9]{10}/[A-Z0-9]{10}', 15, 2048)
        self.add_api_object('LexBotAliasArn', self.LexBotAliasArn)
        self.LexIntentName = APIObject('LexIntentName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('LexIntentName', self.LexIntentName)
        self.Metadata = APIObject('Metadata', 'string', r'.*', 0, 1024)
        self.add_api_object('Metadata', self.Metadata)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NonEmptyResourceName = APIObject('NonEmptyResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 256)
        self.add_api_object('NonEmptyResourceName', self.NonEmptyResourceName)
        self.NonEmptySensitiveString1600 = APIObject('NonEmptySensitiveString1600', 'string', r'.*', 1, 1600)
        self.add_api_object('NonEmptySensitiveString1600', self.NonEmptySensitiveString1600)
        self.ResourceName = APIObject('ResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 256)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SensitiveChimeArn = APIObject('SensitiveChimeArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 5, 1600)
        self.add_api_object('SensitiveChimeArn', self.SensitiveChimeArn)
        self.SensitiveString1600 = APIObject('SensitiveString1600', 'string', r'.*', 0, 1600)
        self.add_api_object('SensitiveString1600', self.SensitiveString1600)
        self.String1600 = APIObject('String1600', 'string', r'.*', 0, 1600)
        self.add_api_object('String1600', self.String1600)
        self.String64 = APIObject('String64', 'string', r'.*', 0, 64)
        self.add_api_object('String64', self.String64)
        self.UserId = APIObject('UserId', 'string', r'[A-Za-z0-9]([A-Za-z0-9\:\-\_\.\@]{0,62}[A-Za-z0-9])?', 1, 64)
        self.add_api_object('UserId', self.UserId)
        self.UserName = APIObject('UserName', 'string', r'.*\S.*', 1, 100)
        self.add_api_object('UserName', self.UserName)

class ChimeSdkMediaPipelines(Service):
    def __init__(self):
        super().__init__('ChimeSdkMediaPipelines')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn[\/\:\-\_\.a-zA-Z0-9]+$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.Arn = APIObject('Arn', 'string', r'^arn[\/\:\-\_\.a-zA-Z0-9]+$', 1, 1024)
        self.add_api_object('Arn', self.Arn)
        self.AudioSampleRateOption = APIObject('AudioSampleRateOption', 'string', r'44100|48000', None, None)
        self.add_api_object('AudioSampleRateOption', self.AudioSampleRateOption)
        self.AwsRegion = APIObject('AwsRegion', 'string', r'^([a-z]+-){2,}\d+$', 1, 32)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.CategoryName = APIObject('CategoryName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('CategoryName', self.CategoryName)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[-_a-zA-Z0-9]*', 2, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.FragmentNumberString = APIObject('FragmentNumberString', 'string', r'^[0-9]+$', 1, 128)
        self.add_api_object('FragmentNumberString', self.FragmentNumberString)
        self.GuidString = APIObject('GuidString', 'string', r'[a-fA-F0-9]{8}(?:-[a-fA-F0-9]{4}){3}-[a-fA-F0-9]{12}', 36, 36)
        self.add_api_object('GuidString', self.GuidString)
        self.Keyword = APIObject('Keyword', 'string', r'^[\s0-9a-zA-Z\'-]+', 1, 100)
        self.add_api_object('Keyword', self.Keyword)
        self.KinesisVideoStreamArn = APIObject('KinesisVideoStreamArn', 'string', r'arn:[a-z\d-]+:kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+', 1, 1024)
        self.add_api_object('KinesisVideoStreamArn', self.KinesisVideoStreamArn)
        self.KinesisVideoStreamPoolId = APIObject('KinesisVideoStreamPoolId', 'string', r'^[0-9a-zA-Z._-]+', 1, 256)
        self.add_api_object('KinesisVideoStreamPoolId', self.KinesisVideoStreamPoolId)
        self.KinesisVideoStreamPoolName = APIObject('KinesisVideoStreamPoolName', 'string', r'^[0-9a-zA-Z._-]+', 1, 128)
        self.add_api_object('KinesisVideoStreamPoolName', self.KinesisVideoStreamPoolName)
        self.LanguageOptions = APIObject('LanguageOptions', 'string', r'^[a-zA-Z-,]+', 1, 200)
        self.add_api_object('LanguageOptions', self.LanguageOptions)
        self.MediaInsightsPipelineConfigurationNameString = APIObject('MediaInsightsPipelineConfigurationNameString', 'string', r'^[0-9a-zA-Z._-]+', 2, 64)
        self.add_api_object('MediaInsightsPipelineConfigurationNameString', self.MediaInsightsPipelineConfigurationNameString)
        self.ModelName = APIObject('ModelName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('ModelName', self.ModelName)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, 1024)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.PiiEntityTypes = APIObject('PiiEntityTypes', 'string', r'^[A-Z_, ]+', 1, 300)
        self.add_api_object('PiiEntityTypes', self.PiiEntityTypes)
        self.RuleName = APIObject('RuleName', 'string', r'^[0-9a-zA-Z._-]+', 2, 64)
        self.add_api_object('RuleName', self.RuleName)
        self.String = APIObject('String', 'string', r'.*', None, 4096)
        self.add_api_object('String', self.String)
        self.TileAspectRatio = APIObject('TileAspectRatio', 'string', r'^\d{1,2}\/\d{1,2}$', None, None)
        self.add_api_object('TileAspectRatio', self.TileAspectRatio)
        self.VocabularyFilterName = APIObject('VocabularyFilterName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('VocabularyFilterName', self.VocabularyFilterName)
        self.VocabularyFilterNames = APIObject('VocabularyFilterNames', 'string', r'^[a-zA-Z0-9,-._]+', 1, 3000)
        self.add_api_object('VocabularyFilterNames', self.VocabularyFilterNames)
        self.VocabularyName = APIObject('VocabularyName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('VocabularyName', self.VocabularyName)
        self.VocabularyNames = APIObject('VocabularyNames', 'string', r'^[a-zA-Z0-9,-._]+', 1, 3000)
        self.add_api_object('VocabularyNames', self.VocabularyNames)

class ChimeSdkMeetings(Service):
    def __init__(self):
        super().__init__('ChimeSdkMeetings')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:.*', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.Arn = APIObject('Arn', 'string', r'^arn[\/\:\-\_\.a-zA-Z0-9]+$', 1, 1024)
        self.add_api_object('Arn', self.Arn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[-_a-zA-Z0-9]*', 2, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.GuidString = APIObject('GuidString', 'string', r'[a-fA-F0-9]{8}(?:-[a-fA-F0-9]{4}){3}-[a-fA-F0-9]{12}', None, None)
        self.add_api_object('GuidString', self.GuidString)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\w+-=\.:/@]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TenantId = APIObject('TenantId', 'string', r'^(?!.*?(.)\1{3})[-_!@#$a-zA-Z0-9]*$', 2, 256)
        self.add_api_object('TenantId', self.TenantId)
        self.TranscribeLanguageModelName = APIObject('TranscribeLanguageModelName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('TranscribeLanguageModelName', self.TranscribeLanguageModelName)
        self.TranscribeLanguageOptions = APIObject('TranscribeLanguageOptions', 'string', r'^[a-zA-Z-,]+', 1, 200)
        self.add_api_object('TranscribeLanguageOptions', self.TranscribeLanguageOptions)
        self.TranscribePiiEntityTypes = APIObject('TranscribePiiEntityTypes', 'string', r'^[A-Z_, ]+', 1, 300)
        self.add_api_object('TranscribePiiEntityTypes', self.TranscribePiiEntityTypes)
        self.TranscribeVocabularyNamesOrFilterNamesString = APIObject('TranscribeVocabularyNamesOrFilterNamesString', 'string', r'^[a-zA-Z0-9,-._]+', 1, 3000)
        self.add_api_object('TranscribeVocabularyNamesOrFilterNamesString', self.TranscribeVocabularyNamesOrFilterNamesString)

class ChimeSdkMessaging(Service):
    def __init__(self):
        super().__init__('ChimeSdkMessaging')
        self.ChannelId = APIObject('ChannelId', 'string', r'[A-Za-z0-9]([A-Za-z0-9\:\-\_\.\@]{0,62}[A-Za-z0-9])?', 1, 64)
        self.add_api_object('ChannelId', self.ChannelId)
        self.ChimeArn = APIObject('ChimeArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 5, 1600)
        self.add_api_object('ChimeArn', self.ChimeArn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[-_a-zA-Z0-9]*', 2, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.Content = APIObject('Content', 'string', r'[\s\S]*', 0, 4096)
        self.add_api_object('Content', self.Content)
        self.ContentType = APIObject('ContentType', 'string', r'[\s\S]*', 0, 45)
        self.add_api_object('ContentType', self.ContentType)
        self.FilterRule = APIObject('FilterRule', 'string', r'[\s\S]*', 1, None)
        self.add_api_object('FilterRule', self.FilterRule)
        self.LambdaFunctionArn = APIObject('LambdaFunctionArn', 'string', r'arn:aws:lambda:[a-z]{2}-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9\-_\.]+(:(\$LATEST|[a-zA-Z0-9\-_]+))?', 15, 2048)
        self.add_api_object('LambdaFunctionArn', self.LambdaFunctionArn)
        self.MessageAttributeName = APIObject('MessageAttributeName', 'string', r'[\s\S]*', 1, 64)
        self.add_api_object('MessageAttributeName', self.MessageAttributeName)
        self.MessageAttributeStringValue = APIObject('MessageAttributeStringValue', 'string', r'[\s\S]*', 1, 512)
        self.add_api_object('MessageAttributeStringValue', self.MessageAttributeStringValue)
        self.MessageId = APIObject('MessageId', 'string', r'[-_a-zA-Z0-9]*', 1, 128)
        self.add_api_object('MessageId', self.MessageId)
        self.Metadata = APIObject('Metadata', 'string', r'.*', 0, 1024)
        self.add_api_object('Metadata', self.Metadata)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NonEmptyContent = APIObject('NonEmptyContent', 'string', r'[\s\S]*', 1, None)
        self.add_api_object('NonEmptyContent', self.NonEmptyContent)
        self.NonEmptyResourceName = APIObject('NonEmptyResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 256)
        self.add_api_object('NonEmptyResourceName', self.NonEmptyResourceName)
        self.PushNotificationBody = APIObject('PushNotificationBody', 'string', r'[\s\S]*', 1, 150)
        self.add_api_object('PushNotificationBody', self.PushNotificationBody)
        self.PushNotificationTitle = APIObject('PushNotificationTitle', 'string', r'.*', 1, 50)
        self.add_api_object('PushNotificationTitle', self.PushNotificationTitle)
        self.ResourceName = APIObject('ResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 256)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SearchFieldValue = APIObject('SearchFieldValue', 'string', r'[\s\S]*', 1, 512)
        self.add_api_object('SearchFieldValue', self.SearchFieldValue)
        self.StatusDetail = APIObject('StatusDetail', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('StatusDetail', self.StatusDetail)
        self.SubChannelId = APIObject('SubChannelId', 'string', r'[-_a-zA-Z0-9]*', 1, 128)
        self.add_api_object('SubChannelId', self.SubChannelId)

class ChimeSdkVoice(Service):
    def __init__(self):
        super().__init__('ChimeSdkVoice')
        self.AlexaSkillId = APIObject('AlexaSkillId', 'string', r'amzn1\.application-oa2-client\.[0-9a-fA-F]{32}', None, 64)
        self.add_api_object('AlexaSkillId', self.AlexaSkillId)
        self.Alpha2CountryCode = APIObject('Alpha2CountryCode', 'string', r'[A-Z]{2}', None, None)
        self.add_api_object('Alpha2CountryCode', self.Alpha2CountryCode)
        self.AreaCode = APIObject('AreaCode', 'string', r'^$|^[0-9]{3,3}$', None, None)
        self.add_api_object('AreaCode', self.AreaCode)
        self.Arn = APIObject('Arn', 'string', r'^arn[\/\:\-\_\.a-zA-Z0-9]+$', 1, 1024)
        self.add_api_object('Arn', self.Arn)
        self.CallingName = APIObject('CallingName', 'string', r'^$|^[a-zA-Z0-9 ]{2,15}$', None, None)
        self.add_api_object('CallingName', self.CallingName)
        self.ClientRequestId = APIObject('ClientRequestId', 'string', r'^[-_a-zA-Z0-9]*${2,64}$', None, None)
        self.add_api_object('ClientRequestId', self.ClientRequestId)
        self.Country = APIObject('Country', 'string', r'^$|^[A-Z]{2,2}$', None, None)
        self.add_api_object('Country', self.Country)
        self.E164PhoneNumber = APIObject('E164PhoneNumber', 'string', r'^\+?[1-9]\d{1,14}$', None, None)
        self.add_api_object('E164PhoneNumber', self.E164PhoneNumber)
        self.FunctionArn = APIObject('FunctionArn', 'string', r'arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(:(\$LATEST|[a-zA-Z0-9-_]+))?', None, 10000)
        self.add_api_object('FunctionArn', self.FunctionArn)
        self.GuidString = APIObject('GuidString', 'string', r'[a-fA-F0-9]{8}(?:-[a-fA-F0-9]{4}){3}-[a-fA-F0-9]{12}', None, None)
        self.add_api_object('GuidString', self.GuidString)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.NonEmptyString128 = APIObject('NonEmptyString128', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('NonEmptyString128', self.NonEmptyString128)
        self.NonEmptyString256 = APIObject('NonEmptyString256', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('NonEmptyString256', self.NonEmptyString256)
        self.PhoneNumberName = APIObject('PhoneNumberName', 'string', r'^$|^[a-zA-Z0-9\,\.\_\-]+(\s+[a-zA-Z0-9\,\.\_\-]+)*$', 0, 256)
        self.add_api_object('PhoneNumberName', self.PhoneNumberName)
        self.ProxySessionNameString = APIObject('ProxySessionNameString', 'string', r'^$|^[a-zA-Z0-9 ]{0,30}$', None, None)
        self.add_api_object('ProxySessionNameString', self.ProxySessionNameString)
        self.SensitiveNonEmptyString = APIObject('SensitiveNonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('SensitiveNonEmptyString', self.SensitiveNonEmptyString)
        self.SipMediaApplicationName = APIObject('SipMediaApplicationName', 'string', r'[a-zA-Z0-9 _.-]+', 1, 256)
        self.add_api_object('SipMediaApplicationName', self.SipMediaApplicationName)
        self.SipRuleName = APIObject('SipRuleName', 'string', r'[a-zA-Z0-9 _.-]+', 1, 256)
        self.add_api_object('SipRuleName', self.SipRuleName)
        self.TollFreePrefix = APIObject('TollFreePrefix', 'string', r'^8(00|33|44|55|66|77|88)$', 3, 3)
        self.add_api_object('TollFreePrefix', self.TollFreePrefix)
        self.VoiceConnectorGroupName = APIObject('VoiceConnectorGroupName', 'string', r'[a-zA-Z0-9 _.-]+', 1, 256)
        self.add_api_object('VoiceConnectorGroupName', self.VoiceConnectorGroupName)
        self.VoiceConnectorName = APIObject('VoiceConnectorName', 'string', r'[a-zA-Z0-9 _.-]+', 1, 256)
        self.add_api_object('VoiceConnectorName', self.VoiceConnectorName)
        self.VoiceProfileDomainName = APIObject('VoiceProfileDomainName', 'string', r'[a-zA-Z0-9 _.-]+', 1, 256)
        self.add_api_object('VoiceProfileDomainName', self.VoiceProfileDomainName)

class Chime(Service):
    def __init__(self):
        super().__init__('Chime')
        self.AccountName = APIObject('AccountName', 'string', r'.*\S.*', 1, 100)
        self.add_api_object('AccountName', self.AccountName)
        self.Alpha2CountryCode = APIObject('Alpha2CountryCode', 'string', r'[A-Z]{2}', None, None)
        self.add_api_object('Alpha2CountryCode', self.Alpha2CountryCode)
        self.AreaCode = APIObject('AreaCode', 'string', r'^$|^[0-9]{3,3}$', None, None)
        self.add_api_object('AreaCode', self.AreaCode)
        self.Arn = APIObject('Arn', 'string', r'^arn[\/\:\-\_\.a-zA-Z0-9]+$', 1, 1024)
        self.add_api_object('Arn', self.Arn)
        self.CallingName = APIObject('CallingName', 'string', r'^$|^[a-zA-Z0-9 ]{2,15}$', None, None)
        self.add_api_object('CallingName', self.CallingName)
        self.ChimeArn = APIObject('ChimeArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 5, 1600)
        self.add_api_object('ChimeArn', self.ChimeArn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[-_a-zA-Z0-9]*', 2, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.Content = APIObject('Content', 'string', r'[\s\S]*', 0, 4096)
        self.add_api_object('Content', self.Content)
        self.Country = APIObject('Country', 'string', r'^$|^[A-Z]{2,2}$', None, None)
        self.add_api_object('Country', self.Country)
        self.E164PhoneNumber = APIObject('E164PhoneNumber', 'string', r'^\+?[1-9]\d{1,14}$', None, None)
        self.add_api_object('E164PhoneNumber', self.E164PhoneNumber)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'.+@.+\..+', None, None)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.FunctionArn = APIObject('FunctionArn', 'string', r'arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(:(\$LATEST|[a-zA-Z0-9-_]+))?', None, 10000)
        self.add_api_object('FunctionArn', self.FunctionArn)
        self.GuidString = APIObject('GuidString', 'string', r'[a-fA-F0-9]{8}(?:-[a-fA-F0-9]{4}){3}-[a-fA-F0-9]{12}', None, None)
        self.add_api_object('GuidString', self.GuidString)
        self.JoinTokenString = APIObject('JoinTokenString', 'string', r'^[a-zA-Z0-9+/]+$', 2, 2048)
        self.add_api_object('JoinTokenString', self.JoinTokenString)
        self.MessageId = APIObject('MessageId', 'string', r'[-_a-zA-Z0-9]*', 1, 128)
        self.add_api_object('MessageId', self.MessageId)
        self.Metadata = APIObject('Metadata', 'string', r'.*', 0, 1024)
        self.add_api_object('Metadata', self.Metadata)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NonEmptyContent = APIObject('NonEmptyContent', 'string', r'[\s\S]*', 1, None)
        self.add_api_object('NonEmptyContent', self.NonEmptyContent)
        self.NonEmptyResourceName = APIObject('NonEmptyResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 1, 256)
        self.add_api_object('NonEmptyResourceName', self.NonEmptyResourceName)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.NonEmptyString128 = APIObject('NonEmptyString128', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('NonEmptyString128', self.NonEmptyString128)
        self.ProxySessionNameString = APIObject('ProxySessionNameString', 'string', r'^$|^[a-zA-Z0-9 ]{0,30}$', None, None)
        self.add_api_object('ProxySessionNameString', self.ProxySessionNameString)
        self.ResourceName = APIObject('ResourceName', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]*', 0, 256)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SensitiveNonEmptyString = APIObject('SensitiveNonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('SensitiveNonEmptyString', self.SensitiveNonEmptyString)
        self.TollFreePrefix = APIObject('TollFreePrefix', 'string', r'^8(00|33|44|55|66|77|88)$', 3, 3)
        self.add_api_object('TollFreePrefix', self.TollFreePrefix)
        self.TranscribeLanguageModelName = APIObject('TranscribeLanguageModelName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('TranscribeLanguageModelName', self.TranscribeLanguageModelName)
        self.TranscribeLanguageOptions = APIObject('TranscribeLanguageOptions', 'string', r'^[a-zA-Z-,]+', 1, 200)
        self.add_api_object('TranscribeLanguageOptions', self.TranscribeLanguageOptions)
        self.TranscribePiiEntityTypes = APIObject('TranscribePiiEntityTypes', 'string', r'^[A-Z_, ]+', 1, 300)
        self.add_api_object('TranscribePiiEntityTypes', self.TranscribePiiEntityTypes)
        self.TranscribeVocabularyNamesOrFilterNamesString = APIObject('TranscribeVocabularyNamesOrFilterNamesString', 'string', r'^[a-zA-Z0-9,-._]+', 1, 3000)
        self.add_api_object('TranscribeVocabularyNamesOrFilterNamesString', self.TranscribeVocabularyNamesOrFilterNamesString)
        self.UserId = APIObject('UserId', 'string', r'[A-Za-z0-9]([A-Za-z0-9\:\-\_\.\@]{0,62}[A-Za-z0-9])?', 1, 64)
        self.add_api_object('UserId', self.UserId)
        self.UserName = APIObject('UserName', 'string', r'.*\S.*', 1, 100)
        self.add_api_object('UserName', self.UserName)

class Cleanrooms(Service):
    def __init__(self):
        super().__init__('Cleanrooms')
        self.AccountId = APIObject('AccountId', 'string', r'\d+', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AnalysisRuleColumnName = APIObject('AnalysisRuleColumnName', 'string', r'[a-z0-9_](([a-z0-9_ ]+-)*([a-z0-9_ ]+))?', 1, 127)
        self.add_api_object('AnalysisRuleColumnName', self.AnalysisRuleColumnName)
        self.AnalysisTemplateArn = APIObject('AnalysisTemplateArn', 'string', r'arn:aws:cleanrooms:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:membership/[\d\w-]+/analysistemplate/[\d\w-]+', 0, 200)
        self.add_api_object('AnalysisTemplateArn', self.AnalysisTemplateArn)
        self.AnalysisTemplateArnOrQueryWildcard = APIObject('AnalysisTemplateArnOrQueryWildcard', 'string', r'(ANY_QUERY|arn:aws:cleanrooms:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:membership/[\d\w-]+/analysistemplate/[\d\w-]+)', 0, 200)
        self.add_api_object('AnalysisTemplateArnOrQueryWildcard', self.AnalysisTemplateArnOrQueryWildcard)
        self.AnalysisTemplateIdentifier = APIObject('AnalysisTemplateIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('AnalysisTemplateIdentifier', self.AnalysisTemplateIdentifier)
        self.CleanroomsArn = APIObject('CleanroomsArn', 'string', r'arn:aws:cleanrooms:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:[\d\w/-]+', 0, 100)
        self.add_api_object('CleanroomsArn', self.CleanroomsArn)
        self.CollaborationArn = APIObject('CollaborationArn', 'string', r'arn:aws:[\w]+:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:collaboration/[\d\w-]+', 0, 100)
        self.add_api_object('CollaborationArn', self.CollaborationArn)
        self.CollaborationDescription = APIObject('CollaborationDescription', 'string', r'(?!\s*$)[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t\r\n]*', 1, 255)
        self.add_api_object('CollaborationDescription', self.CollaborationDescription)
        self.CollaborationIdentifier = APIObject('CollaborationIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('CollaborationIdentifier', self.CollaborationIdentifier)
        self.CollaborationName = APIObject('CollaborationName', 'string', r'(?!\s*$)[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t]*', 1, 100)
        self.add_api_object('CollaborationName', self.CollaborationName)
        self.ColumnName = APIObject('ColumnName', 'string', r'[a-z0-9_](([a-z0-9_ ]+-)*([a-z0-9_ ]+))?', 0, 128)
        self.add_api_object('ColumnName', self.ColumnName)
        self.ColumnTypeString = APIObject('ColumnTypeString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t]*', 0, 255)
        self.add_api_object('ColumnTypeString', self.ColumnTypeString)
        self.ConfiguredAudienceModelArn = APIObject('ConfiguredAudienceModelArn', 'string', r'arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:configured-audience-model/[-a-zA-Z0-9_/.]+', 20, 2048)
        self.add_api_object('ConfiguredAudienceModelArn', self.ConfiguredAudienceModelArn)
        self.ConfiguredAudienceModelAssociationArn = APIObject('ConfiguredAudienceModelAssociationArn', 'string', r'arn:aws:cleanrooms:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:membership/[\d\w-]+/configuredaudiencemodelassociation/[\d\w-]+', 0, 256)
        self.add_api_object('ConfiguredAudienceModelAssociationArn', self.ConfiguredAudienceModelAssociationArn)
        self.ConfiguredAudienceModelAssociationIdentifier = APIObject('ConfiguredAudienceModelAssociationIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('ConfiguredAudienceModelAssociationIdentifier', self.ConfiguredAudienceModelAssociationIdentifier)
        self.ConfiguredAudienceModelAssociationName = APIObject('ConfiguredAudienceModelAssociationName', 'string', r'(?!\s*$)[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t]*', 1, 100)
        self.add_api_object('ConfiguredAudienceModelAssociationName', self.ConfiguredAudienceModelAssociationName)
        self.ConfiguredTableArn = APIObject('ConfiguredTableArn', 'string', r'arn:aws:[\w]+:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:configuredtable/[\d\w-]+', 0, 100)
        self.add_api_object('ConfiguredTableArn', self.ConfiguredTableArn)
        self.ConfiguredTableAssociationArn = APIObject('ConfiguredTableAssociationArn', 'string', r'arn:aws:[\w]+:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:configuredtableassociation/[\d\w-]+/[\d\w-]+', 0, 100)
        self.add_api_object('ConfiguredTableAssociationArn', self.ConfiguredTableAssociationArn)
        self.ConfiguredTableAssociationIdentifier = APIObject('ConfiguredTableAssociationIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('ConfiguredTableAssociationIdentifier', self.ConfiguredTableAssociationIdentifier)
        self.ConfiguredTableIdentifier = APIObject('ConfiguredTableIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('ConfiguredTableIdentifier', self.ConfiguredTableIdentifier)
        self.DisplayName = APIObject('DisplayName', 'string', r'(?!\s*$)[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t]*', 1, 100)
        self.add_api_object('DisplayName', self.DisplayName)
        self.GlueDatabaseName = APIObject('GlueDatabaseName', 'string', r'[a-zA-Z0-9_](([a-zA-Z0-9_]+-)*([a-zA-Z0-9_]+))?', 0, 128)
        self.add_api_object('GlueDatabaseName', self.GlueDatabaseName)
        self.GlueTableName = APIObject('GlueTableName', 'string', r'[a-zA-Z0-9_](([a-zA-Z0-9_ ]+-)*([a-zA-Z0-9_ ]+))?', 0, 128)
        self.add_api_object('GlueTableName', self.GlueTableName)
        self.KeyPrefix = APIObject('KeyPrefix', 'string', r'[\w!.=*/-]*', 0, 512)
        self.add_api_object('KeyPrefix', self.KeyPrefix)
        self.MembershipArn = APIObject('MembershipArn', 'string', r'arn:aws:[\w]+:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:membership/[\d\w-]+', 0, 100)
        self.add_api_object('MembershipArn', self.MembershipArn)
        self.MembershipIdentifier = APIObject('MembershipIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('MembershipIdentifier', self.MembershipIdentifier)
        self.ParameterName = APIObject('ParameterName', 'string', r'[0-9a-zA-Z_]+', 1, 100)
        self.add_api_object('ParameterName', self.ParameterName)
        self.PrivacyBudgetTemplateArn = APIObject('PrivacyBudgetTemplateArn', 'string', r'arn:aws:[\w]+:[\w]{2}-[\w]{4,9}-[\d]:[\d]{12}:privacybudgettemplate/[\d\w-]+', 0, 100)
        self.add_api_object('PrivacyBudgetTemplateArn', self.PrivacyBudgetTemplateArn)
        self.PrivacyBudgetTemplateIdentifier = APIObject('PrivacyBudgetTemplateIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('PrivacyBudgetTemplateIdentifier', self.PrivacyBudgetTemplateIdentifier)
        self.ProtectedQueryIdentifier = APIObject('ProtectedQueryIdentifier', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('ProtectedQueryIdentifier', self.ProtectedQueryIdentifier)
        self.ProtectedQueryS3OutputConfigurationBucketString = APIObject('ProtectedQueryS3OutputConfigurationBucketString', 'string', r'.*(?!^(\d+\.)+\d+$)(^(([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])\.)*([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])$).*', 3, 63)
        self.add_api_object('ProtectedQueryS3OutputConfigurationBucketString', self.ProtectedQueryS3OutputConfigurationBucketString)
        self.ResourceAlias = APIObject('ResourceAlias', 'string', r'[a-zA-Z0-9_](([a-zA-Z0-9_ ]+-)*([a-zA-Z0-9_ ]+))?', 0, 128)
        self.add_api_object('ResourceAlias', self.ResourceAlias)
        self.ResourceDescription = APIObject('ResourceDescription', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t\r\n]*', 0, 255)
        self.add_api_object('ResourceDescription', self.ResourceDescription)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam::[\w]+:role/[\w+=./@-]+', 32, 512)
        self.add_api_object('RoleArn', self.RoleArn)
        self.TableAlias = APIObject('TableAlias', 'string', r'[a-zA-Z0-9_](([a-zA-Z0-9_ ]+-)*([a-zA-Z0-9_ ]+))?', 0, 128)
        self.add_api_object('TableAlias', self.TableAlias)
        self.TableDescription = APIObject('TableDescription', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t\r\n]*', 0, 255)
        self.add_api_object('TableDescription', self.TableDescription)
        self.UUID = APIObject('UUID', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('UUID', self.UUID)

class Cleanroomsml(Service):
    def __init__(self):
        super().__init__('Cleanroomsml')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AudienceGenerationJobArn = APIObject('AudienceGenerationJobArn', 'string', r'^arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:audience-generation-job/[-a-zA-Z0-9_/.]+$', 20, 2048)
        self.add_api_object('AudienceGenerationJobArn', self.AudienceGenerationJobArn)
        self.AudienceModelArn = APIObject('AudienceModelArn', 'string', r'^arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:audience-model/[-a-zA-Z0-9_/.]+$', 20, 2048)
        self.add_api_object('AudienceModelArn', self.AudienceModelArn)
        self.ColumnName = APIObject('ColumnName', 'string', r'^[a-zA-Z0-9_](([a-zA-Z0-9_ ]+-)*([a-zA-Z0-9_ ]+))?$', 1, 128)
        self.add_api_object('ColumnName', self.ColumnName)
        self.ConfiguredAudienceModelArn = APIObject('ConfiguredAudienceModelArn', 'string', r'^arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:configured-audience-model/[-a-zA-Z0-9_/.]+$', 20, 2048)
        self.add_api_object('ConfiguredAudienceModelArn', self.ConfiguredAudienceModelArn)
        self.GlueDatabaseName = APIObject('GlueDatabaseName', 'string', r'^[a-zA-Z0-9_](([a-zA-Z0-9_]+-)*([a-zA-Z0-9_]+))?$', 1, 128)
        self.add_api_object('GlueDatabaseName', self.GlueDatabaseName)
        self.GlueTableName = APIObject('GlueTableName', 'string', r'^[a-zA-Z0-9_](([a-zA-Z0-9_ ]+-)*([a-zA-Z0-9_ ]+))?$', 1, 128)
        self.add_api_object('GlueTableName', self.GlueTableName)
        self.Hash = APIObject('Hash', 'string', r'^[0-9a-f]+$', 64, 128)
        self.add_api_object('Hash', self.Hash)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:aws[-a-z]*:iam::[0-9]{12}:role/.+$', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws[-a-z]*:kms:[-a-z0-9]+:[0-9]{12}:key/.+$', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.NameString = APIObject('NameString', 'string', r'^(?!\s*$)[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t]*$', 1, 63)
        self.add_api_object('NameString', self.NameString)
        self.ResourceDescription = APIObject('ResourceDescription', 'string', r'^[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\t\r\n]*$', 0, 255)
        self.add_api_object('ResourceDescription', self.ResourceDescription)
        self.S3Path = APIObject('S3Path', 'string', r'^s3://.+$', 1, 1285)
        self.add_api_object('S3Path', self.S3Path)
        self.TaggableArn = APIObject('TaggableArn', 'string', r'^arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:(training-dataset|audience-model|configured-audience-model|audience-generation-job)/[-a-zA-Z0-9_/.]+$', 20, 2048)
        self.add_api_object('TaggableArn', self.TaggableArn)
        self.TrainingDatasetArn = APIObject('TrainingDatasetArn', 'string', r'^arn:aws[-a-z]*:cleanrooms-ml:[-a-z0-9]+:[0-9]{12}:training-dataset/[-a-zA-Z0-9_/.]+$', 20, 2048)
        self.add_api_object('TrainingDatasetArn', self.TrainingDatasetArn)
        self.UUID = APIObject('UUID', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', 36, 36)
        self.add_api_object('UUID', self.UUID)

class Cloud9(Service):
    def __init__(self):
        super().__init__('Cloud9')
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[\x20-\x7E]{10,128}', None, None)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.EnvironmentArn = APIObject('EnvironmentArn', 'string', r'arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):cloud9:([a-z]{2}-[a-z]+-\d{1}):[0-9]{12}:environment:[a-zA-Z0-9]{8,32}', None, None)
        self.add_api_object('EnvironmentArn', self.EnvironmentArn)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'^[a-zA-Z0-9]{8,32}$', None, None)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.InstanceType = APIObject('InstanceType', 'string', r'^[a-z]+[1-9][.][a-z0-9]+$', 5, 20)
        self.add_api_object('InstanceType', self.InstanceType)
        self.SubnetId = APIObject('SubnetId', 'string', r'^(subnet-[0-9a-f]{8}|subnet-[0-9a-f]{17})$', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.UserArn = APIObject('UserArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):(iam|sts)::\d+:(root|(user\/[\w+=/:,.@-]{1,64}|federated-user\/[\w+=/:,.@-]{2,32}|assumed-role\/[\w+=:,.@-]{1,64}\/[\w+=,.@-]{1,64}))$', None, None)
        self.add_api_object('UserArn', self.UserArn)

class Cloudcontrol(Service):
    def __init__(self):
        super().__init__('Cloudcontrol')
        self.ClientToken = APIObject('ClientToken', 'string', r'[-A-Za-z0-9+/=]+', 1, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'.+', 1, 1024)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.HandlerNextToken = APIObject('HandlerNextToken', 'string', r'.+', 1, 2048)
        self.add_api_object('HandlerNextToken', self.HandlerNextToken)
        self.Identifier = APIObject('Identifier', 'string', r'.+', 1, 1024)
        self.add_api_object('Identifier', self.Identifier)
        self.NextToken = APIObject('NextToken', 'string', r'[-A-Za-z0-9+/=]+', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.PatchDocument = APIObject('PatchDocument', 'string', r'[\s\S]*', 1, 65536)
        self.add_api_object('PatchDocument', self.PatchDocument)
        self.Properties = APIObject('Properties', 'string', r'[\s\S]*', 1, 65536)
        self.add_api_object('Properties', self.Properties)
        self.RequestToken = APIObject('RequestToken', 'string', r'[-A-Za-z0-9+/=]+', 1, 128)
        self.add_api_object('RequestToken', self.RequestToken)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:.+:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.StatusMessage = APIObject('StatusMessage', 'string', r'[\s\S]*', 0, 1024)
        self.add_api_object('StatusMessage', self.StatusMessage)
        self.TypeName = APIObject('TypeName', 'string', r'[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}', 10, 196)
        self.add_api_object('TypeName', self.TypeName)
        self.TypeVersionId = APIObject('TypeVersionId', 'string', r'[A-Za-z0-9-]+', 1, 128)
        self.add_api_object('TypeVersionId', self.TypeVersionId)

class Clouddirectory(Service):
    def __init__(self):
        super().__init__('Clouddirectory')
        self.AttributeName = APIObject('AttributeName', 'string', r'^[a-zA-Z0-9._-]*$', 1, 64)
        self.add_api_object('AttributeName', self.AttributeName)
        self.DirectoryName = APIObject('DirectoryName', 'string', r'^[a-zA-Z0-9._-]*$', 1, 64)
        self.add_api_object('DirectoryName', self.DirectoryName)
        self.FacetName = APIObject('FacetName', 'string', r'^[a-zA-Z0-9._-]*$', 1, 64)
        self.add_api_object('FacetName', self.FacetName)
        self.LinkName = APIObject('LinkName', 'string', r'[^\/\[\]\(\):\{\}#@!?\s\\;]+', 1, 64)
        self.add_api_object('LinkName', self.LinkName)
        self.RuleKey = APIObject('RuleKey', 'string', r'^[a-zA-Z0-9._-]*$', 1, 64)
        self.add_api_object('RuleKey', self.RuleKey)
        self.SchemaName = APIObject('SchemaName', 'string', r'^[a-zA-Z0-9._-]*$', 1, 32)
        self.add_api_object('SchemaName', self.SchemaName)
        self.TypedLinkName = APIObject('TypedLinkName', 'string', r'^[a-zA-Z0-9._-]*$', None, None)
        self.add_api_object('TypedLinkName', self.TypedLinkName)
        self.Version = APIObject('Version', 'string', r'^[a-zA-Z0-9._-]*$', 1, 10)
        self.add_api_object('Version', self.Version)

class Cloudformation(Service):
    def __init__(self):
        super().__init__('Cloudformation')
        self.Account = APIObject('Account', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('Account', self.Account)
        self.AccountsUrl = APIObject('AccountsUrl', 'string', r'(s3://|http(s?)://).+', 1, 5120)
        self.add_api_object('AccountsUrl', self.AccountsUrl)
        self.ChangeSetId = APIObject('ChangeSetId', 'string', r'arn:[-a-zA-Z0-9:/]*', 1, None)
        self.add_api_object('ChangeSetId', self.ChangeSetId)
        self.ChangeSetName = APIObject('ChangeSetName', 'string', r'[a-zA-Z][-a-zA-Z0-9]*', 1, 128)
        self.add_api_object('ChangeSetName', self.ChangeSetName)
        self.ChangeSetNameOrId = APIObject('ChangeSetNameOrId', 'string', r'[a-zA-Z][-a-zA-Z0-9]*|arn:[-a-zA-Z0-9:/]*', 1, 1600)
        self.add_api_object('ChangeSetNameOrId', self.ChangeSetNameOrId)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[a-zA-Z0-9][-a-zA-Z0-9]*', 1, 128)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.ConfigurationSchema = APIObject('ConfigurationSchema', 'string', r'[\s\S]+', 1, 60000)
        self.add_api_object('ConfigurationSchema', self.ConfigurationSchema)
        self.ConnectionArn = APIObject('ConnectionArn', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 1, 256)
        self.add_api_object('ConnectionArn', self.ConnectionArn)
        self.ExecutionRoleName = APIObject('ExecutionRoleName', 'string', r'[a-zA-Z_0-9+=,.@-]+', 1, 64)
        self.add_api_object('ExecutionRoleName', self.ExecutionRoleName)
        self.HookTargetTypeName = APIObject('HookTargetTypeName', 'string', r'^[a-zA-Z0-9]{2,64}::[a-zA-Z0-9]{2,64}::[a-zA-Z0-9]{2,64}$', 1, 256)
        self.add_api_object('HookTargetTypeName', self.HookTargetTypeName)
        self.HookTypeConfigurationVersionId = APIObject('HookTypeConfigurationVersionId', 'string', r'[A-Za-z0-9-]+', 1, 128)
        self.add_api_object('HookTypeConfigurationVersionId', self.HookTypeConfigurationVersionId)
        self.HookTypeVersionId = APIObject('HookTypeVersionId', 'string', r'[A-Za-z0-9-]+', 1, 128)
        self.add_api_object('HookTypeVersionId', self.HookTypeVersionId)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.OperationResultFilterValues = APIObject('OperationResultFilterValues', 'string', r'^\S{6,9}$', 6, 9)
        self.add_api_object('OperationResultFilterValues', self.OperationResultFilterValues)
        self.OrganizationalUnitId = APIObject('OrganizationalUnitId', 'string', r'^(ou-[a-z0-9]{4,32}-[a-z0-9]{8,32}|r-[a-z0-9]{4,32})$', None, None)
        self.add_api_object('OrganizationalUnitId', self.OrganizationalUnitId)
        self.PrivateTypeArn = APIObject('PrivateTypeArn', 'string', r'arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}:[0-9]{12}:type/.+', None, 1024)
        self.add_api_object('PrivateTypeArn', self.PrivateTypeArn)
        self.PublicVersionNumber = APIObject('PublicVersionNumber', 'string', r'^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(.*)$', 5, None)
        self.add_api_object('PublicVersionNumber', self.PublicVersionNumber)
        self.PublisherId = APIObject('PublisherId', 'string', r'[0-9a-zA-Z]{12,40}', 1, 40)
        self.add_api_object('PublisherId', self.PublisherId)
        self.PublisherName = APIObject('PublisherName', 'string', r'[\s\S]+', 1, 100)
        self.add_api_object('PublisherName', self.PublisherName)
        self.PublisherProfile = APIObject('PublisherProfile', 'string', r'(http:|https:)+[^\s]+[\w]', None, 1024)
        self.add_api_object('PublisherProfile', self.PublisherProfile)
        self.Region = APIObject('Region', 'string', r'^[a-zA-Z0-9-]{1,128}$', None, None)
        self.add_api_object('Region', self.Region)
        self.RegistrationToken = APIObject('RegistrationToken', 'string', r'[a-zA-Z0-9][-a-zA-Z0-9]*', 1, 128)
        self.add_api_object('RegistrationToken', self.RegistrationToken)
        self.RequestToken = APIObject('RequestToken', 'string', r'[a-zA-Z0-9][-a-zA-Z0-9]*', 1, 128)
        self.add_api_object('RequestToken', self.RequestToken)
        self.ResourceToSkip = APIObject('ResourceToSkip', 'string', r'[a-zA-Z0-9]+|[a-zA-Z][-a-zA-Z0-9]*\.[a-zA-Z0-9]+', None, None)
        self.add_api_object('ResourceToSkip', self.ResourceToSkip)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:.+:iam::[0-9]{12}:role/.+', 1, 256)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[\s\S]+', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.StackIdsUrl = APIObject('StackIdsUrl', 'string', r'(s3://|http(s?)://).+', 1, 5120)
        self.add_api_object('StackIdsUrl', self.StackIdsUrl)
        self.StackInstanceFilterValues = APIObject('StackInstanceFilterValues', 'string', r'^\S{1,128}$', 1, 128)
        self.add_api_object('StackInstanceFilterValues', self.StackInstanceFilterValues)
        self.StackNameOrId = APIObject('StackNameOrId', 'string', r'([a-zA-Z][-a-zA-Z0-9]*)|(arn:\b(aws|aws-us-gov|aws-cn)\b:[-a-zA-Z0-9:/._+]*)', 1, None)
        self.add_api_object('StackNameOrId', self.StackNameOrId)
        self.StackSetNameOrId = APIObject('StackSetNameOrId', 'string', r'[a-zA-Z][-a-zA-Z0-9]*(?::[a-zA-Z0-9]{8}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{12})?', None, None)
        self.add_api_object('StackSetNameOrId', self.StackSetNameOrId)
        self.ThirdPartyTypeArn = APIObject('ThirdPartyTypeArn', 'string', r'arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}::type/.+/[0-9a-zA-Z]{12,40}/.+', None, 1024)
        self.add_api_object('ThirdPartyTypeArn', self.ThirdPartyTypeArn)
        self.TypeArn = APIObject('TypeArn', 'string', r'arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}:([0-9]{12})?:type/.+', None, 1024)
        self.add_api_object('TypeArn', self.TypeArn)
        self.TypeConfiguration = APIObject('TypeConfiguration', 'string', r'[\s\S]+', 1, 204800)
        self.add_api_object('TypeConfiguration', self.TypeConfiguration)
        self.TypeConfigurationAlias = APIObject('TypeConfigurationAlias', 'string', r'^[a-zA-Z0-9]{1,256}$', 1, 256)
        self.add_api_object('TypeConfigurationAlias', self.TypeConfigurationAlias)
        self.TypeConfigurationArn = APIObject('TypeConfigurationArn', 'string', r'arn:aws[A-Za-z0-9-]{0,64}:cloudformation:[A-Za-z0-9-]{1,64}:([0-9]{12})?:type-configuration/.+', None, 1024)
        self.add_api_object('TypeConfigurationArn', self.TypeConfigurationArn)
        self.TypeName = APIObject('TypeName', 'string', r'[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}::[A-Za-z0-9]{2,64}(::MODULE){0,1}', 10, 204)
        self.add_api_object('TypeName', self.TypeName)
        self.TypeNamePrefix = APIObject('TypeNamePrefix', 'string', r'([A-Za-z0-9]{2,64}::){0,2}([A-Za-z0-9]{2,64}:?){0,1}', 1, 204)
        self.add_api_object('TypeNamePrefix', self.TypeNamePrefix)
        self.TypeTestsStatusDescription = APIObject('TypeTestsStatusDescription', 'string', r'[\s\S]+', 1, 1024)
        self.add_api_object('TypeTestsStatusDescription', self.TypeTestsStatusDescription)
        self.TypeVersionId = APIObject('TypeVersionId', 'string', r'[A-Za-z0-9-]+', 1, 128)
        self.add_api_object('TypeVersionId', self.TypeVersionId)

class CloudfrontKeyvaluestore(Service):
    def __init__(self):
        super().__init__('CloudfrontKeyvaluestore')

class Cloudfront(Service):
    def __init__(self):
        super().__init__('Cloudfront')

class Cloudhsm(Service):
    def __init__(self):
        super().__init__('Cloudhsm')
        self.AZ = APIObject('AZ', 'string', r'[a-zA-Z0-9\-]*', None, None)
        self.add_api_object('AZ', self.AZ)
        self.Certificate = APIObject('Certificate', 'string', r'[\w :+=./\n-]*', 600, 2400)
        self.add_api_object('Certificate', self.Certificate)
        self.CertificateFingerprint = APIObject('CertificateFingerprint', 'string', r'([0-9a-fA-F][0-9a-fA-F]:){15}[0-9a-fA-F][0-9a-fA-F]', None, None)
        self.add_api_object('CertificateFingerprint', self.CertificateFingerprint)
        self.ClientArn = APIObject('ClientArn', 'string', r'arn:aws(-iso)?:cloudhsm:[a-zA-Z0-9\-]*:[0-9]{12}:client-[0-9a-f]{8}', None, None)
        self.add_api_object('ClientArn', self.ClientArn)
        self.ClientLabel = APIObject('ClientLabel', 'string', r'[a-zA-Z0-9_.-]{2,64}', None, None)
        self.add_api_object('ClientLabel', self.ClientLabel)
        self.ClientToken = APIObject('ClientToken', 'string', r'[a-zA-Z0-9]{1,64}', None, None)
        self.add_api_object('ClientToken', self.ClientToken)
        self.EniId = APIObject('EniId', 'string', r'eni-[0-9a-f]{8}', None, None)
        self.add_api_object('EniId', self.EniId)
        self.ExternalId = APIObject('ExternalId', 'string', r'[\w :+=./-]*', None, None)
        self.add_api_object('ExternalId', self.ExternalId)
        self.HapgArn = APIObject('HapgArn', 'string', r'arn:aws(-iso)?:cloudhsm:[a-zA-Z0-9\-]*:[0-9]{12}:hapg-[0-9a-f]{8}', None, None)
        self.add_api_object('HapgArn', self.HapgArn)
        self.HsmArn = APIObject('HsmArn', 'string', r'arn:aws(-iso)?:cloudhsm:[a-zA-Z0-9\-]*:[0-9]{12}:hsm-[0-9a-f]{8}', None, None)
        self.add_api_object('HsmArn', self.HsmArn)
        self.HsmSerialNumber = APIObject('HsmSerialNumber', 'string', r'\d{1,16}', None, None)
        self.add_api_object('HsmSerialNumber', self.HsmSerialNumber)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-iso)?:iam::[0-9]{12}:role/[a-zA-Z0-9_\+=,\.\-@]{1,64}', None, None)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IpAddress = APIObject('IpAddress', 'string', r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', None, None)
        self.add_api_object('IpAddress', self.IpAddress)
        self.Label = APIObject('Label', 'string', r'[a-zA-Z0-9_.-]{1,64}', None, None)
        self.add_api_object('Label', self.Label)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[a-zA-Z0-9+/]*', None, None)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PartitionArn = APIObject('PartitionArn', 'string', r'arn:aws(-iso)?:cloudhsm:[a-zA-Z0-9\-]*:[0-9]{12}:hsm-[0-9a-f]{8}/partition-[0-9]{6,12}', None, None)
        self.add_api_object('PartitionArn', self.PartitionArn)
        self.PartitionSerial = APIObject('PartitionSerial', 'string', r'\d{6,12}', None, None)
        self.add_api_object('PartitionSerial', self.PartitionSerial)
        self.SshKey = APIObject('SshKey', 'string', r'[a-zA-Z0-9+/= ._:\\@-]*', None, None)
        self.add_api_object('SshKey', self.SshKey)
        self.String = APIObject('String', 'string', r'[\w :+=./\\-]*', None, None)
        self.add_api_object('String', self.String)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-[0-9a-f]{8}', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.Timestamp = APIObject('Timestamp', 'string', r'\d*', None, None)
        self.add_api_object('Timestamp', self.Timestamp)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-[0-9a-f]{8}', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Cloudhsmv2(Service):
    def __init__(self):
        super().__init__('Cloudhsmv2')
        self.BackupId = APIObject('BackupId', 'string', r'backup-[2-7a-zA-Z]{11,16}', None, None)
        self.add_api_object('BackupId', self.BackupId)
        self.BackupRetentionValue = APIObject('BackupRetentionValue', 'string', r'[0-9]+', 1, 3)
        self.add_api_object('BackupRetentionValue', self.BackupRetentionValue)
        self.Cert = APIObject('Cert', 'string', r'[a-zA-Z0-9+-/=\s]*', None, 5000)
        self.add_api_object('Cert', self.Cert)
        self.ClusterId = APIObject('ClusterId', 'string', r'cluster-[2-7a-zA-Z]{11,16}', None, None)
        self.add_api_object('ClusterId', self.ClusterId)
        self.EniId = APIObject('EniId', 'string', r'eni-[0-9a-fA-F]{8,17}', None, None)
        self.add_api_object('EniId', self.EniId)
        self.ExternalAz = APIObject('ExternalAz', 'string', r'[a-z]{2}(-(gov))?-(east|west|north|south|central){1,2}-\d[a-z]', None, None)
        self.add_api_object('ExternalAz', self.ExternalAz)
        self.Field = APIObject('Field', 'string', r'[a-zA-Z0-9_-]+', None, None)
        self.add_api_object('Field', self.Field)
        self.HsmId = APIObject('HsmId', 'string', r'hsm-[2-7a-zA-Z]{11,16}', None, None)
        self.add_api_object('HsmId', self.HsmId)
        self.HsmType = APIObject('HsmType', 'string', r'(hsm1\.medium)', None, None)
        self.add_api_object('HsmType', self.HsmType)
        self.IpAddress = APIObject('IpAddress', 'string', r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', None, None)
        self.add_api_object('IpAddress', self.IpAddress)
        self.NextToken = APIObject('NextToken', 'string', r'.*', None, 256)
        self.add_api_object('NextToken', self.NextToken)
        self.Region = APIObject('Region', 'string', r'[a-z]{2}(-(gov))?-(east|west|north|south|central){1,2}-\d', None, None)
        self.add_api_object('Region', self.Region)
        self.ResourceId = APIObject('ResourceId', 'string', r'(?:cluster|backup)-[2-7a-zA-Z]{11,16}', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SecurityGroup = APIObject('SecurityGroup', 'string', r'sg-[0-9a-fA-F]{8,17}', None, None)
        self.add_api_object('SecurityGroup', self.SecurityGroup)
        self.StateMessage = APIObject('StateMessage', 'string', r'.*', None, 300)
        self.add_api_object('StateMessage', self.StateMessage)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-[0-9a-fA-F]{8,17}', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-[0-9a-fA-F]', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Cloudsearch(Service):
    def __init__(self):
        super().__init__('Cloudsearch')
        self.DomainName = APIObject('DomainName', 'string', r'[a-z][a-z0-9\-]+', 3, 28)
        self.add_api_object('DomainName', self.DomainName)
        self.FieldName = APIObject('FieldName', 'string', r'[a-z][a-z0-9_]*', 1, 64)
        self.add_api_object('FieldName', self.FieldName)
        self.Language = APIObject('Language', 'string', r'[a-zA-Z]{2,8}(?:-[a-zA-Z]{2,8})*', None, None)
        self.add_api_object('Language', self.Language)

class Cloudsearchdomain(Service):
    def __init__(self):
        super().__init__('Cloudsearchdomain')

class CloudtrailData(Service):
    def __init__(self):
        super().__init__('CloudtrailData')
        self.ChannelArn = APIObject('ChannelArn', 'string', r'^arn:.*$', None, None)
        self.add_api_object('ChannelArn', self.ChannelArn)
        self.ExternalId = APIObject('ExternalId', 'string', r'^[\w+=,.@:\/-]*$', 2, 1224)
        self.add_api_object('ExternalId', self.ExternalId)
        self.Uuid = APIObject('Uuid', 'string', r'^[-_A-Za-z0-9]+$', 1, 128)
        self.add_api_object('Uuid', self.Uuid)

class Cloudtrail(Service):
    def __init__(self):
        super().__init__('Cloudtrail')
        self.AccountId = APIObject('AccountId', 'string', r'\d+', 12, 16)
        self.add_api_object('AccountId', self.AccountId)
        self.ChannelArn = APIObject('ChannelArn', 'string', r'^[a-zA-Z0-9._/\-:]+$', 3, 256)
        self.add_api_object('ChannelArn', self.ChannelArn)
        self.ChannelName = APIObject('ChannelName', 'string', r'^[a-zA-Z0-9._\-]+$', 3, 128)
        self.add_api_object('ChannelName', self.ChannelName)
        self.DeliveryS3Uri = APIObject('DeliveryS3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', None, 1024)
        self.add_api_object('DeliveryS3Uri', self.DeliveryS3Uri)
        self.ErrorCode = APIObject('ErrorCode', 'string', r'^[\w\d\s_.,\-:\[\]]+$', None, 128)
        self.add_api_object('ErrorCode', self.ErrorCode)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'.*', 4, 1000)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.EventDataStoreArn = APIObject('EventDataStoreArn', 'string', r'^[a-zA-Z0-9._/\-:]+$', 3, 256)
        self.add_api_object('EventDataStoreArn', self.EventDataStoreArn)
        self.EventDataStoreKmsKeyId = APIObject('EventDataStoreKmsKeyId', 'string', r'^[a-zA-Z0-9._/\-:]+$', 1, 350)
        self.add_api_object('EventDataStoreKmsKeyId', self.EventDataStoreKmsKeyId)
        self.EventDataStoreName = APIObject('EventDataStoreName', 'string', r'^[a-zA-Z0-9._\-]+$', 3, 128)
        self.add_api_object('EventDataStoreName', self.EventDataStoreName)
        self.EventName = APIObject('EventName', 'string', r'^[A-Za-z0-9_]+$', None, 128)
        self.add_api_object('EventName', self.EventName)
        self.EventSource = APIObject('EventSource', 'string', r'^[a-z0-9_-]+\.amazonaws\.com$', None, 256)
        self.add_api_object('EventSource', self.EventSource)
        self.FederationRoleArn = APIObject('FederationRoleArn', 'string', r'^[a-zA-Z0-9._/\-:@=\+,\.]+$', 3, 125)
        self.add_api_object('FederationRoleArn', self.FederationRoleArn)
        self.Location = APIObject('Location', 'string', r'^[a-zA-Z0-9._/\-:]+$', 3, 1024)
        self.add_api_object('Location', self.Location)
        self.OperatorValue = APIObject('OperatorValue', 'string', r'.+', 1, 2048)
        self.add_api_object('OperatorValue', self.OperatorValue)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'.*', 4, 1000)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.QueryAlias = APIObject('QueryAlias', 'string', r'^[a-zA-Z][a-zA-Z0-9._\-]*$', 1, 256)
        self.add_api_object('QueryAlias', self.QueryAlias)
        self.QueryParameter = APIObject('QueryParameter', 'string', r'.*', 1, 1024)
        self.add_api_object('QueryParameter', self.QueryParameter)
        self.QueryStatement = APIObject('QueryStatement', 'string', r'(?s).*', 1, 10000)
        self.add_api_object('QueryStatement', self.QueryStatement)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^[a-zA-Z0-9._/\-:]+$', 3, 256)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.SelectorField = APIObject('SelectorField', 'string', r'[\w|\d|\.|_]+', 1, 1000)
        self.add_api_object('SelectorField', self.SelectorField)
        self.SelectorName = APIObject('SelectorName', 'string', r'.*', 0, 1000)
        self.add_api_object('SelectorName', self.SelectorName)
        self.Source = APIObject('Source', 'string', r'.*', 1, 256)
        self.add_api_object('Source', self.Source)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9\-]+$', 36, 36)
        self.add_api_object('UUID', self.UUID)

class Cloudwatch(Service):
    def __init__(self):
        super().__init__('Cloudwatch')
        self.AnomalyDetectorMetricStat = APIObject('AnomalyDetectorMetricStat', 'string', r'(SampleCount|Average|Sum|Minimum|Maximum|IQM|(p|tc|tm|ts|wm)(\d{1,2}(\.\d{0,10})?|100)|[ou]\d+(\.\d*)?)(_E|_L|_H)?|(TM|TC|TS|WM)\(((((\d{1,2})(\.\d{0,10})?|100(\.0{0,10})?)%)?:((\d{1,2})(\.\d{0,10})?|100(\.0{0,10})?)%|((\d{1,2})(\.\d{0,10})?|100(\.0{0,10})?)%:(((\d{1,2})(\.\d{0,10})?|100(\.0{0,10})?)%)?)\)|(TM|TC|TS|WM|PR)\(((\d+(\.\d{0,10})?|(\d+(\.\d{0,10})?[Ee][+-]?\d+)):((\d+(\.\d{0,10})?|(\d+(\.\d{0,10})?[Ee][+-]?\d+)))?|((\d+(\.\d{0,10})?|(\d+(\.\d{0,10})?[Ee][+-]?\d+)))?:(\d+(\.\d{0,10})?|(\d+(\.\d{0,10})?[Ee][+-]?\d+)))\)', None, 50)
        self.add_api_object('AnomalyDetectorMetricStat', self.AnomalyDetectorMetricStat)
        self.AnomalyDetectorMetricTimezone = APIObject('AnomalyDetectorMetricTimezone', 'string', r'.*', None, 50)
        self.add_api_object('AnomalyDetectorMetricTimezone', self.AnomalyDetectorMetricTimezone)
        self.InsightRuleDefinition = APIObject('InsightRuleDefinition', 'string', r'[\x00-\x7F]+', 1, 8192)
        self.add_api_object('InsightRuleDefinition', self.InsightRuleDefinition)
        self.InsightRuleMetricName = APIObject('InsightRuleMetricName', 'string', r'[\x20-\x7E]+', 1, 32)
        self.add_api_object('InsightRuleMetricName', self.InsightRuleMetricName)
        self.InsightRuleName = APIObject('InsightRuleName', 'string', r'[\x20-\x7E]+', 1, 128)
        self.add_api_object('InsightRuleName', self.InsightRuleName)
        self.InsightRuleOrderBy = APIObject('InsightRuleOrderBy', 'string', r'[\x20-\x7E]+', 1, 32)
        self.add_api_object('InsightRuleOrderBy', self.InsightRuleOrderBy)
        self.InsightRuleState = APIObject('InsightRuleState', 'string', r'[\x20-\x7E]+', 1, 32)
        self.add_api_object('InsightRuleState', self.InsightRuleState)
        self.Namespace = APIObject('Namespace', 'string', r'[^:].*', 1, 255)
        self.add_api_object('Namespace', self.Namespace)
        self.TemplateName = APIObject('TemplateName', 'string', r'[0-9A-Za-z][\-\.\_0-9A-Za-z]{0,126}[0-9A-Za-z]', 1, 128)
        self.add_api_object('TemplateName', self.TemplateName)

class Codeartifact(Service):
    def __init__(self):
        super().__init__('Codeartifact')
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]{12}', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.Arn = APIObject('Arn', 'string', r'\S+', 1, 1011)
        self.add_api_object('Arn', self.Arn)
        self.AssetName = APIObject('AssetName', 'string', r'\P{C}+', 1, 255)
        self.add_api_object('AssetName', self.AssetName)
        self.Description = APIObject('Description', 'string', r'\P{C}*', None, 1000)
        self.add_api_object('Description', self.Description)
        self.DomainName = APIObject('DomainName', 'string', r'[a-z][a-z0-9\-]{0,48}[a-z0-9]', 2, 50)
        self.add_api_object('DomainName', self.DomainName)
        self.ExternalConnectionName = APIObject('ExternalConnectionName', 'string', r'[A-Za-z0-9][A-Za-z0-9._\-:]{1,99}', 2, 100)
        self.add_api_object('ExternalConnectionName', self.ExternalConnectionName)
        self.HashValue = APIObject('HashValue', 'string', r'[0-9a-f]+', 32, 512)
        self.add_api_object('HashValue', self.HashValue)
        self.PackageGroupContactInfo = APIObject('PackageGroupContactInfo', 'string', r'\P{C}*', 0, 1000)
        self.add_api_object('PackageGroupContactInfo', self.PackageGroupContactInfo)
        self.PackageGroupPattern = APIObject('PackageGroupPattern', 'string', r'[^\p{C}\p{IsWhitespace}]+', 2, 520)
        self.add_api_object('PackageGroupPattern', self.PackageGroupPattern)
        self.PackageGroupPatternPrefix = APIObject('PackageGroupPatternPrefix', 'string', r'\P{C}*', 0, 520)
        self.add_api_object('PackageGroupPatternPrefix', self.PackageGroupPatternPrefix)
        self.PackageName = APIObject('PackageName', 'string', r'[^#/\s]+', 1, 255)
        self.add_api_object('PackageName', self.PackageName)
        self.PackageNamespace = APIObject('PackageNamespace', 'string', r'[^#/\s]+', 1, 255)
        self.add_api_object('PackageNamespace', self.PackageNamespace)
        self.PackageVersion = APIObject('PackageVersion', 'string', r'[^#/\s]+', 1, 255)
        self.add_api_object('PackageVersion', self.PackageVersion)
        self.PackageVersionRevision = APIObject('PackageVersionRevision', 'string', r'\S+', 1, 50)
        self.add_api_object('PackageVersionRevision', self.PackageVersionRevision)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'\S+', 1, 2000)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PolicyDocument = APIObject('PolicyDocument', 'string', r'[\P{C}\s]+', 1, 7168)
        self.add_api_object('PolicyDocument', self.PolicyDocument)
        self.PolicyRevision = APIObject('PolicyRevision', 'string', r'\S+', 1, 100)
        self.add_api_object('PolicyRevision', self.PolicyRevision)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'[A-Za-z0-9][A-Za-z0-9._\-]{1,99}', 2, 100)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.SHA256 = APIObject('SHA256', 'string', r'[0-9a-f]+', 64, 64)
        self.add_api_object('SHA256', self.SHA256)
        self.TagKey = APIObject('TagKey', 'string', r'\P{C}+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'\P{C}*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Codebuild(Service):
    def __init__(self):
        super().__init__('Codebuild')
        self.FleetName = APIObject('FleetName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{1,127}', 2, 128)
        self.add_api_object('FleetName', self.FleetName)
        self.KeyInput = APIObject('KeyInput', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=@+\-]*)$', 1, 127)
        self.add_api_object('KeyInput', self.KeyInput)
        self.ProjectName = APIObject('ProjectName', 'string', r'[A-Za-z0-9][A-Za-z0-9\-_]{1,254}', 2, 255)
        self.add_api_object('ProjectName', self.ProjectName)
        self.ValueInput = APIObject('ValueInput', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=@+\-]*)$', 0, 255)
        self.add_api_object('ValueInput', self.ValueInput)

class Codecatalyst(Service):
    def __init__(self):
        super().__init__('Codecatalyst')
        self.CreateDevEnvironmentRequestAliasString = APIObject('CreateDevEnvironmentRequestAliasString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, 128)
        self.add_api_object('CreateDevEnvironmentRequestAliasString', self.CreateDevEnvironmentRequestAliasString)
        self.GetUserDetailsRequestUserNameString = APIObject('GetUserDetailsRequestUserNameString', 'string', r'[a-zA-Z0-9_.-]{3,100}', 3, 100)
        self.add_api_object('GetUserDetailsRequestUserNameString', self.GetUserDetailsRequestUserNameString)
        self.GetWorkflowRequestProjectNameString = APIObject('GetWorkflowRequestProjectNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('GetWorkflowRequestProjectNameString', self.GetWorkflowRequestProjectNameString)
        self.GetWorkflowRunRequestProjectNameString = APIObject('GetWorkflowRunRequestProjectNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('GetWorkflowRunRequestProjectNameString', self.GetWorkflowRunRequestProjectNameString)
        self.ListWorkflowRunsRequestProjectNameString = APIObject('ListWorkflowRunsRequestProjectNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('ListWorkflowRunsRequestProjectNameString', self.ListWorkflowRunsRequestProjectNameString)
        self.ListWorkflowsRequestSpaceNameString = APIObject('ListWorkflowsRequestSpaceNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('ListWorkflowsRequestSpaceNameString', self.ListWorkflowsRequestSpaceNameString)
        self.NameString = APIObject('NameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 3, 63)
        self.add_api_object('NameString', self.NameString)
        self.ProjectDescription = APIObject('ProjectDescription', 'string', r'[a-zA-Z0-9]+(?:[-_a-zA-Z0-9.,;:/\+=?&$%    ])*', 0, 200)
        self.add_api_object('ProjectDescription', self.ProjectDescription)
        self.ProjectDisplayName = APIObject('ProjectDisplayName', 'string', r'[a-zA-Z0-9]+(?:[-_\. ][a-zA-Z0-9]+)*', 3, 63)
        self.add_api_object('ProjectDisplayName', self.ProjectDisplayName)
        self.RegionString = APIObject('RegionString', 'string', r'(us(?:-gov)?|af|ap|ca|cn|eu|sa)-(central|(?:north|south)?(?:east|west)?)-(\d+)', 3, 16)
        self.add_api_object('RegionString', self.RegionString)
        self.SourceRepositoryIdString = APIObject('SourceRepositoryIdString', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('SourceRepositoryIdString', self.SourceRepositoryIdString)
        self.SourceRepositoryNameString = APIObject('SourceRepositoryNameString', 'string', r'(?!.*[.]git$)[\w\-.]*', 1, 100)
        self.add_api_object('SourceRepositoryNameString', self.SourceRepositoryNameString)
        self.SpaceDescription = APIObject('SpaceDescription', 'string', r'[a-zA-Z0-9]+(?:[-_a-zA-Z0-9.,;:/\+=?&$%    ])*', 0, 200)
        self.add_api_object('SpaceDescription', self.SpaceDescription)
        self.StartWorkflowRunRequestClientTokenString = APIObject('StartWorkflowRunRequestClientTokenString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, 64)
        self.add_api_object('StartWorkflowRunRequestClientTokenString', self.StartWorkflowRunRequestClientTokenString)
        self.StartWorkflowRunRequestProjectNameString = APIObject('StartWorkflowRunRequestProjectNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('StartWorkflowRunRequestProjectNameString', self.StartWorkflowRunRequestProjectNameString)
        self.StartWorkflowRunRequestSpaceNameString = APIObject('StartWorkflowRunRequestSpaceNameString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, None)
        self.add_api_object('StartWorkflowRunRequestSpaceNameString', self.StartWorkflowRunRequestSpaceNameString)
        self.UpdateDevEnvironmentRequestAliasString = APIObject('UpdateDevEnvironmentRequestAliasString', 'string', r'$|^[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 0, 128)
        self.add_api_object('UpdateDevEnvironmentRequestAliasString', self.UpdateDevEnvironmentRequestAliasString)
        self.UpdateDevEnvironmentResponseAliasString = APIObject('UpdateDevEnvironmentResponseAliasString', 'string', r'[a-zA-Z0-9]+(?:[-_\.][a-zA-Z0-9]+)*', 1, 128)
        self.add_api_object('UpdateDevEnvironmentResponseAliasString', self.UpdateDevEnvironmentResponseAliasString)
        self.Uuid = APIObject('Uuid', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('Uuid', self.Uuid)

class Codecommit(Service):
    def __init__(self):
        super().__init__('Codecommit')
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^[a-zA-Z0-9:/_-]+$', None, None)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'[\w\.-]+', 1, 100)
        self.add_api_object('RepositoryName', self.RepositoryName)

class Codeconnections(Service):
    def __init__(self):
        super().__init__('Codeconnections')
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]{12}', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.BranchName = APIObject('BranchName', 'string', r'^.*$', 1, 255)
        self.add_api_object('BranchName', self.BranchName)
        self.ConnectionArn = APIObject('ConnectionArn', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 0, 256)
        self.add_api_object('ConnectionArn', self.ConnectionArn)
        self.ConnectionName = APIObject('ConnectionName', 'string', r'[\s\S]*', 1, 32)
        self.add_api_object('ConnectionName', self.ConnectionName)
        self.HostArn = APIObject('HostArn', 'string', r'arn:aws(-[\w]+)*:(codestar-connections|codeconnections):.+:[0-9]{12}:host\/.+', 0, 256)
        self.add_api_object('HostArn', self.HostArn)
        self.HostName = APIObject('HostName', 'string', r'.*', 1, 64)
        self.add_api_object('HostName', self.HostName)
        self.HostStatus = APIObject('HostStatus', 'string', r'.*', 1, 64)
        self.add_api_object('HostStatus', self.HostStatus)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[\w]+)*:iam::\d{12}:role/[a-zA-Z_0-9+=,.@\-_/]+', 1, 1024)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws(-[\w]+)*:kms:[a-z\-0-9]+:\d{12}:key/[a-zA-Z0-9\-]+', 1, 1024)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.NextToken = APIObject('NextToken', 'string', r'^.*$', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.OwnerId = APIObject('OwnerId', 'string', r'^.*$', 1, 255)
        self.add_api_object('OwnerId', self.OwnerId)
        self.RepositoryLinkArn = APIObject('RepositoryLinkArn', 'string', r'^arn:aws(?:-[a-z]+)*:(codestar-connections|codeconnections):[a-z\-0-9]+:\d{12}:repository-link\/[a-zA-Z0-9\-:/]+', None, None)
        self.add_api_object('RepositoryLinkArn', self.RepositoryLinkArn)
        self.RepositoryLinkId = APIObject('RepositoryLinkId', 'string', r'^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('RepositoryLinkId', self.RepositoryLinkId)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'^.*$', 1, 128)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[0-9A-Za-z]+[0-9A-Za-z_\\-]*$', 1, 100)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'sg-\w{8}(\w{9})?', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SharpNextToken = APIObject('SharpNextToken', 'string', r'^.*$', 1, 2048)
        self.add_api_object('SharpNextToken', self.SharpNextToken)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-\w{8}(\w{9})?', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TlsCertificate = APIObject('TlsCertificate', 'string', r'[\s\S]*', 1, 16384)
        self.add_api_object('TlsCertificate', self.TlsCertificate)
        self.Url = APIObject('Url', 'string', r'.*', 1, 512)
        self.add_api_object('Url', self.Url)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-\w{8}(\w{9})?', 12, 21)
        self.add_api_object('VpcId', self.VpcId)

class Codedeploy(Service):
    def __init__(self):
        super().__init__('Codedeploy')

class CodeguruReviewer(Service):
    def __init__(self):
        super().__init__('CodeguruReviewer')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws[^:\s]*:codeguru-reviewer:[^:\s]+:[\d]{12}:[a-z-]+:[\w-]+$', 1, 1600)
        self.add_api_object('Arn', self.Arn)
        self.AssociationArn = APIObject('AssociationArn', 'string', r'^arn:aws[^:\s]*:codeguru-reviewer:[^:\s]+:[\d]{12}:association:[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 1, 1600)
        self.add_api_object('AssociationArn', self.AssociationArn)
        self.BuildArtifactsObjectKey = APIObject('BuildArtifactsObjectKey', 'string', r'^\S(.*\S)?$', 1, 1024)
        self.add_api_object('BuildArtifactsObjectKey', self.BuildArtifactsObjectKey)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[\w-]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.CodeReviewName = APIObject('CodeReviewName', 'string', r'[a-zA-Z0-9-_]*', 1, 100)
        self.add_api_object('CodeReviewName', self.CodeReviewName)
        self.ConnectionArn = APIObject('ConnectionArn', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 0, 256)
        self.add_api_object('ConnectionArn', self.ConnectionArn)
        self.EventName = APIObject('EventName', 'string', r'^[ \-A-Z_a-z]+$', 1, 32)
        self.add_api_object('EventName', self.EventName)
        self.EventState = APIObject('EventState', 'string', r'^[ \-A-Z_a-z]+$', 1, 32)
        self.add_api_object('EventState', self.EventState)
        self.KMSKeyId = APIObject('KMSKeyId', 'string', r'[a-zA-Z0-9-]+', 1, 2048)
        self.add_api_object('KMSKeyId', self.KMSKeyId)
        self.LongDescription = APIObject('LongDescription', 'string', r'^\S(.*\S)?$', 1, 1000)
        self.add_api_object('LongDescription', self.LongDescription)
        self.Name = APIObject('Name', 'string', r'^\S[\w.-]*$', 1, 100)
        self.add_api_object('Name', self.Name)
        self.Owner = APIObject('Owner', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('Owner', self.Owner)
        self.Requester = APIObject('Requester', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('Requester', self.Requester)
        self.RuleId = APIObject('RuleId', 'string', r'^\S+\/[a-zA-Z0-9-]+@v\d+\.\d+$', 1, 64)
        self.add_api_object('RuleId', self.RuleId)
        self.RuleName = APIObject('RuleName', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('RuleName', self.RuleName)
        self.RuleTag = APIObject('RuleTag', 'string', r'^\S(.*\S)?$', 1, 50)
        self.add_api_object('RuleTag', self.RuleTag)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^\S(.*\S)?$', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.ShortDescription = APIObject('ShortDescription', 'string', r'^\S(.*\S)?$', 1, 200)
        self.add_api_object('ShortDescription', self.ShortDescription)
        self.SourceCodeArtifactsObjectKey = APIObject('SourceCodeArtifactsObjectKey', 'string', r'^\S(.*\S)?$', 1, 1024)
        self.add_api_object('SourceCodeArtifactsObjectKey', self.SourceCodeArtifactsObjectKey)

class CodeguruSecurity(Service):
    def __init__(self):
        super().__init__('CodeguruSecurity')
        self.ClientToken = APIObject('ClientToken', 'string', r'^[\S]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws:kms:[\S]+:[\d]{12}:key\/(([a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})|(mrk-[0-9a-zA-Z]{32}))$', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.NextToken = APIObject('NextToken', 'string', r'^[\S]+$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.ScanName = APIObject('ScanName', 'string', r'^[a-zA-Z0-9-_$:.]*$', 1, 140)
        self.add_api_object('ScanName', self.ScanName)
        self.ScanNameArn = APIObject('ScanNameArn', 'string', r'^arn:aws:codeguru-security:[\S]+:[\d]{12}:scans\/[a-zA-Z0-9-_$:.]*$', 1, 300)
        self.add_api_object('ScanNameArn', self.ScanNameArn)
        self.Uuid = APIObject('Uuid', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('Uuid', self.Uuid)

class Codeguruprofiler(Service):
    def __init__(self):
        super().__init__('Codeguruprofiler')
        self.AnomalyInstanceId = APIObject('AnomalyInstanceId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('AnomalyInstanceId', self.AnomalyInstanceId)
        self.ChannelId = APIObject('ChannelId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('ChannelId', self.ChannelId)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[\w-]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.FindingsReportId = APIObject('FindingsReportId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('FindingsReportId', self.FindingsReportId)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[\w-]+$', 1, 64)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ProfilingGroupName = APIObject('ProfilingGroupName', 'string', r'^[\w-]+$', 1, 255)
        self.add_api_object('ProfilingGroupName', self.ProfilingGroupName)
        self.RevisionId = APIObject('RevisionId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('RevisionId', self.RevisionId)

class Codepipeline(Service):
    def __init__(self):
        super().__init__('Codepipeline')
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.ActionConfigurationQueryableValue = APIObject('ActionConfigurationQueryableValue', 'string', r'[a-zA-Z0-9_-]+', 1, 50)
        self.add_api_object('ActionConfigurationQueryableValue', self.ActionConfigurationQueryableValue)
        self.ActionName = APIObject('ActionName', 'string', r'[A-Za-z0-9.@\-_]+', 1, 100)
        self.add_api_object('ActionName', self.ActionName)
        self.ActionNamespace = APIObject('ActionNamespace', 'string', r'[A-Za-z0-9@\-_]+', 1, 100)
        self.add_api_object('ActionNamespace', self.ActionNamespace)
        self.ActionProvider = APIObject('ActionProvider', 'string', r'[0-9A-Za-z_-]+', 1, 35)
        self.add_api_object('ActionProvider', self.ActionProvider)
        self.ActionTypeOwner = APIObject('ActionTypeOwner', 'string', r'AWS|ThirdParty', None, None)
        self.add_api_object('ActionTypeOwner', self.ActionTypeOwner)
        self.AllowedAccount = APIObject('AllowedAccount', 'string', r'[0-9]{12}|\*', None, None)
        self.add_api_object('AllowedAccount', self.AllowedAccount)
        self.ApprovalToken = APIObject('ApprovalToken', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('ApprovalToken', self.ApprovalToken)
        self.ArtifactName = APIObject('ArtifactName', 'string', r'[a-zA-Z0-9_\-]+', 1, 100)
        self.add_api_object('ArtifactName', self.ArtifactName)
        self.ArtifactStoreLocation = APIObject('ArtifactStoreLocation', 'string', r'[a-zA-Z0-9\-\.]+', 3, 63)
        self.add_api_object('ArtifactStoreLocation', self.ArtifactStoreLocation)
        self.ClientId = APIObject('ClientId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('ClientId', self.ClientId)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.DisabledReason = APIObject('DisabledReason', 'string', r'[a-zA-Z0-9!@ \(\)\.\*\?\-]+', 1, 300)
        self.add_api_object('DisabledReason', self.DisabledReason)
        self.GitBranchNamePattern = APIObject('GitBranchNamePattern', 'string', r'.*', 1, 255)
        self.add_api_object('GitBranchNamePattern', self.GitBranchNamePattern)
        self.GitFilePathPattern = APIObject('GitFilePathPattern', 'string', r'.*', 1, 255)
        self.add_api_object('GitFilePathPattern', self.GitFilePathPattern)
        self.JobId = APIObject('JobId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('JobId', self.JobId)
        self.LambdaFunctionArn = APIObject('LambdaFunctionArn', 'string', r'arn:aws(-[\w]+)*:lambda:.+:[0-9]{12}:function:.+', 1, 140)
        self.add_api_object('LambdaFunctionArn', self.LambdaFunctionArn)
        self.OutputVariablesKey = APIObject('OutputVariablesKey', 'string', r'[A-Za-z0-9@\-_]+', None, None)
        self.add_api_object('OutputVariablesKey', self.OutputVariablesKey)
        self.PipelineArn = APIObject('PipelineArn', 'string', r'arn:aws(-[\w]+)*:codepipeline:.+:[0-9]{12}:.+', None, None)
        self.add_api_object('PipelineArn', self.PipelineArn)
        self.PipelineExecutionId = APIObject('PipelineExecutionId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('PipelineExecutionId', self.PipelineExecutionId)
        self.PipelineName = APIObject('PipelineName', 'string', r'[A-Za-z0-9.@\-_]+', 1, 100)
        self.add_api_object('PipelineName', self.PipelineName)
        self.PipelineVariableDescription = APIObject('PipelineVariableDescription', 'string', r'.*', 0, 200)
        self.add_api_object('PipelineVariableDescription', self.PipelineVariableDescription)
        self.PipelineVariableName = APIObject('PipelineVariableName', 'string', r'[A-Za-z0-9@\-_]+', 1, 128)
        self.add_api_object('PipelineVariableName', self.PipelineVariableName)
        self.PipelineVariableValue = APIObject('PipelineVariableValue', 'string', r'.*', 1, 1000)
        self.add_api_object('PipelineVariableValue', self.PipelineVariableValue)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws(-[\w]+)*:codepipeline:.+:[0-9]{12}:.+', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws(-[\w]+)*:iam::[0-9]{12}:role/.*', None, 1024)
        self.add_api_object('RoleArn', self.RoleArn)
        self.StageName = APIObject('StageName', 'string', r'[A-Za-z0-9.@\-_]+', 1, 100)
        self.add_api_object('StageName', self.StageName)
        self.Version = APIObject('Version', 'string', r'[0-9A-Za-z_-]+', 1, 9)
        self.add_api_object('Version', self.Version)
        self.WebhookName = APIObject('WebhookName', 'string', r'[A-Za-z0-9.@\-_]+', 1, 100)
        self.add_api_object('WebhookName', self.WebhookName)

class CodestarConnections(Service):
    def __init__(self):
        super().__init__('CodestarConnections')
        self.AccountId = APIObject('AccountId', 'string', r'[0-9]{12}', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.BranchName = APIObject('BranchName', 'string', r'^.*$', 1, 255)
        self.add_api_object('BranchName', self.BranchName)
        self.ConnectionArn = APIObject('ConnectionArn', 'string', r'arn:aws(-[\w]+)*:.+:.+:[0-9]{12}:.+', 0, 256)
        self.add_api_object('ConnectionArn', self.ConnectionArn)
        self.ConnectionName = APIObject('ConnectionName', 'string', r'[\s\S]*', 1, 32)
        self.add_api_object('ConnectionName', self.ConnectionName)
        self.HostArn = APIObject('HostArn', 'string', r'arn:aws(-[\w]+)*:codestar-connections:.+:[0-9]{12}:host\/.+', 0, 256)
        self.add_api_object('HostArn', self.HostArn)
        self.HostName = APIObject('HostName', 'string', r'.*', 1, 64)
        self.add_api_object('HostName', self.HostName)
        self.HostStatus = APIObject('HostStatus', 'string', r'.*', 1, 64)
        self.add_api_object('HostStatus', self.HostStatus)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[\w]+)*:iam::\d{12}:role/[a-zA-Z_0-9+=,.@\-_/]+', 1, 1024)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws(-[\w]+)*:kms:[a-z\-0-9]+:\d{12}:key/[a-zA-Z0-9\-]+', 1, 1024)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.NextToken = APIObject('NextToken', 'string', r'^.*$', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.OwnerId = APIObject('OwnerId', 'string', r'^.*$', 1, 255)
        self.add_api_object('OwnerId', self.OwnerId)
        self.RepositoryLinkArn = APIObject('RepositoryLinkArn', 'string', r'^arn:aws(?:-[a-z]+)*:codestar-connections:[a-z\-0-9]+:\d{12}:repository-link\/[a-zA-Z0-9\-:/]+', None, None)
        self.add_api_object('RepositoryLinkArn', self.RepositoryLinkArn)
        self.RepositoryLinkId = APIObject('RepositoryLinkId', 'string', r'^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('RepositoryLinkId', self.RepositoryLinkId)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'^.*$', 1, 128)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[0-9A-Za-z]+[0-9A-Za-z_\\-]*$', 1, 100)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'sg-\w{8}(\w{9})?', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SharpNextToken = APIObject('SharpNextToken', 'string', r'^.*$', 1, 2048)
        self.add_api_object('SharpNextToken', self.SharpNextToken)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-\w{8}(\w{9})?', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TlsCertificate = APIObject('TlsCertificate', 'string', r'[\s\S]*', 1, 16384)
        self.add_api_object('TlsCertificate', self.TlsCertificate)
        self.Url = APIObject('Url', 'string', r'.*', 1, 512)
        self.add_api_object('Url', self.Url)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-\w{8}(\w{9})?', 12, 21)
        self.add_api_object('VpcId', self.VpcId)

class CodestarNotifications(Service):
    def __init__(self):
        super().__init__('CodestarNotifications')
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[\w:/-]+$', 1, 256)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.NextToken = APIObject('NextToken', 'string', r'^[\w/+=]+$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.NotificationRuleArn = APIObject('NotificationRuleArn', 'string', r'^arn:aws[^:\s]*:codestar-notifications:[^:\s]+:\d{12}:notificationrule\/(.*\S)?$', None, None)
        self.add_api_object('NotificationRuleArn', self.NotificationRuleArn)
        self.NotificationRuleName = APIObject('NotificationRuleName', 'string', r'[A-Za-z0-9\-_ ]+$', 1, 64)
        self.add_api_object('NotificationRuleName', self.NotificationRuleName)
        self.NotificationRuleResource = APIObject('NotificationRuleResource', 'string', r'^arn:aws[^:\s]*:[^:\s]*:[^:\s]*:[0-9]{12}:[^\s]+$', None, None)
        self.add_api_object('NotificationRuleResource', self.NotificationRuleResource)
        self.ResourceType = APIObject('ResourceType', 'string', r'^([a-zA-Z0-9-])+$', 1, None)
        self.add_api_object('ResourceType', self.ResourceType)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetType = APIObject('TargetType', 'string', r'^[A-Za-z]+$', None, None)
        self.add_api_object('TargetType', self.TargetType)

class Codestar(Service):
    def __init__(self):
        super().__init__('Codestar')
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[\w:/-]+$', 1, 256)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.Email = APIObject('Email', 'string', r'^[\w-.+]+@[\w-.+]+$', 3, 128)
        self.add_api_object('Email', self.Email)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[\w/+=]+$', 1, 512)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ProjectArn = APIObject('ProjectArn', 'string', r'^arn:aws[^:\s]*:codestar:[^:\s]+:[0-9]{12}:project\/[a-z]([a-z0-9|-])+$', None, None)
        self.add_api_object('ProjectArn', self.ProjectArn)
        self.ProjectDescription = APIObject('ProjectDescription', 'string', r'^$|^\S(.*\S)?$', None, 1024)
        self.add_api_object('ProjectDescription', self.ProjectDescription)
        self.ProjectId = APIObject('ProjectId', 'string', r'^[a-z][a-z0-9-]+$', 2, 15)
        self.add_api_object('ProjectId', self.ProjectId)
        self.ProjectName = APIObject('ProjectName', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('ProjectName', self.ProjectName)
        self.ProjectTemplateId = APIObject('ProjectTemplateId', 'string', r'^arn:aws[^:\s]{0,5}:codestar:[^:\s]+::project-template(\/(github|codecommit))?\/[a-z0-9-]+$', 1, None)
        self.add_api_object('ProjectTemplateId', self.ProjectTemplateId)
        self.Reason = APIObject('Reason', 'string', r'^$|^\S(.*\S)?$', None, 1024)
        self.add_api_object('Reason', self.Reason)
        self.RepositoryDescription = APIObject('RepositoryDescription', 'string', r'^\S(.*\S)?$', 1, 1000)
        self.add_api_object('RepositoryDescription', self.RepositoryDescription)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'^\S[\w.-]*$', 1, 100)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.RepositoryOwner = APIObject('RepositoryOwner', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('RepositoryOwner', self.RepositoryOwner)
        self.RepositoryType = APIObject('RepositoryType', 'string', r'^(user|organization|User|Organization)$', None, None)
        self.add_api_object('RepositoryType', self.RepositoryType)
        self.ResourceId = APIObject('ResourceId', 'string', r'^arn\:aws\:\S.*\:.*', 11, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.Role = APIObject('Role', 'string', r'^(Owner|Viewer|Contributor)$', None, None)
        self.add_api_object('Role', self.Role)
        self.SshPublicKey = APIObject('SshPublicKey', 'string', r'^[\t\r\n\u0020-\u00FF]*$', None, 16384)
        self.add_api_object('SshPublicKey', self.SshPublicKey)
        self.StackId = APIObject('StackId', 'string', r'^arn:aws[^:\s]*:cloudformation:[^:\s]+:[0-9]{12}:stack\/[^:\s]+\/[^:\s]+$', None, None)
        self.add_api_object('StackId', self.StackId)
        self.State = APIObject('State', 'string', r'^(CreateInProgress|CreateComplete|CreateFailed|DeleteComplete|DeleteFailed|DeleteInProgress|UpdateComplete|UpdateInProgress|UpdateFailed|Unknown)$', None, None)
        self.add_api_object('State', self.State)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TemplateParameterKey = APIObject('TemplateParameterKey', 'string', r'^\S(.*\S)?$', 1, 30)
        self.add_api_object('TemplateParameterKey', self.TemplateParameterKey)
        self.TemplateParameterValue = APIObject('TemplateParameterValue', 'string', r'^\S(.*\S)?$', 1, 100)
        self.add_api_object('TemplateParameterValue', self.TemplateParameterValue)
        self.UserArn = APIObject('UserArn', 'string', r'^arn:aws:iam::\d{12}:user(?:(\u002F)|(\u002F[\u0021-\u007E]+\u002F))[\w+=,.@-]+$', 32, 95)
        self.add_api_object('UserArn', self.UserArn)
        self.UserProfileDisplayName = APIObject('UserProfileDisplayName', 'string', r'^\S(.*\S)?$', 1, 64)
        self.add_api_object('UserProfileDisplayName', self.UserProfileDisplayName)

class CognitoIdentity(Service):
    def __init__(self):
        super().__init__('CognitoIdentity')
        self.AccountId = APIObject('AccountId', 'string', r'\d+', 1, 15)
        self.add_api_object('AccountId', self.AccountId)
        self.ClaimName = APIObject('ClaimName', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 64)
        self.add_api_object('ClaimName', self.ClaimName)
        self.CognitoIdentityProviderClientId = APIObject('CognitoIdentityProviderClientId', 'string', r'[\w_]+', 1, 128)
        self.add_api_object('CognitoIdentityProviderClientId', self.CognitoIdentityProviderClientId)
        self.CognitoIdentityProviderName = APIObject('CognitoIdentityProviderName', 'string', r'[\w._:/-]+', 1, 128)
        self.add_api_object('CognitoIdentityProviderName', self.CognitoIdentityProviderName)
        self.DeveloperProviderName = APIObject('DeveloperProviderName', 'string', r'[\w._-]+', 1, 128)
        self.add_api_object('DeveloperProviderName', self.DeveloperProviderName)
        self.IdentityId = APIObject('IdentityId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityId', self.IdentityId)
        self.IdentityPoolId = APIObject('IdentityPoolId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityPoolId', self.IdentityPoolId)
        self.IdentityPoolName = APIObject('IdentityPoolName', 'string', r'[\w\s+=,.@-]+', 1, 128)
        self.add_api_object('IdentityPoolName', self.IdentityPoolName)
        self.IdentityProviderId = APIObject('IdentityProviderId', 'string', r'[\w.;_/-]+', 1, 128)
        self.add_api_object('IdentityProviderId', self.IdentityProviderId)
        self.PaginationKey = APIObject('PaginationKey', 'string', r'[\S]+', 1, 65535)
        self.add_api_object('PaginationKey', self.PaginationKey)
        self.RoleType = APIObject('RoleType', 'string', r'(un)?authenticated', 1, 128)
        self.add_api_object('RoleType', self.RoleType)

class CognitoIdp(Service):
    def __init__(self):
        super().__init__('CognitoIdp')
        self.AWSAccountIdType = APIObject('AWSAccountIdType', 'string', r'[0-9]+', None, 12)
        self.add_api_object('AWSAccountIdType', self.AWSAccountIdType)
        self.ArnType = APIObject('ArnType', 'string', r'arn:[\w+=/,.@-]+:[\w+=/,.@-]+:([\w+=/,.@-]*)?:[0-9]+:[\w+=/,.@-]+(:[\w+=/,.@-]+)?(:[\w+=/,.@-]+)?', 20, 2048)
        self.add_api_object('ArnType', self.ArnType)
        self.AttributeNameType = APIObject('AttributeNameType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 32)
        self.add_api_object('AttributeNameType', self.AttributeNameType)
        self.ClientIdType = APIObject('ClientIdType', 'string', r'[\w+]+', 1, 128)
        self.add_api_object('ClientIdType', self.ClientIdType)
        self.ClientNameType = APIObject('ClientNameType', 'string', r'[\w\s+=,.@-]+', 1, 128)
        self.add_api_object('ClientNameType', self.ClientNameType)
        self.ClientSecretType = APIObject('ClientSecretType', 'string', r'[\w+]+', 1, 64)
        self.add_api_object('ClientSecretType', self.ClientSecretType)
        self.CompletionMessageType = APIObject('CompletionMessageType', 'string', r'[\w]+', 1, 128)
        self.add_api_object('CompletionMessageType', self.CompletionMessageType)
        self.ConfirmationCodeType = APIObject('ConfirmationCodeType', 'string', r'[\S]+', 1, 2048)
        self.add_api_object('ConfirmationCodeType', self.ConfirmationCodeType)
        self.CustomAttributeNameType = APIObject('CustomAttributeNameType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 20)
        self.add_api_object('CustomAttributeNameType', self.CustomAttributeNameType)
        self.DeviceKeyType = APIObject('DeviceKeyType', 'string', r'[\w-]+_[0-9a-f-]+', 1, 55)
        self.add_api_object('DeviceKeyType', self.DeviceKeyType)
        self.DomainType = APIObject('DomainType', 'string', r'^[a-z0-9](?:[a-z0-9\-]{0,61}[a-z0-9])?$', 1, 63)
        self.add_api_object('DomainType', self.DomainType)
        self.EmailAddressType = APIObject('EmailAddressType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+@[\p{L}\p{M}\p{S}\p{N}\p{P}]+', None, None)
        self.add_api_object('EmailAddressType', self.EmailAddressType)
        self.EmailNotificationBodyType = APIObject('EmailNotificationBodyType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]+', 6, 20000)
        self.add_api_object('EmailNotificationBodyType', self.EmailNotificationBodyType)
        self.EmailNotificationSubjectType = APIObject('EmailNotificationSubjectType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s]+', 1, 140)
        self.add_api_object('EmailNotificationSubjectType', self.EmailNotificationSubjectType)
        self.EmailVerificationMessageByLinkType = APIObject('EmailVerificationMessageByLinkType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]*\{##[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]*##\}[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]*', 6, 20000)
        self.add_api_object('EmailVerificationMessageByLinkType', self.EmailVerificationMessageByLinkType)
        self.EmailVerificationMessageType = APIObject('EmailVerificationMessageType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]*\{####\}[\p{L}\p{M}\p{S}\p{N}\p{P}\s*]*', 6, 20000)
        self.add_api_object('EmailVerificationMessageType', self.EmailVerificationMessageType)
        self.EmailVerificationSubjectByLinkType = APIObject('EmailVerificationSubjectByLinkType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s]+', 1, 140)
        self.add_api_object('EmailVerificationSubjectByLinkType', self.EmailVerificationSubjectByLinkType)
        self.EmailVerificationSubjectType = APIObject('EmailVerificationSubjectType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\s]+', 1, 140)
        self.add_api_object('EmailVerificationSubjectType', self.EmailVerificationSubjectType)
        self.EventIdType = APIObject('EventIdType', 'string', r'[\w+-]+', 1, 50)
        self.add_api_object('EventIdType', self.EventIdType)
        self.GroupNameType = APIObject('GroupNameType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 128)
        self.add_api_object('GroupNameType', self.GroupNameType)
        self.HexStringType = APIObject('HexStringType', 'string', r'^[0-9a-fA-F]+$', None, None)
        self.add_api_object('HexStringType', self.HexStringType)
        self.IdpIdentifierType = APIObject('IdpIdentifierType', 'string', r'[\w\s+=.@-]+', 1, 40)
        self.add_api_object('IdpIdentifierType', self.IdpIdentifierType)
        self.PaginationKey = APIObject('PaginationKey', 'string', r'[\S]+', 1, 131072)
        self.add_api_object('PaginationKey', self.PaginationKey)
        self.PaginationKeyType = APIObject('PaginationKeyType', 'string', r'[\S]+', 1, None)
        self.add_api_object('PaginationKeyType', self.PaginationKeyType)
        self.PasswordType = APIObject('PasswordType', 'string', r'[\S]+', None, 256)
        self.add_api_object('PasswordType', self.PasswordType)
        self.ProviderNameType = APIObject('ProviderNameType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\p{Z}]+', 1, 32)
        self.add_api_object('ProviderNameType', self.ProviderNameType)
        self.ProviderNameTypeV2 = APIObject('ProviderNameTypeV2', 'string', r'[^_\p{Z}][\p{L}\p{M}\p{S}\p{N}\p{P}][^_\p{Z}]+', 1, 32)
        self.add_api_object('ProviderNameTypeV2', self.ProviderNameTypeV2)
        self.RedirectUrlType = APIObject('RedirectUrlType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 1024)
        self.add_api_object('RedirectUrlType', self.RedirectUrlType)
        self.ResourceServerIdentifierType = APIObject('ResourceServerIdentifierType', 'string', r'[\x21\x23-\x5B\x5D-\x7E]+', 1, 256)
        self.add_api_object('ResourceServerIdentifierType', self.ResourceServerIdentifierType)
        self.ResourceServerNameType = APIObject('ResourceServerNameType', 'string', r'[\w\s+=,.@-]+', 1, 256)
        self.add_api_object('ResourceServerNameType', self.ResourceServerNameType)
        self.ResourceServerScopeNameType = APIObject('ResourceServerScopeNameType', 'string', r'[\x21\x23-\x2E\x30-\x5B\x5D-\x7E]+', 1, 256)
        self.add_api_object('ResourceServerScopeNameType', self.ResourceServerScopeNameType)
        self.S3BucketType = APIObject('S3BucketType', 'string', r'^[0-9A-Za-z\.\-_]*(?<!\.)$', 3, 1024)
        self.add_api_object('S3BucketType', self.S3BucketType)
        self.SESConfigurationSet = APIObject('SESConfigurationSet', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('SESConfigurationSet', self.SESConfigurationSet)
        self.ScopeType = APIObject('ScopeType', 'string', r'[\x21\x23-\x5B\x5D-\x7E]+', 1, 256)
        self.add_api_object('ScopeType', self.ScopeType)
        self.SearchPaginationTokenType = APIObject('SearchPaginationTokenType', 'string', r'[\S]+', 1, None)
        self.add_api_object('SearchPaginationTokenType', self.SearchPaginationTokenType)
        self.SecretCodeType = APIObject('SecretCodeType', 'string', r'[A-Za-z0-9]+', 16, None)
        self.add_api_object('SecretCodeType', self.SecretCodeType)
        self.SecretHashType = APIObject('SecretHashType', 'string', r'[\w+=/]+', 1, 128)
        self.add_api_object('SecretHashType', self.SecretHashType)
        self.SmsVerificationMessageType = APIObject('SmsVerificationMessageType', 'string', r'.*\{####\}.*', 6, 140)
        self.add_api_object('SmsVerificationMessageType', self.SmsVerificationMessageType)
        self.SoftwareTokenMFAUserCodeType = APIObject('SoftwareTokenMFAUserCodeType', 'string', r'[0-9]+', 6, 6)
        self.add_api_object('SoftwareTokenMFAUserCodeType', self.SoftwareTokenMFAUserCodeType)
        self.TokenModelType = APIObject('TokenModelType', 'string', r'[A-Za-z0-9-_=.]+', None, None)
        self.add_api_object('TokenModelType', self.TokenModelType)
        self.UserImportJobIdType = APIObject('UserImportJobIdType', 'string', r'import-[0-9a-zA-Z-]+', 1, 55)
        self.add_api_object('UserImportJobIdType', self.UserImportJobIdType)
        self.UserImportJobNameType = APIObject('UserImportJobNameType', 'string', r'[\w\s+=,.@-]+', 1, 128)
        self.add_api_object('UserImportJobNameType', self.UserImportJobNameType)
        self.UserPoolIdType = APIObject('UserPoolIdType', 'string', r'[\w-]+_[0-9a-zA-Z]+', 1, 55)
        self.add_api_object('UserPoolIdType', self.UserPoolIdType)
        self.UserPoolNameType = APIObject('UserPoolNameType', 'string', r'[\w\s+=,.@-]+', 1, 128)
        self.add_api_object('UserPoolNameType', self.UserPoolNameType)
        self.UsernameType = APIObject('UsernameType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 128)
        self.add_api_object('UsernameType', self.UsernameType)

class CognitoSync(Service):
    def __init__(self):
        super().__init__('CognitoSync')
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'arn:aws:sns:[-0-9a-z]+:\d+:app/[A-Z_]+/[a-zA-Z0-9_.-]+', None, None)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.AssumeRoleArn = APIObject('AssumeRoleArn', 'string', r'arn:aws:iam::\d+:role/.*', 20, 2048)
        self.add_api_object('AssumeRoleArn', self.AssumeRoleArn)
        self.DatasetName = APIObject('DatasetName', 'string', r'[a-zA-Z0-9_.:-]+', 1, 128)
        self.add_api_object('DatasetName', self.DatasetName)
        self.IdentityId = APIObject('IdentityId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityId', self.IdentityId)
        self.IdentityPoolId = APIObject('IdentityPoolId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityPoolId', self.IdentityPoolId)

class Comprehend(Service):
    def __init__(self):
        super().__init__('Comprehend')
        self.AttributeNamesListItem = APIObject('AttributeNamesListItem', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*', 1, 63)
        self.add_api_object('AttributeNamesListItem', self.AttributeNamesListItem)
        self.ClientRequestTokenString = APIObject('ClientRequestTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientRequestTokenString', self.ClientRequestTokenString)
        self.ComprehendArn = APIObject('ComprehendArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:[a-zA-Z0-9-]{1,64}/[a-zA-Z0-9](-*[a-zA-Z0-9])*((/dataset/[a-zA-Z0-9](-*[a-zA-Z0-9])*)|(/version/[a-zA-Z0-9](-*[a-zA-Z0-9])*))?', None, 256)
        self.add_api_object('ComprehendArn', self.ComprehendArn)
        self.ComprehendArnName = APIObject('ComprehendArnName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', None, 63)
        self.add_api_object('ComprehendArnName', self.ComprehendArnName)
        self.ComprehendDatasetArn = APIObject('ComprehendDatasetArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:flywheel/[a-zA-Z0-9](-*[a-zA-Z0-9])*/dataset/[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 256)
        self.add_api_object('ComprehendDatasetArn', self.ComprehendDatasetArn)
        self.ComprehendEndpointArn = APIObject('ComprehendEndpointArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:(document-classifier-endpoint|entity-recognizer-endpoint)/[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 256)
        self.add_api_object('ComprehendEndpointArn', self.ComprehendEndpointArn)
        self.ComprehendEndpointName = APIObject('ComprehendEndpointName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', None, 40)
        self.add_api_object('ComprehendEndpointName', self.ComprehendEndpointName)
        self.ComprehendFlywheelArn = APIObject('ComprehendFlywheelArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:flywheel/[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 256)
        self.add_api_object('ComprehendFlywheelArn', self.ComprehendFlywheelArn)
        self.ComprehendModelArn = APIObject('ComprehendModelArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:(document-classifier|entity-recognizer)/[a-zA-Z0-9](-*[a-zA-Z0-9])*(/version/[a-zA-Z0-9](-*[a-zA-Z0-9])*)?', None, 256)
        self.add_api_object('ComprehendModelArn', self.ComprehendModelArn)
        self.Description = APIObject('Description', 'string', r'^([a-zA-Z0-9_])[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', None, 2048)
        self.add_api_object('Description', self.Description)
        self.DocumentClassifierArn = APIObject('DocumentClassifierArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:document-classifier/[a-zA-Z0-9](-*[a-zA-Z0-9])*(/version/[a-zA-Z0-9](-*[a-zA-Z0-9])*)?', None, 256)
        self.add_api_object('DocumentClassifierArn', self.DocumentClassifierArn)
        self.DocumentClassifierEndpointArn = APIObject('DocumentClassifierEndpointArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:([0-9]{12}|aws):document-classifier-endpoint/[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 256)
        self.add_api_object('DocumentClassifierEndpointArn', self.DocumentClassifierEndpointArn)
        self.EntityRecognizerArn = APIObject('EntityRecognizerArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:entity-recognizer/[a-zA-Z0-9](-*[a-zA-Z0-9])*(/version/[a-zA-Z0-9](-*[a-zA-Z0-9])*)?', None, 256)
        self.add_api_object('EntityRecognizerArn', self.EntityRecognizerArn)
        self.EntityRecognizerEndpointArn = APIObject('EntityRecognizerEndpointArn', 'string', r'arn:aws(-[^:]+)?:comprehend:[a-zA-Z0-9-]*:[0-9]{12}:entity-recognizer-endpoint/[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 256)
        self.add_api_object('EntityRecognizerEndpointArn', self.EntityRecognizerEndpointArn)
        self.EntityTypeName = APIObject('EntityTypeName', 'string', r'^(?![^\n\r\t,]*\\n|\\r|\\t)[^\n\r\t,]+$', None, 64)
        self.add_api_object('EntityTypeName', self.EntityTypeName)
        self.EventTypeString = APIObject('EventTypeString', 'string', r'[A-Z_]*', 1, 40)
        self.add_api_object('EventTypeString', self.EventTypeString)
        self.FlywheelIterationId = APIObject('FlywheelIterationId', 'string', r'[0-9]{8}T[0-9]{6}Z', None, 63)
        self.add_api_object('FlywheelIterationId', self.FlywheelIterationId)
        self.FlywheelS3Uri = APIObject('FlywheelS3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', None, 512)
        self.add_api_object('FlywheelS3Uri', self.FlywheelS3Uri)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.JobId = APIObject('JobId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 32)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 256)
        self.add_api_object('JobName', self.JobName)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^\p{ASCII}+$', None, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.LabelDelimiter = APIObject('LabelDelimiter', 'string', r'^[ ~!@#$%^*\-_+=|\\:;\t>?/]$', 1, 1)
        self.add_api_object('LabelDelimiter', self.LabelDelimiter)
        self.LabelListItem = APIObject('LabelListItem', 'string', r'^\P{C}*$', None, 5000)
        self.add_api_object('LabelListItem', self.LabelListItem)
        self.MaskCharacter = APIObject('MaskCharacter', 'string', r'[!@#$%&*]', 1, 1)
        self.add_api_object('MaskCharacter', self.MaskCharacter)
        self.Policy = APIObject('Policy', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 20000)
        self.add_api_object('Policy', self.Policy)
        self.PolicyRevisionId = APIObject('PolicyRevisionId', 'string', r'[0-9A-Fa-f]+', None, 64)
        self.add_api_object('PolicyRevisionId', self.PolicyRevisionId)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', None, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'[-0-9a-zA-Z]+', 1, 32)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'[-0-9a-zA-Z]+', 1, 32)
        self.add_api_object('SubnetId', self.SubnetId)
        self.VersionName = APIObject('VersionName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', None, 63)
        self.add_api_object('VersionName', self.VersionName)

class Comprehendmedical(Service):
    def __init__(self):
        super().__init__('Comprehendmedical')
        self.ClientRequestTokenString = APIObject('ClientRequestTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientRequestTokenString', self.ClientRequestTokenString)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.JobId = APIObject('JobId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 32)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 256)
        self.add_api_object('JobName', self.JobName)
        self.KMSKey = APIObject('KMSKey', 'string', r'.*', 1, 2048)
        self.add_api_object('KMSKey', self.KMSKey)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[0-9a-z\.\-_]*(?!\.)$', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'.*', None, 1024)
        self.add_api_object('S3Key', self.S3Key)

class ComputeOptimizer(Service):
    def __init__(self):
        super().__init__('ComputeOptimizer')

class Config(Service):
    def __init__(self):
        super().__init__('Config')
        self.AccountId = APIObject('AccountId', 'string', r'\d{12}', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.ConfigRuleName = APIObject('ConfigRuleName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ConfigRuleName', self.ConfigRuleName)
        self.ConfigurationAggregatorArn = APIObject('ConfigurationAggregatorArn', 'string', r'arn:aws[a-z\-]*:config:[a-z\-\d]+:\d+:config-aggregator/config-aggregator-[a-z\d]+', None, None)
        self.add_api_object('ConfigurationAggregatorArn', self.ConfigurationAggregatorArn)
        self.ConfigurationAggregatorName = APIObject('ConfigurationAggregatorName', 'string', r'[\w\-]+', 1, 256)
        self.add_api_object('ConfigurationAggregatorName', self.ConfigurationAggregatorName)
        self.ConformancePackName = APIObject('ConformancePackName', 'string', r'[a-zA-Z][-a-zA-Z0-9]*', 1, 256)
        self.add_api_object('ConformancePackName', self.ConformancePackName)
        self.OrganizationConfigRuleName = APIObject('OrganizationConfigRuleName', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('OrganizationConfigRuleName', self.OrganizationConfigRuleName)
        self.OrganizationConformancePackName = APIObject('OrganizationConformancePackName', 'string', r'[a-zA-Z][-a-zA-Z0-9]*', 1, 128)
        self.add_api_object('OrganizationConformancePackName', self.OrganizationConformancePackName)
        self.PolicyRuntime = APIObject('PolicyRuntime', 'string', r'guard\-2\.x\.x', 1, 64)
        self.add_api_object('PolicyRuntime', self.PolicyRuntime)
        self.QueryArn = APIObject('QueryArn', 'string', r'^arn:aws[a-z\-]*:config:[a-z\-\d]+:\d+:stored-query/[a-zA-Z0-9-_]+/query-[a-zA-Z\d-_/]+$', 1, 500)
        self.add_api_object('QueryArn', self.QueryArn)
        self.QueryDescription = APIObject('QueryDescription', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('QueryDescription', self.QueryDescription)
        self.QueryExpression = APIObject('QueryExpression', 'string', r'[\s\S]*', 1, 4096)
        self.add_api_object('QueryExpression', self.QueryExpression)
        self.QueryId = APIObject('QueryId', 'string', r'^\S+$', 1, 36)
        self.add_api_object('QueryId', self.QueryId)
        self.QueryName = APIObject('QueryName', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('QueryName', self.QueryName)
        self.RetentionConfigurationName = APIObject('RetentionConfigurationName', 'string', r'[\w\-]+', 1, 256)
        self.add_api_object('RetentionConfigurationName', self.RetentionConfigurationName)
        self.SSMDocumentName = APIObject('SSMDocumentName', 'string', r'^[a-zA-Z0-9_\-.:/]{3,200}$', None, None)
        self.add_api_object('SSMDocumentName', self.SSMDocumentName)
        self.SSMDocumentVersion = APIObject('SSMDocumentVersion', 'string', r'([$]LATEST|[$]DEFAULT|^[1-9][0-9]*$)', None, None)
        self.add_api_object('SSMDocumentVersion', self.SSMDocumentVersion)
        self.SchemaVersionId = APIObject('SchemaVersionId', 'string', r'[A-Za-z0-9-]+', 1, 128)
        self.add_api_object('SchemaVersionId', self.SchemaVersionId)
        self.TemplateS3Uri = APIObject('TemplateS3Uri', 'string', r's3://.*', 1, 1024)
        self.add_api_object('TemplateS3Uri', self.TemplateS3Uri)

class ConnectContactLens(Service):
    def __init__(self):
        super().__init__('ConnectContactLens')
        self.CategoryName = APIObject('CategoryName', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('CategoryName', self.CategoryName)
        self.ContactId = APIObject('ContactId', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('ContactId', self.ContactId)
        self.InstanceId = APIObject('InstanceId', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('InstanceId', self.InstanceId)
        self.NextToken = APIObject('NextToken', 'string', r'.*\S.*', 1, 131070)
        self.add_api_object('NextToken', self.NextToken)
        self.ParticipantId = APIObject('ParticipantId', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('ParticipantId', self.ParticipantId)
        self.ParticipantRole = APIObject('ParticipantRole', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('ParticipantRole', self.ParticipantRole)
        self.TranscriptContent = APIObject('TranscriptContent', 'string', r'.*\S.*', 1, None)
        self.add_api_object('TranscriptContent', self.TranscriptContent)
        self.TranscriptId = APIObject('TranscriptId', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('TranscriptId', self.TranscriptId)

class Connect(Service):
    def __init__(self):
        super().__init__('Connect')
        self.AwsRegion = APIObject('AwsRegion', 'string', r'[a-z]{2}(-[a-z]+){1,2}(-[0-9])?', 8, 31)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.ContactFlowModuleDescription = APIObject('ContactFlowModuleDescription', 'string', r'.*\S.*', 0, 500)
        self.add_api_object('ContactFlowModuleDescription', self.ContactFlowModuleDescription)
        self.ContactFlowModuleName = APIObject('ContactFlowModuleName', 'string', r'.*\S.*', 1, 127)
        self.add_api_object('ContactFlowModuleName', self.ContactFlowModuleName)
        self.ContactTagKey = APIObject('ContactTagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('ContactTagKey', self.ContactTagKey)
        self.CreateSecurityProfileName = APIObject('CreateSecurityProfileName', 'string', r'^[ a-zA-Z0-9_@-]+$', 1, 127)
        self.add_api_object('CreateSecurityProfileName', self.CreateSecurityProfileName)
        self.Description250 = APIObject('Description250', 'string', r'(^[\S].*[\S]$)|(^[\S]$)', 1, 250)
        self.add_api_object('Description250', self.Description250)
        self.DirectoryAlias = APIObject('DirectoryAlias', 'string', r'^(?!d-)([\da-zA-Z]+)([-]*[\da-zA-Z])*$', 1, 45)
        self.add_api_object('DirectoryAlias', self.DirectoryAlias)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', 12, 12)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.FileName = APIObject('FileName', 'string', r'^\P{C}*$', 1, 256)
        self.add_api_object('FileName', self.FileName)
        self.InstanceArn = APIObject('InstanceArn', 'string', r'arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z]+-[0-9-]{1}:[0-9]{1,20}:instance/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('InstanceArn', self.InstanceArn)
        self.InstanceIdOrArn = APIObject('InstanceIdOrArn', 'string', r'^(arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z]+-[0-9]{1}:[0-9]{1,20}:instance/)?[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 1, 250)
        self.add_api_object('InstanceIdOrArn', self.InstanceIdOrArn)
        self.Name128 = APIObject('Name128', 'string', r'(^[\S].*[\S]$)|(^[\S]$)', 1, 128)
        self.add_api_object('Name128', self.Name128)
        self.Password = APIObject('Password', 'string', r'/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d\S]{8,64}$/', None, None)
        self.add_api_object('Password', self.Password)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'\\+[1-9]\\d{1,14}$', None, None)
        self.add_api_object('PhoneNumber', self.PhoneNumber)
        self.PhoneNumberDescription = APIObject('PhoneNumberDescription', 'string', r'^[\W\S_]*', 0, 500)
        self.add_api_object('PhoneNumberDescription', self.PhoneNumberDescription)
        self.PhoneNumberPrefix = APIObject('PhoneNumberPrefix', 'string', r'\\+?[0-9]{1,11}', None, None)
        self.add_api_object('PhoneNumberPrefix', self.PhoneNumberPrefix)
        self.PhoneNumberWorkflowMessage = APIObject('PhoneNumberWorkflowMessage', 'string', r'^[\W\S_]*', 0, 255)
        self.add_api_object('PhoneNumberWorkflowMessage', self.PhoneNumberWorkflowMessage)
        self.RegionName = APIObject('RegionName', 'string', r'[a-z]{2}(-[a-z]+){1,2}(-[0-9])?', None, None)
        self.add_api_object('RegionName', self.RegionName)
        self.RuleName = APIObject('RuleName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('RuleName', self.RuleName)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://\S+/.+|https://\\S+\\.s3\\.\\S+\\.amazonaws\\.com/\\S+', 1, 2000)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SourceApplicationName = APIObject('SourceApplicationName', 'string', r'^[a-zA-Z0-9_ -]+$', 1, 100)
        self.add_api_object('SourceApplicationName', self.SourceApplicationName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TrafficDistributionGroupArn = APIObject('TrafficDistributionGroupArn', 'string', r'^arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z]+-[0-9]{1}:[0-9]{1,20}:traffic-distribution-group/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('TrafficDistributionGroupArn', self.TrafficDistributionGroupArn)
        self.TrafficDistributionGroupId = APIObject('TrafficDistributionGroupId', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('TrafficDistributionGroupId', self.TrafficDistributionGroupId)
        self.TrafficDistributionGroupIdOrArn = APIObject('TrafficDistributionGroupIdOrArn', 'string', r'^(arn:(aws|aws-us-gov):connect:[a-z]{2}-[a-z-]+-[0-9]{1}:[0-9]{1,20}:traffic-distribution-group/)?[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('TrafficDistributionGroupIdOrArn', self.TrafficDistributionGroupIdOrArn)
        self.ViewAction = APIObject('ViewAction', 'string', r'^([\p{L}\p{N}_.:\/=+\-@()\']+[\p{L}\p{Z}\p{N}_.:\/=+\-@()\']*)$', 1, 255)
        self.add_api_object('ViewAction', self.ViewAction)
        self.ViewContentSha256 = APIObject('ViewContentSha256', 'string', r'^[a-zA-Z0-9]$', 1, 64)
        self.add_api_object('ViewContentSha256', self.ViewContentSha256)
        self.ViewDescription = APIObject('ViewDescription', 'string', r'^([\p{L}\p{N}_.:\/=+\-@,()\']+[\p{L}\p{Z}\p{N}_.:\/=+\-@,()\']*)$', 1, 4096)
        self.add_api_object('ViewDescription', self.ViewDescription)
        self.ViewId = APIObject('ViewId', 'string', r'^[a-zA-Z0-9\_\-:\/$]+$', 1, 500)
        self.add_api_object('ViewId', self.ViewId)
        self.ViewName = APIObject('ViewName', 'string', r'^([\p{L}\p{N}_.:\/=+\-@()\']+[\p{L}\p{Z}\p{N}_.:\/=+\-@()\']*)$', 1, 255)
        self.add_api_object('ViewName', self.ViewName)
        self.ViewsClientToken = APIObject('ViewsClientToken', 'string', r'^([\p{L}\p{Z}\p{N}_.:\/=+\-@]*)$', None, 500)
        self.add_api_object('ViewsClientToken', self.ViewsClientToken)
        self.ViewsInstanceId = APIObject('ViewsInstanceId', 'string', r'^[a-zA-Z0-9\_\-:\/]+$', 1, 100)
        self.add_api_object('ViewsInstanceId', self.ViewsInstanceId)
        self.ViewsNextToken = APIObject('ViewsNextToken', 'string', r'^[a-zA-Z0-9=\/+_.-]+$', 1, 4096)
        self.add_api_object('ViewsNextToken', self.ViewsNextToken)
        self.VocabularyName = APIObject('VocabularyName', 'string', r'^[0-9a-zA-Z._-]+', 1, 140)
        self.add_api_object('VocabularyName', self.VocabularyName)
        self.VocabularyNextToken = APIObject('VocabularyNextToken', 'string', r'.*\S.*', 1, 131070)
        self.add_api_object('VocabularyNextToken', self.VocabularyNextToken)

class Connectcampaigns(Service):
    def __init__(self):
        super().__init__('Connectcampaigns')
        self.Arn = APIObject('Arn', 'string', r'arn:.*', 20, 500)
        self.add_api_object('Arn', self.Arn)
        self.AttributeName = APIObject('AttributeName', 'string', r'[a-zA-Z0-9\-_]+', 0, 32767)
        self.add_api_object('AttributeName', self.AttributeName)
        self.AttributeValue = APIObject('AttributeValue', 'string', r'.*', 0, 32767)
        self.add_api_object('AttributeValue', self.AttributeValue)
        self.CampaignId = APIObject('CampaignId', 'string', r'[\S]*', 0, 256)
        self.add_api_object('CampaignId', self.CampaignId)
        self.ClientToken = APIObject('ClientToken', 'string', r'[a-zA-Z0-9_\-.]*', 0, 200)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DestinationPhoneNumber = APIObject('DestinationPhoneNumber', 'string', r'[\d\-+]*', 0, 20)
        self.add_api_object('DestinationPhoneNumber', self.DestinationPhoneNumber)
        self.DialRequestId = APIObject('DialRequestId', 'string', r'[a-zA-Z0-9_\-.]*', 0, 256)
        self.add_api_object('DialRequestId', self.DialRequestId)
        self.InstanceId = APIObject('InstanceId', 'string', r'[a-zA-Z0-9_\-.]*', 0, 256)
        self.add_api_object('InstanceId', self.InstanceId)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Connectcases(Service):
    def __init__(self):
        super().__init__('Connectcases')
        self.DomainName = APIObject('DomainName', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('DomainName', self.DomainName)
        self.FieldName = APIObject('FieldName', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('FieldName', self.FieldName)
        self.FieldOptionName = APIObject('FieldOptionName', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('FieldOptionName', self.FieldOptionName)
        self.FieldOptionValue = APIObject('FieldOptionValue', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('FieldOptionValue', self.FieldOptionValue)
        self.LayoutName = APIObject('LayoutName', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('LayoutName', self.LayoutName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TemplateName = APIObject('TemplateName', 'string', r'^.*[\S]$', 1, 100)
        self.add_api_object('TemplateName', self.TemplateName)

class Connectparticipant(Service):
    def __init__(self):
        super().__init__('Connectparticipant')
        self.ViewAction = APIObject('ViewAction', 'string', r'^([\p{L}\p{N}_.:\/=+\-@()\']+[\p{L}\p{Z}\p{N}_.:\/=+\-@()\']*)$', 1, 255)
        self.add_api_object('ViewAction', self.ViewAction)
        self.ViewId = APIObject('ViewId', 'string', r'^[a-zA-Z0-9\_\-:\/$]+$', 1, 500)
        self.add_api_object('ViewId', self.ViewId)
        self.ViewName = APIObject('ViewName', 'string', r'^([\p{L}\p{N}_.:\/=+\-@()\']+[\p{L}\p{Z}\p{N}_.:\/=+\-@()\']*)$', 1, 255)
        self.add_api_object('ViewName', self.ViewName)

class Controlcatalog(Service):
    def __init__(self):
        super().__init__('Controlcatalog')
        self.CommonControlArn = APIObject('CommonControlArn', 'string', r'^arn:(aws(?:[-a-z]*)?):controlcatalog:::common-control/[0-9a-z]+$', 41, 2048)
        self.add_api_object('CommonControlArn', self.CommonControlArn)
        self.DomainArn = APIObject('DomainArn', 'string', r'^arn:(aws(?:[-a-z]*)?):controlcatalog:::domain/[0-9a-z]+$', 33, 2048)
        self.add_api_object('DomainArn', self.DomainArn)
        self.ObjectiveArn = APIObject('ObjectiveArn', 'string', r'^arn:(aws(?:[-a-z]*)?):controlcatalog:::objective/[0-9a-z]+$', 36, 2048)
        self.add_api_object('ObjectiveArn', self.ObjectiveArn)

class Controltower(Service):
    def __init__(self):
        super().__init__('Controltower')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws[0-9a-zA-Z_\-:\/]+$', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.BaselineArn = APIObject('BaselineArn', 'string', r'^arn:[a-z-]+:controltower:[a-z0-9-]*:[0-9]{0,12}:baseline/[A-Z0-9]{16}$', None, None)
        self.add_api_object('BaselineArn', self.BaselineArn)
        self.BaselineVersion = APIObject('BaselineVersion', 'string', r'^\d+(?:\.\d+){0,2}$', 1, 10)
        self.add_api_object('BaselineVersion', self.BaselineVersion)
        self.ControlIdentifier = APIObject('ControlIdentifier', 'string', r'^arn:aws[0-9a-zA-Z_\-:\/]+$', 20, 2048)
        self.add_api_object('ControlIdentifier', self.ControlIdentifier)
        self.LandingZoneVersion = APIObject('LandingZoneVersion', 'string', r'^\d+.\d+$', 3, 10)
        self.add_api_object('LandingZoneVersion', self.LandingZoneVersion)
        self.ListEnabledBaselinesNextToken = APIObject('ListEnabledBaselinesNextToken', 'string', r'\S+', None, None)
        self.add_api_object('ListEnabledBaselinesNextToken', self.ListEnabledBaselinesNextToken)
        self.OperationIdentifier = APIObject('OperationIdentifier', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 36, 36)
        self.add_api_object('OperationIdentifier', self.OperationIdentifier)
        self.TargetIdentifier = APIObject('TargetIdentifier', 'string', r'^arn:aws[0-9a-zA-Z_\-:\/]+$', 20, 2048)
        self.add_api_object('TargetIdentifier', self.TargetIdentifier)

class CostOptimizationHub(Service):
    def __init__(self):
        super().__init__('CostOptimizationHub')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('AccountId', self.AccountId)

class Cur(Service):
    def __init__(self):
        super().__init__('Cur')
        self.BillingViewArn = APIObject('BillingViewArn', 'string', r'(arn:aws(-cn)?:billing::[0-9]{12}:billingview/)?[a-zA-Z0-9_\+=\.\-@].{1,30}', None, 128)
        self.add_api_object('BillingViewArn', self.BillingViewArn)
        self.GenericString = APIObject('GenericString', 'string', r'[A-Za-z0-9_\.\-=]*', None, 256)
        self.add_api_object('GenericString', self.GenericString)
        self.LastDelivery = APIObject('LastDelivery', 'string', r'[0-9]{8}[T][0-9]{6}([Z]|[+-][0-9]{4})', 16, 20)
        self.add_api_object('LastDelivery', self.LastDelivery)
        self.ReportName = APIObject('ReportName', 'string', r'''[0-9A-Za-z!\-_.*\\'()]+''', None, 256)
        self.add_api_object('ReportName', self.ReportName)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[A-Za-z0-9_\.\-]+', None, 256)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Prefix = APIObject('S3Prefix', 'string', r'''[0-9A-Za-z!\-_.*\\'()/]*''', None, 256)
        self.add_api_object('S3Prefix', self.S3Prefix)
        self.TagKey = APIObject('TagKey', 'string', r'.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class CustomerProfiles(Service):
    def __init__(self):
        super().__init__('CustomerProfiles')
        self.name = APIObject('name', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('name', self.name)
        self.BucketName = APIObject('BucketName', 'string', r'\S+', 3, 63)
        self.add_api_object('BucketName', self.BucketName)
        self.BucketPrefix = APIObject('BucketPrefix', 'string', r'.*', None, 512)
        self.add_api_object('BucketPrefix', self.BucketPrefix)
        self.ConnectorProfileName = APIObject('ConnectorProfileName', 'string', r'[\w/!@#+=.-]+', None, 256)
        self.add_api_object('ConnectorProfileName', self.ConnectorProfileName)
        self.DatetimeTypeFieldName = APIObject('DatetimeTypeFieldName', 'string', r'.*', None, 256)
        self.add_api_object('DatetimeTypeFieldName', self.DatetimeTypeFieldName)
        self.DestinationField = APIObject('DestinationField', 'string', r'.*', None, 256)
        self.add_api_object('DestinationField', self.DestinationField)
        self.FlowDescription = APIObject('FlowDescription', 'string', r'[\w!@#\-.?,\s]*', None, 2048)
        self.add_api_object('FlowDescription', self.FlowDescription)
        self.FlowName = APIObject('FlowName', 'string', r'[a-zA-Z0-9][\w!@#.-]+', None, 256)
        self.add_api_object('FlowName', self.FlowName)
        self.JobScheduleTime = APIObject('JobScheduleTime', 'string', r'^([0-9]|0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$', 3, 5)
        self.add_api_object('JobScheduleTime', self.JobScheduleTime)
        self.KmsArn = APIObject('KmsArn', 'string', r'arn:aws:kms:.*:[0-9]+:.*', 20, 2048)
        self.add_api_object('KmsArn', self.KmsArn)
        self.Object = APIObject('Object', 'string', r'\S+', None, 512)
        self.add_api_object('Object', self.Object)
        self.Property = APIObject('Property', 'string', r'.+', None, 2048)
        self.add_api_object('Property', self.Property)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam:.*:[0-9]+:.*', None, 512)
        self.add_api_object('RoleArn', self.RoleArn)
        self.ScheduleExpression = APIObject('ScheduleExpression', 'string', r'.*', None, 256)
        self.add_api_object('ScheduleExpression', self.ScheduleExpression)
        self.TagArn = APIObject('TagArn', 'string', r'^arn:[a-z0-9]{1,10}:profile', None, 256)
        self.add_api_object('TagArn', self.TagArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Timezone = APIObject('Timezone', 'string', r'.*', None, 256)
        self.add_api_object('Timezone', self.Timezone)
        self.attributeName = APIObject('attributeName', 'string', r'^[a-zA-Z0-9_.-]+$', 1, 64)
        self.add_api_object('attributeName', self.attributeName)
        self.displayName = APIObject('displayName', 'string', r'^[a-zA-Z_][a-zA-Z_0-9-\s]*$', 1, 255)
        self.add_api_object('displayName', self.displayName)
        self.s3BucketName = APIObject('s3BucketName', 'string', r'^[a-z0-9.-]+$', 3, 63)
        self.add_api_object('s3BucketName', self.s3BucketName)
        self.s3KeyName = APIObject('s3KeyName', 'string', r'.*', 1, 1024)
        self.add_api_object('s3KeyName', self.s3KeyName)
        self.s3KeyNameCustomerOutputConfig = APIObject('s3KeyNameCustomerOutputConfig', 'string', r'.*', 1, 800)
        self.add_api_object('s3KeyNameCustomerOutputConfig', self.s3KeyNameCustomerOutputConfig)
        self.stringTo2048 = APIObject('stringTo2048', 'string', r'.*', None, 2048)
        self.add_api_object('stringTo2048', self.stringTo2048)
        self.typeName = APIObject('typeName', 'string', r'^[a-zA-Z_][a-zA-Z_0-9-]*$', 1, 255)
        self.add_api_object('typeName', self.typeName)
        self.uuid = APIObject('uuid', 'string', r'[a-f0-9]{32}', None, None)
        self.add_api_object('uuid', self.uuid)

class Databrew(Service):
    def __init__(self):
        super().__init__('Databrew')
        self.BucketOwner = APIObject('BucketOwner', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('BucketOwner', self.BucketOwner)
        self.ClientSessionId = APIObject('ClientSessionId', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-]*$', 1, 255)
        self.add_api_object('ClientSessionId', self.ClientSessionId)
        self.Condition = APIObject('Condition', 'string', r'^[A-Z\_]+$', 1, 128)
        self.add_api_object('Condition', self.Condition)
        self.EntityType = APIObject('EntityType', 'string', r'^[A-Z_][A-Z\\d_]*$', 1, 128)
        self.add_api_object('EntityType', self.EntityType)
        self.ErrorCode = APIObject('ErrorCode', 'string', r'^[1-5][0-9][0-9]$', None, None)
        self.add_api_object('ErrorCode', self.ErrorCode)
        self.Expression = APIObject('Expression', 'string', r'^[<>0-9A-Za-z_.,:)(!= ]+$', 4, 1024)
        self.add_api_object('Expression', self.Expression)
        self.LocaleCode = APIObject('LocaleCode', 'string', r'^[A-Za-z0-9_\.#@\-]+$', 2, 100)
        self.add_api_object('LocaleCode', self.LocaleCode)
        self.Operation = APIObject('Operation', 'string', r'^[A-Z\_]+$', 1, 128)
        self.add_api_object('Operation', self.Operation)
        self.ParameterName = APIObject('ParameterName', 'string', r'^[A-Za-z0-9]+$', 1, 128)
        self.add_api_object('ParameterName', self.ParameterName)
        self.Statistic = APIObject('Statistic', 'string', r'^[A-Z\_]+$', 1, 128)
        self.add_api_object('Statistic', self.Statistic)
        self.TimezoneOffset = APIObject('TimezoneOffset', 'string', r'^(Z|[-+](\d|\d{2}|\d{2}:?\d{2}))$', 1, 6)
        self.add_api_object('TimezoneOffset', self.TimezoneOffset)
        self.ValueReference = APIObject('ValueReference', 'string', r'^:[A-Za-z0-9_]+$', 2, 128)
        self.add_api_object('ValueReference', self.ValueReference)

class Dataexchange(Service):
    def __init__(self):
        super().__init__('Dataexchange')
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'.*/^[\d]{12}$/.*', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.ClientToken = APIObject('ClientToken', 'string', r'[\x21-\x7E]{1,64}', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam::(\d{12}):role\/.+', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.stringMin24Max24PatternAZaZ094AZaZ092AZaZ093 = APIObject('stringMin24Max24PatternAZaZ094AZaZ092AZaZ093', 'string', r'(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?', 24, 24)
        self.add_api_object('stringMin24Max24PatternAZaZ094AZaZ092AZaZ093', self.stringMin24Max24PatternAZaZ094AZaZ092AZaZ093)

class Datapipeline(Service):
    def __init__(self):
        super().__init__('Datapipeline')
        self.attributeNameString = APIObject('attributeNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 256)
        self.add_api_object('attributeNameString', self.attributeNameString)
        self.attributeValueString = APIObject('attributeValueString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 10240)
        self.add_api_object('attributeValueString', self.attributeValueString)
        self.fieldNameString = APIObject('fieldNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 256)
        self.add_api_object('fieldNameString', self.fieldNameString)
        self.fieldStringValue = APIObject('fieldStringValue', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 10240)
        self.add_api_object('fieldStringValue', self.fieldStringValue)
        self.id = APIObject('id', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1024)
        self.add_api_object('id', self.id)
        self.longString = APIObject('longString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 20971520)
        self.add_api_object('longString', self.longString)
        self.string = APIObject('string', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 1024)
        self.add_api_object('string', self.string)
        self.taskId = APIObject('taskId', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 2048)
        self.add_api_object('taskId', self.taskId)
        self.validationMessage = APIObject('validationMessage', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 10000)
        self.add_api_object('validationMessage', self.validationMessage)

class Datasync(Service):
    def __init__(self):
        super().__init__('Datasync')
        self.ActivationKey = APIObject('ActivationKey', 'string', r'[A-Z0-9]{5}(-[A-Z0-9]{5}){4}', None, 29)
        self.add_api_object('ActivationKey', self.ActivationKey)
        self.AgentArn = APIObject('AgentArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]+:[0-9]{12}:agent/agent-[0-9a-z]{17}$', None, 128)
        self.add_api_object('AgentArn', self.AgentArn)
        self.AgentVersion = APIObject('AgentVersion', 'string', r'^[a-zA-Z0-9\s+=._:@/-]+$', 1, 256)
        self.add_api_object('AgentVersion', self.AgentVersion)
        self.AzureBlobContainerUrl = APIObject('AzureBlobContainerUrl', 'string', r'^https:\/\/[A-Za-z0-9]((\.|-+)?[A-Za-z0-9]){0,252}\/[a-z0-9](-?[a-z0-9]){2,62}$', None, 325)
        self.add_api_object('AzureBlobContainerUrl', self.AzureBlobContainerUrl)
        self.AzureBlobSasToken = APIObject('AzureBlobSasToken', 'string', r'^.+$', 1, 255)
        self.add_api_object('AzureBlobSasToken', self.AzureBlobSasToken)
        self.AzureBlobSubdirectory = APIObject('AzureBlobSubdirectory', 'string', r'^[\p{L}\p{M}\p{Z}\p{S}\p{N}\p{P}\p{C}]*$', None, 1024)
        self.add_api_object('AzureBlobSubdirectory', self.AzureBlobSubdirectory)
        self.DiscoveryJobArn = APIObject('DiscoveryJobArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]+:[0-9]{12}:system/storage-system-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}/job/discovery-job-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, 256)
        self.add_api_object('DiscoveryJobArn', self.DiscoveryJobArn)
        self.DiscoveryNextToken = APIObject('DiscoveryNextToken', 'string', r'[a-zA-Z0-9=_-]+', None, 65535)
        self.add_api_object('DiscoveryNextToken', self.DiscoveryNextToken)
        self.DiscoveryServerHostname = APIObject('DiscoveryServerHostname', 'string', r'^(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])$', None, 255)
        self.add_api_object('DiscoveryServerHostname', self.DiscoveryServerHostname)
        self.Ec2SecurityGroupArn = APIObject('Ec2SecurityGroupArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):ec2:[a-z\-0-9]*:[0-9]{12}:security-group/sg-[a-f0-9]+$', None, 128)
        self.add_api_object('Ec2SecurityGroupArn', self.Ec2SecurityGroupArn)
        self.Ec2SubnetArn = APIObject('Ec2SubnetArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):ec2:[a-z\-0-9]*:[0-9]{12}:subnet/.*$', None, 128)
        self.add_api_object('Ec2SubnetArn', self.Ec2SubnetArn)
        self.EfsAccessPointArn = APIObject('EfsAccessPointArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):elasticfilesystem:[a-z\-0-9]+:[0-9]{12}:access-point/fsap-[0-9a-f]{8,40}$', None, 128)
        self.add_api_object('EfsAccessPointArn', self.EfsAccessPointArn)
        self.EfsFilesystemArn = APIObject('EfsFilesystemArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):elasticfilesystem:[a-z\-0-9]*:[0-9]{12}:file-system/fs-.*$', None, 128)
        self.add_api_object('EfsFilesystemArn', self.EfsFilesystemArn)
        self.EfsSubdirectory = APIObject('EfsSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\p{Zs}]*$', None, 4096)
        self.add_api_object('EfsSubdirectory', self.EfsSubdirectory)
        self.Endpoint = APIObject('Endpoint', 'string', r'\A(25[0-5]|2[0-4]\d|[0-1]?\d?\d)(\.(25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}\z', 7, 15)
        self.add_api_object('Endpoint', self.Endpoint)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'.*', None, 128)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.FilterAttributeValue = APIObject('FilterAttributeValue', 'string', r'^[0-9a-zA-Z_\ \-\:\*\.\\/\?-]*$', 1, 255)
        self.add_api_object('FilterAttributeValue', self.FilterAttributeValue)
        self.FilterType = APIObject('FilterType', 'string', r'^[A-Z0-9_]+$', None, 128)
        self.add_api_object('FilterType', self.FilterType)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[^\x00]+$', None, 102400)
        self.add_api_object('FilterValue', self.FilterValue)
        self.FsxFilesystemArn = APIObject('FsxFilesystemArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):fsx:[a-z\-0-9]*:[0-9]{12}:file-system/fs-.*$', None, 128)
        self.add_api_object('FsxFilesystemArn', self.FsxFilesystemArn)
        self.FsxLustreSubdirectory = APIObject('FsxLustreSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\$\p{Zs}]+$', None, 4096)
        self.add_api_object('FsxLustreSubdirectory', self.FsxLustreSubdirectory)
        self.FsxOntapSubdirectory = APIObject('FsxOntapSubdirectory', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,255}$', None, 255)
        self.add_api_object('FsxOntapSubdirectory', self.FsxOntapSubdirectory)
        self.FsxOpenZfsSubdirectory = APIObject('FsxOpenZfsSubdirectory', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,4096}$', None, 4096)
        self.add_api_object('FsxOpenZfsSubdirectory', self.FsxOpenZfsSubdirectory)
        self.FsxWindowsSubdirectory = APIObject('FsxWindowsSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\$\p{Zs}]+$', None, 4096)
        self.add_api_object('FsxWindowsSubdirectory', self.FsxWindowsSubdirectory)
        self.HdfsServerHostname = APIObject('HdfsServerHostname', 'string', r'^(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])$', 1, 255)
        self.add_api_object('HdfsServerHostname', self.HdfsServerHostname)
        self.HdfsSubdirectory = APIObject('HdfsSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\$\p{Zs}]+$', None, 4096)
        self.add_api_object('HdfsSubdirectory', self.HdfsSubdirectory)
        self.HdfsUser = APIObject('HdfsUser', 'string', r'^[_.A-Za-z0-9][-_.A-Za-z0-9]*$', 1, 256)
        self.add_api_object('HdfsUser', self.HdfsUser)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):iam::[0-9]{12}:role/.*$', None, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KerberosPrincipal = APIObject('KerberosPrincipal', 'string', r'^.+$', 1, 256)
        self.add_api_object('KerberosPrincipal', self.KerberosPrincipal)
        self.KmsKeyProviderUri = APIObject('KmsKeyProviderUri', 'string', r'^kms:\/\/http[s]?@(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])(;(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9]))*:[0-9]{1,5}\/kms$', 1, 255)
        self.add_api_object('KmsKeyProviderUri', self.KmsKeyProviderUri)
        self.LocationArn = APIObject('LocationArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]+:[0-9]{12}:location/loc-[0-9a-z]{17}$', None, 128)
        self.add_api_object('LocationArn', self.LocationArn)
        self.LocationUri = APIObject('LocationUri', 'string', r'^(efs|nfs|s3|smb|hdfs|fsx[a-z0-9-]+)://[a-zA-Z0-9.:/\-]+$', None, 4360)
        self.add_api_object('LocationUri', self.LocationUri)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):logs:[a-z\-0-9]+:[0-9]{12}:log-group:([^:\*]*)(:\*)?$', None, 562)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.Name = APIObject('Name', 'string', r'^[\p{L}\p{M}\p{N}\s+=._:@\/-]+$', 1, 256)
        self.add_api_object('Name', self.Name)
        self.NetworkInterfaceArn = APIObject('NetworkInterfaceArn', 'string', r'^arn:aws[\-a-z]{0,}:ec2:[a-z\-0-9]*:[0-9]{12}:network-interface/eni-[0-9a-f]+$', None, 128)
        self.add_api_object('NetworkInterfaceArn', self.NetworkInterfaceArn)
        self.NextToken = APIObject('NextToken', 'string', r'[a-zA-Z0-9=_-]+', None, 65535)
        self.add_api_object('NextToken', self.NextToken)
        self.NfsSubdirectory = APIObject('NfsSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\p{Zs}]+$', None, 4096)
        self.add_api_object('NfsSubdirectory', self.NfsSubdirectory)
        self.ObjectStorageAccessKey = APIObject('ObjectStorageAccessKey', 'string', r'^.*$', 0, 200)
        self.add_api_object('ObjectStorageAccessKey', self.ObjectStorageAccessKey)
        self.ObjectStorageBucketName = APIObject('ObjectStorageBucketName', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\$\p{Zs}]+$', 3, 63)
        self.add_api_object('ObjectStorageBucketName', self.ObjectStorageBucketName)
        self.ObjectStorageSecretKey = APIObject('ObjectStorageSecretKey', 'string', r'^.*$', 0, 200)
        self.add_api_object('ObjectStorageSecretKey', self.ObjectStorageSecretKey)
        self.PtolemyPassword = APIObject('PtolemyPassword', 'string', r'^(?!.*[:\"][^:"]*$).+$', None, 1024)
        self.add_api_object('PtolemyPassword', self.PtolemyPassword)
        self.PtolemyString = APIObject('PtolemyString', 'string', r'^.{0,1024}$', None, 1024)
        self.add_api_object('PtolemyString', self.PtolemyString)
        self.PtolemyUUID = APIObject('PtolemyUUID', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('PtolemyUUID', self.PtolemyUUID)
        self.PtolemyUsername = APIObject('PtolemyUsername', 'string', r'^(?!.*[:\"][^:"]*$).+$', None, 1024)
        self.add_api_object('PtolemyUsername', self.PtolemyUsername)
        self.ResourceId = APIObject('ResourceId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.S3BucketArn = APIObject('S3BucketArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):(s3|s3-outposts):[a-z\-0-9]*:[0-9]*:.*$', None, 156)
        self.add_api_object('S3BucketArn', self.S3BucketArn)
        self.S3ObjectVersionId = APIObject('S3ObjectVersionId', 'string', r'^.+$', 1, 100)
        self.add_api_object('S3ObjectVersionId', self.S3ObjectVersionId)
        self.S3Subdirectory = APIObject('S3Subdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\p{Zs}]*$', None, 4096)
        self.add_api_object('S3Subdirectory', self.S3Subdirectory)
        self.ScheduleDisabledReason = APIObject('ScheduleDisabledReason', 'string', r'^[\w\s.,\'?!:;\/=|<>()-]*$', None, 8192)
        self.add_api_object('ScheduleDisabledReason', self.ScheduleDisabledReason)
        self.ScheduleExpressionCron = APIObject('ScheduleExpressionCron', 'string', r'^[a-zA-Z0-9\ \_\*\?\,\|\^\-\/\#\s\(\)\+]*$', None, 256)
        self.add_api_object('ScheduleExpressionCron', self.ScheduleExpressionCron)
        self.SecretsManagerArn = APIObject('SecretsManagerArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):secretsmanager:[a-z\-0-9]+:[0-9]{12}:secret:.*', None, 2048)
        self.add_api_object('SecretsManagerArn', self.SecretsManagerArn)
        self.ServerHostname = APIObject('ServerHostname', 'string', r'^(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])$', None, 255)
        self.add_api_object('ServerHostname', self.ServerHostname)
        self.SmbDomain = APIObject('SmbDomain', 'string', r'^[A-Za-z0-9]((\.|-+)?[A-Za-z0-9]){0,252}$', None, 253)
        self.add_api_object('SmbDomain', self.SmbDomain)
        self.SmbPassword = APIObject('SmbPassword', 'string', r'^.{0,104}$', None, 104)
        self.add_api_object('SmbPassword', self.SmbPassword)
        self.SmbSubdirectory = APIObject('SmbSubdirectory', 'string', r'^[a-zA-Z0-9_\-\+\./\(\)\$\p{Zs}]+$', None, 4096)
        self.add_api_object('SmbSubdirectory', self.SmbSubdirectory)
        self.SmbUser = APIObject('SmbUser', 'string', r'^[^\x5B\x5D\\/:;|=,+*?]{1,104}$', None, 104)
        self.add_api_object('SmbUser', self.SmbUser)
        self.StorageSystemArn = APIObject('StorageSystemArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]+:[0-9]{12}:system/storage-system-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, 128)
        self.add_api_object('StorageSystemArn', self.StorageSystemArn)
        self.StorageVirtualMachineArn = APIObject('StorageVirtualMachineArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):fsx:[a-z\-0-9]+:[0-9]{12}:storage-virtual-machine/fs-[0-9a-f]+/svm-[0-9a-f]{17,}$', None, 162)
        self.add_api_object('StorageVirtualMachineArn', self.StorageVirtualMachineArn)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z0-9\s+=._:/-]+$', 1, 256)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[a-zA-Z0-9\s+=._:@/-]+$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaggableResourceArn = APIObject('TaggableResourceArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]+:[0-9]{12}:(agent|task|location|system)/((agent|task|loc)-[a-f0-9]{17}|storage-system-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})(/execution/exec-[a-f0-9]{17})?$', None, 128)
        self.add_api_object('TaggableResourceArn', self.TaggableResourceArn)
        self.TaskArn = APIObject('TaskArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]*:[0-9]{12}:task/task-[0-9a-f]{17}$', None, 128)
        self.add_api_object('TaskArn', self.TaskArn)
        self.TaskExecutionArn = APIObject('TaskExecutionArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):datasync:[a-z\-0-9]*:[0-9]{12}:task/task-[0-9a-f]{17}/execution/exec-[0-9a-f]{17}$', None, 128)
        self.add_api_object('TaskExecutionArn', self.TaskExecutionArn)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'^vpce-[0-9a-f]{17}$', None, None)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)

class Datazone(Service):
    def __init__(self):
        super().__init__('Datazone')
        self.AssetId = APIObject('AssetId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('AssetId', self.AssetId)
        self.AssetIdentifier = APIObject('AssetIdentifier', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('AssetIdentifier', self.AssetIdentifier)
        self.AssetTypeIdentifier = APIObject('AssetTypeIdentifier', 'string', r'^(?!\.)[\w\.]*\w$', 1, 513)
        self.add_api_object('AssetTypeIdentifier', self.AssetTypeIdentifier)
        self.AuthorizedPrincipalIdentifier = APIObject('AuthorizedPrincipalIdentifier', 'string', r'^[a-zA-Z0-9:/_-]*$', None, None)
        self.add_api_object('AuthorizedPrincipalIdentifier', self.AuthorizedPrincipalIdentifier)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.AwsRegion = APIObject('AwsRegion', 'string', r'^[a-z]{2}-[a-z]{4,10}-\d$', None, None)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[\x21-\x7E]+$', 1, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CronString = APIObject('CronString', 'string', r'cron\((\b[0-5]?[0-9]\b) (\b2[0-3]\b|\b[0-1]?[0-9]\b) (.*){1,5} (.*){1,5} (.*){1,5} (.*){1,5}\)', 1, 256)
        self.add_api_object('CronString', self.CronString)
        self.CustomParameterKeyNameString = APIObject('CustomParameterKeyNameString', 'string', r'^[a-zA-Z_][a-zA-Z0-9_]*$', None, None)
        self.add_api_object('CustomParameterKeyNameString', self.CustomParameterKeyNameString)
        self.DataPointIdentifier = APIObject('DataPointIdentifier', 'string', r'^[a-zA-Z0-9_-]{0,36}$', None, None)
        self.add_api_object('DataPointIdentifier', self.DataPointIdentifier)
        self.DataProductId = APIObject('DataProductId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('DataProductId', self.DataProductId)
        self.DataSourceId = APIObject('DataSourceId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('DataSourceId', self.DataSourceId)
        self.DataSourceRunId = APIObject('DataSourceRunId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('DataSourceRunId', self.DataSourceRunId)
        self.DomainId = APIObject('DomainId', 'string', r'^dzd[-_][a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('DomainId', self.DomainId)
        self.EntityId = APIObject('EntityId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityIdentifier = APIObject('EntityIdentifier', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('EntityIdentifier', self.EntityIdentifier)
        self.EnvironmentBlueprintId = APIObject('EnvironmentBlueprintId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('EnvironmentBlueprintId', self.EnvironmentBlueprintId)
        self.EnvironmentBlueprintName = APIObject('EnvironmentBlueprintName', 'string', r'^[\w -]+$', 1, 64)
        self.add_api_object('EnvironmentBlueprintName', self.EnvironmentBlueprintName)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'^[\w -]+$', 1, 64)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.EnvironmentProfileId = APIObject('EnvironmentProfileId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('EnvironmentProfileId', self.EnvironmentProfileId)
        self.EnvironmentProfileName = APIObject('EnvironmentProfileName', 'string', r'^[\w -]+$', 1, 64)
        self.add_api_object('EnvironmentProfileName', self.EnvironmentProfileName)
        self.FormName = APIObject('FormName', 'string', r'^(?![0-9_])\w+$|^_\w*[a-zA-Z0-9]\w*$', 1, 128)
        self.add_api_object('FormName', self.FormName)
        self.FormTypeIdentifier = APIObject('FormTypeIdentifier', 'string', r'^(?!\.)[\w\.]*\w$', 1, 385)
        self.add_api_object('FormTypeIdentifier', self.FormTypeIdentifier)
        self.FormTypeName = APIObject('FormTypeName', 'string', r'^(amazon.datazone.)?(?![0-9_])\w+$|^_\w*[a-zA-Z0-9]\w*$', 1, 128)
        self.add_api_object('FormTypeName', self.FormTypeName)
        self.GlossaryId = APIObject('GlossaryId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('GlossaryId', self.GlossaryId)
        self.GlossaryTermId = APIObject('GlossaryTermId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('GlossaryTermId', self.GlossaryTermId)
        self.GlueRunConfigurationInputDataAccessRoleString = APIObject('GlueRunConfigurationInputDataAccessRoleString', 'string', r'^arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]{1,128}$', None, None)
        self.add_api_object('GlueRunConfigurationInputDataAccessRoleString', self.GlueRunConfigurationInputDataAccessRoleString)
        self.GlueRunConfigurationOutputAccountIdString = APIObject('GlueRunConfigurationOutputAccountIdString', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('GlueRunConfigurationOutputAccountIdString', self.GlueRunConfigurationOutputAccountIdString)
        self.GlueRunConfigurationOutputDataAccessRoleString = APIObject('GlueRunConfigurationOutputDataAccessRoleString', 'string', r'^arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]{1,128}$', None, None)
        self.add_api_object('GlueRunConfigurationOutputDataAccessRoleString', self.GlueRunConfigurationOutputDataAccessRoleString)
        self.GlueRunConfigurationOutputRegionString = APIObject('GlueRunConfigurationOutputRegionString', 'string', r'[a-z]{2}-?(iso|gov)?-{1}[a-z]*-{1}[0-9]', 4, 16)
        self.add_api_object('GlueRunConfigurationOutputRegionString', self.GlueRunConfigurationOutputRegionString)
        self.GroupIdentifier = APIObject('GroupIdentifier', 'string', r'(^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$|[\p{L}\p{M}\p{S}\p{N}\p{P}\t\n\r  ]+)', None, None)
        self.add_api_object('GroupIdentifier', self.GroupIdentifier)
        self.GroupProfileId = APIObject('GroupProfileId', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('GroupProfileId', self.GroupProfileId)
        self.GroupProfileName = APIObject('GroupProfileName', 'string', r'^[a-zA-Z_0-9+=,.@-]+$', 1, 1024)
        self.add_api_object('GroupProfileName', self.GroupProfileName)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws(|-cn|-us-gov):kms:[a-zA-Z0-9-]*:[0-9]{12}:key/[a-zA-Z0-9-]{36}$', 1, 1024)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.ListingId = APIObject('ListingId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('ListingId', self.ListingId)
        self.MetadataGenerationRunIdentifier = APIObject('MetadataGenerationRunIdentifier', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('MetadataGenerationRunIdentifier', self.MetadataGenerationRunIdentifier)
        self.ProjectId = APIObject('ProjectId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('ProjectId', self.ProjectId)
        self.ProjectName = APIObject('ProjectName', 'string', r'^[\w -]+$', 1, 64)
        self.add_api_object('ProjectName', self.ProjectName)
        self.RedshiftClusterStorageClusterNameString = APIObject('RedshiftClusterStorageClusterNameString', 'string', r'^[0-9a-z].[a-z0-9\-]*$', 1, 63)
        self.add_api_object('RedshiftClusterStorageClusterNameString', self.RedshiftClusterStorageClusterNameString)
        self.RedshiftCredentialConfigurationSecretManagerArnString = APIObject('RedshiftCredentialConfigurationSecretManagerArnString', 'string', r'^arn:aws[^:]*:secretsmanager:[a-z]{2}-?(iso|gov)?-{1}[a-z]*-{1}[0-9]:\d{12}:secret:.*$', 0, 256)
        self.add_api_object('RedshiftCredentialConfigurationSecretManagerArnString', self.RedshiftCredentialConfigurationSecretManagerArnString)
        self.RedshiftRunConfigurationInputDataAccessRoleString = APIObject('RedshiftRunConfigurationInputDataAccessRoleString', 'string', r'^arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]{1,128}$', None, None)
        self.add_api_object('RedshiftRunConfigurationInputDataAccessRoleString', self.RedshiftRunConfigurationInputDataAccessRoleString)
        self.RedshiftRunConfigurationOutputAccountIdString = APIObject('RedshiftRunConfigurationOutputAccountIdString', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('RedshiftRunConfigurationOutputAccountIdString', self.RedshiftRunConfigurationOutputAccountIdString)
        self.RedshiftRunConfigurationOutputDataAccessRoleString = APIObject('RedshiftRunConfigurationOutputDataAccessRoleString', 'string', r'^arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]{1,128}$', None, None)
        self.add_api_object('RedshiftRunConfigurationOutputDataAccessRoleString', self.RedshiftRunConfigurationOutputDataAccessRoleString)
        self.RedshiftRunConfigurationOutputRegionString = APIObject('RedshiftRunConfigurationOutputRegionString', 'string', r'[a-z]{2}-?(iso|gov)?-{1}[a-z]*-{1}[0-9]', 4, 16)
        self.add_api_object('RedshiftRunConfigurationOutputRegionString', self.RedshiftRunConfigurationOutputRegionString)
        self.RedshiftServerlessStorageWorkgroupNameString = APIObject('RedshiftServerlessStorageWorkgroupNameString', 'string', r'^[a-z0-9-]+$', 3, 64)
        self.add_api_object('RedshiftServerlessStorageWorkgroupNameString', self.RedshiftServerlessStorageWorkgroupNameString)
        self.RegionName = APIObject('RegionName', 'string', r'^[a-z]{2}-?(iso|gov)?-{1}[a-z]*-{1}[0-9]$', 4, 16)
        self.add_api_object('RegionName', self.RegionName)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]*$', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SubscriptionGrantId = APIObject('SubscriptionGrantId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('SubscriptionGrantId', self.SubscriptionGrantId)
        self.SubscriptionId = APIObject('SubscriptionId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('SubscriptionId', self.SubscriptionId)
        self.SubscriptionRequestId = APIObject('SubscriptionRequestId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('SubscriptionRequestId', self.SubscriptionRequestId)
        self.SubscriptionTargetId = APIObject('SubscriptionTargetId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('SubscriptionTargetId', self.SubscriptionTargetId)
        self.TagKey = APIObject('TagKey', 'string', r'^[\w \.:/=+@-]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\w \.:/=+@-]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaskId = APIObject('TaskId', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('TaskId', self.TaskId)
        self.TimeSeriesDataPointIdentifier = APIObject('TimeSeriesDataPointIdentifier', 'string', r'^[a-zA-Z0-9_-]{1,36}$', None, None)
        self.add_api_object('TimeSeriesDataPointIdentifier', self.TimeSeriesDataPointIdentifier)
        self.TypeName = APIObject('TypeName', 'string', r'^[^\.]*', 1, 256)
        self.add_api_object('TypeName', self.TypeName)
        self.UserIdentifier = APIObject('UserIdentifier', 'string', r'(^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$|^[a-zA-Z_0-9+=,.@-]+$|^arn:aws:iam::\d{12}:.+$)', None, None)
        self.add_api_object('UserIdentifier', self.UserIdentifier)
        self.UserProfileId = APIObject('UserProfileId', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('UserProfileId', self.UserProfileId)
        self.UserProfileName = APIObject('UserProfileName', 'string', r'^[a-zA-Z_0-9+=,.@-]+$', 1, 1024)
        self.add_api_object('UserProfileName', self.UserProfileName)

class Dax(Service):
    def __init__(self):
        super().__init__('Dax')

class Deadline(Service):
    def __init__(self):
        super().__init__('Deadline')
        self.AggregationId = APIObject('AggregationId', 'string', r'^[0-9a-f]{32}$', None, None)
        self.add_api_object('AggregationId', self.AggregationId)
        self.AmountCapabilityName = APIObject('AmountCapabilityName', 'string', r'^([a-zA-Z][a-zA-Z0-9]{0,63}:)?amount(\.[a-zA-Z][a-zA-Z0-9]{0,63})+$', 1, 100)
        self.add_api_object('AmountCapabilityName', self.AmountCapabilityName)
        self.AttributeCapabilityName = APIObject('AttributeCapabilityName', 'string', r'^([a-zA-Z][a-zA-Z0-9]{0,63}:)?attr(\.[a-zA-Z][a-zA-Z0-9]{0,63})+$', 1, 100)
        self.add_api_object('AttributeCapabilityName', self.AttributeCapabilityName)
        self.AttributeCapabilityValue = APIObject('AttributeCapabilityValue', 'string', r'^[a-zA-Z_]([a-zA-Z0-9_\-]{0,99})$', 1, 100)
        self.add_api_object('AttributeCapabilityValue', self.AttributeCapabilityValue)
        self.BudgetId = APIObject('BudgetId', 'string', r'^budget-[0-9a-f]{32}$', None, None)
        self.add_api_object('BudgetId', self.BudgetId)
        self.DnsName = APIObject('DnsName', 'string', r'^vpce-[\w]+-[\w]+.vpce-svc-[\w]+.*.vpce.amazonaws.com$', None, None)
        self.add_api_object('DnsName', self.DnsName)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'^(STEP:step-[0-9a-f]{32}:.*)|(JOB:job-[0-9a-f]{32}:.*)$', 1, 1024)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.FarmId = APIObject('FarmId', 'string', r'^farm-[0-9a-f]{32}$', None, None)
        self.add_api_object('FarmId', self.FarmId)
        self.FileSystemLocationName = APIObject('FileSystemLocationName', 'string', r'^[0-9A-Za-z ]*$', 1, 64)
        self.add_api_object('FileSystemLocationName', self.FileSystemLocationName)
        self.FleetId = APIObject('FleetId', 'string', r'^fleet-[0-9a-f]{32}$', None, None)
        self.add_api_object('FleetId', self.FleetId)
        self.FloatString = APIObject('FloatString', 'string', r'^[-]?(0|[1-9][0-9]*)([.][0-9]+)?([eE][+-]?[0-9]+)?$', 1, 26)
        self.add_api_object('FloatString', self.FloatString)
        self.HostName = APIObject('HostName', 'string', r'^[a-zA-Z0-9_\.\-]{0,255}$', None, None)
        self.add_api_object('HostName', self.HostName)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:(aws[a-zA-Z-]*):iam::\d{12}:role(/[!-.0-~]+)*/[\w+=,.@-]+$', None, None)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IdentityCenterInstanceArn = APIObject('IdentityCenterInstanceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso:::instance/(sso)?ins-[a-zA-Z0-9-.]{16}$', None, None)
        self.add_api_object('IdentityCenterInstanceArn', self.IdentityCenterInstanceArn)
        self.IdentityCenterPrincipalId = APIObject('IdentityCenterPrincipalId', 'string', r'^([0-9a-f]{10}-|)[A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12}$', 1, 47)
        self.add_api_object('IdentityCenterPrincipalId', self.IdentityCenterPrincipalId)
        self.IdentityStoreId = APIObject('IdentityStoreId', 'string', r'^d-[0-9a-f]{10}$|^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', 1, 36)
        self.add_api_object('IdentityStoreId', self.IdentityStoreId)
        self.InstanceType = APIObject('InstanceType', 'string', r'^[a-zA-Z0-9]+\.[a-zA-Z0-9]+$', None, None)
        self.add_api_object('InstanceType', self.InstanceType)
        self.IntString = APIObject('IntString', 'string', r'^[-]?(0|[1-9][0-9]*)$', 1, 20)
        self.add_api_object('IntString', self.IntString)
        self.IpV4Address = APIObject('IpV4Address', 'string', r'^(?:[0-9]{1,3}\.){3}[0-9]{1,3}$', None, None)
        self.add_api_object('IpV4Address', self.IpV4Address)
        self.IpV6Address = APIObject('IpV6Address', 'string', r'^(?:[A-F0-9]{1,4}:){7}[A-F0-9]{1,4}$', None, None)
        self.add_api_object('IpV6Address', self.IpV6Address)
        self.JobId = APIObject('JobId', 'string', r'^job-[0-9a-f]{32}$', None, None)
        self.add_api_object('JobId', self.JobId)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:(aws[a-zA-Z-]*):kms:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:key/[\w-]{1,120}$', None, None)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LicenseEndpointId = APIObject('LicenseEndpointId', 'string', r'^le-[0-9a-f]{32}$', None, None)
        self.add_api_object('LicenseEndpointId', self.LicenseEndpointId)
        self.MeteredProductId = APIObject('MeteredProductId', 'string', r'^[0-9a-z]{1,32}-[.0-9a-z]{1,32}$', None, None)
        self.add_api_object('MeteredProductId', self.MeteredProductId)
        self.MonitorId = APIObject('MonitorId', 'string', r'^monitor-[0-9a-f]{32}$', None, None)
        self.add_api_object('MonitorId', self.MonitorId)
        self.PosixUserGroupString = APIObject('PosixUserGroupString', 'string', r'^(?:[a-z][a-z0-9-]{0,30})?$', 0, 31)
        self.add_api_object('PosixUserGroupString', self.PosixUserGroupString)
        self.PosixUserUserString = APIObject('PosixUserUserString', 'string', r'^(?:[a-z][a-z0-9-]{0,30})?$', 0, 31)
        self.add_api_object('PosixUserUserString', self.PosixUserUserString)
        self.QueueEnvironmentId = APIObject('QueueEnvironmentId', 'string', r'^queueenv-[0-9a-f]{32}$', None, None)
        self.add_api_object('QueueEnvironmentId', self.QueueEnvironmentId)
        self.QueueId = APIObject('QueueId', 'string', r'^queue-[0-9a-f]{32}$', None, None)
        self.add_api_object('QueueId', self.QueueId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-[\w]{1,120}$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SessionActionId = APIObject('SessionActionId', 'string', r'^sessionaction-[0-9a-f]{32}-(0|([1-9][0-9]{0,9}))$', None, None)
        self.add_api_object('SessionActionId', self.SessionActionId)
        self.SessionId = APIObject('SessionId', 'string', r'^session-[0-9a-f]{32}$', None, None)
        self.add_api_object('SessionId', self.SessionId)
        self.StepId = APIObject('StepId', 'string', r'^step-[0-9a-f]{32}$', None, None)
        self.add_api_object('StepId', self.StepId)
        self.StorageProfileId = APIObject('StorageProfileId', 'string', r'^sp-[0-9a-f]{32}$', None, None)
        self.add_api_object('StorageProfileId', self.StorageProfileId)
        self.Subdomain = APIObject('Subdomain', 'string', r'^[a-z0-9-]{1,100}$', None, None)
        self.add_api_object('Subdomain', self.Subdomain)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[\w]{1,120}$', 1, 32)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TaskId = APIObject('TaskId', 'string', r'^task-[0-9a-f]{32}-(0|([1-9][0-9]{0,9}))$', None, None)
        self.add_api_object('TaskId', self.TaskId)
        self.Timezone = APIObject('Timezone', 'string', r'^UTC[-+][01][0-9]:(30|00)$', 9, 9)
        self.add_api_object('Timezone', self.Timezone)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-[\w]{1,120}$', 1, 32)
        self.add_api_object('VpcId', self.VpcId)
        self.WindowsUserPasswordArnString = APIObject('WindowsUserPasswordArnString', 'string', r'^arn:(aws[a-zA-Z-]*):secretsmanager:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:secret:[a-zA-Z0-9-/_+=.@]{1,2028}$', 20, 2048)
        self.add_api_object('WindowsUserPasswordArnString', self.WindowsUserPasswordArnString)
        self.WindowsUserUserString = APIObject('WindowsUserUserString', 'string', r'^[^"\'/\[\]:;|=,+*?<>\s]*$', 0, 111)
        self.add_api_object('WindowsUserUserString', self.WindowsUserUserString)
        self.WorkerId = APIObject('WorkerId', 'string', r'^worker-[0-9a-f]{32}$', None, None)
        self.add_api_object('WorkerId', self.WorkerId)

class Detective(Service):
    def __init__(self):
        super().__init__('Detective')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]+$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'^.+@(?:(?:(?!-)[A-Za-z0-9-]{1,62})?[A-Za-z0-9]{1}\.)+[A-Za-z]{2,63}$', 1, 64)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.EntityArn = APIObject('EntityArn', 'string', r'^arn:.*', None, None)
        self.add_api_object('EntityArn', self.EntityArn)
        self.GraphArn = APIObject('GraphArn', 'string', r'^arn:aws[-\w]{0,10}?:detective:[-\w]{2,20}?:\d{12}?:graph:[abcdef\d]{32}?$', None, None)
        self.add_api_object('GraphArn', self.GraphArn)
        self.InvestigationId = APIObject('InvestigationId', 'string', r'^[0-9]+$', 21, 21)
        self.add_api_object('InvestigationId', self.InvestigationId)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Devicefarm(Service):
    def __init__(self):
        super().__init__('Devicefarm')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:.+', 32, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.DeviceFarmArn = APIObject('DeviceFarmArn', 'string', r'^arn:aws:devicefarm:.+', 32, 1011)
        self.add_api_object('DeviceFarmArn', self.DeviceFarmArn)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', 1, 4096)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.ResourceDescription = APIObject('ResourceDescription', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('ResourceDescription', self.ResourceDescription)
        self.ResourceId = APIObject('ResourceId', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-[0-9a-fA-F]{8,}$', 1, 4096)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[0-9a-fA-F]{8,}$', 1, 4096)
        self.add_api_object('SubnetId', self.SubnetId)

class DevopsGuru(Service):
    def __init__(self):
        super().__init__('DevopsGuru')
        self.AnomalyId = APIObject('AnomalyId', 'string', r'^[\w~.-]*$', 1, 100)
        self.add_api_object('AnomalyId', self.AnomalyId)
        self.AppBoundaryKey = APIObject('AppBoundaryKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('AppBoundaryKey', self.AppBoundaryKey)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9]+[a-zA-Z0-9-]*$', 1, 100)
        self.add_api_object('ClientToken', self.ClientToken)
        self.EventResourceArn = APIObject('EventResourceArn', 'string', r'^arn:aws[-a-z]*:[a-z0-9-]*:[a-z0-9-]*:\d{12}:.*$', 36, 2048)
        self.add_api_object('EventResourceArn', self.EventResourceArn)
        self.EventResourceName = APIObject('EventResourceName', 'string', r'^.*$', 0, 2048)
        self.add_api_object('EventResourceName', self.EventResourceName)
        self.EventResourceType = APIObject('EventResourceType', 'string', r'^.*$', 0, 2048)
        self.add_api_object('EventResourceType', self.EventResourceType)
        self.EventSource = APIObject('EventSource', 'string', r'^[a-z]+[a-z0-9]*\.amazonaws\.com|aws\.events$', 10, 50)
        self.add_api_object('EventSource', self.EventSource)
        self.InsightId = APIObject('InsightId', 'string', r'^[\w-]*$', 1, 100)
        self.add_api_object('InsightId', self.InsightId)
        self.InsightName = APIObject('InsightName', 'string', r'^[\s\S]*$', 1, 530)
        self.add_api_object('InsightName', self.InsightName)
        self.KMSKeyId = APIObject('KMSKeyId', 'string', r'^.*$', 1, 2048)
        self.add_api_object('KMSKeyId', self.KMSKeyId)
        self.MonitoredResourceName = APIObject('MonitoredResourceName', 'string', r'[\.\-_\/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('MonitoredResourceName', self.MonitoredResourceName)
        self.NotificationChannelId = APIObject('NotificationChannelId', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 36, 36)
        self.add_api_object('NotificationChannelId', self.NotificationChannelId)
        self.OrganizationalUnitId = APIObject('OrganizationalUnitId', 'string', r'^ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$', None, 68)
        self.add_api_object('OrganizationalUnitId', self.OrganizationalUnitId)
        self.ResourceType = APIObject('ResourceType', 'string', r'^[a-zA-Z]+[a-zA-Z0-9-_:]*$', 1, 256)
        self.add_api_object('ResourceType', self.ResourceType)
        self.SsmOpsItemId = APIObject('SsmOpsItemId', 'string', r'^.*$', 1, 100)
        self.add_api_object('SsmOpsItemId', self.SsmOpsItemId)
        self.StackName = APIObject('StackName', 'string', r'^[a-zA-Z*]+[a-zA-Z0-9-]*$', 1, 128)
        self.add_api_object('StackName', self.StackName)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*|\*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TopicArn = APIObject('TopicArn', 'string', r'^arn:aws[a-z0-9-]*:sns:[a-z0-9-]+:\d{12}:[^:]+$', 36, 1024)
        self.add_api_object('TopicArn', self.TopicArn)
        self.UuidNextToken = APIObject('UuidNextToken', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 36, 36)
        self.add_api_object('UuidNextToken', self.UuidNextToken)

class Directconnect(Service):
    def __init__(self):
        super().__init__('Directconnect')
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Discovery(Service):
    def __init__(self):
        super().__init__('Discovery')
        self.AgentId = APIObject('AgentId', 'string', r'\S+', 10, 20)
        self.add_api_object('AgentId', self.AgentId)
        self.ApplicationDescription = APIObject('ApplicationDescription', 'string', r'(^$|[\s\S]*\S[\s\S]*)', None, 1000)
        self.add_api_object('ApplicationDescription', self.ApplicationDescription)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'\S+', None, 200)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'[\s\S]*\S[\s\S]*', None, 127)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.Condition = APIObject('Condition', 'string', r'\S+', None, 200)
        self.add_api_object('Condition', self.Condition)
        self.ConfigurationId = APIObject('ConfigurationId', 'string', r'\S*', None, 200)
        self.add_api_object('ConfigurationId', self.ConfigurationId)
        self.ConfigurationsExportId = APIObject('ConfigurationsExportId', 'string', r'\S*', None, 200)
        self.add_api_object('ConfigurationsExportId', self.ConfigurationsExportId)
        self.EC2InstanceType = APIObject('EC2InstanceType', 'string', r'[a-zA-Z0-9\d\.\-]+', 1, 25)
        self.add_api_object('EC2InstanceType', self.EC2InstanceType)
        self.FilterName = APIObject('FilterName', 'string', r'[\s\S]*\S[\s\S]*', None, 1000)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValue = APIObject('FilterValue', 'string', r'(^$|[\s\S]*\S[\s\S]*)', None, 1000)
        self.add_api_object('FilterValue', self.FilterValue)
        self.ImportTaskIdentifier = APIObject('ImportTaskIdentifier', 'string', r'^import-task-[a-fA-F0-9]{32}$', None, 200)
        self.add_api_object('ImportTaskIdentifier', self.ImportTaskIdentifier)
        self.ImportTaskName = APIObject('ImportTaskName', 'string', r'[\s\S]*\S[\s\S]*', 1, 255)
        self.add_api_object('ImportTaskName', self.ImportTaskName)
        self.ImportURL = APIObject('ImportURL', 'string', r'\S+://\S+/[\s\S]*\S[\s\S]*', 1, 4000)
        self.add_api_object('ImportURL', self.ImportURL)
        self.OrderByElementFieldName = APIObject('OrderByElementFieldName', 'string', r'[\s\S]*\S[\s\S]*', None, 1000)
        self.add_api_object('OrderByElementFieldName', self.OrderByElementFieldName)
        self.String = APIObject('String', 'string', r'[\s\S]*', None, 10000)
        self.add_api_object('String', self.String)
        self.StringMax255 = APIObject('StringMax255', 'string', r'[\s\S]*\S[\s\S]*', 1, 255)
        self.add_api_object('StringMax255', self.StringMax255)
        self.UUID = APIObject('UUID', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('UUID', self.UUID)
        self.UsageMetricBasisName = APIObject('UsageMetricBasisName', 'string', r'^(p(\d{1,2}|100)|AVG|SPEC|MAX)$', None, None)
        self.add_api_object('UsageMetricBasisName', self.UsageMetricBasisName)
        self.UserPreferredRegion = APIObject('UserPreferredRegion', 'string', r'[a-z]{2}-[a-z\-]+-[0-9]+', 1, 30)
        self.add_api_object('UserPreferredRegion', self.UserPreferredRegion)

class Dlm(Service):
    def __init__(self):
        super().__init__('Dlm')
        self.ActionName = APIObject('ActionName', 'string', r'[0-9A-Za-z _-]+', 0, 120)
        self.add_api_object('ActionName', self.ActionName)
        self.AvailabilityZone = APIObject('AvailabilityZone', 'string', r'([a-z]+-){2,3}\d[a-z]', 0, 16)
        self.add_api_object('AvailabilityZone', self.AvailabilityZone)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.CmkArn = APIObject('CmkArn', 'string', r'arn:aws(-[a-z]{1,3}){0,2}:kms:([a-z]+-){2,3}\d:\d+:key/.*', 0, 2048)
        self.add_api_object('CmkArn', self.CmkArn)
        self.CronExpression = APIObject('CronExpression', 'string', r'cron\([^\n]{11,100}\)', 17, 106)
        self.add_api_object('CronExpression', self.CronExpression)
        self.DescriptionRegex = APIObject('DescriptionRegex', 'string', r'[\p{all}]*', 0, 1000)
        self.add_api_object('DescriptionRegex', self.DescriptionRegex)
        self.ExecutionHandler = APIObject('ExecutionHandler', 'string', r'^([a-zA-Z0-9_\-.]{3,128}|[a-zA-Z0-9_\-.:/]{3,200}|[A-Z0-9_]+)$', 0, 200)
        self.add_api_object('ExecutionHandler', self.ExecutionHandler)
        self.ExecutionRoleArn = APIObject('ExecutionRoleArn', 'string', r'arn:aws(-[a-z]{1,3}){0,2}:iam::\d+:role/.*', 0, 2048)
        self.add_api_object('ExecutionRoleArn', self.ExecutionRoleArn)
        self.PolicyArn = APIObject('PolicyArn', 'string', r'^arn:aws(-[a-z]{1,3}){0,2}:dlm:[A-Za-z0-9_/.-]{0,63}:\d+:policy/[0-9A-Za-z_-]{1,128}$', 0, 2048)
        self.add_api_object('PolicyArn', self.PolicyArn)
        self.PolicyDescription = APIObject('PolicyDescription', 'string', r'[0-9A-Za-z _-]+', 0, 500)
        self.add_api_object('PolicyDescription', self.PolicyDescription)
        self.PolicyId = APIObject('PolicyId', 'string', r'policy-[a-f0-9]+', 0, 64)
        self.add_api_object('PolicyId', self.PolicyId)
        self.ScheduleName = APIObject('ScheduleName', 'string', r'[0-9A-Za-z _-]+', 0, 120)
        self.add_api_object('ScheduleName', self.ScheduleName)
        self.StatusMessage = APIObject('StatusMessage', 'string', r'[\p{all}]*', 0, 500)
        self.add_api_object('StatusMessage', self.StatusMessage)
        self.String = APIObject('String', 'string', r'[\p{all}]*', 0, 500)
        self.add_api_object('String', self.String)
        self.TagFilter = APIObject('TagFilter', 'string', r'[\p{all}]*', 0, 256)
        self.add_api_object('TagFilter', self.TagFilter)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\p{all}]*', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Target = APIObject('Target', 'string', r'^[\w:\-\/\*]+$', 0, 2048)
        self.add_api_object('Target', self.Target)
        self.TargetRegion = APIObject('TargetRegion', 'string', r'([a-z]+-){2,3}\d', 0, 16)
        self.add_api_object('TargetRegion', self.TargetRegion)
        self.Time = APIObject('Time', 'string', r'^(0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$', 5, 5)
        self.add_api_object('Time', self.Time)

class Dms(Service):
    def __init__(self):
        super().__init__('Dms')

class DocdbElastic(Service):
    def __init__(self):
        super().__init__('DocdbElastic')
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Docdb(Service):
    def __init__(self):
        super().__init__('Docdb')
        self.GlobalClusterIdentifier = APIObject('GlobalClusterIdentifier', 'string', r'[A-Za-z][0-9A-Za-z-:._]*', 1, 255)
        self.add_api_object('GlobalClusterIdentifier', self.GlobalClusterIdentifier)

class Drs(Service):
    def __init__(self):
        super().__init__('Drs')
        self.ARN = APIObject('ARN', 'string', r'^arn:.{16,2044}$', 20, 2048)
        self.add_api_object('ARN', self.ARN)
        self.AccountID = APIObject('AccountID', 'string', r'[0-9]{12,}', 12, 12)
        self.add_api_object('AccountID', self.AccountID)
        self.AgentVersion = APIObject('AgentVersion', 'string', r'^[0-9]{1,5}.[0-9]{1,5}.[0-9]{1,5}(.[0-9]{4}.[0-9]{3}.[0-9]{4})?$', None, None)
        self.add_api_object('AgentVersion', self.AgentVersion)
        self.AwsAvailabilityZone = APIObject('AwsAvailabilityZone', 'string', r'^(us(-gov)?|ap|ca|cn|eu|sa|af|me|il)-(central|north|(north(?:east|west))|south|south(?:east|west)|east|west)-[0-9][a-z]$', 0, 255)
        self.add_api_object('AwsAvailabilityZone', self.AwsAvailabilityZone)
        self.AwsRegion = APIObject('AwsRegion', 'string', r'^(us(-gov)?|ap|ca|cn|eu|sa|af|me|il)-(central|north|(north(?:east|west))|south|south(?:east|west)|east|west)-[0-9]$', 0, 255)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.CfnStackName = APIObject('CfnStackName', 'string', r'^[a-zA-Z][-a-zA-Z0-9]*$', 1, 128)
        self.add_api_object('CfnStackName', self.CfnStackName)
        self.EC2InstanceID = APIObject('EC2InstanceID', 'string', r'^i-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('EC2InstanceID', self.EC2InstanceID)
        self.EbsSnapshot = APIObject('EbsSnapshot', 'string', r'^snap-[0-9a-zA-Z]{17}$', None, None)
        self.add_api_object('EbsSnapshot', self.EbsSnapshot)
        self.EbsVolumeID = APIObject('EbsVolumeID', 'string', r'^vol-([0-9a-fA-F]{8}|[0-9a-fA-F]{17})$', 10, 19)
        self.add_api_object('EbsVolumeID', self.EbsVolumeID)
        self.FailureReason = APIObject('FailureReason', 'string', r'^[0-9a-zA-Z ():/.,\'-_#*;]*$', 0, 256)
        self.add_api_object('FailureReason', self.FailureReason)
        self.ISO8601DatetimeString = APIObject('ISO8601DatetimeString', 'string', r'^[1-9][0-9]*-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]+)?Z$', 19, 32)
        self.add_api_object('ISO8601DatetimeString', self.ISO8601DatetimeString)
        self.JobID = APIObject('JobID', 'string', r'^drsjob-[0-9a-zA-Z]{17}$', 24, 24)
        self.add_api_object('JobID', self.JobID)
        self.LaunchActionDescription = APIObject('LaunchActionDescription', 'string', r'^[0-9a-zA-Z ():/.,\'-_#*; ]*$', 0, 1024)
        self.add_api_object('LaunchActionDescription', self.LaunchActionDescription)
        self.LaunchActionId = APIObject('LaunchActionId', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', 1, 64)
        self.add_api_object('LaunchActionId', self.LaunchActionId)
        self.LaunchActionName = APIObject('LaunchActionName', 'string', r'^[A-Za-z0-9][A-Za-z0-9 /_-]*$', 1, 256)
        self.add_api_object('LaunchActionName', self.LaunchActionName)
        self.LaunchActionParameterName = APIObject('LaunchActionParameterName', 'string', r'^([A-Za-z0-9])+$', 1, 1011)
        self.add_api_object('LaunchActionParameterName', self.LaunchActionParameterName)
        self.LaunchActionParameterValue = APIObject('LaunchActionParameterValue', 'string', r'^[A-Za-z0-9.-]+$', 1, 1011)
        self.add_api_object('LaunchActionParameterValue', self.LaunchActionParameterValue)
        self.LaunchActionResourceId = APIObject('LaunchActionResourceId', 'string', r'^(s-[0-9a-zA-Z]{17}$|lct-[0-9a-zA-Z]{17})$', None, None)
        self.add_api_object('LaunchActionResourceId', self.LaunchActionResourceId)
        self.LaunchActionRunId = APIObject('LaunchActionRunId', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', 1, 64)
        self.add_api_object('LaunchActionRunId', self.LaunchActionRunId)
        self.LaunchActionVersion = APIObject('LaunchActionVersion', 'string', r'^(\$DEFAULT|\$LATEST|[0-9]+)$', 1, 10)
        self.add_api_object('LaunchActionVersion', self.LaunchActionVersion)
        self.LaunchConfigurationTemplateID = APIObject('LaunchConfigurationTemplateID', 'string', r'^lct-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('LaunchConfigurationTemplateID', self.LaunchConfigurationTemplateID)
        self.OutpostARN = APIObject('OutpostARN', 'string', r'^arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/op-[a-f0-9]{17}$', 20, 255)
        self.add_api_object('OutpostARN', self.OutpostARN)
        self.ProductCodeId = APIObject('ProductCodeId', 'string', r'^([A-Za-z0-9])+$', 25, 25)
        self.add_api_object('ProductCodeId', self.ProductCodeId)
        self.RecoveryInstanceID = APIObject('RecoveryInstanceID', 'string', r'^i-[0-9a-fA-F]{8,}$', 10, 19)
        self.add_api_object('RecoveryInstanceID', self.RecoveryInstanceID)
        self.RecoverySnapshotID = APIObject('RecoverySnapshotID', 'string', r'^pit-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('RecoverySnapshotID', self.RecoverySnapshotID)
        self.ReplicationConfigurationTemplateID = APIObject('ReplicationConfigurationTemplateID', 'string', r'^rct-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('ReplicationConfigurationTemplateID', self.ReplicationConfigurationTemplateID)
        self.SecurityGroupID = APIObject('SecurityGroupID', 'string', r'^sg-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('SecurityGroupID', self.SecurityGroupID)
        self.SourceNetworkID = APIObject('SourceNetworkID', 'string', r'^sn-[0-9a-zA-Z]{17}$', 20, 20)
        self.add_api_object('SourceNetworkID', self.SourceNetworkID)
        self.SourceServerARN = APIObject('SourceServerARN', 'string', r'^arn:(?:[0-9a-zA-Z_-]+:){3}([0-9]{12,}):source-server/(s-[0-9a-zA-Z]{17})$', 20, 2048)
        self.add_api_object('SourceServerARN', self.SourceServerARN)
        self.SourceServerID = APIObject('SourceServerID', 'string', r'^s-[0-9a-zA-Z]{17}$', 19, 19)
        self.add_api_object('SourceServerID', self.SourceServerID)
        self.SsmDocumentName = APIObject('SsmDocumentName', 'string', r'^([A-Za-z0-9-/:])+$', 1, 1011)
        self.add_api_object('SsmDocumentName', self.SsmDocumentName)
        self.SubnetID = APIObject('SubnetID', 'string', r'^subnet-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('SubnetID', self.SubnetID)
        self.VpcID = APIObject('VpcID', 'string', r'^vpc-[0-9a-fA-F]{8,}$', 12, 21)
        self.add_api_object('VpcID', self.VpcID)

class Ds(Service):
    def __init__(self):
        super().__init__('Ds')
        self.AliasName = APIObject('AliasName', 'string', r'^(?!D-|d-)([\da-zA-Z]+)([-]*[\da-zA-Z])*', 1, 62)
        self.add_api_object('AliasName', self.AliasName)
        self.CertificateId = APIObject('CertificateId', 'string', r'^c-[0-9a-f]{10}$', None, None)
        self.add_api_object('CertificateId', self.CertificateId)
        self.CidrIp = APIObject('CidrIp', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(\/([1-9]|[1-2][0-9]|3[0-2]))$', None, None)
        self.add_api_object('CidrIp', self.CidrIp)
        self.ComputerPassword = APIObject('ComputerPassword', 'string', r'[\u0020-\u00FF]+', 8, 64)
        self.add_api_object('ComputerPassword', self.ComputerPassword)
        self.CustomerId = APIObject('CustomerId', 'string', r'^(\d{12})$', None, None)
        self.add_api_object('CustomerId', self.CustomerId)
        self.CustomerUserName = APIObject('CustomerUserName', 'string', r'^(?!.*\\|.*"|.*\/|.*\[|.*\]|.*:|.*;|.*\||.*=|.*,|.*\+|.*\*|.*\?|.*<|.*>|.*@).*$', 1, 64)
        self.add_api_object('CustomerUserName', self.CustomerUserName)
        self.Description = APIObject('Description', 'string', r'^([a-zA-Z0-9_])[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', 0, 128)
        self.add_api_object('Description', self.Description)
        self.DirectoryConfigurationSettingName = APIObject('DirectoryConfigurationSettingName', 'string', r'^[a-zA-Z0-9-/. _]*$', 1, 255)
        self.add_api_object('DirectoryConfigurationSettingName', self.DirectoryConfigurationSettingName)
        self.DirectoryConfigurationSettingValue = APIObject('DirectoryConfigurationSettingValue', 'string', r'^[a-zA-Z0-9_]*$', 1, 255)
        self.add_api_object('DirectoryConfigurationSettingValue', self.DirectoryConfigurationSettingValue)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', None, None)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.DirectoryName = APIObject('DirectoryName', 'string', r'^([a-zA-Z0-9]+[\\.-])+([a-zA-Z0-9])+$', None, None)
        self.add_api_object('DirectoryName', self.DirectoryName)
        self.DirectoryShortName = APIObject('DirectoryShortName', 'string', r'^[^\\/:*?"<>|.]+[^\\/:*?"<>|]*$', None, None)
        self.add_api_object('DirectoryShortName', self.DirectoryShortName)
        self.DomainControllerId = APIObject('DomainControllerId', 'string', r'^dc-[0-9a-f]{10}$', None, None)
        self.add_api_object('DomainControllerId', self.DomainControllerId)
        self.IpAddr = APIObject('IpAddr', 'string', r'^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$', None, None)
        self.add_api_object('IpAddr', self.IpAddr)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[-._/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.OCSPUrl = APIObject('OCSPUrl', 'string', r'^(https?|ftp|file|ldaps?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;()]*[-a-zA-Z0-9+&@#/%=~_|()]', 1, 1024)
        self.add_api_object('OCSPUrl', self.OCSPUrl)
        self.Password = APIObject('Password', 'string', r'(?=^.{8,64}$)((?=.*\d)(?=.*[A-Z])(?=.*[a-z])|(?=.*\d)(?=.*[^A-Za-z0-9\s])(?=.*[a-z])|(?=.*[^A-Za-z0-9\s])(?=.*[A-Z])(?=.*[a-z])|(?=.*\d)(?=.*[A-Z])(?=.*[^A-Za-z0-9\s]))^.*', None, None)
        self.add_api_object('Password', self.Password)
        self.RadiusSharedSecret = APIObject('RadiusSharedSecret', 'string', r'^(\p{LD}|\p{Punct}| )+$', 8, 512)
        self.add_api_object('RadiusSharedSecret', self.RadiusSharedSecret)
        self.RemoteDomainName = APIObject('RemoteDomainName', 'string', r'^([a-zA-Z0-9]+[\\.-])+([a-zA-Z0-9])+[.]?$', None, 1024)
        self.add_api_object('RemoteDomainName', self.RemoteDomainName)
        self.RequestId = APIObject('RequestId', 'string', r'^([A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12})$', None, None)
        self.add_api_object('RequestId', self.RequestId)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[d]-[0-9a-f]{10}$', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SID = APIObject('SID', 'string', r'[&\w+-.@]+', 1, 256)
        self.add_api_object('SID', self.SID)
        self.SchemaExtensionId = APIObject('SchemaExtensionId', 'string', r'^e-[0-9a-f]{10}$', None, None)
        self.add_api_object('SchemaExtensionId', self.SchemaExtensionId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^(sg-[0-9a-f]{8}|sg-[0-9a-f]{17})$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'^s-[0-9a-f]{10}$', None, None)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.SnapshotName = APIObject('SnapshotName', 'string', r'^([a-zA-Z0-9_])[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', 0, 128)
        self.add_api_object('SnapshotName', self.SnapshotName)
        self.SubnetId = APIObject('SubnetId', 'string', r'^(subnet-[0-9a-f]{8}|subnet-[0-9a-f]{17})$', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TopicName = APIObject('TopicName', 'string', r'[a-zA-Z0-9_-]+', 1, 256)
        self.add_api_object('TopicName', self.TopicName)
        self.TrustId = APIObject('TrustId', 'string', r'^t-[0-9a-f]{10}$', None, None)
        self.add_api_object('TrustId', self.TrustId)
        self.TrustPassword = APIObject('TrustPassword', 'string', r'^(\p{LD}|\p{Punct}| )+$', 1, 128)
        self.add_api_object('TrustPassword', self.TrustPassword)
        self.UserName = APIObject('UserName', 'string', r'[a-zA-Z0-9._-]+', 1, None)
        self.add_api_object('UserName', self.UserName)
        self.VpcId = APIObject('VpcId', 'string', r'^(vpc-[0-9a-f]{8}|vpc-[0-9a-f]{17})$', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Dynamodb(Service):
    def __init__(self):
        super().__init__('Dynamodb')
        self.AliasName = APIObject('AliasName', 'string', r'^(?!D-|d-)([\da-zA-Z]+)([-]*[\da-zA-Z])*', 1, 62)
        self.add_api_object('AliasName', self.AliasName)
        self.CertificateId = APIObject('CertificateId', 'string', r'^c-[0-9a-f]{10}$', None, None)
        self.add_api_object('CertificateId', self.CertificateId)
        self.CidrIp = APIObject('CidrIp', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(\/([1-9]|[1-2][0-9]|3[0-2]))$', None, None)
        self.add_api_object('CidrIp', self.CidrIp)
        self.ComputerPassword = APIObject('ComputerPassword', 'string', r'[\u0020-\u00FF]+', 8, 64)
        self.add_api_object('ComputerPassword', self.ComputerPassword)
        self.CustomerId = APIObject('CustomerId', 'string', r'^(\d{12})$', None, None)
        self.add_api_object('CustomerId', self.CustomerId)
        self.CustomerUserName = APIObject('CustomerUserName', 'string', r'^(?!.*\\|.*"|.*\/|.*\[|.*\]|.*:|.*;|.*\||.*=|.*,|.*\+|.*\*|.*\?|.*<|.*>|.*@).*$', 1, 64)
        self.add_api_object('CustomerUserName', self.CustomerUserName)
        self.Description = APIObject('Description', 'string', r'^([a-zA-Z0-9_])[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', 0, 128)
        self.add_api_object('Description', self.Description)
        self.DirectoryConfigurationSettingName = APIObject('DirectoryConfigurationSettingName', 'string', r'^[a-zA-Z0-9-/. _]*$', 1, 255)
        self.add_api_object('DirectoryConfigurationSettingName', self.DirectoryConfigurationSettingName)
        self.DirectoryConfigurationSettingValue = APIObject('DirectoryConfigurationSettingValue', 'string', r'^[a-zA-Z0-9_]*$', 1, 255)
        self.add_api_object('DirectoryConfigurationSettingValue', self.DirectoryConfigurationSettingValue)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', None, None)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.DirectoryName = APIObject('DirectoryName', 'string', r'^([a-zA-Z0-9]+[\\.-])+([a-zA-Z0-9])+$', None, None)
        self.add_api_object('DirectoryName', self.DirectoryName)
        self.DirectoryShortName = APIObject('DirectoryShortName', 'string', r'^[^\\/:*?"<>|.]+[^\\/:*?"<>|]*$', None, None)
        self.add_api_object('DirectoryShortName', self.DirectoryShortName)
        self.DomainControllerId = APIObject('DomainControllerId', 'string', r'^dc-[0-9a-f]{10}$', None, None)
        self.add_api_object('DomainControllerId', self.DomainControllerId)
        self.IpAddr = APIObject('IpAddr', 'string', r'^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$', None, None)
        self.add_api_object('IpAddr', self.IpAddr)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[-._/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.OCSPUrl = APIObject('OCSPUrl', 'string', r'^(https?|ftp|file|ldaps?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;()]*[-a-zA-Z0-9+&@#/%=~_|()]', 1, 1024)
        self.add_api_object('OCSPUrl', self.OCSPUrl)
        self.Password = APIObject('Password', 'string', r'(?=^.{8,64}$)((?=.*\d)(?=.*[A-Z])(?=.*[a-z])|(?=.*\d)(?=.*[^A-Za-z0-9\s])(?=.*[a-z])|(?=.*[^A-Za-z0-9\s])(?=.*[A-Z])(?=.*[a-z])|(?=.*\d)(?=.*[A-Z])(?=.*[^A-Za-z0-9\s]))^.*', None, None)
        self.add_api_object('Password', self.Password)
        self.RadiusSharedSecret = APIObject('RadiusSharedSecret', 'string', r'^(\p{LD}|\p{Punct}| )+$', 8, 512)
        self.add_api_object('RadiusSharedSecret', self.RadiusSharedSecret)
        self.RemoteDomainName = APIObject('RemoteDomainName', 'string', r'^([a-zA-Z0-9]+[\\.-])+([a-zA-Z0-9])+[.]?$', None, 1024)
        self.add_api_object('RemoteDomainName', self.RemoteDomainName)
        self.RequestId = APIObject('RequestId', 'string', r'^([A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12})$', None, None)
        self.add_api_object('RequestId', self.RequestId)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[d]-[0-9a-f]{10}$', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SID = APIObject('SID', 'string', r'[&\w+-.@]+', 1, 256)
        self.add_api_object('SID', self.SID)
        self.SchemaExtensionId = APIObject('SchemaExtensionId', 'string', r'^e-[0-9a-f]{10}$', None, None)
        self.add_api_object('SchemaExtensionId', self.SchemaExtensionId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^(sg-[0-9a-f]{8}|sg-[0-9a-f]{17})$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'^s-[0-9a-f]{10}$', None, None)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.SnapshotName = APIObject('SnapshotName', 'string', r'^([a-zA-Z0-9_])[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', 0, 128)
        self.add_api_object('SnapshotName', self.SnapshotName)
        self.SubnetId = APIObject('SubnetId', 'string', r'^(subnet-[0-9a-f]{8}|subnet-[0-9a-f]{17})$', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TopicName = APIObject('TopicName', 'string', r'[a-zA-Z0-9_-]+', 1, 256)
        self.add_api_object('TopicName', self.TopicName)
        self.TrustId = APIObject('TrustId', 'string', r'^t-[0-9a-f]{10}$', None, None)
        self.add_api_object('TrustId', self.TrustId)
        self.TrustPassword = APIObject('TrustPassword', 'string', r'^(\p{LD}|\p{Punct}| )+$', 1, 128)
        self.add_api_object('TrustPassword', self.TrustPassword)
        self.UserName = APIObject('UserName', 'string', r'[a-zA-Z0-9._-]+', 1, None)
        self.add_api_object('UserName', self.UserName)
        self.VpcId = APIObject('VpcId', 'string', r'^(vpc-[0-9a-f]{8}|vpc-[0-9a-f]{17})$', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Dynamodbstreams(Service):
    def __init__(self):
        super().__init__('Dynamodbstreams')
        self.TableName = APIObject('TableName', 'string', r'[a-zA-Z0-9_.-]+', 3, 255)
        self.add_api_object('TableName', self.TableName)

class Ebs(Service):
    def __init__(self):
        super().__init__('Ebs')
        self.BlockToken = APIObject('BlockToken', 'string', r'^[A-Za-z0-9+/=]+$', None, 256)
        self.add_api_object('BlockToken', self.BlockToken)
        self.Checksum = APIObject('Checksum', 'string', r'^[A-Za-z0-9+/=]+$', None, 64)
        self.add_api_object('Checksum', self.Checksum)
        self.ChecksumAggregationMethod = APIObject('ChecksumAggregationMethod', 'string', r'^[A-Za-z0-9]+$', None, 32)
        self.add_api_object('ChecksumAggregationMethod', self.ChecksumAggregationMethod)
        self.ChecksumAlgorithm = APIObject('ChecksumAlgorithm', 'string', r'^[A-Za-z0-9]+$', None, 32)
        self.add_api_object('ChecksumAlgorithm', self.ChecksumAlgorithm)
        self.Description = APIObject('Description', 'string', r'^[\S\s]+$', None, 255)
        self.add_api_object('Description', self.Description)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'^[\S]+$', None, 255)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws[a-z\-]*:kms:.*:[0-9]{12}:key/.*', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.OwnerId = APIObject('OwnerId', 'string', r'\S+', 1, 24)
        self.add_api_object('OwnerId', self.OwnerId)
        self.PageToken = APIObject('PageToken', 'string', r'^[A-Za-z0-9+/=]+$', None, 256)
        self.add_api_object('PageToken', self.PageToken)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'^snap-[0-9a-f]+$', 1, 64)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.TagKey = APIObject('TagKey', 'string', r'^[\S\s]+$', None, 127)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\S\s]*$', None, 255)
        self.add_api_object('TagValue', self.TagValue)

class Ec2InstanceConnect(Service):
    def __init__(self):
        super().__init__('Ec2InstanceConnect')
        self.AvailabilityZone = APIObject('AvailabilityZone', 'string', r'^(\w+-){2,3}\d+\w+$', 6, 32)
        self.add_api_object('AvailabilityZone', self.AvailabilityZone)
        self.InstanceId = APIObject('InstanceId', 'string', r'^i-[a-f0-9]+$', 10, 32)
        self.add_api_object('InstanceId', self.InstanceId)
        self.InstanceOSUser = APIObject('InstanceOSUser', 'string', r'(^[A-Za-z_][A-Za-z0-9\@\._-]{0,30}[A-Za-z0-9\$_-]?$)|(^(?=.{2,32}$)[0-9]{1,32}[A-Za-z\@\._-][A-Za-z0-9\@\._-]*[A-Za-z0-9\$_-]?$)', 1, 32)
        self.add_api_object('InstanceOSUser', self.InstanceOSUser)

class Ec2(Service):
    def __init__(self):
        super().__init__('Ec2')

class EcrPublic(Service):
    def __init__(self):
        super().__init__('EcrPublic')
        self.Base64 = APIObject('Base64', 'string', r'^\S+$', None, None)
        self.add_api_object('Base64', self.Base64)
        self.LayerDigest = APIObject('LayerDigest', 'string', r'[a-zA-Z0-9-_+.]+:[a-fA-F0-9]+', None, None)
        self.add_api_object('LayerDigest', self.LayerDigest)
        self.RegistryAliasName = APIObject('RegistryAliasName', 'string', r'[a-z][a-z0-9]+(?:[._-][a-z0-9]+)*', 2, 50)
        self.add_api_object('RegistryAliasName', self.RegistryAliasName)
        self.RegistryId = APIObject('RegistryId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('RegistryId', self.RegistryId)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'(?:[a-z0-9]+(?:[._-][a-z0-9]+)*/)*[a-z0-9]+(?:[._-][a-z0-9]+)*', 2, 205)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.UploadId = APIObject('UploadId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('UploadId', self.UploadId)

class Ecr(Service):
    def __init__(self):
        super().__init__('Ecr')
        self.Base64 = APIObject('Base64', 'string', r'^\S+$', None, None)
        self.add_api_object('Base64', self.Base64)
        self.CredentialArn = APIObject('CredentialArn', 'string', r'^arn:aws:secretsmanager:[a-zA-Z0-9-:]+:secret:ecr\-pullthroughcache\/[a-zA-Z0-9\/_+=.@-]+$', 50, 612)
        self.add_api_object('CredentialArn', self.CredentialArn)
        self.LayerDigest = APIObject('LayerDigest', 'string', r'[a-zA-Z0-9-_+.]+:[a-fA-F0-9]+', None, None)
        self.add_api_object('LayerDigest', self.LayerDigest)
        self.PullThroughCacheRuleRepositoryPrefix = APIObject('PullThroughCacheRuleRepositoryPrefix', 'string', r'(?:[a-z0-9]+(?:[._-][a-z0-9]+)*/)*[a-z0-9]+(?:[._-][a-z0-9]+)*', 2, 30)
        self.add_api_object('PullThroughCacheRuleRepositoryPrefix', self.PullThroughCacheRuleRepositoryPrefix)
        self.Region = APIObject('Region', 'string', r'[0-9a-z-]{2,25}', 2, 25)
        self.add_api_object('Region', self.Region)
        self.RegistryId = APIObject('RegistryId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('RegistryId', self.RegistryId)
        self.RepositoryFilterValue = APIObject('RepositoryFilterValue', 'string', r'^(?:[a-z0-9]+(?:[._-][a-z0-9]*)*/)*[a-z0-9]*(?:[._-][a-z0-9]*)*$', 2, 256)
        self.add_api_object('RepositoryFilterValue', self.RepositoryFilterValue)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'(?:[a-z0-9]+(?:[._-][a-z0-9]+)*/)*[a-z0-9]+(?:[._-][a-z0-9]+)*', 2, 256)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.ScanningRepositoryFilterValue = APIObject('ScanningRepositoryFilterValue', 'string', r'^[a-z0-9*](?:[._\-/a-z0-9*]?[a-z0-9*]+)*$', 1, 255)
        self.add_api_object('ScanningRepositoryFilterValue', self.ScanningRepositoryFilterValue)
        self.UploadId = APIObject('UploadId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('UploadId', self.UploadId)

class Ecs(Service):
    def __init__(self):
        super().__init__('Ecs')
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Efs(Service):
    def __init__(self):
        super().__init__('Efs')
        self.AccessPointArn = APIObject('AccessPointArn', 'string', r'^arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:access-point/fsap-[0-9a-f]{8,40}$', None, 128)
        self.add_api_object('AccessPointArn', self.AccessPointArn)
        self.AccessPointId = APIObject('AccessPointId', 'string', r'^(arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:access-point/fsap-[0-9a-f]{8,40}|fsap-[0-9a-f]{8,40})$', None, 128)
        self.add_api_object('AccessPointId', self.AccessPointId)
        self.AvailabilityZoneName = APIObject('AvailabilityZoneName', 'string', r'.+', 1, 64)
        self.add_api_object('AvailabilityZoneName', self.AvailabilityZoneName)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^(\d{12})|(\d{4}-\d{4}-\d{4})$', None, 14)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.ClientToken = APIObject('ClientToken', 'string', r'.+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CreationToken = APIObject('CreationToken', 'string', r'.+', 1, 64)
        self.add_api_object('CreationToken', self.CreationToken)
        self.FileSystemId = APIObject('FileSystemId', 'string', r'^(arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:file-system/fs-[0-9a-f]{8,40}|fs-[0-9a-f]{8,40})$', None, 128)
        self.add_api_object('FileSystemId', self.FileSystemId)
        self.IpAddress = APIObject('IpAddress', 'string', r'^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$', 7, 15)
        self.add_api_object('IpAddress', self.IpAddress)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^([0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}|mrk-[0-9a-f]{32}|alias/[a-zA-Z0-9/_-]+|(arn:aws[-a-z]*:kms:[a-z0-9-]+:\d{12}:((key/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})|(key/mrk-[0-9a-f]{32})|(alias/[a-zA-Z0-9/_-]+))))$', None, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.Marker = APIObject('Marker', 'string', r'.+', 1, 128)
        self.add_api_object('Marker', self.Marker)
        self.MountTargetId = APIObject('MountTargetId', 'string', r'^fsmt-[0-9a-f]{8,40}$', 13, 45)
        self.add_api_object('MountTargetId', self.MountTargetId)
        self.Path = APIObject('Path', 'string', r'^(\/|(\/(?!\.)+[^$#<>;`|&?{}^*/\n]+){1,4})$', 1, 100)
        self.add_api_object('Path', self.Path)
        self.Permissions = APIObject('Permissions', 'string', r'^[0-7]{3,4}$', 3, 4)
        self.add_api_object('Permissions', self.Permissions)
        self.Policy = APIObject('Policy', 'string', r'[\s\S]+', 1, 20000)
        self.add_api_object('Policy', self.Policy)
        self.RegionName = APIObject('RegionName', 'string', r'^[a-z]{2}-((iso[a-z]{0,1}-)|(gov-)){0,1}[a-z]+-{0,1}[0-9]{0,1}$', 1, 64)
        self.add_api_object('RegionName', self.RegionName)
        self.ResourceId = APIObject('ResourceId', 'string', r'^(arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:(access-point/fsap|file-system/fs)-[0-9a-f]{8,40}|fs(ap)?-[0-9a-f]{8,40})$', None, 128)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SecurityGroup = APIObject('SecurityGroup', 'string', r'^sg-[0-9a-f]{8,40}', 11, 43)
        self.add_api_object('SecurityGroup', self.SecurityGroup)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[0-9a-f]{8,40}$', 15, 47)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^(?![aA]{1}[wW]{1}[sS]{1}:)([\p{L}\p{Z}\p{N}_.:/=+\-@]+)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Token = APIObject('Token', 'string', r'.+', 1, 128)
        self.add_api_object('Token', self.Token)

class EksAuth(Service):
    def __init__(self):
        super().__init__('EksAuth')
        self.ClusterName = APIObject('ClusterName', 'string', r'[0-9A-Za-z][A-Za-z0-9\-_]*', 1, 100)
        self.add_api_object('ClusterName', self.ClusterName)
        self.JwtToken = APIObject('JwtToken', 'string', r'[A-Za-z0-9-_=]+\.[A-Za-z0-9-_=]+\.[A-Za-z0-9-_=]+', 1, None)
        self.add_api_object('JwtToken', self.JwtToken)

class Eks(Service):
    def __init__(self):
        super().__init__('Eks')
        self.ClusterName = APIObject('ClusterName', 'string', r'^[0-9A-Za-z][A-Za-z0-9\-_]*', 1, 100)
        self.add_api_object('ClusterName', self.ClusterName)
        self.EksAnywhereSubscriptionName = APIObject('EksAnywhereSubscriptionName', 'string', r'^[0-9A-Za-z][A-Za-z0-9\-_]*', 1, 100)
        self.add_api_object('EksAnywhereSubscriptionName', self.EksAnywhereSubscriptionName)

class ElasticInference(Service):
    def __init__(self):
        super().__init__('ElasticInference')
        self.AcceleratorId = APIObject('AcceleratorId', 'string', r'^eia-[0-9a-f]+$', 1, 256)
        self.add_api_object('AcceleratorId', self.AcceleratorId)
        self.AcceleratorTypeName = APIObject('AcceleratorTypeName', 'string', r'^\S+$', 1, 256)
        self.add_api_object('AcceleratorTypeName', self.AcceleratorTypeName)
        self.FilterName = APIObject('FilterName', 'string', r'^\S+$', 1, 128)
        self.add_api_object('FilterName', self.FilterName)
        self.Key = APIObject('Key', 'string', r'^\S+$', 1, 256)
        self.add_api_object('Key', self.Key)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z0-9+/]+={0,2}$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'^arn:aws[^\s:]*:elastic-inference:[^\s:]+:\d{12}:elastic-inference-accelerator/eia-[0-9a-f]+$', 1, 1011)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.String = APIObject('String', 'string', r'^.*$', None, 500000)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^\S$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', None, 256)
        self.add_api_object('TagValue', self.TagValue)

class Elasticache(Service):
    def __init__(self):
        super().__init__('Elasticache')

class Elasticbeanstalk(Service):
    def __init__(self):
        super().__init__('Elasticbeanstalk')
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.SourceLocation = APIObject('SourceLocation', 'string', r'.+/.+', 3, 255)
        self.add_api_object('SourceLocation', self.SourceLocation)

class Elastictranscoder(Service):
    def __init__(self):
        super().__init__('Elastictranscoder')
        self.AccessControl = APIObject('AccessControl', 'string', r'(^FullControl$)|(^Read$)|(^ReadAcp$)|(^WriteAcp$)', None, None)
        self.add_api_object('AccessControl', self.AccessControl)
        self.Ascending = APIObject('Ascending', 'string', r'(^true$)|(^false$)', None, None)
        self.add_api_object('Ascending', self.Ascending)
        self.AspectRatio = APIObject('AspectRatio', 'string', r'(^auto$)|(^1:1$)|(^4:3$)|(^3:2$)|(^16:9$)', None, None)
        self.add_api_object('AspectRatio', self.AspectRatio)
        self.AudioBitDepth = APIObject('AudioBitDepth', 'string', r'(^8$)|(^16$)|(^24$)|(^32$)', None, None)
        self.add_api_object('AudioBitDepth', self.AudioBitDepth)
        self.AudioBitOrder = APIObject('AudioBitOrder', 'string', r'(^LittleEndian$)', None, None)
        self.add_api_object('AudioBitOrder', self.AudioBitOrder)
        self.AudioBitRate = APIObject('AudioBitRate', 'string', r'^\d{1,3}$', None, None)
        self.add_api_object('AudioBitRate', self.AudioBitRate)
        self.AudioChannels = APIObject('AudioChannels', 'string', r'(^auto$)|(^0$)|(^1$)|(^2$)', None, None)
        self.add_api_object('AudioChannels', self.AudioChannels)
        self.AudioCodec = APIObject('AudioCodec', 'string', r'(^AAC$)|(^vorbis$)|(^mp3$)|(^mp2$)|(^pcm$)|(^flac$)', None, None)
        self.add_api_object('AudioCodec', self.AudioCodec)
        self.AudioCodecProfile = APIObject('AudioCodecProfile', 'string', r'(^auto$)|(^AAC-LC$)|(^HE-AAC$)|(^HE-AACv2$)', None, None)
        self.add_api_object('AudioCodecProfile', self.AudioCodecProfile)
        self.AudioPackingMode = APIObject('AudioPackingMode', 'string', r'(^SingleTrack$)|(^OneChannelPerTrack$)|(^OneChannelPerTrackWithMosTo8Tracks$)', None, None)
        self.add_api_object('AudioPackingMode', self.AudioPackingMode)
        self.AudioSampleRate = APIObject('AudioSampleRate', 'string', r'(^auto$)|(^22050$)|(^32000$)|(^44100$)|(^48000$)|(^96000$)|(^192000$)', None, None)
        self.add_api_object('AudioSampleRate', self.AudioSampleRate)
        self.AudioSigned = APIObject('AudioSigned', 'string', r'(^Unsigned$)|(^Signed$)', None, None)
        self.add_api_object('AudioSigned', self.AudioSigned)
        self.Base64EncodedString = APIObject('Base64EncodedString', 'string', r'^$|(^(?:[A-Za-z0-9\+/]{4})*(?:[A-Za-z0-9\+/]{2}==|[A-Za-z0-9\+/]{3}=)?$)', None, None)
        self.add_api_object('Base64EncodedString', self.Base64EncodedString)
        self.BucketName = APIObject('BucketName', 'string', r'^(\w|\.|-){1,255}$', None, None)
        self.add_api_object('BucketName', self.BucketName)
        self.CaptionFormatFormat = APIObject('CaptionFormatFormat', 'string', r'(^mov-text$)|(^srt$)|(^scc$)|(^webvtt$)|(^dfxp$)|(^cea-708$)', None, None)
        self.add_api_object('CaptionFormatFormat', self.CaptionFormatFormat)
        self.CaptionFormatPattern = APIObject('CaptionFormatPattern', 'string', r'(^$)|(^.*\{language\}.*$)', None, None)
        self.add_api_object('CaptionFormatPattern', self.CaptionFormatPattern)
        self.CaptionMergePolicy = APIObject('CaptionMergePolicy', 'string', r'(^MergeOverride$)|(^MergeRetain$)|(^Override$)', None, None)
        self.add_api_object('CaptionMergePolicy', self.CaptionMergePolicy)
        self.Digits = APIObject('Digits', 'string', r'^\d{1,5}$', None, None)
        self.add_api_object('Digits', self.Digits)
        self.DigitsOrAuto = APIObject('DigitsOrAuto', 'string', r'(^auto$)|(^\d{2,4}$)', None, None)
        self.add_api_object('DigitsOrAuto', self.DigitsOrAuto)
        self.EncryptionMode = APIObject('EncryptionMode', 'string', r'(^s3$)|(^s3-aws-kms$)|(^aes-cbc-pkcs7$)|(^aes-ctr$)|(^aes-gcm$)', None, None)
        self.add_api_object('EncryptionMode', self.EncryptionMode)
        self.FixedGOP = APIObject('FixedGOP', 'string', r'(^true$)|(^false$)', None, None)
        self.add_api_object('FixedGOP', self.FixedGOP)
        self.FloatString = APIObject('FloatString', 'string', r'^\d{1,5}(\.\d{0,5})?$', None, None)
        self.add_api_object('FloatString', self.FloatString)
        self.FrameRate = APIObject('FrameRate', 'string', r'(^auto$)|(^10$)|(^15$)|(^23.97$)|(^24$)|(^25$)|(^29.97$)|(^30$)|(^50$)|(^60$)', None, None)
        self.add_api_object('FrameRate', self.FrameRate)
        self.GranteeType = APIObject('GranteeType', 'string', r'(^Canonical$)|(^Email$)|(^Group$)', None, None)
        self.add_api_object('GranteeType', self.GranteeType)
        self.HlsContentProtectionMethod = APIObject('HlsContentProtectionMethod', 'string', r'(^aes-128$)', None, None)
        self.add_api_object('HlsContentProtectionMethod', self.HlsContentProtectionMethod)
        self.HorizontalAlign = APIObject('HorizontalAlign', 'string', r'(^Left$)|(^Right$)|(^Center$)', None, None)
        self.add_api_object('HorizontalAlign', self.HorizontalAlign)
        self.Id = APIObject('Id', 'string', r'^\d{13}-\w{6}$', None, None)
        self.add_api_object('Id', self.Id)
        self.Interlaced = APIObject('Interlaced', 'string', r'(^auto$)|(^true$)|(^false$)', None, None)
        self.add_api_object('Interlaced', self.Interlaced)
        self.JobContainer = APIObject('JobContainer', 'string', r'(^auto$)|(^3gp$)|(^asf$)|(^avi$)|(^divx$)|(^flv$)|(^mkv$)|(^mov$)|(^mp4$)|(^mpeg$)|(^mpeg-ps$)|(^mpeg-ts$)|(^mxf$)|(^ogg$)|(^ts$)|(^vob$)|(^wav$)|(^webm$)|(^mp3$)|(^m4a$)|(^aac$)', None, None)
        self.add_api_object('JobContainer', self.JobContainer)
        self.JobStatus = APIObject('JobStatus', 'string', r'(^Submitted$)|(^Progressing$)|(^Complete$)|(^Canceled$)|(^Error$)', None, None)
        self.add_api_object('JobStatus', self.JobStatus)
        self.JpgOrPng = APIObject('JpgOrPng', 'string', r'(^jpg$)|(^png$)', None, None)
        self.add_api_object('JpgOrPng', self.JpgOrPng)
        self.KeyIdGuid = APIObject('KeyIdGuid', 'string', r'(^[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$)|(^[0-9A-Fa-f]{32}$)', None, None)
        self.add_api_object('KeyIdGuid', self.KeyIdGuid)
        self.KeyStoragePolicy = APIObject('KeyStoragePolicy', 'string', r'(^NoStore$)|(^WithVariantPlaylists$)', None, None)
        self.add_api_object('KeyStoragePolicy', self.KeyStoragePolicy)
        self.KeyframesMaxDist = APIObject('KeyframesMaxDist', 'string', r'^\d{1,6}$', None, None)
        self.add_api_object('KeyframesMaxDist', self.KeyframesMaxDist)
        self.MaxFrameRate = APIObject('MaxFrameRate', 'string', r'(^10$)|(^15$)|(^23.97$)|(^24$)|(^25$)|(^29.97$)|(^30$)|(^50$)|(^60$)', None, None)
        self.add_api_object('MaxFrameRate', self.MaxFrameRate)
        self.MergePolicy = APIObject('MergePolicy', 'string', r'(^Replace$)|(^Prepend$)|(^Append$)|(^Fallback$)', None, None)
        self.add_api_object('MergePolicy', self.MergePolicy)
        self.NonEmptyBase64EncodedString = APIObject('NonEmptyBase64EncodedString', 'string', r'(^(?:[A-Za-z0-9\+/]{4})*(?:[A-Za-z0-9\+/]{2}==|[A-Za-z0-9\+/]{3}=)?$)', None, None)
        self.add_api_object('NonEmptyBase64EncodedString', self.NonEmptyBase64EncodedString)
        self.Opacity = APIObject('Opacity', 'string', r'^\d{1,3}(\.\d{0,20})?$', None, None)
        self.add_api_object('Opacity', self.Opacity)
        self.PaddingPolicy = APIObject('PaddingPolicy', 'string', r'(^Pad$)|(^NoPad$)', None, None)
        self.add_api_object('PaddingPolicy', self.PaddingPolicy)
        self.PipelineStatus = APIObject('PipelineStatus', 'string', r'(^Active$)|(^Paused$)', None, None)
        self.add_api_object('PipelineStatus', self.PipelineStatus)
        self.PixelsOrPercent = APIObject('PixelsOrPercent', 'string', r'(^\d{1,3}(\.\d{0,5})?%$)|(^\d{1,4}?px$)', None, None)
        self.add_api_object('PixelsOrPercent', self.PixelsOrPercent)
        self.PlayReadyDrmFormatString = APIObject('PlayReadyDrmFormatString', 'string', r'(^microsoft$)|(^discretix-3.0$)', None, None)
        self.add_api_object('PlayReadyDrmFormatString', self.PlayReadyDrmFormatString)
        self.PlaylistFormat = APIObject('PlaylistFormat', 'string', r'(^HLSv3$)|(^HLSv4$)|(^Smooth$)|(^MPEG-DASH$)', None, None)
        self.add_api_object('PlaylistFormat', self.PlaylistFormat)
        self.PresetContainer = APIObject('PresetContainer', 'string', r'(^mp4$)|(^ts$)|(^webm$)|(^mp3$)|(^flac$)|(^oga$)|(^ogg$)|(^fmp4$)|(^mpg$)|(^flv$)|(^gif$)|(^mxf$)|(^wav$)|(^mp2$)', None, None)
        self.add_api_object('PresetContainer', self.PresetContainer)
        self.PresetType = APIObject('PresetType', 'string', r'(^System$)|(^Custom$)', None, None)
        self.add_api_object('PresetType', self.PresetType)
        self.Resolution = APIObject('Resolution', 'string', r'(^auto$)|(^\d{1,5}x\d{1,5}$)', None, None)
        self.add_api_object('Resolution', self.Resolution)
        self.Role = APIObject('Role', 'string', r'^arn:aws:iam::\w{12}:role/.+$', None, None)
        self.add_api_object('Role', self.Role)
        self.Rotate = APIObject('Rotate', 'string', r'(^auto$)|(^0$)|(^90$)|(^180$)|(^270$)', None, None)
        self.add_api_object('Rotate', self.Rotate)
        self.SizingPolicy = APIObject('SizingPolicy', 'string', r'(^Fit$)|(^Fill$)|(^Stretch$)|(^Keep$)|(^ShrinkToFit$)|(^ShrinkToFill$)', None, None)
        self.add_api_object('SizingPolicy', self.SizingPolicy)
        self.SnsTopic = APIObject('SnsTopic', 'string', r'(^$)|(^arn:aws:sns:.*:\w{12}:.+$)', None, None)
        self.add_api_object('SnsTopic', self.SnsTopic)
        self.StorageClass = APIObject('StorageClass', 'string', r'(^ReducedRedundancy$)|(^Standard$)', None, None)
        self.add_api_object('StorageClass', self.StorageClass)
        self.Success = APIObject('Success', 'string', r'(^true$)|(^false$)', None, None)
        self.add_api_object('Success', self.Success)
        self.Target = APIObject('Target', 'string', r'(^Content$)|(^Frame$)', None, None)
        self.add_api_object('Target', self.Target)
        self.ThumbnailPattern = APIObject('ThumbnailPattern', 'string', r'(^$)|(^.*\{count\}.*$)', None, None)
        self.add_api_object('ThumbnailPattern', self.ThumbnailPattern)
        self.ThumbnailResolution = APIObject('ThumbnailResolution', 'string', r'^\d{1,5}x\d{1,5}$', None, None)
        self.add_api_object('ThumbnailResolution', self.ThumbnailResolution)
        self.Time = APIObject('Time', 'string', r'(^\d{1,5}(\.\d{0,3})?$)|(^([0-1]?[0-9]:|2[0-3]:)?([0-5]?[0-9]:)?[0-5]?[0-9](\.\d{0,3})?$)', None, None)
        self.add_api_object('Time', self.Time)
        self.TimeOffset = APIObject('TimeOffset', 'string', r'(^[+-]?\d{1,5}(\.\d{0,3})?$)|(^[+-]?([0-1]?[0-9]:|2[0-3]:)?([0-5]?[0-9]:)?[0-5]?[0-9](\.\d{0,3})?$)', None, None)
        self.add_api_object('TimeOffset', self.TimeOffset)
        self.VerticalAlign = APIObject('VerticalAlign', 'string', r'(^Top$)|(^Bottom$)|(^Center$)', None, None)
        self.add_api_object('VerticalAlign', self.VerticalAlign)
        self.VideoBitRate = APIObject('VideoBitRate', 'string', r'(^\d{2,5}$)|(^auto$)', None, None)
        self.add_api_object('VideoBitRate', self.VideoBitRate)
        self.VideoCodec = APIObject('VideoCodec', 'string', r'(^H\.264$)|(^vp8$)|(^vp9$)|(^mpeg2$)|(^gif$)', None, None)
        self.add_api_object('VideoCodec', self.VideoCodec)
        self.WatermarkKey = APIObject('WatermarkKey', 'string', r'(^.{1,1020}.jpg$)|(^.{1,1019}.jpeg$)|(^.{1,1020}.png$)', 1, 1024)
        self.add_api_object('WatermarkKey', self.WatermarkKey)
        self.WatermarkSizingPolicy = APIObject('WatermarkSizingPolicy', 'string', r'(^Fit$)|(^Stretch$)|(^ShrinkToFit$)', None, None)
        self.add_api_object('WatermarkSizingPolicy', self.WatermarkSizingPolicy)

class Elb(Service):
    def __init__(self):
        super().__init__('Elb')
        self.AdditionalAttributeKey = APIObject('AdditionalAttributeKey', 'string', r'^[a-zA-Z0-9.]+$', None, 256)
        self.add_api_object('AdditionalAttributeKey', self.AdditionalAttributeKey)
        self.AdditionalAttributeValue = APIObject('AdditionalAttributeValue', 'string', r'^[a-zA-Z0-9.]+$', None, 256)
        self.add_api_object('AdditionalAttributeValue', self.AdditionalAttributeValue)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Elbv2(Service):
    def __init__(self):
        super().__init__('Elbv2')
        self.CustomerOwnedIpv4Pool = APIObject('CustomerOwnedIpv4Pool', 'string', r'^(ipv4pool-coip-)[a-zA-Z0-9]+$', None, 256)
        self.add_api_object('CustomerOwnedIpv4Pool', self.CustomerOwnedIpv4Pool)
        self.FixedResponseActionStatusCode = APIObject('FixedResponseActionStatusCode', 'string', r'^(2|4|5)\d\d$', None, None)
        self.add_api_object('FixedResponseActionStatusCode', self.FixedResponseActionStatusCode)
        self.LoadBalancerAttributeKey = APIObject('LoadBalancerAttributeKey', 'string', r'^[a-zA-Z0-9._]+$', None, 256)
        self.add_api_object('LoadBalancerAttributeKey', self.LoadBalancerAttributeKey)
        self.RedirectActionProtocol = APIObject('RedirectActionProtocol', 'string', r'^(HTTPS?|#\{protocol\})$', None, None)
        self.add_api_object('RedirectActionProtocol', self.RedirectActionProtocol)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetGroupAttributeKey = APIObject('TargetGroupAttributeKey', 'string', r'^[a-zA-Z0-9._]+$', None, 256)
        self.add_api_object('TargetGroupAttributeKey', self.TargetGroupAttributeKey)
        self.TrustStoreName = APIObject('TrustStoreName', 'string', r'^([a-zA-Z0-9]+-)*[a-zA-Z0-9]+$', 1, 32)
        self.add_api_object('TrustStoreName', self.TrustStoreName)

class EmrContainers(Service):
    def __init__(self):
        super().__init__('EmrContainers')
        self.ACMCertArn = APIObject('ACMCertArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):acm:.+:(\d{12}):certificate/.+$', 44, 2048)
        self.add_api_object('ACMCertArn', self.ACMCertArn)
        self.Base64Encoded = APIObject('Base64Encoded', 'string', r'^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?$', None, 5000)
        self.add_api_object('Base64Encoded', self.Base64Encoded)
        self.ClientToken = APIObject('ClientToken', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ClusterId = APIObject('ClusterId', 'string', r'^[0-9A-Za-z][A-Za-z0-9\-_]*', 1, 100)
        self.add_api_object('ClusterId', self.ClusterId)
        self.CredentialType = APIObject('CredentialType', 'string', r'^.*\S.*$', 1, 64)
        self.add_api_object('CredentialType', self.CredentialType)
        self.EndpointArn = APIObject('EndpointArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):\/virtualclusters\/[0-9a-zA-Z]+\/endpoints\/[0-9a-zA-Z]+$', 60, 1024)
        self.add_api_object('EndpointArn', self.EndpointArn)
        self.EndpointType = APIObject('EndpointType', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('EndpointType', self.EndpointType)
        self.EntryPointArgument = APIObject('EntryPointArgument', 'string', r'.*\S.*', 1, 10280)
        self.add_api_object('EntryPointArgument', self.EntryPointArgument)
        self.EntryPointPath = APIObject('EntryPointPath', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('EntryPointPath', self.EntryPointPath)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):iam::(\d{12})?:(role((\u002F)|(\u002F[\u0021-\u007F]+\u002F))[\w+=,.@-]+)$', 20, 2048)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.JobArn = APIObject('JobArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):\/virtualclusters\/[0-9a-zA-Z]+\/jobruns\/[0-9a-zA-Z]+$', 60, 1024)
        self.add_api_object('JobArn', self.JobArn)
        self.JobTemplateArn = APIObject('JobTemplateArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):\/jobtemplates\/[0-9a-zA-Z]+$', 60, 1024)
        self.add_api_object('JobTemplateArn', self.JobTemplateArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^(arn:(aws[a-zA-Z0-9-]*):kms:.+:(\d{12})?:key\/[(0-9a-zA-Z)-?]+|\$\{[a-zA-Z]\w*\})$', 3, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.KubernetesNamespace = APIObject('KubernetesNamespace', 'string', r'[a-z0-9]([-a-z0-9]*[a-z0-9])?', 1, 63)
        self.add_api_object('KubernetesNamespace', self.KubernetesNamespace)
        self.LogContext = APIObject('LogContext', 'string', r'^((?!.*-s3alias)(?!xn--.*)[a-z0-9][-a-z0-9.]*)?[a-z0-9]$', 3, 63)
        self.add_api_object('LogContext', self.LogContext)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.NextToken = APIObject('NextToken', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.ParametricIAMRoleArn = APIObject('ParametricIAMRoleArn', 'string', r'(^arn:(aws[a-zA-Z0-9-]*):iam::(\d{12})?:(role((\u002F)|(\u002F[\u0021-\u007F]+\u002F))[\w+=,.@-]+)$)|([\.\-_\#A-Za-z0-9\$\{\}]+)', 4, 2048)
        self.add_api_object('ParametricIAMRoleArn', self.ParametricIAMRoleArn)
        self.ParametricReleaseLabel = APIObject('ParametricReleaseLabel', 'string', r'([\.\-_/A-Za-z0-9]+|\$\{[a-zA-Z]\w*\})', 1, 64)
        self.add_api_object('ParametricReleaseLabel', self.ParametricReleaseLabel)
        self.ReleaseLabel = APIObject('ReleaseLabel', 'string', r'[\.\-_/A-Za-z0-9]+', 1, 64)
        self.add_api_object('ReleaseLabel', self.ReleaseLabel)
        self.RequestIdentityUserArn = APIObject('RequestIdentityUserArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):(iam|sts)::(\d{12})?:[\w/+=,.@-]+$', 20, 2048)
        self.add_api_object('RequestIdentityUserArn', self.RequestIdentityUserArn)
        self.ResourceIdString = APIObject('ResourceIdString', 'string', r'[0-9a-z]+', 1, 64)
        self.add_api_object('ResourceIdString', self.ResourceIdString)
        self.ResourceNameString = APIObject('ResourceNameString', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 64)
        self.add_api_object('ResourceNameString', self.ResourceNameString)
        self.RotationSize = APIObject('RotationSize', 'string', r'^\d+(\.\d+)?[KMG][Bb]?$', 3, 12)
        self.add_api_object('RotationSize', self.RotationSize)
        self.RsiArn = APIObject('RsiArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):/virtualclusters/.+$', 60, 500)
        self.add_api_object('RsiArn', self.RsiArn)
        self.SecretsManagerArn = APIObject('SecretsManagerArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):secretsmanager:.+:(\d{12}):secret:[0-9a-zA-Z/_+=.@-]+$', 3, 2048)
        self.add_api_object('SecretsManagerArn', self.SecretsManagerArn)
        self.SecurityConfigurationArn = APIObject('SecurityConfigurationArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):\/securityconfigurations\/[0-9a-zA-Z]+$', 60, 1024)
        self.add_api_object('SecurityConfigurationArn', self.SecurityConfigurationArn)
        self.SessionTagValue = APIObject('SessionTagValue', 'string', r'[\.\-_/#A-Za-z0-9 ]+', 1, 512)
        self.add_api_object('SessionTagValue', self.SessionTagValue)
        self.SparkSqlParameters = APIObject('SparkSqlParameters', 'string', r'.*\S.*', 1, 102400)
        self.add_api_object('SparkSqlParameters', self.SparkSqlParameters)
        self.SparkSubmitParameters = APIObject('SparkSubmitParameters', 'string', r'.*\S.*', 1, 102400)
        self.add_api_object('SparkSubmitParameters', self.SparkSubmitParameters)
        self.String1024 = APIObject('String1024', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('String1024', self.String1024)
        self.String128 = APIObject('String128', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('String128', self.String128)
        self.String2048 = APIObject('String2048', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('String2048', self.String2048)
        self.String256 = APIObject('String256', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('String256', self.String256)
        self.StringEmpty256 = APIObject('StringEmpty256', 'string', r'.*\S.*', 0, 256)
        self.add_api_object('StringEmpty256', self.StringEmpty256)
        self.TemplateParameter = APIObject('TemplateParameter', 'string', r'[\.\-_/#A-Za-z0-9\$\{\}]+', 1, 512)
        self.add_api_object('TemplateParameter', self.TemplateParameter)
        self.TemplateParameterName = APIObject('TemplateParameterName', 'string', r'[\.\-_\#A-Za-z0-9]+', 1, 512)
        self.add_api_object('TemplateParameterName', self.TemplateParameterName)
        self.Token = APIObject('Token', 'string', r'^.*\S.*$', 1, None)
        self.add_api_object('Token', self.Token)
        self.UriString = APIObject('UriString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\r\n\t]*', 1, 10280)
        self.add_api_object('UriString', self.UriString)
        self.VirtualClusterArn = APIObject('VirtualClusterArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):emr-containers:.+:(\d{12}):\/virtualclusters\/[0-9a-zA-Z]+$', 60, 1024)
        self.add_api_object('VirtualClusterArn', self.VirtualClusterArn)

class EmrServerless(Service):
    def __init__(self):
        super().__init__('EmrServerless')
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):emr-serverless:.+:(\d{12}):\/applications\/[0-9a-zA-Z]+', 60, 1024)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'[0-9a-z]+', 1, 64)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'[A-Za-z0-9._/#-]+', 1, 64)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.ClientToken = APIObject('ClientToken', 'string', r'[A-Za-z0-9._-]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ConfigurationPropertyKey = APIObject('ConfigurationPropertyKey', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('ConfigurationPropertyKey', self.ConfigurationPropertyKey)
        self.ConfigurationPropertyValue = APIObject('ConfigurationPropertyValue', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('ConfigurationPropertyValue', self.ConfigurationPropertyValue)
        self.CpuSize = APIObject('CpuSize', 'string', r'[1-9][0-9]*(\s)?(vCPU|vcpu|VCPU)?', 1, 15)
        self.add_api_object('CpuSize', self.CpuSize)
        self.DiskSize = APIObject('DiskSize', 'string', r'[1-9][0-9]*(\s)?(GB|gb|gB|Gb)', 1, 15)
        self.add_api_object('DiskSize', self.DiskSize)
        self.DiskType = APIObject('DiskType', 'string', r'(SHUFFLE_OPTIMIZED|[Ss]huffle_[Oo]ptimized|STANDARD|[Ss]tandard)', None, None)
        self.add_api_object('DiskType', self.DiskType)
        self.EncryptionKeyArn = APIObject('EncryptionKeyArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):kms:[a-zA-Z0-9\-]*:(\d{12})?:key\/[a-zA-Z0-9-]+', 20, 2048)
        self.add_api_object('EncryptionKeyArn', self.EncryptionKeyArn)
        self.EntryPointArgument = APIObject('EntryPointArgument', 'string', r'.*\S.*', 1, 10280)
        self.add_api_object('EntryPointArgument', self.EntryPointArgument)
        self.EntryPointPath = APIObject('EntryPointPath', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('EntryPointPath', self.EntryPointPath)
        self.HiveCliParameters = APIObject('HiveCliParameters', 'string', r'.*\S.*', 1, 102400)
        self.add_api_object('HiveCliParameters', self.HiveCliParameters)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):iam::(\d{12})?:(role((\u002F)|(\u002F[\u0021-\u007F]+\u002F))[\w+=,.@-]+)', 20, 2048)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.ImageDigest = APIObject('ImageDigest', 'string', r'sha256:[0-9a-f]{64}', None, None)
        self.add_api_object('ImageDigest', self.ImageDigest)
        self.ImageUri = APIObject('ImageUri', 'string', r'([a-z0-9]+[a-z0-9-.]*)\/((?:[a-z0-9]+(?:[._-][a-z0-9]+)*\/)*[a-z0-9]+(?:[._-][a-z0-9]+)*)(?:\:([a-zA-Z0-9_][a-zA-Z0-9-._]{0,299})|@(sha256:[0-9a-f]{64}))', 1, 1024)
        self.add_api_object('ImageUri', self.ImageUri)
        self.InitScriptPath = APIObject('InitScriptPath', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('InitScriptPath', self.InitScriptPath)
        self.JobArn = APIObject('JobArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):emr-serverless:.+:(\d{12}):\/applications\/[0-9a-zA-Z]+\/jobruns\/[0-9a-zA-Z]+', 60, 1024)
        self.add_api_object('JobArn', self.JobArn)
        self.JobRunId = APIObject('JobRunId', 'string', r'[0-9a-z]+', 1, 64)
        self.add_api_object('JobRunId', self.JobRunId)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.LogStreamNamePrefix = APIObject('LogStreamNamePrefix', 'string', r'[^:*]*', 1, 512)
        self.add_api_object('LogStreamNamePrefix', self.LogStreamNamePrefix)
        self.LogTypeString = APIObject('LogTypeString', 'string', r'[a-zA-Z]+[-_]*[a-zA-Z]+', 1, 50)
        self.add_api_object('LogTypeString', self.LogTypeString)
        self.MemorySize = APIObject('MemorySize', 'string', r'[1-9][0-9]*(\s)?(GB|gb|gB|Gb)?', 1, 15)
        self.add_api_object('MemorySize', self.MemorySize)
        self.NextToken = APIObject('NextToken', 'string', r'[A-Za-z0-9_=-]+', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.PrometheusUrlString = APIObject('PrometheusUrlString', 'string', r'https://aps-workspaces.([a-z]{2}-[a-z-]{1,20}-[1-9]).amazonaws(.[0-9A-Za-z]{2,4})+/workspaces/[-_.0-9A-Za-z]{1,100}/api/v1/remote_write', 1, 10280)
        self.add_api_object('PrometheusUrlString', self.PrometheusUrlString)
        self.Query = APIObject('Query', 'string', r'.*\S.*', 1, 10280)
        self.add_api_object('Query', self.Query)
        self.ReleaseLabel = APIObject('ReleaseLabel', 'string', r'[A-Za-z0-9._/-]+', 1, 64)
        self.add_api_object('ReleaseLabel', self.ReleaseLabel)
        self.RequestIdentityUserArn = APIObject('RequestIdentityUserArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):(iam|sts)::(\d{12})?:[\w/+=,.@-]+', 20, 2048)
        self.add_api_object('RequestIdentityUserArn', self.RequestIdentityUserArn)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):emr-serverless:.+:(\d{12}):\/applications\/[0-9a-zA-Z]+(\/jobruns\/[0-9a-zA-Z]+)?', 60, 1024)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.SecurityGroupString = APIObject('SecurityGroupString', 'string', r'[-0-9a-zA-Z]+.*', 1, 32)
        self.add_api_object('SecurityGroupString', self.SecurityGroupString)
        self.SparkSubmitParameters = APIObject('SparkSubmitParameters', 'string', r'.*\S.*', 1, 102400)
        self.add_api_object('SparkSubmitParameters', self.SparkSubmitParameters)
        self.String1024 = APIObject('String1024', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('String1024', self.String1024)
        self.String256 = APIObject('String256', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('String256', self.String256)
        self.SubnetString = APIObject('SubnetString', 'string', r'[-0-9a-zA-Z]+.*', 1, 32)
        self.add_api_object('SubnetString', self.SubnetString)
        self.TagKey = APIObject('TagKey', 'string', r'[A-Za-z0-9 /_.:=+@-]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[A-Za-z0-9 /_.:=+@-]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UriString = APIObject('UriString', 'string', r'.*[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\r\n\t]*.*', 1, 10280)
        self.add_api_object('UriString', self.UriString)
        self.WorkerTypeString = APIObject('WorkerTypeString', 'string', r'[a-zA-Z]+[-_]*[a-zA-Z]+', 1, 50)
        self.add_api_object('WorkerTypeString', self.WorkerTypeString)

class Emr(Service):
    def __init__(self):
        super().__init__('Emr')
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):iam::(\d{12})?:(role((\u002F)|(\u002F[\u0021-\u007F]+\u002F))[\w+=,.@-]+)$', 20, 2048)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.InstanceType = APIObject('InstanceType', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 256)
        self.add_api_object('InstanceType', self.InstanceType)
        self.UriString = APIObject('UriString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDBFF-\uDC00\uDFFF\r\n\t]*', 1, 10280)
        self.add_api_object('UriString', self.UriString)
        self.XmlString = APIObject('XmlString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 10280)
        self.add_api_object('XmlString', self.XmlString)
        self.XmlStringMaxLen256 = APIObject('XmlStringMaxLen256', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 256)
        self.add_api_object('XmlStringMaxLen256', self.XmlStringMaxLen256)

class Entityresolution(Service):
    def __init__(self):
        super().__init__('Entityresolution')
        self.AttributeName = APIObject('AttributeName', 'string', r'^[a-zA-Z_0-9- \t]*$', 0, 255)
        self.add_api_object('AttributeName', self.AttributeName)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.BatchDeleteUniqueIdInputInputSourceString = APIObject('BatchDeleteUniqueIdInputInputSourceString', 'string', r'^arn:(aws|aws-us-gov|aws-cn):glue:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(table/[a-zA-Z_0-9-]{1,255}/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('BatchDeleteUniqueIdInputInputSourceString', self.BatchDeleteUniqueIdInputInputSourceString)
        self.EntityName = APIObject('EntityName', 'string', r'^[a-zA-Z_0-9-]*$', 1, 255)
        self.add_api_object('EntityName', self.EntityName)
        self.EntityNameOrIdMappingWorkflowArn = APIObject('EntityNameOrIdMappingWorkflowArn', 'string', r'^[a-zA-Z_0-9-=+/]*$|^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idmappingworkflow/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('EntityNameOrIdMappingWorkflowArn', self.EntityNameOrIdMappingWorkflowArn)
        self.EntityNameOrIdNamespaceArn = APIObject('EntityNameOrIdNamespaceArn', 'string', r'^[a-zA-Z_0-9-=+/]*$|^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idnamespace/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('EntityNameOrIdNamespaceArn', self.EntityNameOrIdNamespaceArn)
        self.IdMappingWorkflowArn = APIObject('IdMappingWorkflowArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idmappingworkflow/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('IdMappingWorkflowArn', self.IdMappingWorkflowArn)
        self.IdMappingWorkflowInputSourceInputSourceARNString = APIObject('IdMappingWorkflowInputSourceInputSourceARNString', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idnamespace/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(matchingworkflow/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):glue:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(table/[a-zA-Z_0-9-]{1,255}/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('IdMappingWorkflowInputSourceInputSourceARNString', self.IdMappingWorkflowInputSourceInputSourceARNString)
        self.IdNamespaceArn = APIObject('IdNamespaceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idnamespace/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('IdNamespaceArn', self.IdNamespaceArn)
        self.IdNamespaceInputSourceInputSourceARNString = APIObject('IdNamespaceInputSourceInputSourceARNString', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idnamespace/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(matchingworkflow/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):glue:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(table/[a-zA-Z_0-9-]{1,255}/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('IdNamespaceInputSourceInputSourceARNString', self.IdNamespaceInputSourceInputSourceARNString)
        self.InputSourceInputSourceARNString = APIObject('InputSourceInputSourceARNString', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(idnamespace/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(matchingworkflow/[a-zA-Z_0-9-]{1,255})$|^arn:(aws|aws-us-gov|aws-cn):glue:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(table/[a-zA-Z_0-9-]{1,255}/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('InputSourceInputSourceARNString', self.InputSourceInputSourceARNString)
        self.JobId = APIObject('JobId', 'string', r'^[a-f0-9]{32}$', None, None)
        self.add_api_object('JobId', self.JobId)
        self.KMSArn = APIObject('KMSArn', 'string', r'^arn:aws:kms:.*:[0-9]+:.*$', None, None)
        self.add_api_object('KMSArn', self.KMSArn)
        self.MatchingWorkflowArn = APIObject('MatchingWorkflowArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(matchingworkflow/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('MatchingWorkflowArn', self.MatchingWorkflowArn)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z_0-9-=+/]*$', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.PolicyToken = APIObject('PolicyToken', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('PolicyToken', self.PolicyToken)
        self.ProviderServiceArn = APIObject('ProviderServiceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):(entityresolution):([a-z]{2}-[a-z]{1,10}-[0-9])::providerservice/([a-zA-Z0-9_-]{1,255})/([a-zA-Z0-9_-]{1,255})$', 20, 255)
        self.add_api_object('ProviderServiceArn', self.ProviderServiceArn)
        self.RecordAttributeMapKeyString = APIObject('RecordAttributeMapKeyString', 'string', r'^[a-zA-Z_0-9- \t]*$', 0, 255)
        self.add_api_object('RecordAttributeMapKeyString', self.RecordAttributeMapKeyString)
        self.RecordAttributeMapValueString = APIObject('RecordAttributeMapValueString', 'string', r'^[a-zA-Z_0-9-./@ ()+\t]*$', 0, 255)
        self.add_api_object('RecordAttributeMapValueString', self.RecordAttributeMapValueString)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', 32, 512)
        self.add_api_object('RoleArn', self.RoleArn)
        self.RuleRuleNameString = APIObject('RuleRuleNameString', 'string', r'^[a-zA-Z_0-9- \t]*$', 0, 255)
        self.add_api_object('RuleRuleNameString', self.RuleRuleNameString)
        self.S3Path = APIObject('S3Path', 'string', r'^s3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?$', 1, 1024)
        self.add_api_object('S3Path', self.S3Path)
        self.SchemaMappingArn = APIObject('SchemaMappingArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:(schemamapping/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('SchemaMappingArn', self.SchemaMappingArn)
        self.StatementAction = APIObject('StatementAction', 'string', r'^(entityresolution:[a-zA-Z0-9]+)$', 3, 64)
        self.add_api_object('StatementAction', self.StatementAction)
        self.StatementId = APIObject('StatementId', 'string', r'^[0-9A-Za-z]+$', 1, 64)
        self.add_api_object('StatementId', self.StatementId)
        self.StatementPrincipal = APIObject('StatementPrincipal', 'string', r'^(\d{12})|([a-z0-9\.]+)$', 12, 64)
        self.add_api_object('StatementPrincipal', self.StatementPrincipal)
        self.UniqueId = APIObject('UniqueId', 'string', r'^[a-zA-Z_0-9-,]*$', 1, 760)
        self.add_api_object('UniqueId', self.UniqueId)
        self.VeniceGlobalArn = APIObject('VeniceGlobalArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn):entityresolution:[a-z]{2}-[a-z]{1,10}-[0-9]:[0-9]{12}:((schemamapping|matchingworkflow|idmappingworkflow|idnamespace)/[a-zA-Z_0-9-]{1,255})$', None, None)
        self.add_api_object('VeniceGlobalArn', self.VeniceGlobalArn)

class Es(Service):
    def __init__(self):
        super().__init__('Es')
        self.AWSAccount = APIObject('AWSAccount', 'string', r'^[0-9]+$', None, None)
        self.add_api_object('AWSAccount', self.AWSAccount)
        self.DescribePackagesFilterValue = APIObject('DescribePackagesFilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?-]*$', None, None)
        self.add_api_object('DescribePackagesFilterValue', self.DescribePackagesFilterValue)
        self.DomainArn = APIObject('DomainArn', 'string', r'arn:aws[a-z\-]*:[a-z]+:[a-z0-9\-]+:[0-9]+:domain\/[a-z0-9\-]+', 1, 512)
        self.add_api_object('DomainArn', self.DomainArn)
        self.DomainName = APIObject('DomainName', 'string', r'[a-z][a-z0-9\-]+', 3, 28)
        self.add_api_object('DomainName', self.DomainName)
        self.DomainNameFqdn = APIObject('DomainNameFqdn', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', 1, 255)
        self.add_api_object('DomainNameFqdn', self.DomainNameFqdn)
        self.ElasticsearchVersionString = APIObject('ElasticsearchVersionString', 'string', r'^[0-9]{1}\.[0-9]{1,2}$|^OpenSearch_[0-9]{1,2}\.[0-9]{1,2}$|^OS_[0-9]{1,2}\.[0-9]{1,2}$', None, None)
        self.add_api_object('ElasticsearchVersionString', self.ElasticsearchVersionString)
        self.Endpoint = APIObject('Endpoint', 'string', r'^[A-Za-z0-9\-\.]+$', None, None)
        self.add_api_object('Endpoint', self.Endpoint)
        self.GUID = APIObject('GUID', 'string', r'\p{XDigit}{8}-\p{XDigit}{4}-\p{XDigit}{4}-\p{XDigit}{4}-\p{XDigit}{12}', None, None)
        self.add_api_object('GUID', self.GUID)
        self.IdentityPoolId = APIObject('IdentityPoolId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityPoolId', self.IdentityPoolId)
        self.PackageName = APIObject('PackageName', 'string', r'[a-z][a-z0-9\-]+', 3, 28)
        self.add_api_object('PackageName', self.PackageName)
        self.UserPoolId = APIObject('UserPoolId', 'string', r'[\w-]+_[0-9a-zA-Z]+', 1, 55)
        self.add_api_object('UserPoolId', self.UserPoolId)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'^aos-[a-zA-Z0-9]*$', 5, 256)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)

class Events(Service):
    def __init__(self):
        super().__init__('Events')
        self.RuleName = APIObject('RuleName', 'string', r'[\.\-_A-Za-z0-9]+', 1, 64)
        self.add_api_object('RuleName', self.RuleName)
        self.TargetId = APIObject('TargetId', 'string', r'[\.\-_A-Za-z0-9]+', 1, 64)
        self.add_api_object('TargetId', self.TargetId)

class Evidently(Service):
    def __init__(self):
        super().__init__('Evidently')
        self.AppConfigResourceId = APIObject('AppConfigResourceId', 'string', r'[a-z0-9]{4,7}', None, None)
        self.add_api_object('AppConfigResourceId', self.AppConfigResourceId)
        self.Arn = APIObject('Arn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', 0, 2048)
        self.add_api_object('Arn', self.Arn)
        self.CwDimensionSafeName = APIObject('CwDimensionSafeName', 'string', r'^[\S]+$', 1, 255)
        self.add_api_object('CwDimensionSafeName', self.CwDimensionSafeName)
        self.CwLogGroupSafeName = APIObject('CwLogGroupSafeName', 'string', r'^[-a-zA-Z0-9._/]+$', 1, 512)
        self.add_api_object('CwLogGroupSafeName', self.CwLogGroupSafeName)
        self.Description = APIObject('Description', 'string', r'.*', 0, 160)
        self.add_api_object('Description', self.Description)
        self.EntityId = APIObject('EntityId', 'string', r'.*', 1, 512)
        self.add_api_object('EntityId', self.EntityId)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'.*', 1, 1024)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.ExperimentArn = APIObject('ExperimentArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:project/[-a-zA-Z0-9._]*/experiment/[-a-zA-Z0-9._]*', 0, 2048)
        self.add_api_object('ExperimentArn', self.ExperimentArn)
        self.ExperimentName = APIObject('ExperimentName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('ExperimentName', self.ExperimentName)
        self.FeatureArn = APIObject('FeatureArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:project/[-a-zA-Z0-9._]*/feature/[-a-zA-Z0-9._]*', 0, 2048)
        self.add_api_object('FeatureArn', self.FeatureArn)
        self.FeatureName = APIObject('FeatureName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('FeatureName', self.FeatureName)
        self.GroupName = APIObject('GroupName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('GroupName', self.GroupName)
        self.JsonPath = APIObject('JsonPath', 'string', r'.*', 1, 256)
        self.add_api_object('JsonPath', self.JsonPath)
        self.LaunchArn = APIObject('LaunchArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:project/[-a-zA-Z0-9._]*/launch/[-a-zA-Z0-9._]*', 0, 2048)
        self.add_api_object('LaunchArn', self.LaunchArn)
        self.LaunchName = APIObject('LaunchName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('LaunchName', self.LaunchName)
        self.MetricUnitLabel = APIObject('MetricUnitLabel', 'string', r'.*', 1, 256)
        self.add_api_object('MetricUnitLabel', self.MetricUnitLabel)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 1, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.ProjectArn = APIObject('ProjectArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:project/[-a-zA-Z0-9._]*', 0, 2048)
        self.add_api_object('ProjectArn', self.ProjectArn)
        self.ProjectName = APIObject('ProjectName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('ProjectName', self.ProjectName)
        self.ProjectRef = APIObject('ProjectRef', 'string', r'(^[a-zA-Z0-9._-]*$)|(arn:[^:]*:[^:]*:[^:]*:[^:]*:project/[a-zA-Z0-9._-]*)', 0, 2048)
        self.add_api_object('ProjectRef', self.ProjectRef)
        self.RandomizationSalt = APIObject('RandomizationSalt', 'string', r'.*', 0, 127)
        self.add_api_object('RandomizationSalt', self.RandomizationSalt)
        self.S3BucketSafeName = APIObject('S3BucketSafeName', 'string', r'^[a-z0-9][-a-z0-9]*[a-z0-9]$', 3, 63)
        self.add_api_object('S3BucketSafeName', self.S3BucketSafeName)
        self.S3PrefixSafeName = APIObject('S3PrefixSafeName', 'string', r'^[-a-zA-Z0-9!_.*\'()/]*$', 1, 1024)
        self.add_api_object('S3PrefixSafeName', self.S3PrefixSafeName)
        self.SegmentArn = APIObject('SegmentArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:segment/[-a-zA-Z0-9._]*', 0, 2048)
        self.add_api_object('SegmentArn', self.SegmentArn)
        self.SegmentName = APIObject('SegmentName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 64)
        self.add_api_object('SegmentName', self.SegmentName)
        self.SegmentRef = APIObject('SegmentRef', 'string', r'(^[-a-zA-Z0-9._]*$)|(arn:[^:]*:[^:]*:[^:]*:[^:]*:segment/[-a-zA-Z0-9._]*)', 0, 2048)
        self.add_api_object('SegmentRef', self.SegmentRef)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TreatmentName = APIObject('TreatmentName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('TreatmentName', self.TreatmentName)
        self.Uuid = APIObject('Uuid', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 36, 36)
        self.add_api_object('Uuid', self.Uuid)
        self.VariationName = APIObject('VariationName', 'string', r'^[-a-zA-Z0-9._]*$', 1, 127)
        self.add_api_object('VariationName', self.VariationName)

class FinspaceData(Service):
    def __init__(self):
        super().__init__('FinspaceData')
        self.AccessKeyId = APIObject('AccessKeyId', 'string', r'[\s\S]*\S[\s\S]*', 1, 255)
        self.add_api_object('AccessKeyId', self.AccessKeyId)
        self.AliasString = APIObject('AliasString', 'string', r'^alias\/\S+', 1, 255)
        self.add_api_object('AliasString', self.AliasString)
        self.ClientToken = APIObject('ClientToken', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ColumnDescription = APIObject('ColumnDescription', 'string', r'[\s\S]*', None, 512)
        self.add_api_object('ColumnDescription', self.ColumnDescription)
        self.ColumnName = APIObject('ColumnName', 'string', r'.*\S.*', None, 126)
        self.add_api_object('ColumnName', self.ColumnName)
        self.DatasetDescription = APIObject('DatasetDescription', 'string', r'[\s\S]*', None, 1000)
        self.add_api_object('DatasetDescription', self.DatasetDescription)
        self.DatasetTitle = APIObject('DatasetTitle', 'string', r'.*\S.*', 1, 255)
        self.add_api_object('DatasetTitle', self.DatasetTitle)
        self.Email = APIObject('Email', 'string', r'[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,4}', 4, 320)
        self.add_api_object('Email', self.Email)
        self.FirstName = APIObject('FirstName', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('FirstName', self.FirstName)
        self.LastName = APIObject('LastName', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('LastName', self.LastName)
        self.OwnerName = APIObject('OwnerName', 'string', r'.*\S.*', 1, 250)
        self.add_api_object('OwnerName', self.OwnerName)
        self.Password = APIObject('Password', 'string', r'.*\S.*', 8, 20)
        self.add_api_object('Password', self.Password)
        self.PermissionGroupDescription = APIObject('PermissionGroupDescription', 'string', r'[\s\S]*', 1, 4000)
        self.add_api_object('PermissionGroupDescription', self.PermissionGroupDescription)
        self.PermissionGroupId = APIObject('PermissionGroupId', 'string', r'.*\S.*', 1, 26)
        self.add_api_object('PermissionGroupId', self.PermissionGroupId)
        self.PermissionGroupName = APIObject('PermissionGroupName', 'string', r'.*\S.*', 1, 255)
        self.add_api_object('PermissionGroupName', self.PermissionGroupName)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'^[\+0-9\#\,\(][\+0-9\-\.\/\(\)\,\#\s]+$', 10, 20)
        self.add_api_object('PhoneNumber', self.PhoneNumber)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws[a-z\-]*:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^.*\S.*$', 1, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3Key = APIObject('S3Key', 'string', r'^.*\S.*$', 1, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.SecretAccessKey = APIObject('SecretAccessKey', 'string', r'[\s\S]*\S[\s\S]*', 1, 1000)
        self.add_api_object('SecretAccessKey', self.SecretAccessKey)
        self.SessionToken = APIObject('SessionToken', 'string', r'[\s\S]*\S[\s\S]*', 1, 1000)
        self.add_api_object('SessionToken', self.SessionToken)
        self.StringMapKey = APIObject('StringMapKey', 'string', r'[\s\S]*\S[\s\S]*', None, 128)
        self.add_api_object('StringMapKey', self.StringMapKey)
        self.StringMapValue = APIObject('StringMapValue', 'string', r'[\s\S]*\S[\s\S]*', None, 1000)
        self.add_api_object('StringMapValue', self.StringMapValue)
        self.StringValueLength1to250 = APIObject('StringValueLength1to250', 'string', r'[\s\S]*\S[\s\S]*', 1, 250)
        self.add_api_object('StringValueLength1to250', self.StringValueLength1to250)
        self.StringValueLength1to255 = APIObject('StringValueLength1to255', 'string', r'[\s\S]*\S[\s\S]*', 1, 255)
        self.add_api_object('StringValueLength1to255', self.StringValueLength1to255)
        self.UserId = APIObject('UserId', 'string', r'.*\S.*', 1, 26)
        self.add_api_object('UserId', self.UserId)
        self.stringValueLength1to1024 = APIObject('stringValueLength1to1024', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('stringValueLength1to1024', self.stringValueLength1to1024)
        self.stringValueLength1to63 = APIObject('stringValueLength1to63', 'string', r'.*\S.*', 1, 63)
        self.add_api_object('stringValueLength1to63', self.stringValueLength1to63)

class Finspace(Service):
    def __init__(self):
        super().__init__('Finspace')
        self.AvailabilityZoneId = APIObject('AvailabilityZoneId', 'string', r'^[a-zA-Z0-9-]+$', 8, 12)
        self.add_api_object('AvailabilityZoneId', self.AvailabilityZoneId)
        self.ChangesetId = APIObject('ChangesetId', 'string', r'^[a-zA-Z0-9]+$', 1, 26)
        self.add_api_object('ChangesetId', self.ChangesetId)
        self.ClientToken = APIObject('ClientToken', 'string', r'.*\S.*', 1, 36)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ClientTokenString = APIObject('ClientTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientTokenString', self.ClientTokenString)
        self.DataBundleArn = APIObject('DataBundleArn', 'string', r'^arn:aws:finspace:[A-Za-z0-9_/.-]{0,63}:\d*:data-bundle/[0-9A-Za-z_-]{1,128}$', 20, 2048)
        self.add_api_object('DataBundleArn', self.DataBundleArn)
        self.DatabaseName = APIObject('DatabaseName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('DatabaseName', self.DatabaseName)
        self.DbPath = APIObject('DbPath', 'string', r'^(\*)*[\/\?\*]([^\/]+\/){0,2}[^\/]*$', 1, 1025)
        self.add_api_object('DbPath', self.DbPath)
        self.Description = APIObject('Description', 'string', r'^[a-zA-Z0-9. ]{1,1000}$', 1, 1000)
        self.add_api_object('Description', self.Description)
        self.EmailId = APIObject('EmailId', 'string', r'[A-Z0-9a-z._%+-]+@[A-Za-z0-9.-]+[.]+[A-Za-z]+', 1, 128)
        self.add_api_object('EmailId', self.EmailId)
        self.EnvironmentArn = APIObject('EnvironmentArn', 'string', r'^arn:aws:finspace:[A-Za-z0-9_/.-]{0,63}:\d+:environment/[0-9A-Za-z_-]{1,128}$', 20, 2048)
        self.add_api_object('EnvironmentArn', self.EnvironmentArn)
        self.EnvironmentErrorMessage = APIObject('EnvironmentErrorMessage', 'string', r'^[a-zA-Z0-9. ]{1,1000}$', 0, 1000)
        self.add_api_object('EnvironmentErrorMessage', self.EnvironmentErrorMessage)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'.*\S.*', 1, 32)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-]*[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.ExecutionRoleArn = APIObject('ExecutionRoleArn', 'string', r'^arn:aws[a-z0-9-]*:iam::\d{12}:role\/[\w-\/.@+=,]{1,1017}$', 1, 1024)
        self.add_api_object('ExecutionRoleArn', self.ExecutionRoleArn)
        self.FederationAttributeKey = APIObject('FederationAttributeKey', 'string', r'.*', 1, 32)
        self.add_api_object('FederationAttributeKey', self.FederationAttributeKey)
        self.FederationAttributeValue = APIObject('FederationAttributeValue', 'string', r'.*', 1, 1000)
        self.add_api_object('FederationAttributeValue', self.FederationAttributeValue)
        self.FederationProviderName = APIObject('FederationProviderName', 'string', r'[^_\p{Z}][\p{L}\p{M}\p{S}\p{N}\p{P}][^_\p{Z}]+', 1, 32)
        self.add_api_object('FederationProviderName', self.FederationProviderName)
        self.FinSpaceTaggableArn = APIObject('FinSpaceTaggableArn', 'string', r'^arn:aws:finspace:[A-Za-z0-9_/.-]{0,63}:\d+:(environment|kxEnvironment)/[0-9A-Za-z_-]{1,128}(/(kxCluster|kxUser|kxVolume|kxScalingGroup)/[a-zA-Z0-9_-]{1,255}|/(kxDatabase/[a-zA-Z0-9_-]{1,255}(/kxDataview/[a-zA-Z0-9_-]{1,255})?))?$', 20, 2048)
        self.add_api_object('FinSpaceTaggableArn', self.FinSpaceTaggableArn)
        self.IdType = APIObject('IdType', 'string', r'^[a-zA-Z0-9]{1,26}$', 1, 26)
        self.add_api_object('IdType', self.IdType)
        self.InitializationScriptFilePath = APIObject('InitializationScriptFilePath', 'string', r'^[a-zA-Z0-9\_\-\.\/\\]+$', 1, 255)
        self.add_api_object('InitializationScriptFilePath', self.InitializationScriptFilePath)
        self.KmsKeyARN = APIObject('KmsKeyARN', 'string', r'^arn:aws:kms:.*:\d+:.*$', 1, 1000)
        self.add_api_object('KmsKeyARN', self.KmsKeyARN)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^[a-zA-Z-0-9-:\/]*$', 1, 1000)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.KxClusterDescription = APIObject('KxClusterDescription', 'string', r'^[a-zA-Z0-9\_\-\.\s]+$', 1, 1000)
        self.add_api_object('KxClusterDescription', self.KxClusterDescription)
        self.KxClusterName = APIObject('KxClusterName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('KxClusterName', self.KxClusterName)
        self.KxClusterStatusReason = APIObject('KxClusterStatusReason', 'string', r'^[a-zA-Z0-9\_\-\.\s]+$', 1, 250)
        self.add_api_object('KxClusterStatusReason', self.KxClusterStatusReason)
        self.KxCommandLineArgumentKey = APIObject('KxCommandLineArgumentKey', 'string', r'^(?![Aa][Ww][Ss])(s|([a-zA-Z][a-zA-Z0-9_]+))|(AWS_ZIP_DEFAULT)', 1, 1024)
        self.add_api_object('KxCommandLineArgumentKey', self.KxCommandLineArgumentKey)
        self.KxCommandLineArgumentValue = APIObject('KxCommandLineArgumentValue', 'string', r'^[a-zA-Z0-9_:./,]+$', 1, 1024)
        self.add_api_object('KxCommandLineArgumentValue', self.KxCommandLineArgumentValue)
        self.KxDataviewName = APIObject('KxDataviewName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('KxDataviewName', self.KxDataviewName)
        self.KxDataviewStatusReason = APIObject('KxDataviewStatusReason', 'string', r'^[a-zA-Z0-9\_\-\.\s]+$', 1, 250)
        self.add_api_object('KxDataviewStatusReason', self.KxDataviewStatusReason)
        self.KxEnvironmentId = APIObject('KxEnvironmentId', 'string', r'^[a-z0-9]+$', 1, 32)
        self.add_api_object('KxEnvironmentId', self.KxEnvironmentId)
        self.KxEnvironmentName = APIObject('KxEnvironmentName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('KxEnvironmentName', self.KxEnvironmentName)
        self.KxHostType = APIObject('KxHostType', 'string', r'^[a-zA-Z0-9._]+', 1, 32)
        self.add_api_object('KxHostType', self.KxHostType)
        self.KxScalingGroupName = APIObject('KxScalingGroupName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('KxScalingGroupName', self.KxScalingGroupName)
        self.KxUserArn = APIObject('KxUserArn', 'string', r'^arn:aws:finspace:[A-Za-z0-9_/.-]{0,63}:\d+:kxEnvironment/[0-9A-Za-z_-]{1,128}/kxUser/[0-9A-Za-z_-]{1,128}$', 20, 2048)
        self.add_api_object('KxUserArn', self.KxUserArn)
        self.KxUserNameString = APIObject('KxUserNameString', 'string', r'^[0-9A-Za-z_-]{1,50}$', 1, 50)
        self.add_api_object('KxUserNameString', self.KxUserNameString)
        self.KxVolumeArn = APIObject('KxVolumeArn', 'string', r'^arn:aws:finspace:[A-Za-z0-9_/.-]{0,63}:\d+:kxEnvironment/[0-9A-Za-z_-]{1,128}(/kxSharedVolume/[a-zA-Z0-9_-]{1,255})?$', 20, 2048)
        self.add_api_object('KxVolumeArn', self.KxVolumeArn)
        self.KxVolumeName = APIObject('KxVolumeName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('KxVolumeName', self.KxVolumeName)
        self.KxVolumeStatusReason = APIObject('KxVolumeStatusReason', 'string', r'^[a-zA-Z0-9\_\-\.\s]+$', 1, 250)
        self.add_api_object('KxVolumeStatusReason', self.KxVolumeStatusReason)
        self.NameString = APIObject('NameString', 'string', r'^[a-zA-Z0-9]{1,50}$', 1, 50)
        self.add_api_object('NameString', self.NameString)
        self.NodeType = APIObject('NodeType', 'string', r'^[a-zA-Z0-9._]+$', 1, 32)
        self.add_api_object('NodeType', self.NodeType)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'.*', 1, 1000)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.Protocol = APIObject('Protocol', 'string', r'^-1|[0-9]+$', 1, 5)
        self.add_api_object('Protocol', self.Protocol)
        self.ReleaseLabel = APIObject('ReleaseLabel', 'string', r'^[a-zA-Z0-9._-]+$', 1, 16)
        self.add_api_object('ReleaseLabel', self.ReleaseLabel)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws[a-z\-]*:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$', 3, 255)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'^[a-zA-Z0-9\/\!\-_\.\*\'\(\)]+$', 1, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.S3Path = APIObject('S3Path', 'string', r'^s3:\/\/[a-z0-9][a-z0-9-.]{1,61}[a-z0-9]\/([^\/]+\/)*[^\/]*$', 9, 1093)
        self.add_api_object('S3Path', self.S3Path)
        self.SamlMetadataDocument = APIObject('SamlMetadataDocument', 'string', r'.*', 1000, 10000000)
        self.add_api_object('SamlMetadataDocument', self.SamlMetadataDocument)
        self.SecurityGroupIdString = APIObject('SecurityGroupIdString', 'string', r'^sg-([a-z0-9]{8}$|[a-z0-9]{17}$)', 1, 1024)
        self.add_api_object('SecurityGroupIdString', self.SecurityGroupIdString)
        self.SignedKxConnectionString = APIObject('SignedKxConnectionString', 'string', r'^(:|:tcps:\/\/)[a-zA-Z0-9-\.\_]+:\d+:[a-zA-Z0-9-\.\_]+:\S+$', 1, 2048)
        self.add_api_object('SignedKxConnectionString', self.SignedKxConnectionString)
        self.SmsDomainUrl = APIObject('SmsDomainUrl', 'string', r'^[a-zA-Z-0-9-:\/.]*$', 1, 1000)
        self.add_api_object('SmsDomainUrl', self.SmsDomainUrl)
        self.SubnetIdString = APIObject('SubnetIdString', 'string', r'^subnet-([a-z0-9]{8}$|[a-z0-9]{17}$)', 1, 1024)
        self.add_api_object('SubnetIdString', self.SubnetIdString)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[a-zA-Z0-9+-=._:@ ]+$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.ValidCIDRBlock = APIObject('ValidCIDRBlock', 'string', r'^(?:\d{1,3}\.){3}\d{1,3}(?:\/(?:3[0-2]|[12]\d|\d))$', 1, 18)
        self.add_api_object('ValidCIDRBlock', self.ValidCIDRBlock)
        self.ValidHostname = APIObject('ValidHostname', 'string', r'^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])(\.([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9]))*$', 3, 255)
        self.add_api_object('ValidHostname', self.ValidHostname)
        self.ValidIPAddress = APIObject('ValidIPAddress', 'string', r'^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$', None, None)
        self.add_api_object('ValidIPAddress', self.ValidIPAddress)
        self.VolumeName = APIObject('VolumeName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9-_]*[a-zA-Z0-9]$', 3, 63)
        self.add_api_object('VolumeName', self.VolumeName)
        self.VpcIdString = APIObject('VpcIdString', 'string', r'^vpc-([a-z0-9]{8}$|[a-z0-9]{17}$)', 1, 1024)
        self.add_api_object('VpcIdString', self.VpcIdString)
        self.arn = APIObject('arn', 'string', r'^arn:*:*:*:*:*', 20, 2048)
        self.add_api_object('arn', self.arn)
        self.url = APIObject('url', 'string', r'^https?://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]', 1, 1000)
        self.add_api_object('url', self.url)
        self.urn = APIObject('urn', 'string', r'^[A-Za-z0-9._\-:\/#\+]+$', 1, 255)
        self.add_api_object('urn', self.urn)

class Firehose(Service):
    def __init__(self):
        super().__init__('Firehose')
        self.AWSKMSKeyARN = APIObject('AWSKMSKeyARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('AWSKMSKeyARN', self.AWSKMSKeyARN)
        self.AmazonOpenSearchServerlessCollectionEndpoint = APIObject('AmazonOpenSearchServerlessCollectionEndpoint', 'string', r'https:.*', 1, 512)
        self.add_api_object('AmazonOpenSearchServerlessCollectionEndpoint', self.AmazonOpenSearchServerlessCollectionEndpoint)
        self.AmazonOpenSearchServerlessIndexName = APIObject('AmazonOpenSearchServerlessIndexName', 'string', r'.*', 1, 80)
        self.add_api_object('AmazonOpenSearchServerlessIndexName', self.AmazonOpenSearchServerlessIndexName)
        self.AmazonopensearchserviceClusterEndpoint = APIObject('AmazonopensearchserviceClusterEndpoint', 'string', r'https:.*', 1, 512)
        self.add_api_object('AmazonopensearchserviceClusterEndpoint', self.AmazonopensearchserviceClusterEndpoint)
        self.AmazonopensearchserviceDomainARN = APIObject('AmazonopensearchserviceDomainARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('AmazonopensearchserviceDomainARN', self.AmazonopensearchserviceDomainARN)
        self.AmazonopensearchserviceIndexName = APIObject('AmazonopensearchserviceIndexName', 'string', r'.*', 1, 80)
        self.add_api_object('AmazonopensearchserviceIndexName', self.AmazonopensearchserviceIndexName)
        self.AmazonopensearchserviceTypeName = APIObject('AmazonopensearchserviceTypeName', 'string', r'.*', 0, 100)
        self.add_api_object('AmazonopensearchserviceTypeName', self.AmazonopensearchserviceTypeName)
        self.BucketARN = APIObject('BucketARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('BucketARN', self.BucketARN)
        self.ClusterJDBCURL = APIObject('ClusterJDBCURL', 'string', r'jdbc:(redshift|postgresql)://((?!-)[A-Za-z0-9-]{1,63}(?<!-)\.)+(redshift(-serverless)?)\.([a-zA-Z0-9\.]+):\d{1,5}/[a-zA-Z0-9_$-]+', 1, 512)
        self.add_api_object('ClusterJDBCURL', self.ClusterJDBCURL)
        self.CopyOptions = APIObject('CopyOptions', 'string', r'.*', 0, 204800)
        self.add_api_object('CopyOptions', self.CopyOptions)
        self.DataTableColumns = APIObject('DataTableColumns', 'string', r'.*', 0, 204800)
        self.add_api_object('DataTableColumns', self.DataTableColumns)
        self.DataTableName = APIObject('DataTableName', 'string', r'.*', 1, 512)
        self.add_api_object('DataTableName', self.DataTableName)
        self.DeliveryStreamARN = APIObject('DeliveryStreamARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('DeliveryStreamARN', self.DeliveryStreamARN)
        self.DeliveryStreamName = APIObject('DeliveryStreamName', 'string', r'[a-zA-Z0-9_.-]+', 1, 64)
        self.add_api_object('DeliveryStreamName', self.DeliveryStreamName)
        self.DeliveryStreamVersionId = APIObject('DeliveryStreamVersionId', 'string', r'[0-9]+', 1, 50)
        self.add_api_object('DeliveryStreamVersionId', self.DeliveryStreamVersionId)
        self.DestinationId = APIObject('DestinationId', 'string', r'[a-zA-Z0-9-]+', 1, 100)
        self.add_api_object('DestinationId', self.DestinationId)
        self.ElasticsearchClusterEndpoint = APIObject('ElasticsearchClusterEndpoint', 'string', r'https:.*', 1, 512)
        self.add_api_object('ElasticsearchClusterEndpoint', self.ElasticsearchClusterEndpoint)
        self.ElasticsearchDomainARN = APIObject('ElasticsearchDomainARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('ElasticsearchDomainARN', self.ElasticsearchDomainARN)
        self.ElasticsearchIndexName = APIObject('ElasticsearchIndexName', 'string', r'.*', 1, 80)
        self.add_api_object('ElasticsearchIndexName', self.ElasticsearchIndexName)
        self.ElasticsearchTypeName = APIObject('ElasticsearchTypeName', 'string', r'.*', 0, 100)
        self.add_api_object('ElasticsearchTypeName', self.ElasticsearchTypeName)
        self.ErrorOutputPrefix = APIObject('ErrorOutputPrefix', 'string', r'.*', 0, 1024)
        self.add_api_object('ErrorOutputPrefix', self.ErrorOutputPrefix)
        self.FileExtension = APIObject('FileExtension', 'string', r'^$|\.[0-9a-z!\-_.*\'()]+', 0, 128)
        self.add_api_object('FileExtension', self.FileExtension)
        self.HECEndpoint = APIObject('HECEndpoint', 'string', r'.*', 0, 2048)
        self.add_api_object('HECEndpoint', self.HECEndpoint)
        self.HECToken = APIObject('HECToken', 'string', r'.*', 0, 2048)
        self.add_api_object('HECToken', self.HECToken)
        self.HttpEndpointAccessKey = APIObject('HttpEndpointAccessKey', 'string', r'.*', 0, 4096)
        self.add_api_object('HttpEndpointAccessKey', self.HttpEndpointAccessKey)
        self.HttpEndpointAttributeName = APIObject('HttpEndpointAttributeName', 'string', r'^(?!\s*$).+', 1, 256)
        self.add_api_object('HttpEndpointAttributeName', self.HttpEndpointAttributeName)
        self.HttpEndpointAttributeValue = APIObject('HttpEndpointAttributeValue', 'string', r'.*', 0, 1024)
        self.add_api_object('HttpEndpointAttributeValue', self.HttpEndpointAttributeValue)
        self.HttpEndpointName = APIObject('HttpEndpointName', 'string', r'^(?!\s*$).+', 1, 256)
        self.add_api_object('HttpEndpointName', self.HttpEndpointName)
        self.HttpEndpointUrl = APIObject('HttpEndpointUrl', 'string', r'https://.*', 1, 1000)
        self.add_api_object('HttpEndpointUrl', self.HttpEndpointUrl)
        self.KinesisStreamARN = APIObject('KinesisStreamARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('KinesisStreamARN', self.KinesisStreamARN)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]*', 0, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.LogStreamName = APIObject('LogStreamName', 'string', r'[^:*]*', 0, 512)
        self.add_api_object('LogStreamName', self.LogStreamName)
        self.MSKClusterARN = APIObject('MSKClusterARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('MSKClusterARN', self.MSKClusterARN)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'^(?!\s*$).+', 1, 1024)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.NonEmptyStringWithoutWhitespace = APIObject('NonEmptyStringWithoutWhitespace', 'string', r'^\S+$', 1, 1024)
        self.add_api_object('NonEmptyStringWithoutWhitespace', self.NonEmptyStringWithoutWhitespace)
        self.Password = APIObject('Password', 'string', r'.*', 6, 512)
        self.add_api_object('Password', self.Password)
        self.Prefix = APIObject('Prefix', 'string', r'.*', 0, 1024)
        self.add_api_object('Prefix', self.Prefix)
        self.ProcessorParameterValue = APIObject('ProcessorParameterValue', 'string', r'^(?!\s*$).+', 1, 5120)
        self.add_api_object('ProcessorParameterValue', self.ProcessorParameterValue)
        self.RoleARN = APIObject('RoleARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('RoleARN', self.RoleARN)
        self.SnowflakeAccountUrl = APIObject('SnowflakeAccountUrl', 'string', r'.+?\.snowflakecomputing\.com', 24, 2048)
        self.add_api_object('SnowflakeAccountUrl', self.SnowflakeAccountUrl)
        self.SnowflakePrivateKey = APIObject('SnowflakePrivateKey', 'string', r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', 256, 4096)
        self.add_api_object('SnowflakePrivateKey', self.SnowflakePrivateKey)
        self.SnowflakePrivateLinkVpceId = APIObject('SnowflakePrivateLinkVpceId', 'string', r'([a-zA-Z0-9\-\_]+\.){2,3}vpce\.[a-zA-Z0-9\-]*\.vpce-svc\-[a-zA-Z0-9\-]{17}$', 47, 255)
        self.add_api_object('SnowflakePrivateLinkVpceId', self.SnowflakePrivateLinkVpceId)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[\p{L}\p{Z}\p{N}_.:\/=+\-@%]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\p{L}\p{Z}\p{N}_.:\/=+\-@%]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TopicName = APIObject('TopicName', 'string', r'[a-zA-Z0-9\\._\\-]+', 1, 255)
        self.add_api_object('TopicName', self.TopicName)
        self.Username = APIObject('Username', 'string', r'.*', 1, 512)
        self.add_api_object('Username', self.Username)

class Fis(Service):
    def __init__(self):
        super().__init__('Fis')
        self.ActionDescription = APIObject('ActionDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ActionDescription', self.ActionDescription)
        self.ActionId = APIObject('ActionId', 'string', r'[\S]+', None, 128)
        self.add_api_object('ActionId', self.ActionId)
        self.ActionParameterDescription = APIObject('ActionParameterDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ActionParameterDescription', self.ActionParameterDescription)
        self.ActionParameterName = APIObject('ActionParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ActionParameterName', self.ActionParameterName)
        self.ActionTargetName = APIObject('ActionTargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ActionTargetName', self.ActionTargetName)
        self.ClientToken = APIObject('ClientToken', 'string', r'[\S]+', 1, 1024)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CloudWatchLogGroupArn = APIObject('CloudWatchLogGroupArn', 'string', r'[\S]+', 20, 2048)
        self.add_api_object('CloudWatchLogGroupArn', self.CloudWatchLogGroupArn)
        self.ExceptionMessage = APIObject('ExceptionMessage', 'string', r'[\s\S]+', None, 1024)
        self.add_api_object('ExceptionMessage', self.ExceptionMessage)
        self.ExperimentActionDescription = APIObject('ExperimentActionDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ExperimentActionDescription', self.ExperimentActionDescription)
        self.ExperimentActionName = APIObject('ExperimentActionName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentActionName', self.ExperimentActionName)
        self.ExperimentActionParameter = APIObject('ExperimentActionParameter', 'string', r'[\S]+', None, 1024)
        self.add_api_object('ExperimentActionParameter', self.ExperimentActionParameter)
        self.ExperimentActionParameterName = APIObject('ExperimentActionParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentActionParameterName', self.ExperimentActionParameterName)
        self.ExperimentActionStartAfter = APIObject('ExperimentActionStartAfter', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentActionStartAfter', self.ExperimentActionStartAfter)
        self.ExperimentActionStatusReason = APIObject('ExperimentActionStatusReason', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ExperimentActionStatusReason', self.ExperimentActionStatusReason)
        self.ExperimentActionTargetName = APIObject('ExperimentActionTargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentActionTargetName', self.ExperimentActionTargetName)
        self.ExperimentId = APIObject('ExperimentId', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentId', self.ExperimentId)
        self.ExperimentStatusReason = APIObject('ExperimentStatusReason', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ExperimentStatusReason', self.ExperimentStatusReason)
        self.ExperimentTargetFilterPath = APIObject('ExperimentTargetFilterPath', 'string', r'[\S]+', None, 256)
        self.add_api_object('ExperimentTargetFilterPath', self.ExperimentTargetFilterPath)
        self.ExperimentTargetFilterValue = APIObject('ExperimentTargetFilterValue', 'string', r'[\S]+', None, 128)
        self.add_api_object('ExperimentTargetFilterValue', self.ExperimentTargetFilterValue)
        self.ExperimentTargetName = APIObject('ExperimentTargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTargetName', self.ExperimentTargetName)
        self.ExperimentTargetParameterName = APIObject('ExperimentTargetParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTargetParameterName', self.ExperimentTargetParameterName)
        self.ExperimentTargetSelectionMode = APIObject('ExperimentTargetSelectionMode', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTargetSelectionMode', self.ExperimentTargetSelectionMode)
        self.ExperimentTemplateActionDescription = APIObject('ExperimentTemplateActionDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ExperimentTemplateActionDescription', self.ExperimentTemplateActionDescription)
        self.ExperimentTemplateActionName = APIObject('ExperimentTemplateActionName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateActionName', self.ExperimentTemplateActionName)
        self.ExperimentTemplateActionParameter = APIObject('ExperimentTemplateActionParameter', 'string', r'[\S]+', None, 1024)
        self.add_api_object('ExperimentTemplateActionParameter', self.ExperimentTemplateActionParameter)
        self.ExperimentTemplateActionParameterName = APIObject('ExperimentTemplateActionParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateActionParameterName', self.ExperimentTemplateActionParameterName)
        self.ExperimentTemplateActionStartAfter = APIObject('ExperimentTemplateActionStartAfter', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateActionStartAfter', self.ExperimentTemplateActionStartAfter)
        self.ExperimentTemplateActionTargetName = APIObject('ExperimentTemplateActionTargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateActionTargetName', self.ExperimentTemplateActionTargetName)
        self.ExperimentTemplateDescription = APIObject('ExperimentTemplateDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('ExperimentTemplateDescription', self.ExperimentTemplateDescription)
        self.ExperimentTemplateId = APIObject('ExperimentTemplateId', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateId', self.ExperimentTemplateId)
        self.ExperimentTemplateTargetFilterPath = APIObject('ExperimentTemplateTargetFilterPath', 'string', r'[\S]+', None, 256)
        self.add_api_object('ExperimentTemplateTargetFilterPath', self.ExperimentTemplateTargetFilterPath)
        self.ExperimentTemplateTargetFilterValue = APIObject('ExperimentTemplateTargetFilterValue', 'string', r'[\S]+', None, 128)
        self.add_api_object('ExperimentTemplateTargetFilterValue', self.ExperimentTemplateTargetFilterValue)
        self.ExperimentTemplateTargetName = APIObject('ExperimentTemplateTargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateTargetName', self.ExperimentTemplateTargetName)
        self.ExperimentTemplateTargetParameterName = APIObject('ExperimentTemplateTargetParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateTargetParameterName', self.ExperimentTemplateTargetParameterName)
        self.ExperimentTemplateTargetParameterValue = APIObject('ExperimentTemplateTargetParameterValue', 'string', r'^[\p{L}\p{Z}\p{N}_.:/=+\-@]+$', 1, 1024)
        self.add_api_object('ExperimentTemplateTargetParameterValue', self.ExperimentTemplateTargetParameterValue)
        self.ExperimentTemplateTargetSelectionMode = APIObject('ExperimentTemplateTargetSelectionMode', 'string', r'[\S]+', None, 64)
        self.add_api_object('ExperimentTemplateTargetSelectionMode', self.ExperimentTemplateTargetSelectionMode)
        self.NextToken = APIObject('NextToken', 'string', r'[\S]+', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'[\S]+', 20, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'[\S]+', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[\S]+', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'[\s\S]+', 1, 1024)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.StopConditionSource = APIObject('StopConditionSource', 'string', r'[\S]+', None, 64)
        self.add_api_object('StopConditionSource', self.StopConditionSource)
        self.StopConditionValue = APIObject('StopConditionValue', 'string', r'[\s\S]+', 20, 2048)
        self.add_api_object('StopConditionValue', self.StopConditionValue)
        self.TagKey = APIObject('TagKey', 'string', r'[\s\S]+', None, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\S]*', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetAccountConfigurationDescription = APIObject('TargetAccountConfigurationDescription', 'string', r'[\s\S]*', None, 512)
        self.add_api_object('TargetAccountConfigurationDescription', self.TargetAccountConfigurationDescription)
        self.TargetAccountId = APIObject('TargetAccountId', 'string', r'[\S]+', 12, 48)
        self.add_api_object('TargetAccountId', self.TargetAccountId)
        self.TargetInformationKey = APIObject('TargetInformationKey', 'string', r'[\S]+', None, 64)
        self.add_api_object('TargetInformationKey', self.TargetInformationKey)
        self.TargetInformationValue = APIObject('TargetInformationValue', 'string', r'[\S]+', None, 2048)
        self.add_api_object('TargetInformationValue', self.TargetInformationValue)
        self.TargetName = APIObject('TargetName', 'string', r'[\S]+', None, 64)
        self.add_api_object('TargetName', self.TargetName)
        self.TargetResourceTypeDescription = APIObject('TargetResourceTypeDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('TargetResourceTypeDescription', self.TargetResourceTypeDescription)
        self.TargetResourceTypeId = APIObject('TargetResourceTypeId', 'string', r'[\S]+', None, 128)
        self.add_api_object('TargetResourceTypeId', self.TargetResourceTypeId)
        self.TargetResourceTypeParameterDescription = APIObject('TargetResourceTypeParameterDescription', 'string', r'[\s\S]+', None, 512)
        self.add_api_object('TargetResourceTypeParameterDescription', self.TargetResourceTypeParameterDescription)
        self.TargetResourceTypeParameterName = APIObject('TargetResourceTypeParameterName', 'string', r'[\S]+', None, 64)
        self.add_api_object('TargetResourceTypeParameterName', self.TargetResourceTypeParameterName)

class Fms(Service):
    def __init__(self):
        super().__init__('Fms')
        self.AWSAccountId = APIObject('AWSAccountId', 'string', r'^[0-9]+$', 1, 1024)
        self.add_api_object('AWSAccountId', self.AWSAccountId)
        self.AWSRegion = APIObject('AWSRegion', 'string', r'^(af|ap|ca|eu|il|me|mx|sa|us|cn|us-gov)-\w+-\d+$', 6, 32)
        self.add_api_object('AWSRegion', self.AWSRegion)
        self.Base62Id = APIObject('Base62Id', 'string', r'^[a-z0-9A-Z]{22}$', 22, 22)
        self.add_api_object('Base62Id', self.Base62Id)
        self.CIDR = APIObject('CIDR', 'string', r'[a-f0-9:./]+', 0, 256)
        self.add_api_object('CIDR', self.CIDR)
        self.CustomerPolicyScopeId = APIObject('CustomerPolicyScopeId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('CustomerPolicyScopeId', self.CustomerPolicyScopeId)
        self.Description = APIObject('Description', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('Description', self.Description)
        self.DetailedInfo = APIObject('DetailedInfo', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=,+\-@]*)$', 1, 4096)
        self.add_api_object('DetailedInfo', self.DetailedInfo)
        self.FirewallPolicyId = APIObject('FirewallPolicyId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('FirewallPolicyId', self.FirewallPolicyId)
        self.FirewallPolicyName = APIObject('FirewallPolicyName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('FirewallPolicyName', self.FirewallPolicyName)
        self.Identifier = APIObject('Identifier', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 2048)
        self.add_api_object('Identifier', self.Identifier)
        self.ListId = APIObject('ListId', 'string', r'^[a-z0-9A-Z-]{36}$', 36, 36)
        self.add_api_object('ListId', self.ListId)
        self.ManagedServiceData = APIObject('ManagedServiceData', 'string', r'^((?!\\[nr]).)+', 1, 10000)
        self.add_api_object('ManagedServiceData', self.ManagedServiceData)
        self.Name = APIObject('Name', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('Name', self.Name)
        self.NetworkFirewallAction = APIObject('NetworkFirewallAction', 'string', r'^[a-zA-Z0-9]+$', 1, 128)
        self.add_api_object('NetworkFirewallAction', self.NetworkFirewallAction)
        self.NetworkFirewallResourceName = APIObject('NetworkFirewallResourceName', 'string', r'^[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('NetworkFirewallResourceName', self.NetworkFirewallResourceName)
        self.OrganizationalUnitId = APIObject('OrganizationalUnitId', 'string', r'^ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$', 16, 68)
        self.add_api_object('OrganizationalUnitId', self.OrganizationalUnitId)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 4096)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PolicyId = APIObject('PolicyId', 'string', r'^[a-z0-9A-Z-]{36}$', 36, 36)
        self.add_api_object('PolicyId', self.PolicyId)
        self.PolicyUpdateToken = APIObject('PolicyUpdateToken', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('PolicyUpdateToken', self.PolicyUpdateToken)
        self.PreviousListVersion = APIObject('PreviousListVersion', 'string', r'^\d{1,2}$', 1, 2)
        self.add_api_object('PreviousListVersion', self.PreviousListVersion)
        self.Protocol = APIObject('Protocol', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 20)
        self.add_api_object('Protocol', self.Protocol)
        self.RemediationActionDescription = APIObject('RemediationActionDescription', 'string', r'.*', 0, 1024)
        self.add_api_object('RemediationActionDescription', self.RemediationActionDescription)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceDescription = APIObject('ResourceDescription', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('ResourceDescription', self.ResourceDescription)
        self.ResourceId = APIObject('ResourceId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('ResourceName', self.ResourceName)
        self.ResourceTagKey = APIObject('ResourceTagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('ResourceTagKey', self.ResourceTagKey)
        self.ResourceTagValue = APIObject('ResourceTagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('ResourceTagValue', self.ResourceTagValue)
        self.ResourceType = APIObject('ResourceType', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('ResourceType', self.ResourceType)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetViolationReason = APIObject('TargetViolationReason', 'string', r'\w+', 0, 256)
        self.add_api_object('TargetViolationReason', self.TargetViolationReason)
        self.UpdateToken = APIObject('UpdateToken', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 1024)
        self.add_api_object('UpdateToken', self.UpdateToken)
        self.ViolationTarget = APIObject('ViolationTarget', 'string', r'.*', 0, 1024)
        self.add_api_object('ViolationTarget', self.ViolationTarget)

class Forecast(Service):
    def __init__(self):
        super().__init__('Forecast')
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):forecast:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.AttributeValue = APIObject('AttributeValue', 'string', r'.+', None, 256)
        self.add_api_object('AttributeValue', self.AttributeValue)
        self.ForecastType = APIObject('ForecastType', 'string', r'(^0?\.\d\d?$|^mean$)', 2, 4)
        self.add_api_object('ForecastType', self.ForecastType)
        self.Format = APIObject('Format', 'string', r'^CSV|PARQUET$', None, 7)
        self.add_api_object('Format', self.Format)
        self.Frequency = APIObject('Frequency', 'string', r'^Y|M|W|D|H|30min|15min|10min|5min|1min$', 1, 5)
        self.add_api_object('Frequency', self.Frequency)
        self.GeolocationFormat = APIObject('GeolocationFormat', 'string', r'^[a-zA-Z0-9_]+$', None, 256)
        self.add_api_object('GeolocationFormat', self.GeolocationFormat)
        self.KMSKeyArn = APIObject('KMSKeyArn', 'string', r'arn:aws:kms:.*:key/.*', None, 256)
        self.add_api_object('KMSKeyArn', self.KMSKeyArn)
        self.LocalDateTime = APIObject('LocalDateTime', 'string', r'^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}$', None, 19)
        self.add_api_object('LocalDateTime', self.LocalDateTime)
        self.LongArn = APIObject('LongArn', 'string', r'arn:([a-z\d-]+):forecast:.*:.*:.+', None, 300)
        self.add_api_object('LongArn', self.LongArn)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*', 1, 63)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'.+', 1, 3000)
        self.add_api_object('NextToken', self.NextToken)
        self.ParameterKey = APIObject('ParameterKey', 'string', r'^[a-zA-Z0-9\-\_\.\/\[\]\,\\]+$', None, 256)
        self.add_api_object('ParameterKey', self.ParameterKey)
        self.ParameterValue = APIObject('ParameterValue', 'string', r'^[a-zA-Z0-9\-\_\.\/\[\]\,\"\\\s]+$', None, 256)
        self.add_api_object('ParameterValue', self.ParameterValue)
        self.S3Path = APIObject('S3Path', 'string', r'^s3://[a-z0-9].+$', 7, 4096)
        self.add_api_object('S3Path', self.S3Path)
        self.String = APIObject('String', 'string', r'^[a-zA-Z0-9\_]+$', None, 256)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TimeZone = APIObject('TimeZone', 'string', r'^[a-zA-Z0-9\/\+\-\_]+$', None, 256)
        self.add_api_object('TimeZone', self.TimeZone)
        self.TimestampFormat = APIObject('TimestampFormat', 'string', r'''^[a-zA-Z0-9\-\:\.\,\\'\s]+$''', None, 256)
        self.add_api_object('TimestampFormat', self.TimestampFormat)
        self.Value = APIObject('Value', 'string', r'^[a-zA-Z0-9\_\-]+$', None, 256)
        self.add_api_object('Value', self.Value)

class Forecastquery(Service):
    def __init__(self):
        super().__init__('Forecastquery')
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):forecast:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.AttributeName = APIObject('AttributeName', 'string', r'^[a-zA-Z0-9\_\-]+$', None, 256)
        self.add_api_object('AttributeName', self.AttributeName)
        self.LongArn = APIObject('LongArn', 'string', r'arn:([a-z\d-]+):forecast:.*:.*:.+', None, 300)
        self.add_api_object('LongArn', self.LongArn)

class Frauddetector(Service):
    def __init__(self):
        super().__init__('Frauddetector')
        self.Elements = APIObject('Elements', 'string', r'^\S+( +\S+)*$', 1, 320)
        self.add_api_object('Elements', self.Elements)
        self.KmsEncryptionKeyArn = APIObject('KmsEncryptionKeyArn', 'string', r'^DEFAULT|arn:[a-zA-Z0-9-]+:kms:[a-zA-Z0-9-]+:\d{12}:key\/\w{8}-\w{4}-\w{4}-\w{4}-\w{12}$', 7, 90)
        self.add_api_object('KmsEncryptionKeyArn', self.KmsEncryptionKeyArn)
        self.entityRestrictedString = APIObject('entityRestrictedString', 'string', r'^[0-9A-Za-z_.@+-]+$', 1, 256)
        self.add_api_object('entityRestrictedString', self.entityRestrictedString)
        self.filterString = APIObject('filterString', 'string', r'^[0-9A-Za-z_-]+$', 1, 256)
        self.add_api_object('filterString', self.filterString)
        self.floatVersionString = APIObject('floatVersionString', 'string', r'^[1-9][0-9]{0,3}\.[0-9]{1,2}$', 3, 7)
        self.add_api_object('floatVersionString', self.floatVersionString)
        self.fraudDetectorArn = APIObject('fraudDetectorArn', 'string', r'^arn\:aws[a-z-]{0,15}\:frauddetector\:[a-z0-9-]{3,20}\:[0-9]{12}\:[^\s]{2,128}$', 1, 256)
        self.add_api_object('fraudDetectorArn', self.fraudDetectorArn)
        self.iamRoleArn = APIObject('iamRoleArn', 'string', r'^arn\:aws[a-z-]{0,15}\:iam\:\:[0-9]{12}\:role\/[^\s]{2,64}$', 1, 256)
        self.add_api_object('iamRoleArn', self.iamRoleArn)
        self.identifier = APIObject('identifier', 'string', r'^[0-9a-z_-]+$', 1, 64)
        self.add_api_object('identifier', self.identifier)
        self.modelIdentifier = APIObject('modelIdentifier', 'string', r'^[0-9a-z_]+$', 1, 64)
        self.add_api_object('modelIdentifier', self.modelIdentifier)
        self.nextToken = APIObject('nextToken', 'string', r'.*', 0, 8192)
        self.add_api_object('nextToken', self.nextToken)
        self.noDashIdentifier = APIObject('noDashIdentifier', 'string', r'^[0-9a-z_]+$', 1, 64)
        self.add_api_object('noDashIdentifier', self.noDashIdentifier)
        self.s3BucketLocation = APIObject('s3BucketLocation', 'string', r'^s3:\/\/(.+)$', 1, 512)
        self.add_api_object('s3BucketLocation', self.s3BucketLocation)
        self.sageMakerEndpointIdentifier = APIObject('sageMakerEndpointIdentifier', 'string', r'^[0-9A-Za-z_-]+$', 1, 63)
        self.add_api_object('sageMakerEndpointIdentifier', self.sageMakerEndpointIdentifier)
        self.tagKey = APIObject('tagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('tagKey', self.tagKey)
        self.variableType = APIObject('variableType', 'string', r'^[A-Z_]{1,64}$', 1, 64)
        self.add_api_object('variableType', self.variableType)
        self.wholeNumberVersionString = APIObject('wholeNumberVersionString', 'string', r'^([1-9][0-9]*)$', 1, 5)
        self.add_api_object('wholeNumberVersionString', self.wholeNumberVersionString)

class Freetier(Service):
    def __init__(self):
        super().__init__('Freetier')
        self.GenericString = APIObject('GenericString', 'string', r'^[\S\s]*$', 0, 1024)
        self.add_api_object('GenericString', self.GenericString)
        self.NextPageToken = APIObject('NextPageToken', 'string', r'^[\S\s]*$', 1, 8192)
        self.add_api_object('NextPageToken', self.NextPageToken)
        self.Value = APIObject('Value', 'string', r'^[ a-zA-Z0-9\-\:\.\_\/\,\$\(\)]*$', 1, 20)
        self.add_api_object('Value', self.Value)

class Fsx(Service):
    def __init__(self):
        super().__init__('Fsx')
        self.AWSAccountId = APIObject('AWSAccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AWSAccountId', self.AWSAccountId)
        self.ActiveDirectoryFullyQualifiedName = APIObject('ActiveDirectoryFullyQualifiedName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,255}$', 1, 255)
        self.add_api_object('ActiveDirectoryFullyQualifiedName', self.ActiveDirectoryFullyQualifiedName)
        self.AdminPassword = APIObject('AdminPassword', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{8,50}$', 8, 50)
        self.add_api_object('AdminPassword', self.AdminPassword)
        self.Aggregate = APIObject('Aggregate', 'string', r'^(aggr[0-9]{1,2})$', 5, 6)
        self.add_api_object('Aggregate', self.Aggregate)
        self.AlternateDNSName = APIObject('AlternateDNSName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{4,253}$', 4, 253)
        self.add_api_object('AlternateDNSName', self.AlternateDNSName)
        self.ArchivePath = APIObject('ArchivePath', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{3,4357}$', 3, 4357)
        self.add_api_object('ArchivePath', self.ArchivePath)
        self.BackupId = APIObject('BackupId', 'string', r'^(backup-[0-9a-f]{8,})$', 12, 128)
        self.add_api_object('BackupId', self.BackupId)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[A-za-z0-9_.-]{0,63}$', 1, 63)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.DNSName = APIObject('DNSName', 'string', r'^((fs|fc)i?-[0-9a-f]{8,}\..{4,253})$', 16, 275)
        self.add_api_object('DNSName', self.DNSName)
        self.DailyTime = APIObject('DailyTime', 'string', r'^([01]\d|2[0-3]):?([0-5]\d)$', 5, 5)
        self.add_api_object('DailyTime', self.DailyTime)
        self.DataRepositoryAssociationId = APIObject('DataRepositoryAssociationId', 'string', r'^(dra-[0-9a-f]{8,})$', 13, 23)
        self.add_api_object('DataRepositoryAssociationId', self.DataRepositoryAssociationId)
        self.DataRepositoryTaskFilterValue = APIObject('DataRepositoryTaskFilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?\-\_]*$', 1, 128)
        self.add_api_object('DataRepositoryTaskFilterValue', self.DataRepositoryTaskFilterValue)
        self.DataRepositoryTaskPath = APIObject('DataRepositoryTaskPath', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{0,4096}$', 0, 4096)
        self.add_api_object('DataRepositoryTaskPath', self.DataRepositoryTaskPath)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', 12, 12)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.DirectoryPassword = APIObject('DirectoryPassword', 'string', r'^.{1,256}$', 1, 256)
        self.add_api_object('DirectoryPassword', self.DirectoryPassword)
        self.DirectoryUserName = APIObject('DirectoryUserName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,256}$', 1, 256)
        self.add_api_object('DirectoryUserName', self.DirectoryUserName)
        self.FileCacheId = APIObject('FileCacheId', 'string', r'^(fc-[0-9a-f]{8,})$', 11, 21)
        self.add_api_object('FileCacheId', self.FileCacheId)
        self.FileSystemAdministratorsGroupName = APIObject('FileSystemAdministratorsGroupName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,256}$', 1, 256)
        self.add_api_object('FileSystemAdministratorsGroupName', self.FileSystemAdministratorsGroupName)
        self.FileSystemId = APIObject('FileSystemId', 'string', r'^(fs-[0-9a-f]{8,})$', 11, 21)
        self.add_api_object('FileSystemId', self.FileSystemId)
        self.FileSystemTypeVersion = APIObject('FileSystemTypeVersion', 'string', r'^[0-9](.[0-9]*)*$', 1, 20)
        self.add_api_object('FileSystemTypeVersion', self.FileSystemTypeVersion)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?\-\_]*$', 1, 128)
        self.add_api_object('FilterValue', self.FilterValue)
        self.GeneralARN = APIObject('GeneralARN', 'string', r'^arn:[^:]{1,63}:[^:]{0,63}:[^:]{0,63}:(?:|\d{12}):[^/].{0,1023}$', 8, 1024)
        self.add_api_object('GeneralARN', self.GeneralARN)
        self.IpAddress = APIObject('IpAddress', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$', 7, 15)
        self.add_api_object('IpAddress', self.IpAddress)
        self.IpAddressRange = APIObject('IpAddressRange', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{9,17}$', 9, 17)
        self.add_api_object('IpAddressRange', self.IpAddressRange)
        self.JunctionPath = APIObject('JunctionPath', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,255}$', 1, 255)
        self.add_api_object('JunctionPath', self.JunctionPath)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^.{1,2048}$', 1, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.LustreFileSystemMountName = APIObject('LustreFileSystemMountName', 'string', r'^([A-Za-z0-9_-]{1,8})$', 1, 8)
        self.add_api_object('LustreFileSystemMountName', self.LustreFileSystemMountName)
        self.LustreNoSquashNid = APIObject('LustreNoSquashNid', 'string', r'^([0-9\[\]\-]*\.){3}([0-9\[\]\-]*)@tcp$', 11, 43)
        self.add_api_object('LustreNoSquashNid', self.LustreNoSquashNid)
        self.LustreRootSquash = APIObject('LustreRootSquash', 'string', r'^([0-9]{1,10}):([0-9]{1,10})$', 3, 21)
        self.add_api_object('LustreRootSquash', self.LustreRootSquash)
        self.Namespace = APIObject('Namespace', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,4096}$', 1, 4096)
        self.add_api_object('Namespace', self.Namespace)
        self.NetBiosAlias = APIObject('NetBiosAlias', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,255}$', 1, 15)
        self.add_api_object('NetBiosAlias', self.NetBiosAlias)
        self.NetworkInterfaceId = APIObject('NetworkInterfaceId', 'string', r'^(eni-[0-9a-f]{8,})$', 12, 21)
        self.add_api_object('NetworkInterfaceId', self.NetworkInterfaceId)
        self.NextToken = APIObject('NextToken', 'string', r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', 1, 255)
        self.add_api_object('NextToken', self.NextToken)
        self.OpenZFSClients = APIObject('OpenZFSClients', 'string', r'^[ -~]{1,128}$', 1, 128)
        self.add_api_object('OpenZFSClients', self.OpenZFSClients)
        self.OpenZFSNfsExportOption = APIObject('OpenZFSNfsExportOption', 'string', r'^[ -~]{1,128}$', 1, 128)
        self.add_api_object('OpenZFSNfsExportOption', self.OpenZFSNfsExportOption)
        self.OrganizationalUnitDistinguishedName = APIObject('OrganizationalUnitDistinguishedName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,2000}$', 1, 2000)
        self.add_api_object('OrganizationalUnitDistinguishedName', self.OrganizationalUnitDistinguishedName)
        self.Region = APIObject('Region', 'string', r'^[a-z0-9-]{1,20}$', 1, 20)
        self.add_api_object('Region', self.Region)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'^arn:(?=[^:]+:fsx:[^:]+:\d{12}:)((|(?=[a-z0-9-.]{1,63})(?!\d{1,3}(\.\d{1,3}){3})(?![^:]*-{2})(?![^:]*-\.)(?![^:]*\.-)[a-z0-9].*(?<!-)):){4}(?!/).{0,1024}$', 8, 512)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.RouteTableId = APIObject('RouteTableId', 'string', r'^(rtb-[0-9a-f]{8,})$', 12, 21)
        self.add_api_object('RouteTableId', self.RouteTableId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^(sg-[0-9a-f]{8,})$', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SnapshotFilterValue = APIObject('SnapshotFilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?\-\_]*$', 1, 128)
        self.add_api_object('SnapshotFilterValue', self.SnapshotFilterValue)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'^((fs)?volsnap-[0-9a-f]{8,})$', 11, 28)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.SnapshotName = APIObject('SnapshotName', 'string', r'^[a-zA-Z0-9_:.-]{1,203}$', 1, 203)
        self.add_api_object('SnapshotName', self.SnapshotName)
        self.SourceBackupId = APIObject('SourceBackupId', 'string', r'^(backup-[0-9a-f]{8,})$', 12, 128)
        self.add_api_object('SourceBackupId', self.SourceBackupId)
        self.StorageVirtualMachineFilterValue = APIObject('StorageVirtualMachineFilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?\-\_]*$', 1, 128)
        self.add_api_object('StorageVirtualMachineFilterValue', self.StorageVirtualMachineFilterValue)
        self.StorageVirtualMachineId = APIObject('StorageVirtualMachineId', 'string', r'^(svm-[0-9a-f]{17,})$', 21, 21)
        self.add_api_object('StorageVirtualMachineId', self.StorageVirtualMachineId)
        self.StorageVirtualMachineName = APIObject('StorageVirtualMachineName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,47}$', 1, 47)
        self.add_api_object('StorageVirtualMachineName', self.StorageVirtualMachineName)
        self.SubnetId = APIObject('SubnetId', 'string', r'^(subnet-[0-9a-f]{8,})$', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaskId = APIObject('TaskId', 'string', r'^(task-[0-9a-f]{17,})$', 12, 128)
        self.add_api_object('TaskId', self.TaskId)
        self.UUID = APIObject('UUID', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,36}$', None, 36)
        self.add_api_object('UUID', self.UUID)
        self.VerboseFlag = APIObject('VerboseFlag', 'string', r'^(?i)(true|false)$', 4, 5)
        self.add_api_object('VerboseFlag', self.VerboseFlag)
        self.VolumeFilterValue = APIObject('VolumeFilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?\-\_]*$', 1, 128)
        self.add_api_object('VolumeFilterValue', self.VolumeFilterValue)
        self.VolumeId = APIObject('VolumeId', 'string', r'^(fsvol-[0-9a-f]{17,})$', 23, 23)
        self.add_api_object('VolumeId', self.VolumeId)
        self.VolumeName = APIObject('VolumeName', 'string', r'^[^\u0000\u0085\u2028\u2029\r\n]{1,203}$', 1, 203)
        self.add_api_object('VolumeName', self.VolumeName)
        self.VolumePath = APIObject('VolumePath', 'string', r'^[A-za-z0-9\_\.\:\-\/]*$', 1, 2048)
        self.add_api_object('VolumePath', self.VolumePath)
        self.VpcId = APIObject('VpcId', 'string', r'^(vpc-[0-9a-f]{8,})$', 12, 21)
        self.add_api_object('VpcId', self.VpcId)
        self.WeeklyTime = APIObject('WeeklyTime', 'string', r'^[1-7]:([01]\d|2[0-3]):?([0-5]\d)$', 7, 7)
        self.add_api_object('WeeklyTime', self.WeeklyTime)

class Gamelift(Service):
    def __init__(self):
        super().__init__('Gamelift')
        self.AliasArn = APIObject('AliasArn', 'string', r'^arn:.*:alias\/alias-\S+', None, None)
        self.add_api_object('AliasArn', self.AliasArn)
        self.AliasId = APIObject('AliasId', 'string', r'^alias-\S+', None, None)
        self.add_api_object('AliasId', self.AliasId)
        self.AliasIdOrArn = APIObject('AliasIdOrArn', 'string', r'^alias-\S+|^arn:.*:alias\/alias-\S+', None, None)
        self.add_api_object('AliasIdOrArn', self.AliasIdOrArn)
        self.ArnStringModel = APIObject('ArnStringModel', 'string', r'[a-zA-Z0-9:/-]+', 1, 256)
        self.add_api_object('ArnStringModel', self.ArnStringModel)
        self.AutoScalingGroupArn = APIObject('AutoScalingGroupArn', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 256)
        self.add_api_object('AutoScalingGroupArn', self.AutoScalingGroupArn)
        self.BuildArn = APIObject('BuildArn', 'string', r'^arn:.*:build\/build-\S+', None, None)
        self.add_api_object('BuildArn', self.BuildArn)
        self.BuildId = APIObject('BuildId', 'string', r'^build-\S+', None, None)
        self.add_api_object('BuildId', self.BuildId)
        self.BuildIdOrArn = APIObject('BuildIdOrArn', 'string', r'^build-\S+|^arn:.*:build\/build-\S+', None, None)
        self.add_api_object('BuildIdOrArn', self.BuildIdOrArn)
        self.ComputeArn = APIObject('ComputeArn', 'string', r'^arn:.*:compute\/[a-zA-Z0-9\-]+(\/[a-zA-Z0-9\-]+)?', None, 1024)
        self.add_api_object('ComputeArn', self.ComputeArn)
        self.ComputeAuthToken = APIObject('ComputeAuthToken', 'string', r'^[a-zA-Z0-9\-]+', 1, 64)
        self.add_api_object('ComputeAuthToken', self.ComputeAuthToken)
        self.ComputeName = APIObject('ComputeName', 'string', r'^[a-zA-Z0-9\-]+(\/[a-zA-Z0-9\-]+)?', 1, 128)
        self.add_api_object('ComputeName', self.ComputeName)
        self.ComputeNameOrArn = APIObject('ComputeNameOrArn', 'string', r'^[a-zA-Z0-9\-]+(\/[a-zA-Z0-9\-]+)?$|^arn:.*:compute\/[a-zA-Z0-9\-]+(\/[a-zA-Z0-9\-]+)?', None, 1024)
        self.add_api_object('ComputeNameOrArn', self.ComputeNameOrArn)
        self.ContainerGroupDefinitionArn = APIObject('ContainerGroupDefinitionArn', 'string', r'^arn:.*:containergroupdefinition\/containergroupdefinition-[a-zA-Z0-9-]+$', 1, 512)
        self.add_api_object('ContainerGroupDefinitionArn', self.ContainerGroupDefinitionArn)
        self.ContainerGroupDefinitionName = APIObject('ContainerGroupDefinitionName', 'string', r'^[a-zA-Z0-9\-]+$', 1, 128)
        self.add_api_object('ContainerGroupDefinitionName', self.ContainerGroupDefinitionName)
        self.ContainerGroupDefinitionNameOrArn = APIObject('ContainerGroupDefinitionNameOrArn', 'string', r'^[a-zA-Z0-9\-]+$|^arn:.*:containergroupdefinition\/[a-zA-Z0-9\-]+$', 1, 512)
        self.add_api_object('ContainerGroupDefinitionNameOrArn', self.ContainerGroupDefinitionNameOrArn)
        self.CustomInputLocationStringModel = APIObject('CustomInputLocationStringModel', 'string', r'^custom-[A-Za-z0-9\-]+', 8, 64)
        self.add_api_object('CustomInputLocationStringModel', self.CustomInputLocationStringModel)
        self.CustomLocationNameOrArnModel = APIObject('CustomLocationNameOrArnModel', 'string', r'^custom-[A-Za-z0-9\-]+|^arn:.*:location\/custom-\S+', 1, 128)
        self.add_api_object('CustomLocationNameOrArnModel', self.CustomLocationNameOrArnModel)
        self.DnsNameInput = APIObject('DnsNameInput', 'string', r'^[0-9a-zA-Z_\-\.]+', 1, 256)
        self.add_api_object('DnsNameInput', self.DnsNameInput)
        self.FleetArn = APIObject('FleetArn', 'string', r'^arn:.*:fleet\/fleet-\S+', None, None)
        self.add_api_object('FleetArn', self.FleetArn)
        self.FleetId = APIObject('FleetId', 'string', r'^fleet-\S+', None, None)
        self.add_api_object('FleetId', self.FleetId)
        self.FleetIdOrArn = APIObject('FleetIdOrArn', 'string', r'^fleet-\S+|^arn:.*:fleet\/fleet-\S+', None, None)
        self.add_api_object('FleetIdOrArn', self.FleetIdOrArn)
        self.GameServerConnectionInfo = APIObject('GameServerConnectionInfo', 'string', r'.*\S.*', 1, 512)
        self.add_api_object('GameServerConnectionInfo', self.GameServerConnectionInfo)
        self.GameServerData = APIObject('GameServerData', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('GameServerData', self.GameServerData)
        self.GameServerGroupArn = APIObject('GameServerGroupArn', 'string', r'^arn:.*:gameservergroup\/[a-zA-Z0-9-\.]*', 1, 256)
        self.add_api_object('GameServerGroupArn', self.GameServerGroupArn)
        self.GameServerGroupName = APIObject('GameServerGroupName', 'string', r'[a-zA-Z0-9-\.]+', 1, 128)
        self.add_api_object('GameServerGroupName', self.GameServerGroupName)
        self.GameServerGroupNameOrArn = APIObject('GameServerGroupNameOrArn', 'string', r'[a-zA-Z0-9-\.]+|^arn:.*:gameservergroup\/[a-zA-Z0-9-\.]+', 1, 256)
        self.add_api_object('GameServerGroupNameOrArn', self.GameServerGroupNameOrArn)
        self.GameServerId = APIObject('GameServerId', 'string', r'[a-zA-Z0-9-\.]+', 3, 128)
        self.add_api_object('GameServerId', self.GameServerId)
        self.GameServerInstanceId = APIObject('GameServerInstanceId', 'string', r'^i-[0-9a-zA-Z]{17}$', 19, 19)
        self.add_api_object('GameServerInstanceId', self.GameServerInstanceId)
        self.GameSessionQueueArn = APIObject('GameSessionQueueArn', 'string', r'^arn:.*:gamesessionqueue\/[a-zA-Z0-9-]+', 1, 256)
        self.add_api_object('GameSessionQueueArn', self.GameSessionQueueArn)
        self.GameSessionQueueName = APIObject('GameSessionQueueName', 'string', r'[a-zA-Z0-9-]+', 1, 128)
        self.add_api_object('GameSessionQueueName', self.GameSessionQueueName)
        self.GameSessionQueueNameOrArn = APIObject('GameSessionQueueNameOrArn', 'string', r'[a-zA-Z0-9-]+|^arn:.*:gamesessionqueue\/[a-zA-Z0-9-]+', 1, 256)
        self.add_api_object('GameSessionQueueNameOrArn', self.GameSessionQueueNameOrArn)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:.*:role\/[\w+=,.@-]+', 1, 256)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IdStringModel = APIObject('IdStringModel', 'string', r'[a-zA-Z0-9-]+', 1, 48)
        self.add_api_object('IdStringModel', self.IdStringModel)
        self.ImageUriString = APIObject('ImageUriString', 'string', r'^[a-zA-Z0-9-_\.@\/:]+$', 1, 255)
        self.add_api_object('ImageUriString', self.ImageUriString)
        self.InstanceId = APIObject('InstanceId', 'string', r'[a-zA-Z0-9\.-]+', None, None)
        self.add_api_object('InstanceId', self.InstanceId)
        self.IpAddress = APIObject('IpAddress', 'string', r'^[0-9A-Fa-f\:\.]+', 1, 128)
        self.add_api_object('IpAddress', self.IpAddress)
        self.IpRange = APIObject('IpRange', 'string', r'[^\s]+', None, None)
        self.add_api_object('IpRange', self.IpRange)
        self.LaunchParametersStringModel = APIObject('LaunchParametersStringModel', 'string', r'[A-Za-z0-9_:.+\/\\\- =@;{},?\'\[\]"]+', 1, 1024)
        self.add_api_object('LaunchParametersStringModel', self.LaunchParametersStringModel)
        self.LaunchPathStringModel = APIObject('LaunchPathStringModel', 'string', r'[A-Za-z0-9_:.+\/\\\- ]+', 1, 1024)
        self.add_api_object('LaunchPathStringModel', self.LaunchPathStringModel)
        self.LaunchTemplateId = APIObject('LaunchTemplateId', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]+', 1, 255)
        self.add_api_object('LaunchTemplateId', self.LaunchTemplateId)
        self.LaunchTemplateName = APIObject('LaunchTemplateName', 'string', r'[a-zA-Z0-9\(\)\.\-/_]+', 3, 128)
        self.add_api_object('LaunchTemplateName', self.LaunchTemplateName)
        self.LaunchTemplateVersion = APIObject('LaunchTemplateVersion', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]+', 1, 128)
        self.add_api_object('LaunchTemplateVersion', self.LaunchTemplateVersion)
        self.LocationArnModel = APIObject('LocationArnModel', 'string', r'^arn:.*:location\/custom-\S+', 1, 128)
        self.add_api_object('LocationArnModel', self.LocationArnModel)
        self.LocationStringModel = APIObject('LocationStringModel', 'string', r'^[A-Za-z0-9\-]+', 1, 64)
        self.add_api_object('LocationStringModel', self.LocationStringModel)
        self.MatchmakingConfigurationArn = APIObject('MatchmakingConfigurationArn', 'string', r'^arn:.*:matchmakingconfiguration\/[a-zA-Z0-9-\.]*', None, None)
        self.add_api_object('MatchmakingConfigurationArn', self.MatchmakingConfigurationArn)
        self.MatchmakingConfigurationName = APIObject('MatchmakingConfigurationName', 'string', r'[a-zA-Z0-9-\.]*|^arn:.*:matchmakingconfiguration\/[a-zA-Z0-9-\.]*', 1, 256)
        self.add_api_object('MatchmakingConfigurationName', self.MatchmakingConfigurationName)
        self.MatchmakingIdStringModel = APIObject('MatchmakingIdStringModel', 'string', r'[a-zA-Z0-9-\.]*', None, 128)
        self.add_api_object('MatchmakingIdStringModel', self.MatchmakingIdStringModel)
        self.MatchmakingRuleSetArn = APIObject('MatchmakingRuleSetArn', 'string', r'^arn:.*:matchmakingruleset\/[a-zA-Z0-9-\.]*', None, None)
        self.add_api_object('MatchmakingRuleSetArn', self.MatchmakingRuleSetArn)
        self.MatchmakingRuleSetName = APIObject('MatchmakingRuleSetName', 'string', r'[a-zA-Z0-9-\.]*|^arn:.*:matchmakingruleset\/[a-zA-Z0-9-\.]*', 1, 256)
        self.add_api_object('MatchmakingRuleSetName', self.MatchmakingRuleSetName)
        self.NonBlankAndLengthConstraintString = APIObject('NonBlankAndLengthConstraintString', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('NonBlankAndLengthConstraintString', self.NonBlankAndLengthConstraintString)
        self.NonNegativeLimitedLengthDouble = APIObject('NonNegativeLimitedLengthDouble', 'string', r'^\d{1,5}(?:\.\d{1,5})?$', 1, 11)
        self.add_api_object('NonNegativeLimitedLengthDouble', self.NonNegativeLimitedLengthDouble)
        self.NonZeroAnd128MaxAsciiString = APIObject('NonZeroAnd128MaxAsciiString', 'string', r'^[a-zA-Z0-9\-]+$', 1, 128)
        self.add_api_object('NonZeroAnd128MaxAsciiString', self.NonZeroAnd128MaxAsciiString)
        self.PlayerSessionId = APIObject('PlayerSessionId', 'string', r'^psess-\S+', None, None)
        self.add_api_object('PlayerSessionId', self.PlayerSessionId)
        self.QueueCustomEventData = APIObject('QueueCustomEventData', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('QueueCustomEventData', self.QueueCustomEventData)
        self.QueueSnsArnStringModel = APIObject('QueueSnsArnStringModel', 'string', r'[a-zA-Z0-9:_-]*(\.fifo)?', 0, 300)
        self.add_api_object('QueueSnsArnStringModel', self.QueueSnsArnStringModel)
        self.ScriptArn = APIObject('ScriptArn', 'string', r'^arn:.*:script\/script-\S+', None, None)
        self.add_api_object('ScriptArn', self.ScriptArn)
        self.ScriptId = APIObject('ScriptId', 'string', r'^script-\S+', None, None)
        self.add_api_object('ScriptId', self.ScriptId)
        self.ScriptIdOrArn = APIObject('ScriptIdOrArn', 'string', r'^script-\S+|^arn:.*:script\/script-\S+', None, None)
        self.add_api_object('ScriptIdOrArn', self.ScriptIdOrArn)
        self.ServerSdkVersion = APIObject('ServerSdkVersion', 'string', r'^\d+\.\d+\.\d+$', None, 128)
        self.add_api_object('ServerSdkVersion', self.ServerSdkVersion)
        self.Sha256 = APIObject('Sha256', 'string', r'^sha256:[a-fA-F0-9]{64}$', None, None)
        self.add_api_object('Sha256', self.Sha256)
        self.SnsArnStringModel = APIObject('SnsArnStringModel', 'string', r'[a-zA-Z0-9:_/-]*(.fifo)?', 0, 300)
        self.add_api_object('SnsArnStringModel', self.SnsArnStringModel)
        self.VpcSubnet = APIObject('VpcSubnet', 'string', r'^subnet-[0-9a-z]+$', 15, 24)
        self.add_api_object('VpcSubnet', self.VpcSubnet)
        self.WeightedCapacity = APIObject('WeightedCapacity', 'string', r'^[\u0031-\u0039][\u0030-\u0039]{0,2}$', 1, 3)
        self.add_api_object('WeightedCapacity', self.WeightedCapacity)

class Glacier(Service):
    def __init__(self):
        super().__init__('Glacier')

class Globalaccelerator(Service):
    def __init__(self):
        super().__init__('Globalaccelerator')
        self.AttachmentName = APIObject('AttachmentName', 'string', r'[\S\s]+', None, 64)
        self.add_api_object('AttachmentName', self.AttachmentName)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.HealthCheckPath = APIObject('HealthCheckPath', 'string', r'^/[-a-zA-Z0-9@:%_\\+.~#?&/=]*$', None, 255)
        self.add_api_object('HealthCheckPath', self.HealthCheckPath)
        self.Principal = APIObject('Principal', 'string', r'(^\d{12}$|arn:.*)', None, 256)
        self.add_api_object('Principal', self.Principal)

class Glue(Service):
    def __init__(self):
        super().__init__('Glue')
        self.AuthTokenString = APIObject('AuthTokenString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('AuthTokenString', self.AuthTokenString)
        self.CatalogIdString = APIObject('CatalogIdString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('CatalogIdString', self.CatalogIdString)
        self.CodeGenIdentifier = APIObject('CodeGenIdentifier', 'string', r'[A-Za-z_][A-Za-z0-9_]*', 1, 255)
        self.add_api_object('CodeGenIdentifier', self.CodeGenIdentifier)
        self.ColumnNameString = APIObject('ColumnNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 1024)
        self.add_api_object('ColumnNameString', self.ColumnNameString)
        self.ColumnTypeString = APIObject('ColumnTypeString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 131072)
        self.add_api_object('ColumnTypeString', self.ColumnTypeString)
        self.CommentString = APIObject('CommentString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 255)
        self.add_api_object('CommentString', self.CommentString)
        self.CommitIdString = APIObject('CommitIdString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 40)
        self.add_api_object('CommitIdString', self.CommitIdString)
        self.CsvColumnDelimiter = APIObject('CsvColumnDelimiter', 'string', r'[^\r\n]', 1, 1)
        self.add_api_object('CsvColumnDelimiter', self.CsvColumnDelimiter)
        self.CsvQuoteSymbol = APIObject('CsvQuoteSymbol', 'string', r'[^\r\n]', 1, 1)
        self.add_api_object('CsvQuoteSymbol', self.CsvQuoteSymbol)
        self.CustomPatterns = APIObject('CustomPatterns', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 16000)
        self.add_api_object('CustomPatterns', self.CustomPatterns)
        self.DQDLString = APIObject('DQDLString', 'string', r'([\u0020-\u007E\r\s\n])*', 1, 65536)
        self.add_api_object('DQDLString', self.DQDLString)
        self.DataQualityObservationDescription = APIObject('DataQualityObservationDescription', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('DataQualityObservationDescription', self.DataQualityObservationDescription)
        self.DataQualityRuleResultDescription = APIObject('DataQualityRuleResultDescription', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('DataQualityRuleResultDescription', self.DataQualityRuleResultDescription)
        self.DescriptionString = APIObject('DescriptionString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('DescriptionString', self.DescriptionString)
        self.DescriptionStringRemovable = APIObject('DescriptionStringRemovable', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('DescriptionStringRemovable', self.DescriptionStringRemovable)
        self.EnclosedInStringProperty = APIObject('EnclosedInStringProperty', 'string', r'([\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF]|[^\S\r\n"\'])*', None, None)
        self.add_api_object('EnclosedInStringProperty', self.EnclosedInStringProperty)
        self.EnclosedInStringPropertyWithQuote = APIObject('EnclosedInStringPropertyWithQuote', 'string', r'([\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF]|[^\S\r\n])*', None, None)
        self.add_api_object('EnclosedInStringPropertyWithQuote', self.EnclosedInStringPropertyWithQuote)
        self.ExtendedString = APIObject('ExtendedString', 'string', r'[\s\S]*', None, None)
        self.add_api_object('ExtendedString', self.ExtendedString)
        self.FederationIdentifier = APIObject('FederationIdentifier', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 512)
        self.add_api_object('FederationIdentifier', self.FederationIdentifier)
        self.FilterString = APIObject('FilterString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 2048)
        self.add_api_object('FilterString', self.FilterString)
        self.FormatString = APIObject('FormatString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', None, 128)
        self.add_api_object('FormatString', self.FormatString)
        self.GenericLimitedString = APIObject('GenericLimitedString', 'string', r'[A-Za-z0-9_-]*', None, None)
        self.add_api_object('GenericLimitedString', self.GenericLimitedString)
        self.GlueResourceArn = APIObject('GlueResourceArn', 'string', r'arn:(aws|aws-us-gov|aws-cn):glue:.*', 1, 10240)
        self.add_api_object('GlueResourceArn', self.GlueResourceArn)
        self.GlueStudioColumnNameString = APIObject('GlueStudioColumnNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 1024)
        self.add_api_object('GlueStudioColumnNameString', self.GlueStudioColumnNameString)
        self.GlueVersionString = APIObject('GlueVersionString', 'string', r'^\w+\.\w+$', 1, 255)
        self.add_api_object('GlueVersionString', self.GlueVersionString)
        self.GrokPattern = APIObject('GrokPattern', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\t]*', 1, 2048)
        self.add_api_object('GrokPattern', self.GrokPattern)
        self.HashString = APIObject('HashString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('HashString', self.HashString)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'^arn:aws(-(cn|us-gov|iso(-[bef])?))?:iam::[0-9]{12}:role/.+', None, None)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.IdString = APIObject('IdString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('IdString', self.IdString)
        self.KeyString = APIObject('KeyString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('KeyString', self.KeyString)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws:kms:.*', None, None)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LocationString = APIObject('LocationString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', None, 2056)
        self.add_api_object('LocationString', self.LocationString)
        self.LogGroup = APIObject('LogGroup', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroup', self.LogGroup)
        self.LogStream = APIObject('LogStream', 'string', r'[^:*]*', 1, 512)
        self.add_api_object('LogStream', self.LogStream)
        self.MaskValue = APIObject('MaskValue', 'string', r'[*A-Za-z0-9_-]*', 0, 256)
        self.add_api_object('MaskValue', self.MaskValue)
        self.MessagePrefix = APIObject('MessagePrefix', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('MessagePrefix', self.MessagePrefix)
        self.MetadataKeyString = APIObject('MetadataKeyString', 'string', r'[a-zA-Z0-9+-=._./@]+', 1, 128)
        self.add_api_object('MetadataKeyString', self.MetadataKeyString)
        self.MetadataValueString = APIObject('MetadataValueString', 'string', r'[a-zA-Z0-9+-=._./@]+', 1, 256)
        self.add_api_object('MetadataValueString', self.MetadataValueString)
        self.NameString = APIObject('NameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('NameString', self.NameString)
        self.NodeId = APIObject('NodeId', 'string', r'[A-Za-z0-9_-]*', None, None)
        self.add_api_object('NodeId', self.NodeId)
        self.NodeName = APIObject('NodeName', 'string', r'([\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF]|[^\r\n])*', None, None)
        self.add_api_object('NodeName', self.NodeName)
        self.OrchestrationArgumentsValue = APIObject('OrchestrationArgumentsValue', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 4096)
        self.add_api_object('OrchestrationArgumentsValue', self.OrchestrationArgumentsValue)
        self.OrchestrationIAMRoleArn = APIObject('OrchestrationIAMRoleArn', 'string', r'arn:aws[^:]*:iam::[0-9]*:role/.+', 1, 1024)
        self.add_api_object('OrchestrationIAMRoleArn', self.OrchestrationIAMRoleArn)
        self.OrchestrationNameString = APIObject('OrchestrationNameString', 'string', r'[\.\-_A-Za-z0-9]+', 1, 128)
        self.add_api_object('OrchestrationNameString', self.OrchestrationNameString)
        self.OrchestrationRoleArn = APIObject('OrchestrationRoleArn', 'string', r'arn:aws[^:]*:iam::[0-9]*:role/.+', 20, 2048)
        self.add_api_object('OrchestrationRoleArn', self.OrchestrationRoleArn)
        self.OrchestrationS3Location = APIObject('OrchestrationS3Location', 'string', r'^s3://([^/]+)/([^/]+/)*([^/]+)$', 1, 8192)
        self.add_api_object('OrchestrationS3Location', self.OrchestrationS3Location)
        self.PredicateString = APIObject('PredicateString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('PredicateString', self.PredicateString)
        self.PythonVersionString = APIObject('PythonVersionString', 'string', r'^([2-3]|3[.]9)$', None, None)
        self.add_api_object('PythonVersionString', self.PythonVersionString)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam::\d{12}:role/.*', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.RuntimeNameString = APIObject('RuntimeNameString', 'string', r'.*', None, 64)
        self.add_api_object('RuntimeNameString', self.RuntimeNameString)
        self.SchemaDefinitionDiff = APIObject('SchemaDefinitionDiff', 'string', r'.*\S.*', 1, 340000)
        self.add_api_object('SchemaDefinitionDiff', self.SchemaDefinitionDiff)
        self.SchemaDefinitionString = APIObject('SchemaDefinitionString', 'string', r'.*\S.*', 1, 170000)
        self.add_api_object('SchemaDefinitionString', self.SchemaDefinitionString)
        self.SchemaRegistryNameString = APIObject('SchemaRegistryNameString', 'string', r'[a-zA-Z0-9-_$#.]+', 1, 255)
        self.add_api_object('SchemaRegistryNameString', self.SchemaRegistryNameString)
        self.SchemaVersionIdString = APIObject('SchemaVersionIdString', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 36, 36)
        self.add_api_object('SchemaVersionIdString', self.SchemaVersionIdString)
        self.SqlQuery = APIObject('SqlQuery', 'string', r'([\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\s])*', None, None)
        self.add_api_object('SqlQuery', self.SqlQuery)
        self.TransactionIdString = APIObject('TransactionIdString', 'string', r'[\p{L}\p{N}\p{P}]*', 1, 255)
        self.add_api_object('TransactionIdString', self.TransactionIdString)
        self.TypeString = APIObject('TypeString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 20000)
        self.add_api_object('TypeString', self.TypeString)
        self.URI = APIObject('URI', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1024)
        self.add_api_object('URI', self.URI)
        self.VersionString = APIObject('VersionString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('VersionString', self.VersionString)
        self.VersionsString = APIObject('VersionsString', 'string', r'[1-9][0-9]*|[1-9][0-9]*-[1-9][0-9]*', 1, 100000)
        self.add_api_object('VersionsString', self.VersionsString)

class Grafana(Service):
    def __init__(self):
        super().__init__('Grafana')
        self.ClientToken = APIObject('ClientToken', 'string', r'^[!-~]{1,64}$', None, None)
        self.add_api_object('ClientToken', self.ClientToken)
        self.WorkspaceId = APIObject('WorkspaceId', 'string', r'^g-[0-9a-f]{10}$', None, None)
        self.add_api_object('WorkspaceId', self.WorkspaceId)
        self.WorkspaceName = APIObject('WorkspaceName', 'string', r'^[a-zA-Z0-9-._~]{1,255}$', None, None)
        self.add_api_object('WorkspaceName', self.WorkspaceName)

class Greengrass(Service):
    def __init__(self):
        super().__init__('Greengrass')

class Greengrassv2(Service):
    def __init__(self):
        super().__init__('Greengrassv2')
        self.ClientTokenString = APIObject('ClientTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientTokenString', self.ClientTokenString)
        self.ComponentARN = APIObject('ComponentARN', 'string', r'arn:[^:]*:greengrass:[^:]*:(aws|[0-9]+):components:[^:]+', None, None)
        self.add_api_object('ComponentARN', self.ComponentARN)
        self.ComponentVersionARN = APIObject('ComponentVersionARN', 'string', r'arn:[^:]*:greengrass:[^:]*:(aws|[0-9]+):components:[^:]+:versions:[^:]+', None, None)
        self.add_api_object('ComponentVersionARN', self.ComponentVersionARN)
        self.GenericV2ARN = APIObject('GenericV2ARN', 'string', r'arn:[^:]*:greengrass:[^:]*:(aws|[0-9]+):(components|deployments|coreDevices):.*', None, None)
        self.add_api_object('GenericV2ARN', self.GenericV2ARN)
        self.IoTJobARN = APIObject('IoTJobARN', 'string', r'arn:[^:]*:iot:[^:]+:[0-9]+:job/.+', None, None)
        self.add_api_object('IoTJobARN', self.IoTJobARN)
        self.TargetARN = APIObject('TargetARN', 'string', r'arn:[^:]*:iot:[^:]*:[0-9]+:(thing|thinggroup)/.+', None, None)
        self.add_api_object('TargetARN', self.TargetARN)
        self.ThingGroupARN = APIObject('ThingGroupARN', 'string', r'arn:[^:]*:iot:[^:]*:[0-9]+:thinggroup/.+', None, None)
        self.add_api_object('ThingGroupARN', self.ThingGroupARN)

class Groundstation(Service):
    def __init__(self):
        super().__init__('Groundstation')
        self.AWSRegion = APIObject('AWSRegion', 'string', r'^[\w-]+$', 1, 128)
        self.add_api_object('AWSRegion', self.AWSRegion)
        self.AnyArn = APIObject('AnyArn', 'string', r'^(arn:aws:)[\s\S]{0,1024}$', 5, 1024)
        self.add_api_object('AnyArn', self.AnyArn)
        self.ComponentTypeString = APIObject('ComponentTypeString', 'string', r'^[a-zA-Z0-9_]{1,64}$', None, None)
        self.add_api_object('ComponentTypeString', self.ComponentTypeString)
        self.GroundStationName = APIObject('GroundStationName', 'string', r'^[ a-zA-Z0-9-._:=]{4,256}$', 4, 500)
        self.add_api_object('GroundStationName', self.GroundStationName)
        self.InstanceId = APIObject('InstanceId', 'string', r'^[a-z0-9-]{10,64}$', 10, 64)
        self.add_api_object('InstanceId', self.InstanceId)
        self.InstanceType = APIObject('InstanceType', 'string', r'^[a-z0-9.-]{1,64}$', 1, 64)
        self.add_api_object('InstanceType', self.InstanceType)
        self.IpV4Address = APIObject('IpV4Address', 'string', r'^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$', 7, 16)
        self.add_api_object('IpV4Address', self.IpV4Address)
        self.JsonString = APIObject('JsonString', 'string', r'^[{}\[\]:.,"0-9A-z\-_\s]{2,8192}$', 2, 8192)
        self.add_api_object('JsonString', self.JsonString)
        self.KeyAliasArn = APIObject('KeyAliasArn', 'string', r'^arn:aws[a-zA-Z-]{0,16}:kms:[a-z]{2}(-[a-z]{1,16}){1,3}-\d{1}:\d{12}:((alias/[a-zA-Z0-9:/_-]{1,256}))$', 1, 512)
        self.add_api_object('KeyAliasArn', self.KeyAliasArn)
        self.KeyAliasName = APIObject('KeyAliasName', 'string', r'^alias/[a-zA-Z0-9:/_-]+$', 1, 256)
        self.add_api_object('KeyAliasName', self.KeyAliasName)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[A-Za-z0-9-/+_.=]+$', 3, 1000)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[a-z0-9.-]{3,63}$', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3KeyPrefix = APIObject('S3KeyPrefix', 'string', r'^([a-zA-Z0-9_\-=/]|\{satellite_id\}|\{config\-name}|\{s3\-config-id}|\{year\}|\{month\}|\{day\}){1,900}$', 1, 900)
        self.add_api_object('S3KeyPrefix', self.S3KeyPrefix)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'^[a-zA-Z0-9!*\'\)\(./_-]{1,1024}$', 1, 1024)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.S3VersionId = APIObject('S3VersionId', 'string', r'^[\s\S]{1,1024}$', 1, 1024)
        self.add_api_object('S3VersionId', self.S3VersionId)
        self.SafeName = APIObject('SafeName', 'string', r'^[ a-zA-Z0-9_:-]{1,256}$', 1, 256)
        self.add_api_object('SafeName', self.SafeName)
        self.TleLineOne = APIObject('TleLineOne', 'string', r'^1 [ 0-9]{5}[A-Z] [ 0-9]{5}[ A-Z]{3} [ 0-9]{5}[.][ 0-9]{8} (?:(?:[ 0+-][.][ 0-9]{8})|(?: [ +-][.][ 0-9]{7})) [ +-][ 0-9]{5}[+-][ 0-9] [ +-][ 0-9]{5}[+-][ 0-9] [ 0-9] [ 0-9]{4}[ 0-9]$', 69, 69)
        self.add_api_object('TleLineOne', self.TleLineOne)
        self.TleLineTwo = APIObject('TleLineTwo', 'string', r'^2 [ 0-9]{5} [ 0-9]{3}[.][ 0-9]{4} [ 0-9]{3}[.][ 0-9]{4} [ 0-9]{7} [ 0-9]{3}[.][ 0-9]{4} [ 0-9]{3}[.][ 0-9]{4} [ 0-9]{2}[.][ 0-9]{13}[ 0-9]$', 69, 69)
        self.add_api_object('TleLineTwo', self.TleLineTwo)
        self.UnboundedString = APIObject('UnboundedString', 'string', r'^[\s\S]+$', 1, None)
        self.add_api_object('UnboundedString', self.UnboundedString)
        self.Uuid = APIObject('Uuid', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 1, 128)
        self.add_api_object('Uuid', self.Uuid)
        self.VersionString = APIObject('VersionString', 'string', r'^(0|[1-9]\d*)(\.(0|[1-9]\d*))*$', 1, 64)
        self.add_api_object('VersionString', self.VersionString)

class Guardduty(Service):
    def __init__(self):
        super().__init__('Guardduty')
        self.GuardDutyArn = APIObject('GuardDutyArn', 'string', r'^arn:[A-Za-z_.-]{1,20}:guardduty:[A-Za-z0-9_/.-]{0,63}:\d+:detector/[A-Za-z0-9_/.-]{32,264}$', None, None)
        self.add_api_object('GuardDutyArn', self.GuardDutyArn)
        self.InstanceArn = APIObject('InstanceArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):[a-z]+:[a-z]+(-[0-9]+|-[a-z]+)+:([0-9]{12}):[a-z\-]+\/[a-zA-Z0-9]*$', None, None)
        self.add_api_object('InstanceArn', self.InstanceArn)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:[A-Za-z-]+:[A-Za-z0-9]+:[A-Za-z0-9-]+:\d+:(([A-Za-z0-9-]+)[:\/])?[A-Za-z0-9-]*$', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Health(Service):
    def __init__(self):
        super().__init__('Health')
        self.accountId = APIObject('accountId', 'string', r'^\S+$', None, 12)
        self.add_api_object('accountId', self.accountId)
        self.availabilityZone = APIObject('availabilityZone', 'string', r'[a-z]{2}\-[0-9a-z\-]{4,16}', 6, 18)
        self.add_api_object('availabilityZone', self.availabilityZone)
        self.entityArn = APIObject('entityArn', 'string', r'.{0,1600}', None, 1600)
        self.add_api_object('entityArn', self.entityArn)
        self.entityValue = APIObject('entityValue', 'string', r'.{0,1224}', None, 1224)
        self.add_api_object('entityValue', self.entityValue)
        self.eventArn = APIObject('eventArn', 'string', r'arn:aws(-[a-z]+(-[a-z]+)?)?:health:[^:]*:[^:]*:event(?:/[\w-]+){3}', None, 1600)
        self.add_api_object('eventArn', self.eventArn)
        self.eventType = APIObject('eventType', 'string', r'[^:/]{3,100}', 3, 100)
        self.add_api_object('eventType', self.eventType)
        self.eventTypeCode = APIObject('eventTypeCode', 'string', r'[a-zA-Z0-9\_\-]{3,100}', 3, 100)
        self.add_api_object('eventTypeCode', self.eventTypeCode)
        self.locale = APIObject('locale', 'string', r'.{2,256}', 2, 256)
        self.add_api_object('locale', self.locale)
        self.nextToken = APIObject('nextToken', 'string', r'[a-zA-Z0-9=/+_.-]{4,10000}', 4, 10000)
        self.add_api_object('nextToken', self.nextToken)
        self.region = APIObject('region', 'string', r'[^:/]{2,25}', 2, 25)
        self.add_api_object('region', self.region)
        self.service = APIObject('service', 'string', r'[^:/]{2,30}', 2, 30)
        self.add_api_object('service', self.service)
        self.tagKey = APIObject('tagKey', 'string', r'.{0,127}', None, 127)
        self.add_api_object('tagKey', self.tagKey)
        self.tagValue = APIObject('tagValue', 'string', r'.{0,255}', None, 255)
        self.add_api_object('tagValue', self.tagValue)

class Healthlake(Service):
    def __init__(self):
        super().__init__('Healthlake')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:aws((-us-gov)|(-iso)|(-iso-b)|(-cn))?:healthlake:[a-z0-9-]+:\d{12}:datastore\/fhir\/.{32}', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.BoundedLengthString = APIObject('BoundedLengthString', 'string', r'[\P{M}\p{M}]{1,5000}', 1, 5000)
        self.add_api_object('BoundedLengthString', self.BoundedLengthString)
        self.ClientTokenString = APIObject('ClientTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientTokenString', self.ClientTokenString)
        self.DatastoreArn = APIObject('DatastoreArn', 'string', r'^arn:aws((-us-gov)|(-iso)|(-iso-b)|(-cn))?:healthlake:[a-zA-Z0-9-]+:[0-9]{12}:datastore/.+?', None, None)
        self.add_api_object('DatastoreArn', self.DatastoreArn)
        self.DatastoreId = APIObject('DatastoreId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 32)
        self.add_api_object('DatastoreId', self.DatastoreId)
        self.DatastoreName = APIObject('DatastoreName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 256)
        self.add_api_object('DatastoreName', self.DatastoreName)
        self.EncryptionKeyID = APIObject('EncryptionKeyID', 'string', r'(arn:aws((-us-gov)|(-iso)|(-iso-b)|(-cn))?:kms:)?([a-z]{2}-[a-z]+(-[a-z]+)?-\d:)?(\d{12}:)?(((key/)?[a-zA-Z0-9-_]+)|(alias/[a-zA-Z0-9:/_-]+))', 1, 400)
        self.add_api_object('EncryptionKeyID', self.EncryptionKeyID)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.JobId = APIObject('JobId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 32)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 64)
        self.add_api_object('JobName', self.JobName)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'arn:aws:lambda:[a-z]{2}-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9\-_\.]+(:(\$LATEST|[a-zA-Z0-9\-_]+))?', 49, 256)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.Message = APIObject('Message', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 2048)
        self.add_api_object('Message', self.Message)
        self.NextToken = APIObject('NextToken', 'string', r'\p{ASCII}{0,8192}', None, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', None, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.String = APIObject('String', 'string', r'[\P{M}\p{M}]{0,10000}', None, 10000)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Honeycode(Service):
    def __init__(self):
        super().__init__('Honeycode')
        self.BatchErrorMessage = APIObject('BatchErrorMessage', 'string', r'^(?!\s*$).+', None, None)
        self.add_api_object('BatchErrorMessage', self.BatchErrorMessage)
        self.BatchItemId = APIObject('BatchItemId', 'string', r'^(?!\s*$).+', 1, 64)
        self.add_api_object('BatchItemId', self.BatchItemId)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^(?!\s*$).+', 32, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.DelimitedTextDelimiter = APIObject('DelimitedTextDelimiter', 'string', r'^[^\n\r\x00\x08\x0B\x0C\x0E\x1F]?$', 1, 1)
        self.add_api_object('DelimitedTextDelimiter', self.DelimitedTextDelimiter)
        self.Email = APIObject('Email', 'string', r'^([a-zA-Z0-9_\-\.]+)@([a-zA-Z0-9_\-\.]+)\.([a-zA-Z]{2,5})$', 3, 254)
        self.add_api_object('Email', self.Email)
        self.Fact = APIObject('Fact', 'string', r'[\s\S]*', 0, 8192)
        self.add_api_object('Fact', self.Fact)
        self.FormattedValue = APIObject('FormattedValue', 'string', r'[\s\S]*', 0, 8192)
        self.add_api_object('FormattedValue', self.FormattedValue)
        self.Formula = APIObject('Formula', 'string', r'^=.*', 0, 8192)
        self.add_api_object('Formula', self.Formula)
        self.JobId = APIObject('JobId', 'string', r'^[^\n\r\x00\x08\x0B\x0C\x0E\x1F]*$', 1, 100)
        self.add_api_object('JobId', self.JobId)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^(?!\s*$).+', 1, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.RawValue = APIObject('RawValue', 'string', r'[\s\S]*', 0, 32767)
        self.add_api_object('RawValue', self.RawValue)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:honeycode:.+:[0-9]{12}:.+:.+$', 1, 256)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', 36, 36)
        self.add_api_object('ResourceId', self.ResourceId)
        self.RowId = APIObject('RowId', 'string', r'row:[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}\/[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', 77, 77)
        self.add_api_object('RowId', self.RowId)
        self.SecureURL = APIObject('SecureURL', 'string', r'^https:\/\/[^\n\r\x00\x08\x0B\x0C\x0E\x1F]*$', 1, 8000)
        self.add_api_object('SecureURL', self.SecureURL)
        self.TagKey = APIObject('TagKey', 'string', r'^[^\n\r\x00\x08\x0B\x0C\x0E\x1F]*$', 1, 100)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[^\n\r\x00\x08\x0B\x0C\x0E\x1F]*$', 1, 100)
        self.add_api_object('TagValue', self.TagValue)
        self.VariableName = APIObject('VariableName', 'string', r'^(?!\s*$).+', 1, 255)
        self.add_api_object('VariableName', self.VariableName)

class Iam(Service):
    def __init__(self):
        super().__init__('Iam')
        self.CertificationKeyType = APIObject('CertificationKeyType', 'string', r'[\u0020-\u00FF]+', 1, 128)
        self.add_api_object('CertificationKeyType', self.CertificationKeyType)
        self.CertificationValueType = APIObject('CertificationValueType', 'string', r'[\u0020-\u00FF]+', 1, 32)
        self.add_api_object('CertificationValueType', self.CertificationValueType)
        self.SAMLProviderNameType = APIObject('SAMLProviderNameType', 'string', r'[\w._-]+', 1, 128)
        self.add_api_object('SAMLProviderNameType', self.SAMLProviderNameType)
        self.accessKeyIdType = APIObject('accessKeyIdType', 'string', r'[\w]+', 16, 128)
        self.add_api_object('accessKeyIdType', self.accessKeyIdType)
        self.accountAliasType = APIObject('accountAliasType', 'string', r'^[a-z0-9]([a-z0-9]|-(?!-)){1,61}[a-z0-9]$', 3, 63)
        self.add_api_object('accountAliasType', self.accountAliasType)
        self.authenticationCodeType = APIObject('authenticationCodeType', 'string', r'[\d]+', 6, 6)
        self.add_api_object('authenticationCodeType', self.authenticationCodeType)
        self.certificateBodyType = APIObject('certificateBodyType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 16384)
        self.add_api_object('certificateBodyType', self.certificateBodyType)
        self.certificateChainType = APIObject('certificateChainType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 2097152)
        self.add_api_object('certificateChainType', self.certificateChainType)
        self.certificateIdType = APIObject('certificateIdType', 'string', r'[\w]+', 24, 128)
        self.add_api_object('certificateIdType', self.certificateIdType)
        self.customSuffixType = APIObject('customSuffixType', 'string', r'[\w+=,.@-]+', 1, 64)
        self.add_api_object('customSuffixType', self.customSuffixType)
        self.entityNameType = APIObject('entityNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('entityNameType', self.entityNameType)
        self.existingUserNameType = APIObject('existingUserNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('existingUserNameType', self.existingUserNameType)
        self.groupNameType = APIObject('groupNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('groupNameType', self.groupNameType)
        self.idType = APIObject('idType', 'string', r'[\w]+', 16, 128)
        self.add_api_object('idType', self.idType)
        self.instanceProfileNameType = APIObject('instanceProfileNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('instanceProfileNameType', self.instanceProfileNameType)
        self.markerType = APIObject('markerType', 'string', r'[\u0020-\u00FF]+', 1, 320)
        self.add_api_object('markerType', self.markerType)
        self.organizationsEntityPathType = APIObject('organizationsEntityPathType', 'string', r'^o-[0-9a-z]{10,32}\/r-[0-9a-z]{4,32}[0-9a-z-\/]*', 19, 427)
        self.add_api_object('organizationsEntityPathType', self.organizationsEntityPathType)
        self.organizationsPolicyIdType = APIObject('organizationsPolicyIdType', 'string', r'^p-[0-9a-zA-Z_]{8,128}$', None, None)
        self.add_api_object('organizationsPolicyIdType', self.organizationsPolicyIdType)
        self.passwordType = APIObject('passwordType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 128)
        self.add_api_object('passwordType', self.passwordType)
        self.pathPrefixType = APIObject('pathPrefixType', 'string', r'\u002F[\u0021-\u007F]*', 1, 512)
        self.add_api_object('pathPrefixType', self.pathPrefixType)
        self.pathType = APIObject('pathType', 'string', r'(\u002F)|(\u002F[\u0021-\u007E]+\u002F)', 1, 512)
        self.add_api_object('pathType', self.pathType)
        self.policyDocumentType = APIObject('policyDocumentType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 131072)
        self.add_api_object('policyDocumentType', self.policyDocumentType)
        self.policyNameType = APIObject('policyNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('policyNameType', self.policyNameType)
        self.policyPathType = APIObject('policyPathType', 'string', r'((/[A-Za-z0-9\.,\+@=_-]+)*)/', 1, 512)
        self.add_api_object('policyPathType', self.policyPathType)
        self.policyVersionIdType = APIObject('policyVersionIdType', 'string', r'v[1-9][0-9]*(\.[A-Za-z0-9-]*)?', None, None)
        self.add_api_object('policyVersionIdType', self.policyVersionIdType)
        self.privateKeyType = APIObject('privateKeyType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 16384)
        self.add_api_object('privateKeyType', self.privateKeyType)
        self.publicKeyFingerprintType = APIObject('publicKeyFingerprintType', 'string', r'[:\w]+', 48, 48)
        self.add_api_object('publicKeyFingerprintType', self.publicKeyFingerprintType)
        self.publicKeyIdType = APIObject('publicKeyIdType', 'string', r'[\w]+', 20, 128)
        self.add_api_object('publicKeyIdType', self.publicKeyIdType)
        self.publicKeyMaterialType = APIObject('publicKeyMaterialType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 16384)
        self.add_api_object('publicKeyMaterialType', self.publicKeyMaterialType)
        self.roleDescriptionType = APIObject('roleDescriptionType', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u00A1-\u00FF]*', None, 1000)
        self.add_api_object('roleDescriptionType', self.roleDescriptionType)
        self.roleNameType = APIObject('roleNameType', 'string', r'[\w+=,.@-]+', 1, 64)
        self.add_api_object('roleNameType', self.roleNameType)
        self.serialNumberType = APIObject('serialNumberType', 'string', r'[\w+=/:,.@-]+', 9, 256)
        self.add_api_object('serialNumberType', self.serialNumberType)
        self.serverCertificateNameType = APIObject('serverCertificateNameType', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('serverCertificateNameType', self.serverCertificateNameType)
        self.serviceNamespaceType = APIObject('serviceNamespaceType', 'string', r'[\w-]*', 1, 64)
        self.add_api_object('serviceNamespaceType', self.serviceNamespaceType)
        self.serviceSpecificCredentialId = APIObject('serviceSpecificCredentialId', 'string', r'[\w]+', 20, 128)
        self.add_api_object('serviceSpecificCredentialId', self.serviceSpecificCredentialId)
        self.serviceUserName = APIObject('serviceUserName', 'string', r'[\w+=,.@-]+', 17, 200)
        self.add_api_object('serviceUserName', self.serviceUserName)
        self.tagKeyType = APIObject('tagKeyType', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]+', 1, 128)
        self.add_api_object('tagKeyType', self.tagKeyType)
        self.tagValueType = APIObject('tagValueType', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 0, 256)
        self.add_api_object('tagValueType', self.tagValueType)
        self.userNameType = APIObject('userNameType', 'string', r'[\w+=,.@-]+', 1, 64)
        self.add_api_object('userNameType', self.userNameType)
        self.virtualMFADeviceName = APIObject('virtualMFADeviceName', 'string', r'[\w+=,.@-]+', 1, None)
        self.add_api_object('virtualMFADeviceName', self.virtualMFADeviceName)

class Identitystore(Service):
    def __init__(self):
        super().__init__('Identitystore')
        self.AttributePath = APIObject('AttributePath', 'string', r'\p{L}+(?:\.\p{L}+){0,2}', 1, 255)
        self.add_api_object('AttributePath', self.AttributePath)
        self.ExternalIdIdentifier = APIObject('ExternalIdIdentifier', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 256)
        self.add_api_object('ExternalIdIdentifier', self.ExternalIdIdentifier)
        self.ExternalIdIssuer = APIObject('ExternalIdIssuer', 'string', r'(?!(?i)(arn|aws):)[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 100)
        self.add_api_object('ExternalIdIssuer', self.ExternalIdIssuer)
        self.GroupDisplayName = APIObject('GroupDisplayName', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\t\n\r  ]+', 1, 1024)
        self.add_api_object('GroupDisplayName', self.GroupDisplayName)
        self.IdentityStoreId = APIObject('IdentityStoreId', 'string', r'd-[0-9a-f]{10}$|^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 1, 36)
        self.add_api_object('IdentityStoreId', self.IdentityStoreId)
        self.NextToken = APIObject('NextToken', 'string', r'[-a-zA-Z0-9+=/:_]*', 1, 65535)
        self.add_api_object('NextToken', self.NextToken)
        self.RequestId = APIObject('RequestId', 'string', r'[A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12}', 1, 36)
        self.add_api_object('RequestId', self.RequestId)
        self.ResourceId = APIObject('ResourceId', 'string', r'([0-9a-f]{10}-|)[A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12}', 1, 47)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SensitiveStringType = APIObject('SensitiveStringType', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}\t\n\r  　]+', 1, 1024)
        self.add_api_object('SensitiveStringType', self.SensitiveStringType)
        self.UserName = APIObject('UserName', 'string', r'[\p{L}\p{M}\p{S}\p{N}\p{P}]+', 1, 128)
        self.add_api_object('UserName', self.UserName)

class Imagebuilder(Service):
    def __init__(self):
        super().__init__('Imagebuilder')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.AmiNameString = APIObject('AmiNameString', 'string', r'^[-_A-Za-z0-9{][-_A-Za-z0-9\s:{}\.]+[-_A-Za-z0-9}]$', 1, 127)
        self.add_api_object('AmiNameString', self.AmiNameString)
        self.ComponentBuildVersionArn = APIObject('ComponentBuildVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):component/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+/[0-9]+$', None, None)
        self.add_api_object('ComponentBuildVersionArn', self.ComponentBuildVersionArn)
        self.ComponentParameterDescription = APIObject('ComponentParameterDescription', 'string', r'[^\x00]+', 1, 1024)
        self.add_api_object('ComponentParameterDescription', self.ComponentParameterDescription)
        self.ComponentParameterName = APIObject('ComponentParameterName', 'string', r'[^\x00]+', 1, 256)
        self.add_api_object('ComponentParameterName', self.ComponentParameterName)
        self.ComponentParameterType = APIObject('ComponentParameterType', 'string', r'^String|Integer|Boolean|StringList$', 1, 20)
        self.add_api_object('ComponentParameterType', self.ComponentParameterType)
        self.ComponentParameterValue = APIObject('ComponentParameterValue', 'string', r'[^\x00]*', 0, None)
        self.add_api_object('ComponentParameterValue', self.ComponentParameterValue)
        self.ComponentVersionArn = APIObject('ComponentVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):component/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('ComponentVersionArn', self.ComponentVersionArn)
        self.ComponentVersionArnOrBuildVersionArn = APIObject('ComponentVersionArnOrBuildVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):component/[a-z0-9-_]+/(?:(?:([0-9]+|x)\.([0-9]+|x)\.([0-9]+|x))|(?:[0-9]+\.[0-9]+\.[0-9]+/[0-9]+))$', None, None)
        self.add_api_object('ComponentVersionArnOrBuildVersionArn', self.ComponentVersionArnOrBuildVersionArn)
        self.ContainerRecipeArn = APIObject('ContainerRecipeArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):container-recipe/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('ContainerRecipeArn', self.ContainerRecipeArn)
        self.DistributionConfigurationArn = APIObject('DistributionConfigurationArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):distribution-configuration/[a-z0-9-_]+$', None, None)
        self.add_api_object('DistributionConfigurationArn', self.DistributionConfigurationArn)
        self.FilterName = APIObject('FilterName', 'string', r'^[a-zA-Z]{1,1024}$', None, None)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[0-9a-zA-Z./_ :-]{1,1024}$', None, None)
        self.add_api_object('FilterValue', self.FilterValue)
        self.HttpTokens = APIObject('HttpTokens', 'string', r'optional|required', None, None)
        self.add_api_object('HttpTokens', self.HttpTokens)
        self.ImageBuildVersionArn = APIObject('ImageBuildVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):image/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+/[0-9]+$', None, None)
        self.add_api_object('ImageBuildVersionArn', self.ImageBuildVersionArn)
        self.ImageBuilderArn = APIObject('ImageBuilderArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):(?:image-recipe|container-recipe|infrastructure-configuration|distribution-configuration|component|image|image-pipeline|lifecycle-policy|workflow\/(?:build|test|distribution))/[a-z0-9-_]+(?:/(?:(?:x|[0-9]+)\.(?:x|[0-9]+)\.(?:x|[0-9]+))(?:/[0-9]+)?)?$', None, None)
        self.add_api_object('ImageBuilderArn', self.ImageBuilderArn)
        self.ImagePipelineArn = APIObject('ImagePipelineArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):image-pipeline/[a-z0-9-_]+$', None, None)
        self.add_api_object('ImagePipelineArn', self.ImagePipelineArn)
        self.ImageRecipeArn = APIObject('ImageRecipeArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):image-recipe/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('ImageRecipeArn', self.ImageRecipeArn)
        self.ImageVersionArn = APIObject('ImageVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):image/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('ImageVersionArn', self.ImageVersionArn)
        self.ImageVersionArnOrBuildVersionArn = APIObject('ImageVersionArnOrBuildVersionArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):image/[a-z0-9-_]+/(?:(?:([0-9]+|x)\.([0-9]+|x)\.([0-9]+|x))|(?:[0-9]+\.[0-9]+\.[0-9]+/[0-9]+))$', None, None)
        self.add_api_object('ImageVersionArnOrBuildVersionArn', self.ImageVersionArnOrBuildVersionArn)
        self.InfrastructureConfigurationArn = APIObject('InfrastructureConfigurationArn', 'string', r'^arn:aws[^:]*:imagebuilder:[^:]+:(?:[0-9]{12}|aws):infrastructure-configuration/[a-z0-9-_]+$', None, None)
        self.add_api_object('InfrastructureConfigurationArn', self.InfrastructureConfigurationArn)
        self.InlineComponentData = APIObject('InlineComponentData', 'string', r'[^\x00]+', 1, 16000)
        self.add_api_object('InlineComponentData', self.InlineComponentData)
        self.InlineDockerFileTemplate = APIObject('InlineDockerFileTemplate', 'string', r'[^\x00]+', 1, 16000)
        self.add_api_object('InlineDockerFileTemplate', self.InlineDockerFileTemplate)
        self.InlineWorkflowData = APIObject('InlineWorkflowData', 'string', r'[^\x00]+', 1, 16000)
        self.add_api_object('InlineWorkflowData', self.InlineWorkflowData)
        self.InstanceProfileNameType = APIObject('InstanceProfileNameType', 'string', r'^[\w+=,.@-]+$', 1, 256)
        self.add_api_object('InstanceProfileNameType', self.InstanceProfileNameType)
        self.LaunchTemplateId = APIObject('LaunchTemplateId', 'string', r'^lt-[a-z0-9-_]{17}$', None, None)
        self.add_api_object('LaunchTemplateId', self.LaunchTemplateId)
        self.LicenseConfigurationArn = APIObject('LicenseConfigurationArn', 'string', r'^arn:aws[^:]*:license-manager:[^:]+:[0-9]{12}:license-configuration:lic-[a-z0-9-_]{32}$', None, None)
        self.add_api_object('LicenseConfigurationArn', self.LicenseConfigurationArn)
        self.LifecycleExecutionId = APIObject('LifecycleExecutionId', 'string', r'^lce-[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('LifecycleExecutionId', self.LifecycleExecutionId)
        self.LifecyclePolicyArn = APIObject('LifecyclePolicyArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):lifecycle-policy/[a-z0-9-_]+$', None, 1024)
        self.add_api_object('LifecyclePolicyArn', self.LifecyclePolicyArn)
        self.OrganizationArn = APIObject('OrganizationArn', 'string', r'^arn:aws[^:]*:organizations::[0-9]{12}:organization/o-[a-z0-9]{10,32}$', None, None)
        self.add_api_object('OrganizationArn', self.OrganizationArn)
        self.OrganizationalUnitArn = APIObject('OrganizationalUnitArn', 'string', r'^arn:aws[^:]*:organizations::[0-9]{12}:ou/o-[a-z0-9]{10,32}/ou-[0-9a-z]{4,32}-[0-9a-z]{8,32}', None, None)
        self.add_api_object('OrganizationalUnitArn', self.OrganizationalUnitArn)
        self.ParallelGroup = APIObject('ParallelGroup', 'string', r'^[A-Za-z0-9][A-Za-z0-9-_+#]{0,99}$', 1, 100)
        self.add_api_object('ParallelGroup', self.ParallelGroup)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[-_A-Za-z-0-9][-_A-Za-z0-9 ]{1,126}[-_A-Za-z-0-9]$', None, None)
        self.add_api_object('ResourceName', self.ResourceName)
        self.RoleNameOrArn = APIObject('RoleNameOrArn', 'string', r'^(?:arn:aws(?:-[a-z]+)*:iam::[0-9]{12}:role/)?[a-zA-Z_0-9+=,.@\-_/]+$', 1, 2048)
        self.add_api_object('RoleNameOrArn', self.RoleNameOrArn)
        self.SnsTopicArn = APIObject('SnsTopicArn', 'string', r'^arn:aws[^:]*:sns:[^:]+:[0-9]{12}:[a-zA-Z0-9-_]{1,256}$', None, None)
        self.add_api_object('SnsTopicArn', self.SnsTopicArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Timezone = APIObject('Timezone', 'string', r'[a-zA-Z0-9]{2,}(?:\/[a-zA-z0-9-_+]+)*', 3, 100)
        self.add_api_object('Timezone', self.Timezone)
        self.UserDataOverride = APIObject('UserDataOverride', 'string', r'^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$', 1, 21847)
        self.add_api_object('UserDataOverride', self.UserDataOverride)
        self.VersionNumber = APIObject('VersionNumber', 'string', r'^[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('VersionNumber', self.VersionNumber)
        self.WorkflowBuildVersionArn = APIObject('WorkflowBuildVersionArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):workflow/(build|test|distribution)/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+/[0-9]+$', None, 1024)
        self.add_api_object('WorkflowBuildVersionArn', self.WorkflowBuildVersionArn)
        self.WorkflowExecutionId = APIObject('WorkflowExecutionId', 'string', r'^wf-[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('WorkflowExecutionId', self.WorkflowExecutionId)
        self.WorkflowNameArn = APIObject('WorkflowNameArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):workflow/(build|test|distribution)/[a-z0-9-_]+/x\.x\.x$', None, None)
        self.add_api_object('WorkflowNameArn', self.WorkflowNameArn)
        self.WorkflowParameterDescription = APIObject('WorkflowParameterDescription', 'string', r'[^\x00]+', 0, 1024)
        self.add_api_object('WorkflowParameterDescription', self.WorkflowParameterDescription)
        self.WorkflowParameterName = APIObject('WorkflowParameterName', 'string', r'[^\x00]+', 1, 128)
        self.add_api_object('WorkflowParameterName', self.WorkflowParameterName)
        self.WorkflowParameterType = APIObject('WorkflowParameterType', 'string', r'^string|integer|boolean|stringList$', 1, 20)
        self.add_api_object('WorkflowParameterType', self.WorkflowParameterType)
        self.WorkflowParameterValue = APIObject('WorkflowParameterValue', 'string', r'[^\x00]*', 0, None)
        self.add_api_object('WorkflowParameterValue', self.WorkflowParameterValue)
        self.WorkflowStepAction = APIObject('WorkflowStepAction', 'string', r'^[A-Za-z][A-Za-z0-9-_]{1,99}$', None, None)
        self.add_api_object('WorkflowStepAction', self.WorkflowStepAction)
        self.WorkflowStepExecutionId = APIObject('WorkflowStepExecutionId', 'string', r'^step-[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('WorkflowStepExecutionId', self.WorkflowStepExecutionId)
        self.WorkflowStepName = APIObject('WorkflowStepName', 'string', r'^[A-Za-z][A-Za-z0-9-_]{1,99}$', None, None)
        self.add_api_object('WorkflowStepName', self.WorkflowStepName)
        self.WorkflowVersionArn = APIObject('WorkflowVersionArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):workflow/(build|test|distribution)/[a-z0-9-_]+/[0-9]+\.[0-9]+\.[0-9]+$', None, None)
        self.add_api_object('WorkflowVersionArn', self.WorkflowVersionArn)
        self.WorkflowVersionArnOrBuildVersionArn = APIObject('WorkflowVersionArnOrBuildVersionArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):workflow/(build|test|distribution)/[a-z0-9-_]+/(?:(?:([0-9]+|x)\.([0-9]+|x)\.([0-9]+|x))|(?:[0-9]+\.[0-9]+\.[0-9]+/[0-9]+))$', None, None)
        self.add_api_object('WorkflowVersionArnOrBuildVersionArn', self.WorkflowVersionArnOrBuildVersionArn)
        self.WorkflowWildcardVersionArn = APIObject('WorkflowWildcardVersionArn', 'string', r'^arn:aws(?:-[a-z]+)*:imagebuilder:[a-z]{2,}(?:-[a-z]+)+-[0-9]+:(?:[0-9]{12}|aws):workflow/(build|test|distribution)/[a-z0-9-_]+/(?:[0-9]+|x)\.(?:[0-9]+|x)\.(?:[0-9]+|x)$', None, None)
        self.add_api_object('WorkflowWildcardVersionArn', self.WorkflowWildcardVersionArn)

class Importexport(Service):
    def __init__(self):
        super().__init__('Importexport')

class InspectorScan(Service):
    def __init__(self):
        super().__init__('InspectorScan')

class Inspector(Service):
    def __init__(self):
        super().__init__('Inspector')

class Inspector2(Service):
    def __init__(self):
        super().__init__('Inspector2')
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AmiId = APIObject('AmiId', 'string', r'^ami-([a-z0-9]{8}|[a-z0-9]{17}|\*)$', None, None)
        self.add_api_object('AmiId', self.AmiId)
        self.CisFindingArn = APIObject('CisFindingArn', 'string', r'^arn:aws(-gov|-cn)?:inspector2:[-.a-z0-9]{0,20}:\d{12}:owner/\d{12}/cis-finding/[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('CisFindingArn', self.CisFindingArn)
        self.CisOwnerId = APIObject('CisOwnerId', 'string', r'^\d{12}|o-[a-z0-9]{10,32}$', None, None)
        self.add_api_object('CisOwnerId', self.CisOwnerId)
        self.CisScanArn = APIObject('CisScanArn', 'string', r'^arn:aws(-us-gov|-cn)?:inspector2:[-.a-z0-9]{0,20}:\d{12}:owner/(\d{12}|o-[a-z0-9]{10,32})/cis-scan/[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('CisScanArn', self.CisScanArn)
        self.CisScanConfigurationArn = APIObject('CisScanConfigurationArn', 'string', r'^arn:aws(-us-gov|-cn)?:inspector2:[a-z]{2}(-gov)?-[a-z]+-[0-9]{1}:[0-9]{12}:owner/(o-[a-z0-9]+|[0-9]{12})/cis-configuration/[0-9a-fA-F-]+$', None, None)
        self.add_api_object('CisScanConfigurationArn', self.CisScanConfigurationArn)
        self.ExecutionRoleArn = APIObject('ExecutionRoleArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', None, None)
        self.add_api_object('ExecutionRoleArn', self.ExecutionRoleArn)
        self.FindingArn = APIObject('FindingArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:inspector2:[a-z]{2}(-gov)?-[a-z]+-\d{1}:\d{12}:finding/[a-f0-9]{32}$', 1, 100)
        self.add_api_object('FindingArn', self.FindingArn)
        self.FunctionName = APIObject('FunctionName', 'string', r'^[a-zA-Z0-9-_\.]+(:(\$LATEST|[a-zA-Z0-9-_]+))?$', None, None)
        self.add_api_object('FunctionName', self.FunctionName)
        self.ImageHash = APIObject('ImageHash', 'string', r'^sha256:[a-z0-9]{64}$', 71, 71)
        self.add_api_object('ImageHash', self.ImageHash)
        self.IpV4Address = APIObject('IpV4Address', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$', 7, 15)
        self.add_api_object('IpV4Address', self.IpV4Address)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws(-(us-gov|cn))?:kms:([a-z0-9][-.a-z0-9]{0,62})?:[0-9]{12}?:key/(([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})|(mrk-[0-9a-zA-Z]{32}))$', None, None)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LambdaLayerArn = APIObject('LambdaLayerArn', 'string', r'^arn:[a-zA-Z0-9-]+:lambda:[a-zA-Z0-9-]+:\d{12}:layer:[a-zA-Z0-9-_]+:[0-9]+$', None, None)
        self.add_api_object('LambdaLayerArn', self.LambdaLayerArn)
        self.MeteringAccountId = APIObject('MeteringAccountId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('MeteringAccountId', self.MeteringAccountId)
        self.OwnerId = APIObject('OwnerId', 'string', r'(^\d{12}$)|(^o-[a-z0-9]{10,32}$)', 12, 34)
        self.add_api_object('OwnerId', self.OwnerId)
        self.Path = APIObject('Path', 'string', r'^(?:/(?:\.[-\w]+|[-\w]+(?:\.[-\w]+)?))+/?$', 1, 512)
        self.add_api_object('Path', self.Path)
        self.ReportId = APIObject('ReportId', 'string', r'\b[a-f0-9]{8}\b-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-\b[a-f0-9]{12}\b', None, None)
        self.add_api_object('ReportId', self.ReportId)
        self.ResourceId = APIObject('ResourceId', 'string', r'(^arn:.*:ecr:.*:\d{12}:repository\/(?:[a-z0-9]+(?:[._-][a-z0-9]+)*\/)*[a-z0-9]+(?:[._-][a-z0-9]+)*(\/sha256:[a-z0-9]{64})?$)|(^i-([a-z0-9]{8}|[a-z0-9]{17}|\\*)$|(^arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}(-gov)?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_\.]+(:(\$LATEST|[a-zA-Z0-9-_]+))?$))', 10, 341)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-([a-z0-9]{8}|[a-z0-9]{17}|\*)$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SourceLayerHash = APIObject('SourceLayerHash', 'string', r'^sha256:[a-z0-9]{64}$', 71, 71)
        self.add_api_object('SourceLayerHash', self.SourceLayerHash)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-([a-z0-9]{8}|[a-z0-9]{17}|\*)$', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TargetAccount = APIObject('TargetAccount', 'string', r'^\d{12}|ALL_ACCOUNTS|SELF$', None, None)
        self.add_api_object('TargetAccount', self.TargetAccount)
        self.TimeOfDay = APIObject('TimeOfDay', 'string', r'^([0-1]?[0-9]|2[0-3]):[0-5][0-9]$', None, None)
        self.add_api_object('TimeOfDay', self.TimeOfDay)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('UUID', self.UUID)
        self.UsageAccountId = APIObject('UsageAccountId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('UsageAccountId', self.UsageAccountId)
        self.Version = APIObject('Version', 'string', r'^\$LATEST|[0-9]+$', None, None)
        self.add_api_object('Version', self.Version)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-([a-z0-9]{8}|[a-z0-9]{17}|\*)$', None, None)
        self.add_api_object('VpcId', self.VpcId)
        self.VulnId = APIObject('VulnId', 'string', r'^CVE-[12][0-9]{3}-[0-9]{1,10}$', None, None)
        self.add_api_object('VulnId', self.VulnId)

class Internetmonitor(Service):
    def __init__(self):
        super().__init__('Internetmonitor')
        self.Arn = APIObject('Arn', 'string', r'arn:.*', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.HealthEventName = APIObject('HealthEventName', 'string', r'[a-zA-Z0-9/_.-]+', 1, 255)
        self.add_api_object('HealthEventName', self.HealthEventName)
        self.InternetEventId = APIObject('InternetEventId', 'string', r'[a-zA-Z0-9-]+', 1, 255)
        self.add_api_object('InternetEventId', self.InternetEventId)
        self.MonitorArn = APIObject('MonitorArn', 'string', r'arn:.*', 20, 512)
        self.add_api_object('MonitorArn', self.MonitorArn)
        self.ResourceName = APIObject('ResourceName', 'string', r'[a-zA-Z0-9_.-]+', 1, 255)
        self.add_api_object('ResourceName', self.ResourceName)

class IotData(Service):
    def __init__(self):
        super().__init__('IotData')
        self.ShadowName = APIObject('ShadowName', 'string', r'[$a-zA-Z0-9:_-]+', 1, 64)
        self.add_api_object('ShadowName', self.ShadowName)
        self.ThingName = APIObject('ThingName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingName', self.ThingName)

class IotJobsData(Service):
    def __init__(self):
        super().__init__('IotJobsData')
        self.DescribeJobExecutionJobId = APIObject('DescribeJobExecutionJobId', 'string', r'[a-zA-Z0-9_-]+|^\$next', None, None)
        self.add_api_object('DescribeJobExecutionJobId', self.DescribeJobExecutionJobId)
        self.DetailsKey = APIObject('DetailsKey', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('DetailsKey', self.DetailsKey)
        self.DetailsValue = APIObject('DetailsValue', 'string', r'[^\p{C}]*+', 1, 1024)
        self.add_api_object('DetailsValue', self.DetailsValue)
        self.JobId = APIObject('JobId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('JobId', self.JobId)
        self.ThingName = APIObject('ThingName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingName', self.ThingName)

class Iot(Service):
    def __init__(self):
        super().__init__('Iot')
        self.AcmCertificateArn = APIObject('AcmCertificateArn', 'string', r'arn:aws(-cn|-us-gov|-iso-b|-iso)?:acm:[a-z]{2}-(gov-|iso-|isob-)?[a-z]{4,9}-\d{1}:\d{12}:certificate/[a-zA-Z0-9/-]+', 1, 2048)
        self.add_api_object('AcmCertificateArn', self.AcmCertificateArn)
        self.AggregationTypeValue = APIObject('AggregationTypeValue', 'string', r'[a-zA-Z0-9]+', 1, 12)
        self.add_api_object('AggregationTypeValue', self.AggregationTypeValue)
        self.AttributeName = APIObject('AttributeName', 'string', r'[a-zA-Z0-9_.,@/:#-]+', None, 128)
        self.add_api_object('AttributeName', self.AttributeName)
        self.AttributeValue = APIObject('AttributeValue', 'string', r'[a-zA-Z0-9_.,@/:#-]*', None, 800)
        self.add_api_object('AttributeValue', self.AttributeValue)
        self.AuditDescription = APIObject('AuditDescription', 'string', r'[\p{Graph}\x20]*', None, 1000)
        self.add_api_object('AuditDescription', self.AuditDescription)
        self.AuditTaskId = APIObject('AuditTaskId', 'string', r'[a-zA-Z0-9\-]+', 1, 40)
        self.add_api_object('AuditTaskId', self.AuditTaskId)
        self.AuthorizerFunctionArn = APIObject('AuthorizerFunctionArn', 'string', r'[\s\S]*', None, 2048)
        self.add_api_object('AuthorizerFunctionArn', self.AuthorizerFunctionArn)
        self.AuthorizerName = APIObject('AuthorizerName', 'string', r'[\w=,@-]+', 1, 128)
        self.add_api_object('AuthorizerName', self.AuthorizerName)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'[0-9]+', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.BehaviorName = APIObject('BehaviorName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('BehaviorName', self.BehaviorName)
        self.BillingGroupDescription = APIObject('BillingGroupDescription', 'string', r'[\p{Graph}\x20]*', None, 2028)
        self.add_api_object('BillingGroupDescription', self.BillingGroupDescription)
        self.BillingGroupId = APIObject('BillingGroupId', 'string', r'[a-zA-Z0-9\-]+', 1, 128)
        self.add_api_object('BillingGroupId', self.BillingGroupId)
        self.BillingGroupName = APIObject('BillingGroupName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('BillingGroupName', self.BillingGroupName)
        self.CertificateId = APIObject('CertificateId', 'string', r'(0x)?[a-fA-F0-9]+', 64, 64)
        self.add_api_object('CertificateId', self.CertificateId)
        self.CertificatePem = APIObject('CertificatePem', 'string', r'[\s\S]*', 1, 65536)
        self.add_api_object('CertificatePem', self.CertificatePem)
        self.CertificateProviderFunctionArn = APIObject('CertificateProviderFunctionArn', 'string', r'[\s\S]*', None, 2048)
        self.add_api_object('CertificateProviderFunctionArn', self.CertificateProviderFunctionArn)
        self.CertificateProviderName = APIObject('CertificateProviderName', 'string', r'[\w=,@-]+', 1, 128)
        self.add_api_object('CertificateProviderName', self.CertificateProviderName)
        self.CertificateSigningRequest = APIObject('CertificateSigningRequest', 'string', r'[\s\S]*', 1, 4096)
        self.add_api_object('CertificateSigningRequest', self.CertificateSigningRequest)
        self.Cidr = APIObject('Cidr', 'string', r'[a-fA-F0-9:\.\/]+', 2, 43)
        self.add_api_object('Cidr', self.Cidr)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.ClientToken = APIObject('ClientToken', 'string', r'\S{36,64}', 36, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.Comment = APIObject('Comment', 'string', r'[^\p{C}]+', None, 2028)
        self.add_api_object('Comment', self.Comment)
        self.CustomMetricDisplayName = APIObject('CustomMetricDisplayName', 'string', r'[\p{Graph}\x20]*', None, 128)
        self.add_api_object('CustomMetricDisplayName', self.CustomMetricDisplayName)
        self.DayOfMonth = APIObject('DayOfMonth', 'string', r'^([1-9]|[12][0-9]|3[01])$|^LAST$', None, None)
        self.add_api_object('DayOfMonth', self.DayOfMonth)
        self.DetailsKey = APIObject('DetailsKey', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('DetailsKey', self.DetailsKey)
        self.DetailsValue = APIObject('DetailsValue', 'string', r'[^\p{C}]+', 1, None)
        self.add_api_object('DetailsValue', self.DetailsValue)
        self.DimensionName = APIObject('DimensionName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('DimensionName', self.DimensionName)
        self.DomainConfigurationName = APIObject('DomainConfigurationName', 'string', r'[\w.-]+', 1, 128)
        self.add_api_object('DomainConfigurationName', self.DomainConfigurationName)
        self.DomainName = APIObject('DomainName', 'string', r'[\s\S]*', 1, 253)
        self.add_api_object('DomainName', self.DomainName)
        self.ElasticsearchEndpoint = APIObject('ElasticsearchEndpoint', 'string', r'https?://.*', None, None)
        self.add_api_object('ElasticsearchEndpoint', self.ElasticsearchEndpoint)
        self.EndpointType = APIObject('EndpointType', 'string', r'[\s\S]*', None, 128)
        self.add_api_object('EndpointType', self.EndpointType)
        self.Environment = APIObject('Environment', 'string', r'[^\p{C}]+', None, None)
        self.add_api_object('Environment', self.Environment)
        self.EvaluationStatistic = APIObject('EvaluationStatistic', 'string', r'(p0|p0\.1|p0\.01|p1|p10|p50|p90|p99|p99\.9|p99\.99|p100)', None, None)
        self.add_api_object('EvaluationStatistic', self.EvaluationStatistic)
        self.Example = APIObject('Example', 'string', r'[^\p{C}]+', None, None)
        self.add_api_object('Example', self.Example)
        self.FindingId = APIObject('FindingId', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('FindingId', self.FindingId)
        self.FirehoseSeparator = APIObject('FirehoseSeparator', 'string', r'([\n\t])|(\r\n)|(,)', None, None)
        self.add_api_object('FirehoseSeparator', self.FirehoseSeparator)
        self.FleetMetricDescription = APIObject('FleetMetricDescription', 'string', r'[\p{Graph}\x20]*', None, 1024)
        self.add_api_object('FleetMetricDescription', self.FleetMetricDescription)
        self.FleetMetricName = APIObject('FleetMetricName', 'string', r'[a-zA-Z0-9_\-\.]+', 1, 128)
        self.add_api_object('FleetMetricName', self.FleetMetricName)
        self.HttpHeaderName = APIObject('HttpHeaderName', 'string', r'[\s\S]*', 1, 8192)
        self.add_api_object('HttpHeaderName', self.HttpHeaderName)
        self.HttpHeaderValue = APIObject('HttpHeaderValue', 'string', r'[\s\S]*', 1, 8192)
        self.add_api_object('HttpHeaderValue', self.HttpHeaderValue)
        self.HttpQueryString = APIObject('HttpQueryString', 'string', r'[\s\S]*', 1, 4096)
        self.add_api_object('HttpQueryString', self.HttpQueryString)
        self.IndexName = APIObject('IndexName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('IndexName', self.IndexName)
        self.IssuerCertificateSerialNumber = APIObject('IssuerCertificateSerialNumber', 'string', r'[a-fA-F0-9:]+', None, 20)
        self.add_api_object('IssuerCertificateSerialNumber', self.IssuerCertificateSerialNumber)
        self.IssuerCertificateSubject = APIObject('IssuerCertificateSubject', 'string', r'[\p{Graph}\x20]*', None, 1000)
        self.add_api_object('IssuerCertificateSubject', self.IssuerCertificateSubject)
        self.IssuerId = APIObject('IssuerId', 'string', r'(0x)?[a-fA-F0-9]+', None, 64)
        self.add_api_object('IssuerId', self.IssuerId)
        self.JobDescription = APIObject('JobDescription', 'string', r'[^\p{C}]+', None, 2028)
        self.add_api_object('JobDescription', self.JobDescription)
        self.JobId = APIObject('JobId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('JobId', self.JobId)
        self.JobTemplateArn = APIObject('JobTemplateArn', 'string', r'^arn:[!-~]+$', 1, 1600)
        self.add_api_object('JobTemplateArn', self.JobTemplateArn)
        self.JobTemplateId = APIObject('JobTemplateId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('JobTemplateId', self.JobTemplateId)
        self.KeyName = APIObject('KeyName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('KeyName', self.KeyName)
        self.KeyValue = APIObject('KeyValue', 'string', r'[\s\S]*', None, 5120)
        self.add_api_object('KeyValue', self.KeyValue)
        self.ManagedTemplateVersion = APIObject('ManagedTemplateVersion', 'string', r'^[1-9]+.[0-9]+', None, None)
        self.add_api_object('ManagedTemplateVersion', self.ManagedTemplateVersion)
        self.Marker = APIObject('Marker', 'string', r'[A-Za-z0-9+/]+={0,2}', None, 1024)
        self.add_api_object('Marker', self.Marker)
        self.Message = APIObject('Message', 'string', r'[\s\S]*', None, 128)
        self.add_api_object('Message', self.Message)
        self.MetricName = APIObject('MetricName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('MetricName', self.MetricName)
        self.MitigationActionName = APIObject('MitigationActionName', 'string', r'[a-zA-Z0-9_-]+', None, 128)
        self.add_api_object('MitigationActionName', self.MitigationActionName)
        self.MitigationActionsTaskId = APIObject('MitigationActionsTaskId', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('MitigationActionsTaskId', self.MitigationActionsTaskId)
        self.MqttClientId = APIObject('MqttClientId', 'string', r'[\s\S]*', 1, 65535)
        self.add_api_object('MqttClientId', self.MqttClientId)
        self.MqttUsername = APIObject('MqttUsername', 'string', r'[\s\S]*', 1, 65535)
        self.add_api_object('MqttUsername', self.MqttUsername)
        self.NamespaceId = APIObject('NamespaceId', 'string', r'[a-zA-Z0-9_-]+', None, None)
        self.add_api_object('NamespaceId', self.NamespaceId)
        self.OTAUpdateDescription = APIObject('OTAUpdateDescription', 'string', r'[^\p{C}]+', None, 2028)
        self.add_api_object('OTAUpdateDescription', self.OTAUpdateDescription)
        self.OTAUpdateId = APIObject('OTAUpdateId', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('OTAUpdateId', self.OTAUpdateId)
        self.PackageName = APIObject('PackageName', 'string', r'[a-zA-Z0-9-_.]+', 1, 128)
        self.add_api_object('PackageName', self.PackageName)
        self.PackageVersionArn = APIObject('PackageVersionArn', 'string', r'^arn:[!-~]+$', 1, 1600)
        self.add_api_object('PackageVersionArn', self.PackageVersionArn)
        self.Parameter = APIObject('Parameter', 'string', r'[\s\S]*', 0, 2048)
        self.add_api_object('Parameter', self.Parameter)
        self.ParameterKey = APIObject('ParameterKey', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('ParameterKey', self.ParameterKey)
        self.ParameterValue = APIObject('ParameterValue', 'string', r'[^\p{C}]+', 1, 512)
        self.add_api_object('ParameterValue', self.ParameterValue)
        self.PayloadVersion = APIObject('PayloadVersion', 'string', r'^[0-9-]+$', 10, 32)
        self.add_api_object('PayloadVersion', self.PayloadVersion)
        self.PolicyDocument = APIObject('PolicyDocument', 'string', r'[\s\S]*', 0, 404600)
        self.add_api_object('PolicyDocument', self.PolicyDocument)
        self.PolicyName = APIObject('PolicyName', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('PolicyName', self.PolicyName)
        self.PolicyVersionId = APIObject('PolicyVersionId', 'string', r'[0-9]+', None, None)
        self.add_api_object('PolicyVersionId', self.PolicyVersionId)
        self.PrincipalId = APIObject('PrincipalId', 'string', r'[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('PrincipalId', self.PrincipalId)
        self.ReasonCode = APIObject('ReasonCode', 'string', r'[\p{Upper}\p{Digit}_]+', None, 128)
        self.add_api_object('ReasonCode', self.ReasonCode)
        self.RegistrationCode = APIObject('RegistrationCode', 'string', r'(0x)?[a-fA-F0-9]+', 64, 64)
        self.add_api_object('RegistrationCode', self.RegistrationCode)
        self.RegistryS3BucketName = APIObject('RegistryS3BucketName', 'string', r'[a-zA-Z0-9._-]+', 3, 256)
        self.add_api_object('RegistryS3BucketName', self.RegistryS3BucketName)
        self.RegistryS3KeyName = APIObject('RegistryS3KeyName', 'string', r'[a-zA-Z0-9!_.*\'()-\/]+', 1, 1024)
        self.add_api_object('RegistryS3KeyName', self.RegistryS3KeyName)
        self.ReservedDomainConfigurationName = APIObject('ReservedDomainConfigurationName', 'string', r'[\w.:-]+', 1, 128)
        self.add_api_object('ReservedDomainConfigurationName', self.ReservedDomainConfigurationName)
        self.Resource = APIObject('Resource', 'string', r'[\s\S]*', None, 2048)
        self.add_api_object('Resource', self.Resource)
        self.ResourceAttributeKey = APIObject('ResourceAttributeKey', 'string', r'[a-zA-Z0-9:_-]+', 1, None)
        self.add_api_object('ResourceAttributeKey', self.ResourceAttributeKey)
        self.ResourceAttributeValue = APIObject('ResourceAttributeValue', 'string', r'[^\p{C}]+', 1, None)
        self.add_api_object('ResourceAttributeValue', self.ResourceAttributeValue)
        self.ResourceDescription = APIObject('ResourceDescription', 'string', r'[^\p{C}]+', 0, 1024)
        self.add_api_object('ResourceDescription', self.ResourceDescription)
        self.RoleAlias = APIObject('RoleAlias', 'string', r'[\w=,@-]+', 1, 128)
        self.add_api_object('RoleAlias', self.RoleAlias)
        self.RuleName = APIObject('RuleName', 'string', r'^[a-zA-Z0-9_]+$', 1, 128)
        self.add_api_object('RuleName', self.RuleName)
        self.SalesforceEndpoint = APIObject('SalesforceEndpoint', 'string', r'https://ingestion-[a-zA-Z0-9]{1,12}\.[a-zA-Z0-9]+\.((sfdc-matrix\.net)|(sfdcnow\.com))/streams/\w{1,20}/\w{1,20}/event', None, 2000)
        self.add_api_object('SalesforceEndpoint', self.SalesforceEndpoint)
        self.ScheduledAuditName = APIObject('ScheduledAuditName', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('ScheduledAuditName', self.ScheduledAuditName)
        self.SecurityPolicy = APIObject('SecurityPolicy', 'string', r'[\s\S]*', None, 128)
        self.add_api_object('SecurityPolicy', self.SecurityPolicy)
        self.SecurityProfileDescription = APIObject('SecurityProfileDescription', 'string', r'[\p{Graph}\x20]*', None, 1000)
        self.add_api_object('SecurityProfileDescription', self.SecurityProfileDescription)
        self.SecurityProfileName = APIObject('SecurityProfileName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('SecurityProfileName', self.SecurityProfileName)
        self.ServerName = APIObject('ServerName', 'string', r'[\s\S]*', 1, 253)
        self.add_api_object('ServerName', self.ServerName)
        self.ShadowName = APIObject('ShadowName', 'string', r'[$a-zA-Z0-9:_-]+', 1, 64)
        self.add_api_object('ShadowName', self.ShadowName)
        self.StreamDescription = APIObject('StreamDescription', 'string', r'[^\p{C}]+', None, 2028)
        self.add_api_object('StreamDescription', self.StreamDescription)
        self.StreamId = APIObject('StreamId', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('StreamId', self.StreamId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TemplateBody = APIObject('TemplateBody', 'string', r'[\s\S]*', 0, 10240)
        self.add_api_object('TemplateBody', self.TemplateBody)
        self.TemplateDescription = APIObject('TemplateDescription', 'string', r'[^\p{C}]*', 0, 500)
        self.add_api_object('TemplateDescription', self.TemplateDescription)
        self.TemplateName = APIObject('TemplateName', 'string', r'^[0-9A-Za-z_-]+$', 1, 36)
        self.add_api_object('TemplateName', self.TemplateName)
        self.ThingGroupDescription = APIObject('ThingGroupDescription', 'string', r'[\p{Graph}\x20]*', None, 2028)
        self.add_api_object('ThingGroupDescription', self.ThingGroupDescription)
        self.ThingGroupId = APIObject('ThingGroupId', 'string', r'[a-zA-Z0-9\-]+', 1, 128)
        self.add_api_object('ThingGroupId', self.ThingGroupId)
        self.ThingGroupName = APIObject('ThingGroupName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingGroupName', self.ThingGroupName)
        self.ThingName = APIObject('ThingName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingName', self.ThingName)
        self.ThingTypeDescription = APIObject('ThingTypeDescription', 'string', r'[\p{Graph}\x20]*', None, 2028)
        self.add_api_object('ThingTypeDescription', self.ThingTypeDescription)
        self.ThingTypeName = APIObject('ThingTypeName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingTypeName', self.ThingTypeName)
        self.Token = APIObject('Token', 'string', r'[\s\S]*', 1, 6144)
        self.add_api_object('Token', self.Token)
        self.TokenKeyName = APIObject('TokenKeyName', 'string', r'[a-zA-Z0-9_-]+', 1, 128)
        self.add_api_object('TokenKeyName', self.TokenKeyName)
        self.TokenSignature = APIObject('TokenSignature', 'string', r'[A-Za-z0-9+/]+={0,2}', 1, 2560)
        self.add_api_object('TokenSignature', self.TokenSignature)
        self.Value = APIObject('Value', 'string', r'[\s\S]*', 0, 4096)
        self.add_api_object('Value', self.Value)
        self.VerificationStateDescription = APIObject('VerificationStateDescription', 'string', r'[^\p{Cntrl}]*', None, 1000)
        self.add_api_object('VerificationStateDescription', self.VerificationStateDescription)
        self.VersionName = APIObject('VersionName', 'string', r'[a-zA-Z0-9-_.]+', 1, 64)
        self.add_api_object('VersionName', self.VersionName)
        self.ViolationId = APIObject('ViolationId', 'string', r'[a-zA-Z0-9\-]+', 1, 128)
        self.add_api_object('ViolationId', self.ViolationId)

class Iot1clickDevices(Service):
    def __init__(self):
        super().__init__('Iot1clickDevices')

class Iot1clickProjects(Service):
    def __init__(self):
        super().__init__('Iot1clickProjects')
        self.DeviceTemplateName = APIObject('DeviceTemplateName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('DeviceTemplateName', self.DeviceTemplateName)
        self.PlacementName = APIObject('PlacementName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('PlacementName', self.PlacementName)
        self.ProjectArn = APIObject('ProjectArn', 'string', r'^arn:aws:iot1click:[A-Za-z0-9_/.-]{0,63}:\d+:projects/[0-9A-Za-z_-]{1,128}$', None, None)
        self.add_api_object('ProjectArn', self.ProjectArn)
        self.ProjectName = APIObject('ProjectName', 'string', r'^[0-9A-Za-z_-]+$', 1, 128)
        self.add_api_object('ProjectName', self.ProjectName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Iotanalytics(Service):
    def __init__(self):
        super().__init__('Iotanalytics')
        self.BucketKeyExpression = APIObject('BucketKeyExpression', 'string', r'^[a-zA-Z0-9!_.*\'()/{}:-]*$', 1, 255)
        self.add_api_object('BucketKeyExpression', self.BucketKeyExpression)
        self.BucketName = APIObject('BucketName', 'string', r'^[a-zA-Z0-9.\-_]*$', 3, 255)
        self.add_api_object('BucketName', self.BucketName)
        self.ChannelName = APIObject('ChannelName', 'string', r'(^(?!_{2}))(^[a-zA-Z0-9_]+$)', 1, 128)
        self.add_api_object('ChannelName', self.ChannelName)
        self.ColumnDataType = APIObject('ColumnDataType', 'string', r'^[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*$', 1, 131072)
        self.add_api_object('ColumnDataType', self.ColumnDataType)
        self.ColumnName = APIObject('ColumnName', 'string', r'^[A-Za-z_]([A-Za-z0-9]*|[A-Za-z0-9][A-Za-z0-9_]*)$', 1, 255)
        self.add_api_object('ColumnName', self.ColumnName)
        self.DatasetActionName = APIObject('DatasetActionName', 'string', r'^[a-zA-Z0-9_]+$', 1, 128)
        self.add_api_object('DatasetActionName', self.DatasetActionName)
        self.DatasetName = APIObject('DatasetName', 'string', r'(^(?!_{2}))(^[a-zA-Z0-9_]+$)', 1, 128)
        self.add_api_object('DatasetName', self.DatasetName)
        self.DatastoreName = APIObject('DatastoreName', 'string', r'(^(?!_{2}))(^[a-zA-Z0-9_]+$)', 1, 128)
        self.add_api_object('DatastoreName', self.DatastoreName)
        self.GlueDatabaseName = APIObject('GlueDatabaseName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 150)
        self.add_api_object('GlueDatabaseName', self.GlueDatabaseName)
        self.GlueTableName = APIObject('GlueTableName', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 150)
        self.add_api_object('GlueTableName', self.GlueTableName)
        self.IotEventsInputName = APIObject('IotEventsInputName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 128)
        self.add_api_object('IotEventsInputName', self.IotEventsInputName)
        self.LambdaName = APIObject('LambdaName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('LambdaName', self.LambdaName)
        self.LateDataRuleName = APIObject('LateDataRuleName', 'string', r'^[a-zA-Z0-9_]+$', 1, 128)
        self.add_api_object('LateDataRuleName', self.LateDataRuleName)
        self.MessageId = APIObject('MessageId', 'string', r'\p{ASCII}*', 1, 128)
        self.add_api_object('MessageId', self.MessageId)
        self.OutputFileName = APIObject('OutputFileName', 'string', r'[\w\.-]{1,255}', None, None)
        self.add_api_object('OutputFileName', self.OutputFileName)
        self.PartitionAttributeName = APIObject('PartitionAttributeName', 'string', r'^[a-zA-Z0-9_]+$', 1, 128)
        self.add_api_object('PartitionAttributeName', self.PartitionAttributeName)
        self.PipelineName = APIObject('PipelineName', 'string', r'(^(?!_{2}))(^[a-zA-Z0-9_]+$)', 1, 128)
        self.add_api_object('PipelineName', self.PipelineName)
        self.S3KeyPrefix = APIObject('S3KeyPrefix', 'string', r'^[a-zA-Z0-9!_.*\'()/{}:-]*/$', 1, 255)
        self.add_api_object('S3KeyPrefix', self.S3KeyPrefix)
        self.S3PathChannelMessage = APIObject('S3PathChannelMessage', 'string', r'^[a-zA-Z0-9/_!\'(){}\*\s\.\-\=\:]+$', 1, 1024)
        self.add_api_object('S3PathChannelMessage', self.S3PathChannelMessage)
        self.TimestampFormat = APIObject('TimestampFormat', 'string', r'^[a-zA-Z0-9\s\[\]_,.\'/:-]*$', 1, 50)
        self.add_api_object('TimestampFormat', self.TimestampFormat)

class Iotdeviceadvisor(Service):
    def __init__(self):
        super().__init__('Iotdeviceadvisor')

class IoteventsData(Service):
    def __init__(self):
        super().__init__('IoteventsData')
        self.AlarmModelName = APIObject('AlarmModelName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('AlarmModelName', self.AlarmModelName)
        self.DetectorModelName = APIObject('DetectorModelName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('DetectorModelName', self.DetectorModelName)
        self.EphemeralInputName = APIObject('EphemeralInputName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_.-]*$', 1, 128)
        self.add_api_object('EphemeralInputName', self.EphemeralInputName)
        self.KeyValue = APIObject('KeyValue', 'string', r'^[a-zA-Z0-9\-_:]+$', 1, 128)
        self.add_api_object('KeyValue', self.KeyValue)
        self.MessageId = APIObject('MessageId', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('MessageId', self.MessageId)
        self.RequestId = APIObject('RequestId', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('RequestId', self.RequestId)
        self.VariableName = APIObject('VariableName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 128)
        self.add_api_object('VariableName', self.VariableName)

class Iotevents(Service):
    def __init__(self):
        super().__init__('Iotevents')
        self.AlarmModelName = APIObject('AlarmModelName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('AlarmModelName', self.AlarmModelName)
        self.AttributeJsonPath = APIObject('AttributeJsonPath', 'string', r'^((`[\w\- ]+`)|([\w\-]+))(\.((`[\w- ]+`)|([\w\-]+)))*$', 1, 128)
        self.add_api_object('AttributeJsonPath', self.AttributeJsonPath)
        self.DetectorModelName = APIObject('DetectorModelName', 'string', r'^[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('DetectorModelName', self.DetectorModelName)
        self.FirehoseSeparator = APIObject('FirehoseSeparator', 'string', r'([\n\t])|(\r\n)|(,)', None, None)
        self.add_api_object('FirehoseSeparator', self.FirehoseSeparator)
        self.InputName = APIObject('InputName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 128)
        self.add_api_object('InputName', self.InputName)
        self.KeyValue = APIObject('KeyValue', 'string', r'^[a-zA-Z0-9\-_:]+$', 1, 128)
        self.add_api_object('KeyValue', self.KeyValue)
        self.VariableName = APIObject('VariableName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 128)
        self.add_api_object('VariableName', self.VariableName)

class Iotfleethub(Service):
    def __init__(self):
        super().__init__('Iotfleethub')
        self.Arn = APIObject('Arn', 'string', r'^arn:[!-~]+$', 1, 1600)
        self.add_api_object('Arn', self.Arn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.Description = APIObject('Description', 'string', r'^[ -~]*$', 1, 2048)
        self.add_api_object('Description', self.Description)
        self.Id = APIObject('Id', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', 36, 36)
        self.add_api_object('Id', self.Id)
        self.Name = APIObject('Name', 'string', r'^[ -~]*$', 1, 100)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z0-9+/=]+$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Url = APIObject('Url', 'string', r'^https\://\S+$', 1, 256)
        self.add_api_object('Url', self.Url)

class Iotfleetwise(Service):
    def __init__(self):
        super().__init__('Iotfleetwise')
        self.CloudWatchLogGroupName = APIObject('CloudWatchLogGroupName', 'string', r'[\.\-_\/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('CloudWatchLogGroupName', self.CloudWatchLogGroupName)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):iam::(\d{12})?:(role((\u002F)|(\u002F[\u0021-\u007F]+\u002F))[\w+=,.@-]+)', 20, 2048)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.NodePath = APIObject('NodePath', 'string', r'[a-zA-Z0-9_.]+', 1, 150)
        self.add_api_object('NodePath', self.NodePath)
        self.Prefix = APIObject('Prefix', 'string', r'[a-zA-Z0-9-_:./!*\'()]+', 1, 512)
        self.add_api_object('Prefix', self.Prefix)
        self.S3BucketArn = APIObject('S3BucketArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):s3:::.+', 16, 100)
        self.add_api_object('S3BucketArn', self.S3BucketArn)
        self.TimestreamDatabaseName = APIObject('TimestreamDatabaseName', 'string', r'[a-zA-Z0-9_.-]+', 3, 255)
        self.add_api_object('TimestreamDatabaseName', self.TimestreamDatabaseName)
        self.TimestreamTableArn = APIObject('TimestreamTableArn', 'string', r'arn:(aws[a-zA-Z0-9-]*):timestream:[a-zA-Z0-9-]+:[0-9]{12}:database/[a-zA-Z0-9_.-]+/table/[a-zA-Z0-9_.-]+', 20, 2048)
        self.add_api_object('TimestreamTableArn', self.TimestreamTableArn)
        self.TimestreamTableName = APIObject('TimestreamTableName', 'string', r'[a-zA-Z0-9_.-]+', 3, 255)
        self.add_api_object('TimestreamTableName', self.TimestreamTableName)
        self.TopicName = APIObject('TopicName', 'string', r'[a-zA-Z0-9_\-#:./]+', 1, 150)
        self.add_api_object('TopicName', self.TopicName)
        self.attributeName = APIObject('attributeName', 'string', r'[a-zA-Z0-9_.-]+', 1, 150)
        self.add_api_object('attributeName', self.attributeName)
        self.campaignName = APIObject('campaignName', 'string', r'[a-zA-Z\d\-_:]+', 1, 100)
        self.add_api_object('campaignName', self.campaignName)
        self.description = APIObject('description', 'string', r'[^\u0000-\u001F\u007F]+', 1, 2048)
        self.add_api_object('description', self.description)
        self.fleetId = APIObject('fleetId', 'string', r'[a-zA-Z0-9:_-]+', 1, 100)
        self.add_api_object('fleetId', self.fleetId)
        self.message = APIObject('message', 'string', r'[^\u0000-\u001F\u007F]+', 1, 2048)
        self.add_api_object('message', self.message)
        self.resourceName = APIObject('resourceName', 'string', r'[a-zA-Z\d\-_:]+', 1, 100)
        self.add_api_object('resourceName', self.resourceName)
        self.vehicleName = APIObject('vehicleName', 'string', r'[a-zA-Z\d\-_:]+', 1, 100)
        self.add_api_object('vehicleName', self.vehicleName)
        self.wildcardSignalName = APIObject('wildcardSignalName', 'string', r'[\w|*|-]+(\.[\w|*|-]+)*', 1, 150)
        self.add_api_object('wildcardSignalName', self.wildcardSignalName)

class Iotsecuretunneling(Service):
    def __init__(self):
        super().__init__('Iotsecuretunneling')
        self.Description = APIObject('Description', 'string', r'[^\p{C}]{1,2048}', None, None)
        self.add_api_object('Description', self.Description)
        self.NextToken = APIObject('NextToken', 'string', r'[a-zA-Z0-9_=-]{1,4096}', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.Service = APIObject('Service', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('Service', self.Service)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.ThingName = APIObject('ThingName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingName', self.ThingName)
        self.TunnelId = APIObject('TunnelId', 'string', r'[a-zA-Z0-9_\-+=:]{1,128}', None, None)
        self.add_api_object('TunnelId', self.TunnelId)

class Iotsitewise(Service):
    def __init__(self):
        super().__init__('Iotsitewise')
        self.ARN = APIObject('ARN', 'string', r'^arn:aws(-cn|-us-gov)?:[a-zA-Z0-9-:\/_\.]+$', 1, 1600)
        self.add_api_object('ARN', self.ARN)
        self.ActionPayloadString = APIObject('ActionPayloadString', 'string', r'[^\u0000-\u001F\u007F]+', None, None)
        self.add_api_object('ActionPayloadString', self.ActionPayloadString)
        self.AssetPropertyAlias = APIObject('AssetPropertyAlias', 'string', r'[^\u0000-\u001F\u007F]+', 1, 2048)
        self.add_api_object('AssetPropertyAlias', self.AssetPropertyAlias)
        self.CapabilityNamespace = APIObject('CapabilityNamespace', 'string', r'^[a-zA-Z]+:[a-zA-Z]+:[0-9]+$', 1, 512)
        self.add_api_object('CapabilityNamespace', self.CapabilityNamespace)
        self.ClientToken = APIObject('ClientToken', 'string', r'\S{36,64}', 36, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CustomID = APIObject('CustomID', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$|^externalId:[a-zA-Z0-9][a-zA-Z_\-0-9.:]*[a-zA-Z0-9]+', 13, 139)
        self.add_api_object('CustomID', self.CustomID)
        self.DashboardDefinition = APIObject('DashboardDefinition', 'string', r'.+', 0, 204800)
        self.add_api_object('DashboardDefinition', self.DashboardDefinition)
        self.DefaultValue = APIObject('DefaultValue', 'string', r'[^\u0000-\u001F\u007F]+', None, None)
        self.add_api_object('DefaultValue', self.DefaultValue)
        self.Description = APIObject('Description', 'string', r'[^\u0000-\u001F\u007F]+', 1, 2048)
        self.add_api_object('Description', self.Description)
        self.Email = APIObject('Email', 'string', r'[^@]+@[^@]+', 1, 255)
        self.add_api_object('Email', self.Email)
        self.EntryId = APIObject('EntryId', 'string', r'^[a-zA-Z0-9_-]+$', 1, 64)
        self.add_api_object('EntryId', self.EntryId)
        self.ExternalId = APIObject('ExternalId', 'string', r'[a-zA-Z0-9_][a-zA-Z_\-0-9.:]*[a-zA-Z0-9_]+', 2, 128)
        self.add_api_object('ExternalId', self.ExternalId)
        self.ID = APIObject('ID', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', 36, 36)
        self.add_api_object('ID', self.ID)
        self.IdentityId = APIObject('IdentityId', 'string', r'\S+', 1, 256)
        self.add_api_object('IdentityId', self.IdentityId)
        self.Macro = APIObject('Macro', 'string', r'[^\u0000-\u001F\u007F]+', 1, 256)
        self.add_api_object('Macro', self.Macro)
        self.Name = APIObject('Name', 'string', r'[^\u0000-\u001F\u007F]+', 1, 256)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'[A-Za-z0-9+/=]+', 1, 4096)
        self.add_api_object('NextToken', self.NextToken)
        self.PortalClientId = APIObject('PortalClientId', 'string', r'^[!-~]*', 1, 256)
        self.add_api_object('PortalClientId', self.PortalClientId)
        self.PropertyAlias = APIObject('PropertyAlias', 'string', r'[^\u0000-\u001F\u007F]+', 1, None)
        self.add_api_object('PropertyAlias', self.PropertyAlias)
        self.PropertyUnit = APIObject('PropertyUnit', 'string', r'[^\u0000-\u001F\u007F]+', 1, 256)
        self.add_api_object('PropertyUnit', self.PropertyUnit)
        self.QueryStatement = APIObject('QueryStatement', 'string', r'^[\s\S]+$', 1, None)
        self.add_api_object('QueryStatement', self.QueryStatement)
        self.Resolution = APIObject('Resolution', 'string', r'1m|15m|1h|1d', 2, 3)
        self.add_api_object('Resolution', self.Resolution)
        self.SSOApplicationId = APIObject('SSOApplicationId', 'string', r'^[!-~]*', 1, 64)
        self.add_api_object('SSOApplicationId', self.SSOApplicationId)
        self.Url = APIObject('Url', 'string', r'^(http|https)\://\S+', 1, 256)
        self.add_api_object('Url', self.Url)
        self.VariableName = APIObject('VariableName', 'string', r'^[a-z][a-z0-9_]*$', 1, 64)
        self.add_api_object('VariableName', self.VariableName)

class Iotthingsgraph(Service):
    def __init__(self):
        super().__init__('Iotthingsgraph')
        self.FlowTemplateFilterValue = APIObject('FlowTemplateFilterValue', 'string', r'^urn:tdm:(([a-z]{2}-(gov-)?[a-z]{4,9}-[0-9]{1,3}/[0-9]+/)*[\p{Alnum}_]+(/[\p{Alnum}_]+)*):([\p{Alpha}]*):([\p{Alnum}_]+(/[\p{Alnum}_]+)*)$', None, None)
        self.add_api_object('FlowTemplateFilterValue', self.FlowTemplateFilterValue)
        self.SystemTemplateFilterValue = APIObject('SystemTemplateFilterValue', 'string', r'^urn:tdm:(([a-z]{2}-(gov-)?[a-z]{4,9}-[0-9]{1,3}/[0-9]+/)*[\p{Alnum}_]+(/[\p{Alnum}_]+)*):([\p{Alpha}]*):([\p{Alnum}_]+(/[\p{Alnum}_]+)*)$', None, None)
        self.add_api_object('SystemTemplateFilterValue', self.SystemTemplateFilterValue)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.ThingName = APIObject('ThingName', 'string', r'[a-zA-Z0-9:_-]+', 1, 128)
        self.add_api_object('ThingName', self.ThingName)
        self.Urn = APIObject('Urn', 'string', r'^urn:tdm:(([a-z]{2}-(gov-)?[a-z]{4,9}-[0-9]{1,3}/[0-9]+/)*[\p{Alnum}_]+(/[\p{Alnum}_]+)*):([\p{Alpha}]*):([\p{Alnum}_]+(/[\p{Alnum}_]+)*)$', None, 160)
        self.add_api_object('Urn', self.Urn)

class Iottwinmaker(Service):
    def __init__(self):
        super().__init__('Iottwinmaker')
        self.BundleName = APIObject('BundleName', 'string', r'.*', 1, 256)
        self.add_api_object('BundleName', self.BundleName)
        self.ColumnName = APIObject('ColumnName', 'string', r'.*', None, None)
        self.add_api_object('ColumnName', self.ColumnName)
        self.ComponentPath = APIObject('ComponentPath', 'string', r'[a-zA-Z_\-0-9/]+', 1, 2048)
        self.add_api_object('ComponentPath', self.ComponentPath)
        self.ComponentTypeId = APIObject('ComponentTypeId', 'string', r'[a-zA-Z_\.\-0-9:]+', 1, 256)
        self.add_api_object('ComponentTypeId', self.ComponentTypeId)
        self.ComponentTypeName = APIObject('ComponentTypeName', 'string', r'.*[^\u0000-\u001F\u007F]*.*', 0, 256)
        self.add_api_object('ComponentTypeName', self.ComponentTypeName)
        self.Description = APIObject('Description', 'string', r'.*', 0, 2048)
        self.add_api_object('Description', self.Description)
        self.EntityId = APIObject('EntityId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}|^[a-zA-Z0-9][a-zA-Z_\-0-9.:]*[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityName = APIObject('EntityName', 'string', r'[^\u0000-\u001F\u007F]+', 1, 256)
        self.add_api_object('EntityName', self.EntityName)
        self.Expression = APIObject('Expression', 'string', r'(^\$\{Parameters\.[a-zA-z]+([a-zA-z_0-9]*)}$)', 1, 316)
        self.add_api_object('Expression', self.Expression)
        self.Id = APIObject('Id', 'string', r'[a-zA-Z_0-9][a-zA-Z_\-0-9]*[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('Id', self.Id)
        self.IdOrArn = APIObject('IdOrArn', 'string', r'[a-zA-Z_0-9][a-zA-Z_\-0-9]*[a-zA-Z0-9]+$|^arn:((aws)|(aws-cn)|(aws-us-gov)):iottwinmaker:[a-z0-9-]+:[0-9]{12}:[\/a-zA-Z0-9_-]+', 1, 2048)
        self.add_api_object('IdOrArn', self.IdOrArn)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'arn:((aws)|(aws-cn)|(aws-us-gov)):lambda:[a-z0-9-]+:[0-9]{12}:function:[\/a-zA-Z0-9_-]+', 20, 2048)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.LinkedService = APIObject('LinkedService', 'string', r'[a-zA-Z_0-9]+', None, None)
        self.add_api_object('LinkedService', self.LinkedService)
        self.Name = APIObject('Name', 'string', r'[a-zA-Z_\-0-9]+', 1, 256)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'.*', 0, 17880)
        self.add_api_object('NextToken', self.NextToken)
        self.ParentEntityId = APIObject('ParentEntityId', 'string', r'\$ROOT|^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}|^[a-zA-Z0-9][a-zA-Z_\-0-9.:]*[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('ParentEntityId', self.ParentEntityId)
        self.PropertyDisplayName = APIObject('PropertyDisplayName', 'string', r'.*[^\u0000-\u001F\u007F]*.*', 0, 256)
        self.add_api_object('PropertyDisplayName', self.PropertyDisplayName)
        self.QueryStatement = APIObject('QueryStatement', 'string', r'[\s\S]+', 1, 1000)
        self.add_api_object('QueryStatement', self.QueryStatement)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:((aws)|(aws-cn)|(aws-us-gov)):iam::[0-9]{12}:role/.*', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3DestinationLocation = APIObject('S3DestinationLocation', 'string', r'.*(^arn:((aws)|(aws-cn)|(aws-us-gov)):s3:::)([/a-zA-Z0-9_-]+$).*', None, None)
        self.add_api_object('S3DestinationLocation', self.S3DestinationLocation)
        self.S3Location = APIObject('S3Location', 'string', r'.*(^arn:((aws)|(aws-cn)|(aws-us-gov)):s3:::)([a-zA-Z0-9_-]+$).*', 0, 1024)
        self.add_api_object('S3Location', self.S3Location)
        self.S3SourceLocation = APIObject('S3SourceLocation', 'string', r'.*(^arn:((aws)|(aws-cn)|(aws-us-gov)):s3:::)([a-zA-Z0-9_-]+)\/([/.a-zA-Z0-9_-]+$).*', None, None)
        self.add_api_object('S3SourceLocation', self.S3SourceLocation)
        self.S3Url = APIObject('S3Url', 'string', r'[sS]3://[A-Za-z0-9._/-]+', 0, 256)
        self.add_api_object('S3Url', self.S3Url)
        self.SceneCapability = APIObject('SceneCapability', 'string', r'.*', 0, 256)
        self.add_api_object('SceneCapability', self.SceneCapability)
        self.SceneMetadataValue = APIObject('SceneMetadataValue', 'string', r'.*', 0, 2048)
        self.add_api_object('SceneMetadataValue', self.SceneMetadataValue)
        self.SiteWiseExternalId = APIObject('SiteWiseExternalId', 'string', r'.*[a-zA-Z0-9_][a-zA-Z_\-0-9.:]*[a-zA-Z0-9_]+.*', 2, 128)
        self.add_api_object('SiteWiseExternalId', self.SiteWiseExternalId)
        self.String = APIObject('String', 'string', r'.*', 1, 256)
        self.add_api_object('String', self.String)
        self.SyncSource = APIObject('SyncSource', 'string', r'[a-zA-Z_0-9]+', None, None)
        self.add_api_object('SyncSource', self.SyncSource)
        self.TagKey = APIObject('TagKey', 'string', r'([\p{L}\p{Z}\p{N}_.:/=+\-@]*)', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TwinMakerArn = APIObject('TwinMakerArn', 'string', r'arn:((aws)|(aws-cn)|(aws-us-gov)):iottwinmaker:[a-z0-9-]+:[0-9]{12}:[\/a-zA-Z0-9_\-\.:]+', 20, 2048)
        self.add_api_object('TwinMakerArn', self.TwinMakerArn)
        self.Uuid = APIObject('Uuid', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('Uuid', self.Uuid)
        self.Value = APIObject('Value', 'string', r'.*', None, None)
        self.add_api_object('Value', self.Value)
        self.WorkspaceDeleteMessage = APIObject('WorkspaceDeleteMessage', 'string', r'.*', 0, 2048)
        self.add_api_object('WorkspaceDeleteMessage', self.WorkspaceDeleteMessage)

class Iotwireless(Service):
    def __init__(self):
        super().__init__('Iotwireless')
        self.AppEui = APIObject('AppEui', 'string', r'[a-fA-F0-9]{16}', None, None)
        self.add_api_object('AppEui', self.AppEui)
        self.AppKey = APIObject('AppKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('AppKey', self.AppKey)
        self.AppSKey = APIObject('AppSKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('AppSKey', self.AppSKey)
        self.AppServerPrivateKey = APIObject('AppServerPrivateKey', 'string', r'[a-fA-F0-9]{64}', 1, 4096)
        self.add_api_object('AppServerPrivateKey', self.AppServerPrivateKey)
        self.ApplicationServerPublicKey = APIObject('ApplicationServerPublicKey', 'string', r'[a-fA-F0-9]{64}', 1, 4096)
        self.add_api_object('ApplicationServerPublicKey', self.ApplicationServerPublicKey)
        self.CertificatePEM = APIObject('CertificatePEM', 'string', r'[^-A-Za-z0-9+/=]|=[^=]|={3,}${1,4096}', 1, 4096)
        self.add_api_object('CertificatePEM', self.CertificatePEM)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.DestinationName = APIObject('DestinationName', 'string', r'[a-zA-Z0-9-_]+', None, 128)
        self.add_api_object('DestinationName', self.DestinationName)
        self.DevAddr = APIObject('DevAddr', 'string', r'[a-fA-F0-9]{8}', None, None)
        self.add_api_object('DevAddr', self.DevAddr)
        self.DevEui = APIObject('DevEui', 'string', r'[a-fA-F0-9]{16}', None, None)
        self.add_api_object('DevEui', self.DevEui)
        self.FNwkSIntKey = APIObject('FNwkSIntKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('FNwkSIntKey', self.FNwkSIntKey)
        self.Fingerprint = APIObject('Fingerprint', 'string', r'[a-fA-F0-9]{64}', 64, 64)
        self.add_api_object('Fingerprint', self.Fingerprint)
        self.GatewayEui = APIObject('GatewayEui', 'string', r'^(([0-9A-Fa-f]{2}-){7}|([0-9A-Fa-f]{2}:){7}|([0-9A-Fa-f]{2}\s){7}|([0-9A-Fa-f]{2}){7})([0-9A-Fa-f]{2})$', None, None)
        self.add_api_object('GatewayEui', self.GatewayEui)
        self.GenAppKey = APIObject('GenAppKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('GenAppKey', self.GenAppKey)
        self.ISODateTimeString = APIObject('ISODateTimeString', 'string', r'^([\+-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24\:?00)([\.,]\d+(?!:))?)?(\17[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$', None, None)
        self.add_api_object('ISODateTimeString', self.ISODateTimeString)
        self.JoinEui = APIObject('JoinEui', 'string', r'[a-fA-F0-9]{16}', None, None)
        self.add_api_object('JoinEui', self.JoinEui)
        self.MacAddress = APIObject('MacAddress', 'string', r'^([0-9A-Fa-f]{2}[:-]?){5}([0-9A-Fa-f]{2})$', 12, 17)
        self.add_api_object('MacAddress', self.MacAddress)
        self.NetId = APIObject('NetId', 'string', r'[a-fA-F0-9]{6}', None, None)
        self.add_api_object('NetId', self.NetId)
        self.NetworkAnalyzerConfigurationName = APIObject('NetworkAnalyzerConfigurationName', 'string', r'[a-zA-Z0-9-_]+', 1, 1024)
        self.add_api_object('NetworkAnalyzerConfigurationName', self.NetworkAnalyzerConfigurationName)
        self.NwkKey = APIObject('NwkKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('NwkKey', self.NwkKey)
        self.NwkSEncKey = APIObject('NwkSEncKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('NwkSEncKey', self.NwkSEncKey)
        self.NwkSKey = APIObject('NwkSKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('NwkSKey', self.NwkSKey)
        self.PayloadData = APIObject('PayloadData', 'string', r'^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$', None, 2048)
        self.add_api_object('PayloadData', self.PayloadData)
        self.PositionResourceIdentifier = APIObject('PositionResourceIdentifier', 'string', r'[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}', None, None)
        self.add_api_object('PositionResourceIdentifier', self.PositionResourceIdentifier)
        self.SNwkSIntKey = APIObject('SNwkSIntKey', 'string', r'[a-fA-F0-9]{32}', None, None)
        self.add_api_object('SNwkSIntKey', self.SNwkSIntKey)
        self.WirelessGatewayTaskDefinitionId = APIObject('WirelessGatewayTaskDefinitionId', 'string', r'[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}', None, 36)
        self.add_api_object('WirelessGatewayTaskDefinitionId', self.WirelessGatewayTaskDefinitionId)

class IvsRealtime(Service):
    def __init__(self):
        super().__init__('IvsRealtime')
        self.AttributeKey = APIObject('AttributeKey', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('AttributeKey', self.AttributeKey)
        self.ChannelArn = APIObject('ChannelArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:channel/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ChannelArn', self.ChannelArn)
        self.CompositionArn = APIObject('CompositionArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:composition/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('CompositionArn', self.CompositionArn)
        self.CompositionClientToken = APIObject('CompositionClientToken', 'string', r'^[a-zA-Z0-9-_]*$', 1, 64)
        self.add_api_object('CompositionClientToken', self.CompositionClientToken)
        self.DestinationConfigurationName = APIObject('DestinationConfigurationName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('DestinationConfigurationName', self.DestinationConfigurationName)
        self.EncoderConfigurationArn = APIObject('EncoderConfigurationArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:encoder-configuration/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('EncoderConfigurationArn', self.EncoderConfigurationArn)
        self.EncoderConfigurationName = APIObject('EncoderConfigurationName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('EncoderConfigurationName', self.EncoderConfigurationName)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[a-zA-Z0-9+/=_-]*$', 0, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ParticipantClientAttribute = APIObject('ParticipantClientAttribute', 'string', r'^[a-zA-Z0-9-_.,:;\s]*$', 0, 128)
        self.add_api_object('ParticipantClientAttribute', self.ParticipantClientAttribute)
        self.ParticipantId = APIObject('ParticipantId', 'string', r'^[a-zA-Z0-9-]*$', 0, 64)
        self.add_api_object('ParticipantId', self.ParticipantId)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:[a-z-]/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[a-z0-9-.]+$', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.StageArn = APIObject('StageArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:stage/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('StageArn', self.StageArn)
        self.StageName = APIObject('StageName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('StageName', self.StageName)
        self.StageSessionId = APIObject('StageSessionId', 'string', r'^st-[a-zA-Z0-9]+$', 16, 16)
        self.add_api_object('StageSessionId', self.StageSessionId)
        self.StorageConfigurationArn = APIObject('StorageConfigurationArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:storage-configuration/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('StorageConfigurationArn', self.StorageConfigurationArn)
        self.StorageConfigurationName = APIObject('StorageConfigurationName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('StorageConfigurationName', self.StorageConfigurationName)

class Ivs(Service):
    def __init__(self):
        super().__init__('Ivs')
        self.ChannelArn = APIObject('ChannelArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:channel/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ChannelArn', self.ChannelArn)
        self.ChannelName = APIObject('ChannelName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('ChannelName', self.ChannelName)
        self.ChannelPlaybackRestrictionPolicyArn = APIObject('ChannelPlaybackRestrictionPolicyArn', 'string', r'^$|^arn:aws:ivs:[a-z0-9-]+:[0-9]+:playback-restriction-policy/[a-zA-Z0-9-]+$', 0, 128)
        self.add_api_object('ChannelPlaybackRestrictionPolicyArn', self.ChannelPlaybackRestrictionPolicyArn)
        self.ChannelRecordingConfigurationArn = APIObject('ChannelRecordingConfigurationArn', 'string', r'^$|^arn:aws:ivs:[a-z0-9-]+:[0-9]+:recording-configuration/[a-zA-Z0-9-]+$', 0, 128)
        self.add_api_object('ChannelRecordingConfigurationArn', self.ChannelRecordingConfigurationArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[a-zA-Z0-9+/=_-]*$', 0, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PlaybackKeyPairArn = APIObject('PlaybackKeyPairArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:playback-key/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('PlaybackKeyPairArn', self.PlaybackKeyPairArn)
        self.PlaybackKeyPairName = APIObject('PlaybackKeyPairName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('PlaybackKeyPairName', self.PlaybackKeyPairName)
        self.PlaybackRestrictionPolicyArn = APIObject('PlaybackRestrictionPolicyArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:playback-restriction-policy/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('PlaybackRestrictionPolicyArn', self.PlaybackRestrictionPolicyArn)
        self.PlaybackRestrictionPolicyName = APIObject('PlaybackRestrictionPolicyName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('PlaybackRestrictionPolicyName', self.PlaybackRestrictionPolicyName)
        self.RecordingConfigurationArn = APIObject('RecordingConfigurationArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:recording-configuration/[a-zA-Z0-9-]+$', 0, 128)
        self.add_api_object('RecordingConfigurationArn', self.RecordingConfigurationArn)
        self.RecordingConfigurationName = APIObject('RecordingConfigurationName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('RecordingConfigurationName', self.RecordingConfigurationName)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:[a-z-]/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.S3DestinationBucketName = APIObject('S3DestinationBucketName', 'string', r'^[a-z0-9-.]+$', 3, 63)
        self.add_api_object('S3DestinationBucketName', self.S3DestinationBucketName)
        self.StreamId = APIObject('StreamId', 'string', r'^st-[a-zA-Z0-9]+$', 26, 26)
        self.add_api_object('StreamId', self.StreamId)
        self.StreamKeyArn = APIObject('StreamKeyArn', 'string', r'^arn:aws:ivs:[a-z0-9-]+:[0-9]+:stream-key/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('StreamKeyArn', self.StreamKeyArn)

class Ivschat(Service):
    def __init__(self):
        super().__init__('Ivschat')
        self.BucketName = APIObject('BucketName', 'string', r'^[a-z0-9-.]+$', 3, 63)
        self.add_api_object('BucketName', self.BucketName)
        self.DeliveryStreamName = APIObject('DeliveryStreamName', 'string', r'^[a-zA-Z0-9_.-]+$', 1, 64)
        self.add_api_object('DeliveryStreamName', self.DeliveryStreamName)
        self.ID = APIObject('ID', 'string', r'^[a-zA-Z0-9]+$', 12, 12)
        self.add_api_object('ID', self.ID)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'^$|^arn:aws:lambda:[a-z0-9-]+:[0-9]{12}:function:.+', 0, 170)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'^[\.\-_/#A-Za-z0-9]+$', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.LoggingConfigurationArn = APIObject('LoggingConfigurationArn', 'string', r'^arn:aws:ivschat:[a-z0-9-]+:[0-9]+:logging-configuration/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('LoggingConfigurationArn', self.LoggingConfigurationArn)
        self.LoggingConfigurationID = APIObject('LoggingConfigurationID', 'string', r'^[a-zA-Z0-9]+$', 12, 12)
        self.add_api_object('LoggingConfigurationID', self.LoggingConfigurationID)
        self.LoggingConfigurationIdentifier = APIObject('LoggingConfigurationIdentifier', 'string', r'^arn:aws:ivschat:[a-z0-9-]+:[0-9]+:logging-configuration/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('LoggingConfigurationIdentifier', self.LoggingConfigurationIdentifier)
        self.LoggingConfigurationName = APIObject('LoggingConfigurationName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('LoggingConfigurationName', self.LoggingConfigurationName)
        self.MessageID = APIObject('MessageID', 'string', r'^[a-zA-Z0-9]+$', 12, 12)
        self.add_api_object('MessageID', self.MessageID)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:ivschat:[a-z0-9-]+:[0-9]+:[a-z-]/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[a-zA-Z0-9]+$', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.RoomArn = APIObject('RoomArn', 'string', r'^arn:aws:ivschat:[a-z0-9-]+:[0-9]+:room/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('RoomArn', self.RoomArn)
        self.RoomID = APIObject('RoomID', 'string', r'^[a-zA-Z0-9]+$', 12, 12)
        self.add_api_object('RoomID', self.RoomID)
        self.RoomIdentifier = APIObject('RoomIdentifier', 'string', r'^arn:aws:ivschat:[a-z0-9-]+:[0-9]+:room/[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('RoomIdentifier', self.RoomIdentifier)
        self.RoomName = APIObject('RoomName', 'string', r'^[a-zA-Z0-9-_]*$', 0, 128)
        self.add_api_object('RoomName', self.RoomName)

class Kafka(Service):
    def __init__(self):
        super().__init__('Kafka')
        self.stringMin1Max128Pattern09AZaZ09AZaZ0 = APIObject('stringMin1Max128Pattern09AZaZ09AZaZ0', 'string', r'^[0-9A-Za-z][0-9A-Za-z-]{0,}$', 1, 128)
        self.add_api_object('stringMin1Max128Pattern09AZaZ09AZaZ0', self.stringMin1Max128Pattern09AZaZ09AZaZ0)

class Kafkaconnect(Service):
    def __init__(self):
        super().__init__('Kafkaconnect')

class KendraRanking(Service):
    def __init__(self):
        super().__init__('KendraRanking')
        self.ClientTokenName = APIObject('ClientTokenName', 'string', r'^$|[\x00-\x7F]+', 1, 64)
        self.add_api_object('ClientTokenName', self.ClientTokenName)
        self.Description = APIObject('Description', 'string', r'^\P{C}*$', 0, 1000)
        self.add_api_object('Description', self.Description)
        self.DocumentBody = APIObject('DocumentBody', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('DocumentBody', self.DocumentBody)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.NextToken = APIObject('NextToken', 'string', r'^\P{C}*$', 1, 800)
        self.add_api_object('NextToken', self.NextToken)
        self.RescoreExecutionPlanArn = APIObject('RescoreExecutionPlanArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('RescoreExecutionPlanArn', self.RescoreExecutionPlanArn)
        self.RescoreExecutionPlanId = APIObject('RescoreExecutionPlanId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]*', 36, 36)
        self.add_api_object('RescoreExecutionPlanId', self.RescoreExecutionPlanId)
        self.RescoreExecutionPlanName = APIObject('RescoreExecutionPlanName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('RescoreExecutionPlanName', self.RescoreExecutionPlanName)
        self.RescoreId = APIObject('RescoreId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]', 1, 36)
        self.add_api_object('RescoreId', self.RescoreId)

class Kendra(Service):
    def __init__(self):
        super().__init__('Kendra')
        self.AccessControlConfigurationId = APIObject('AccessControlConfigurationId', 'string', r'[a-zA-Z0-9-]+', 1, 36)
        self.add_api_object('AccessControlConfigurationId', self.AccessControlConfigurationId)
        self.AccessControlConfigurationName = APIObject('AccessControlConfigurationName', 'string', r'[\S\s]*', 1, 200)
        self.add_api_object('AccessControlConfigurationName', self.AccessControlConfigurationName)
        self.ClaimRegex = APIObject('ClaimRegex', 'string', r'^\P{C}*$', 1, 100)
        self.add_api_object('ClaimRegex', self.ClaimRegex)
        self.ColumnName = APIObject('ColumnName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 100)
        self.add_api_object('ColumnName', self.ColumnName)
        self.ConfluenceSpaceIdentifier = APIObject('ConfluenceSpaceIdentifier', 'string', r'^\P{C}*$', 1, 255)
        self.add_api_object('ConfluenceSpaceIdentifier', self.ConfluenceSpaceIdentifier)
        self.DataSourceDateFieldFormat = APIObject('DataSourceDateFieldFormat', 'string', r'^(?!\s).*(?<!\s)$', 4, 40)
        self.add_api_object('DataSourceDateFieldFormat', self.DataSourceDateFieldFormat)
        self.DataSourceFieldName = APIObject('DataSourceFieldName', 'string', r'^[a-zA-Z][a-zA-Z0-9_.]*$', 1, 100)
        self.add_api_object('DataSourceFieldName', self.DataSourceFieldName)
        self.DataSourceId = APIObject('DataSourceId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('DataSourceId', self.DataSourceId)
        self.DataSourceName = APIObject('DataSourceName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('DataSourceName', self.DataSourceName)
        self.DataSourceSyncJobId = APIObject('DataSourceSyncJobId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('DataSourceSyncJobId', self.DataSourceSyncJobId)
        self.DatabaseName = APIObject('DatabaseName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 100)
        self.add_api_object('DatabaseName', self.DatabaseName)
        self.Description = APIObject('Description', 'string', r'^\P{C}*$', 0, 1000)
        self.add_api_object('Description', self.Description)
        self.DocumentAttributeKey = APIObject('DocumentAttributeKey', 'string', r'[a-zA-Z0-9_][a-zA-Z0-9_-]*', 1, 200)
        self.add_api_object('DocumentAttributeKey', self.DocumentAttributeKey)
        self.Domain = APIObject('Domain', 'string', r'^(?!-)[A-Za-z0-9-].*(?<!-)$', 1, 63)
        self.add_api_object('Domain', self.Domain)
        self.Duration = APIObject('Duration', 'string', r'[0-9]+[s]', 1, 10)
        self.add_api_object('Duration', self.Duration)
        self.Endpoint = APIObject('Endpoint', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('Endpoint', self.Endpoint)
        self.EnterpriseId = APIObject('EnterpriseId', 'string', r'^[A-Z0-9]*$', 1, 64)
        self.add_api_object('EnterpriseId', self.EnterpriseId)
        self.EntityId = APIObject('EntityId', 'string', r'^([0-9a-f]{10}-|)[A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12}$', 1, 47)
        self.add_api_object('EntityId', self.EntityId)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.ExperienceId = APIObject('ExperienceId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 36)
        self.add_api_object('ExperienceId', self.ExperienceId)
        self.ExperienceName = APIObject('ExperienceName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('ExperienceName', self.ExperienceName)
        self.FailureReason = APIObject('FailureReason', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('FailureReason', self.FailureReason)
        self.FaqId = APIObject('FaqId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('FaqId', self.FaqId)
        self.FaqName = APIObject('FaqName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('FaqName', self.FaqName)
        self.FeaturedResultsSetDescription = APIObject('FeaturedResultsSetDescription', 'string', r'^\P{C}*$', 0, 1000)
        self.add_api_object('FeaturedResultsSetDescription', self.FeaturedResultsSetDescription)
        self.FeaturedResultsSetId = APIObject('FeaturedResultsSetId', 'string', r'^[a-zA-Z-0-9]*', 36, 36)
        self.add_api_object('FeaturedResultsSetId', self.FeaturedResultsSetId)
        self.FeaturedResultsSetName = APIObject('FeaturedResultsSetName', 'string', r'[a-zA-Z0-9][ a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('FeaturedResultsSetName', self.FeaturedResultsSetName)
        self.FeedbackToken = APIObject('FeedbackToken', 'string', r'^\P{C}*.\P{C}*$', 1, 2048)
        self.add_api_object('FeedbackToken', self.FeedbackToken)
        self.FileSystemId = APIObject('FileSystemId', 'string', r'^(fs-[0-9a-f]{8,})$', 11, 21)
        self.add_api_object('FileSystemId', self.FileSystemId)
        self.GroupAttributeField = APIObject('GroupAttributeField', 'string', r'^\P{C}*$', 1, 100)
        self.add_api_object('GroupAttributeField', self.GroupAttributeField)
        self.GroupId = APIObject('GroupId', 'string', r'^\P{C}*$', 1, 1024)
        self.add_api_object('GroupId', self.GroupId)
        self.Host = APIObject('Host', 'string', r'([^\s]*)', 1, 253)
        self.add_api_object('Host', self.Host)
        self.IdentityAttributeName = APIObject('IdentityAttributeName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('IdentityAttributeName', self.IdentityAttributeName)
        self.IndexFieldName = APIObject('IndexFieldName', 'string', r'^\P{C}*$', 1, 30)
        self.add_api_object('IndexFieldName', self.IndexFieldName)
        self.IndexId = APIObject('IndexId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]*', 36, 36)
        self.add_api_object('IndexId', self.IndexId)
        self.IndexName = APIObject('IndexName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('IndexName', self.IndexName)
        self.Issuer = APIObject('Issuer', 'string', r'^\P{C}*$', 1, 65)
        self.add_api_object('Issuer', self.Issuer)
        self.JiraAccountUrl = APIObject('JiraAccountUrl', 'string', r'^https:\/\/[a-zA-Z0-9_\-\.]+(\.atlassian\.net\/)$', 1, 2048)
        self.add_api_object('JiraAccountUrl', self.JiraAccountUrl)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'/arn:aws[a-zA-Z-]*:lambda:[a-z]+-[a-z]+-[0-9]:[0-9]{12}:function:[a-zA-Z0-9-_]+(\/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})?(:[a-zA-Z0-9-_]+)?/', 1, 2048)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.LanguageCode = APIObject('LanguageCode', 'string', r'[a-zA-Z-]*', 2, 10)
        self.add_api_object('LanguageCode', self.LanguageCode)
        self.MetricValue = APIObject('MetricValue', 'string', r'(([1-9][0-9]*)|0)', None, None)
        self.add_api_object('MetricValue', self.MetricValue)
        self.MimeType = APIObject('MimeType', 'string', r'^\P{C}*$', 1, 256)
        self.add_api_object('MimeType', self.MimeType)
        self.NameType = APIObject('NameType', 'string', r'^[\S\s]*$', 1, 100)
        self.add_api_object('NameType', self.NameType)
        self.OneDriveUser = APIObject('OneDriveUser', 'string', r'^(?!\s).+@([a-zA-Z0-9_\-\.]+)\.([a-zA-Z]{2,5})$', 1, 256)
        self.add_api_object('OneDriveUser', self.OneDriveUser)
        self.OrganizationId = APIObject('OrganizationId', 'string', r'd-[0-9a-fA-F]{10}', 12, 12)
        self.add_api_object('OrganizationId', self.OrganizationId)
        self.OrganizationName = APIObject('OrganizationName', 'string', r'^[A-Za-z0-9_.-]+$', 1, 60)
        self.add_api_object('OrganizationName', self.OrganizationName)
        self.PrincipalName = APIObject('PrincipalName', 'string', r'^\P{C}*$', 1, 200)
        self.add_api_object('PrincipalName', self.PrincipalName)
        self.QueryId = APIObject('QueryId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]*', 1, 36)
        self.add_api_object('QueryId', self.QueryId)
        self.QuerySuggestionsBlockListId = APIObject('QuerySuggestionsBlockListId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]*', 36, 36)
        self.add_api_object('QuerySuggestionsBlockListId', self.QuerySuggestionsBlockListId)
        self.QuerySuggestionsBlockListName = APIObject('QuerySuggestionsBlockListName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*', 1, 100)
        self.add_api_object('QuerySuggestionsBlockListName', self.QuerySuggestionsBlockListName)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'^[A-Za-z0-9_.-]+$', 1, 64)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.SalesforceCustomKnowledgeArticleTypeName = APIObject('SalesforceCustomKnowledgeArticleTypeName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 100)
        self.add_api_object('SalesforceCustomKnowledgeArticleTypeName', self.SalesforceCustomKnowledgeArticleTypeName)
        self.SecretArn = APIObject('SecretArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 1, 1284)
        self.add_api_object('SecretArn', self.SecretArn)
        self.SeedUrl = APIObject('SeedUrl', 'string', r'^(https?):\/\/([^\s]*)', 1, 2048)
        self.add_api_object('SeedUrl', self.SeedUrl)
        self.ServiceNowHostUrl = APIObject('ServiceNowHostUrl', 'string', r'^(?!(^(https?|ftp|file):\/\/))[a-z0-9-]+(\.service-now\.com)$', 1, 2048)
        self.add_api_object('ServiceNowHostUrl', self.ServiceNowHostUrl)
        self.ServiceNowKnowledgeArticleFilterQuery = APIObject('ServiceNowKnowledgeArticleFilterQuery', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('ServiceNowKnowledgeArticleFilterQuery', self.ServiceNowKnowledgeArticleFilterQuery)
        self.SharedDriveId = APIObject('SharedDriveId', 'string', r'^\P{C}*$', 1, 256)
        self.add_api_object('SharedDriveId', self.SharedDriveId)
        self.SinceCrawlDate = APIObject('SinceCrawlDate', 'string', r'(20\d{2})-(0?[1-9]|1[0-2])-(0?[1-9]|1\d|2\d|3[01])', 10, 10)
        self.add_api_object('SinceCrawlDate', self.SinceCrawlDate)
        self.SiteId = APIObject('SiteId', 'string', r'^[A-Za-z0-9-]+$', 1, 128)
        self.add_api_object('SiteId', self.SiteId)
        self.SiteMap = APIObject('SiteMap', 'string', r'^(https?):\/\/([^\s]*)', 1, 2048)
        self.add_api_object('SiteMap', self.SiteMap)
        self.SiteUrl = APIObject('SiteUrl', 'string', r'^https:\/\/[a-zA-Z0-9_\-\.]+$', 1, 2048)
        self.add_api_object('SiteUrl', self.SiteUrl)
        self.SubnetId = APIObject('SubnetId', 'string', r'[\-0-9a-zA-Z]+', 1, 200)
        self.add_api_object('SubnetId', self.SubnetId)
        self.SuggestionQueryText = APIObject('SuggestionQueryText', 'string', r'^\P{C}*$', None, None)
        self.add_api_object('SuggestionQueryText', self.SuggestionQueryText)
        self.TableName = APIObject('TableName', 'string', r'^[a-zA-Z][a-zA-Z0-9_]*$', 1, 100)
        self.add_api_object('TableName', self.TableName)
        self.TeamId = APIObject('TeamId', 'string', r'[A-Z0-9]*', 1, 64)
        self.add_api_object('TeamId', self.TeamId)
        self.TenantDomain = APIObject('TenantDomain', 'string', r'^([a-zA-Z0-9]+(-[a-zA-Z0-9]+)*\.)+[a-z]{2,}$', 1, 256)
        self.add_api_object('TenantDomain', self.TenantDomain)
        self.ThesaurusId = APIObject('ThesaurusId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('ThesaurusId', self.ThesaurusId)
        self.ThesaurusName = APIObject('ThesaurusName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('ThesaurusName', self.ThesaurusName)
        self.Token = APIObject('Token', 'string', r'^\P{C}*$', 1, 100000)
        self.add_api_object('Token', self.Token)
        self.Url = APIObject('Url', 'string', r'^(https?|ftp|file):\/\/([^\s]*)', 1, 2048)
        self.add_api_object('Url', self.Url)
        self.UserAccount = APIObject('UserAccount', 'string', r'^\P{C}*$', 1, 256)
        self.add_api_object('UserAccount', self.UserAccount)
        self.UserId = APIObject('UserId', 'string', r'^\P{C}*$', 1, 1024)
        self.add_api_object('UserId', self.UserId)
        self.UserNameAttributeField = APIObject('UserNameAttributeField', 'string', r'^\P{C}*$', 1, 100)
        self.add_api_object('UserNameAttributeField', self.UserNameAttributeField)
        self.VisitorId = APIObject('VisitorId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 256)
        self.add_api_object('VisitorId', self.VisitorId)
        self.VpcSecurityGroupId = APIObject('VpcSecurityGroupId', 'string', r'[-0-9a-zA-Z]+', 1, 200)
        self.add_api_object('VpcSecurityGroupId', self.VpcSecurityGroupId)
        self.WarningMessage = APIObject('WarningMessage', 'string', r'^\P{C}*$', 1, 2048)
        self.add_api_object('WarningMessage', self.WarningMessage)

class Keyspaces(Service):
    def __init__(self):
        super().__init__('Keyspaces')
        self.ARN = APIObject('ARN', 'string', r'arn:(aws[a-zA-Z0-9-]*):cassandra:.+.*', 20, 1000)
        self.add_api_object('ARN', self.ARN)
        self.KeyspaceName = APIObject('KeyspaceName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_]{0,47}', 1, 48)
        self.add_api_object('KeyspaceName', self.KeyspaceName)
        self.TableName = APIObject('TableName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_]{0,47}', 1, 48)
        self.add_api_object('TableName', self.TableName)

class KinesisVideoArchivedMedia(Service):
    def __init__(self):
        super().__init__('KinesisVideoArchivedMedia')
        self.ContentType = APIObject('ContentType', 'string', r'^[a-zA-Z0-9_\.\-]+$', 1, 128)
        self.add_api_object('ContentType', self.ContentType)
        self.FormatConfigValue = APIObject('FormatConfigValue', 'string', r'^[a-zA-Z_0-9]+', 0, 256)
        self.add_api_object('FormatConfigValue', self.FormatConfigValue)
        self.FragmentNumberString = APIObject('FragmentNumberString', 'string', r'^[0-9]+$', 1, 128)
        self.add_api_object('FragmentNumberString', self.FragmentNumberString)
        self.NextToken = APIObject('NextToken', 'string', r'[a-zA-Z0-9+/]+={0,2}', 1, 4096)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:[a-z\d-]+:kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+', 1, 1024)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.StreamName = APIObject('StreamName', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('StreamName', self.StreamName)

class KinesisVideoMedia(Service):
    def __init__(self):
        super().__init__('KinesisVideoMedia')
        self.ContentType = APIObject('ContentType', 'string', r'^[a-zA-Z0-9_\.\-]+$', 1, 128)
        self.add_api_object('ContentType', self.ContentType)
        self.ContinuationToken = APIObject('ContinuationToken', 'string', r'^[a-zA-Z0-9_\.\-]+$', 1, 128)
        self.add_api_object('ContinuationToken', self.ContinuationToken)
        self.FragmentNumberString = APIObject('FragmentNumberString', 'string', r'^[0-9]+$', 1, 128)
        self.add_api_object('FragmentNumberString', self.FragmentNumberString)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:aws:kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+', 1, 1024)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.StreamName = APIObject('StreamName', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('StreamName', self.StreamName)

class KinesisVideoSignaling(Service):
    def __init__(self):
        super().__init__('KinesisVideoSignaling')
        self.ClientId = APIObject('ClientId', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('ClientId', self.ClientId)
        self.MessagePayload = APIObject('MessagePayload', 'string', r'[a-zA-Z0-9+/=]+', 1, 10000)
        self.add_api_object('MessagePayload', self.MessagePayload)
        self.Password = APIObject('Password', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('Password', self.Password)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:aws:kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+', 1, 1024)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.Username = APIObject('Username', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('Username', self.Username)

class KinesisVideoWebrtcStorage(Service):
    def __init__(self):
        super().__init__('KinesisVideoWebrtcStorage')
        self.ChannelArn = APIObject('ChannelArn', 'string', r'^arn:(aws[a-zA-Z-]*):kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+$', None, None)
        self.add_api_object('ChannelArn', self.ChannelArn)

class Kinesis(Service):
    def __init__(self):
        super().__init__('Kinesis')
        self.ConsumerARN = APIObject('ConsumerARN', 'string', r'^(arn):aws.*:kinesis:.*:\d{12}:.*stream\/[a-zA-Z0-9_.-]+\/consumer\/[a-zA-Z0-9_.-]+:[0-9]+', 1, 2048)
        self.add_api_object('ConsumerARN', self.ConsumerARN)
        self.ConsumerName = APIObject('ConsumerName', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('ConsumerName', self.ConsumerName)
        self.HashKey = APIObject('HashKey', 'string', r'0|([1-9]\d{0,38})', None, None)
        self.add_api_object('HashKey', self.HashKey)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:aws.*:kinesis:.*:\d{12}:.*stream/\S+', 1, 2048)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.SequenceNumber = APIObject('SequenceNumber', 'string', r'0|([1-9]\d{0,128})', None, None)
        self.add_api_object('SequenceNumber', self.SequenceNumber)
        self.ShardId = APIObject('ShardId', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('ShardId', self.ShardId)
        self.StreamARN = APIObject('StreamARN', 'string', r'arn:aws.*:kinesis:.*:\d{12}:stream/\S+', 1, 2048)
        self.add_api_object('StreamARN', self.StreamARN)
        self.StreamName = APIObject('StreamName', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('StreamName', self.StreamName)

class Kinesisanalytics(Service):
    def __init__(self):
        super().__init__('Kinesisanalytics')
        self.ApplicationName = APIObject('ApplicationName', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.BucketARN = APIObject('BucketARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('BucketARN', self.BucketARN)
        self.Id = APIObject('Id', 'string', r'[a-zA-Z0-9_.-]+', 1, 50)
        self.add_api_object('Id', self.Id)
        self.KinesisAnalyticsARN = APIObject('KinesisAnalyticsARN', 'string', r'arn:aws:kinesisanalytics:[a-z]{2}-[a-z]+-\d{1}+:\d{12}+:application/[a-zA-Z0-9_.-]{1,128}', 1, 2048)
        self.add_api_object('KinesisAnalyticsARN', self.KinesisAnalyticsARN)
        self.LogStreamARN = APIObject('LogStreamARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('LogStreamARN', self.LogStreamARN)
        self.RecordEncoding = APIObject('RecordEncoding', 'string', r'UTF-8', None, None)
        self.add_api_object('RecordEncoding', self.RecordEncoding)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.RoleARN = APIObject('RoleARN', 'string', r'arn:aws:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', 1, 2048)
        self.add_api_object('RoleARN', self.RoleARN)

class Kinesisanalyticsv2(Service):
    def __init__(self):
        super().__init__('Kinesisanalyticsv2')
        self.ApplicationMaintenanceWindowEndTime = APIObject('ApplicationMaintenanceWindowEndTime', 'string', r'([01][0-9]|2[0-3]):[0-5][0-9]', 5, 5)
        self.add_api_object('ApplicationMaintenanceWindowEndTime', self.ApplicationMaintenanceWindowEndTime)
        self.ApplicationMaintenanceWindowStartTime = APIObject('ApplicationMaintenanceWindowStartTime', 'string', r'([01][0-9]|2[0-3]):[0-5][0-9]', 5, 5)
        self.add_api_object('ApplicationMaintenanceWindowStartTime', self.ApplicationMaintenanceWindowStartTime)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.BasePath = APIObject('BasePath', 'string', r'[a-zA-Z0-9/!-_.*\'()]+', 1, 1024)
        self.add_api_object('BasePath', self.BasePath)
        self.BucketARN = APIObject('BucketARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('BucketARN', self.BucketARN)
        self.ConditionalToken = APIObject('ConditionalToken', 'string', r'[a-zA-Z0-9-_+/=]+', 1, 512)
        self.add_api_object('ConditionalToken', self.ConditionalToken)
        self.DatabaseARN = APIObject('DatabaseARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('DatabaseARN', self.DatabaseARN)
        self.Id = APIObject('Id', 'string', r'[a-zA-Z0-9_.-]+', 1, 50)
        self.add_api_object('Id', self.Id)
        self.InAppStreamName = APIObject('InAppStreamName', 'string', r'[^-\s<>&]*', 1, 32)
        self.add_api_object('InAppStreamName', self.InAppStreamName)
        self.KinesisAnalyticsARN = APIObject('KinesisAnalyticsARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('KinesisAnalyticsARN', self.KinesisAnalyticsARN)
        self.LogStreamARN = APIObject('LogStreamARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('LogStreamARN', self.LogStreamARN)
        self.MavenArtifactId = APIObject('MavenArtifactId', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('MavenArtifactId', self.MavenArtifactId)
        self.MavenGroupId = APIObject('MavenGroupId', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('MavenGroupId', self.MavenGroupId)
        self.MavenVersion = APIObject('MavenVersion', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('MavenVersion', self.MavenVersion)
        self.RecordColumnName = APIObject('RecordColumnName', 'string', r'[^-\s<>&]*', 1, 256)
        self.add_api_object('RecordColumnName', self.RecordColumnName)
        self.RecordEncoding = APIObject('RecordEncoding', 'string', r'UTF-8', 5, 5)
        self.add_api_object('RecordEncoding', self.RecordEncoding)
        self.RecordRowPath = APIObject('RecordRowPath', 'string', r'^(?=^\$)(?=^\S+$).*$', 1, 65535)
        self.add_api_object('RecordRowPath', self.RecordRowPath)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.RoleARN = APIObject('RoleARN', 'string', r'arn:.*', 1, 2048)
        self.add_api_object('RoleARN', self.RoleARN)
        self.SnapshotName = APIObject('SnapshotName', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('SnapshotName', self.SnapshotName)

class Kinesisvideo(Service):
    def __init__(self):
        super().__init__('Kinesisvideo')
        self.ChannelName = APIObject('ChannelName', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('ChannelName', self.ChannelName)
        self.DestinationRegion = APIObject('DestinationRegion', 'string', r'^[a-z]+(-[a-z]+)?-[a-z]+-[0-9]$', 9, 14)
        self.add_api_object('DestinationRegion', self.DestinationRegion)
        self.DestinationUri = APIObject('DestinationUri', 'string', r'^[a-zA-Z_0-9]+:(//)?([^/]+)/?([^*]*)$', 1, 255)
        self.add_api_object('DestinationUri', self.DestinationUri)
        self.DeviceName = APIObject('DeviceName', 'string', r'[a-zA-Z0-9_.-]+', 1, 128)
        self.add_api_object('DeviceName', self.DeviceName)
        self.FormatConfigValue = APIObject('FormatConfigValue', 'string', r'^[a-zA-Z_0-9]+', 0, 256)
        self.add_api_object('FormatConfigValue', self.FormatConfigValue)
        self.HubDeviceArn = APIObject('HubDeviceArn', 'string', r'arn:[a-z\d-]+:iot:[a-z0-9-]+:[0-9]+:thing/[a-zA-Z0-9_.-]+', 1, 1024)
        self.add_api_object('HubDeviceArn', self.HubDeviceArn)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'.+', 1, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.MediaType = APIObject('MediaType', 'string', r'[\w\-\.\+]+/[\w\-\.\+]+(,[\w\-\.\+]+/[\w\-\.\+]+)*', 1, 128)
        self.add_api_object('MediaType', self.MediaType)
        self.MediaUriSecretArn = APIObject('MediaUriSecretArn', 'string', r'arn:[a-z\d-]+:secretsmanager:[a-z0-9-]+:[0-9]+:secret:[a-zA-Z0-9_.-]+', 20, 2048)
        self.add_api_object('MediaUriSecretArn', self.MediaUriSecretArn)
        self.NextToken = APIObject('NextToken', 'string', r'[a-zA-Z0-9+/=]*', 0, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:[a-z\d-]+:kinesisvideo:[a-z0-9-]+:[0-9]+:[a-z]+/[a-zA-Z0-9_.-]+/[0-9]+', 1, 1024)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.ScheduleExpression = APIObject('ScheduleExpression', 'string', r'[^\n]{11,100}', 11, 100)
        self.add_api_object('ScheduleExpression', self.ScheduleExpression)
        self.StreamName = APIObject('StreamName', 'string', r'[a-zA-Z0-9_.-]+', 1, 256)
        self.add_api_object('StreamName', self.StreamName)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Version = APIObject('Version', 'string', r'[a-zA-Z0-9]+', 1, 64)
        self.add_api_object('Version', self.Version)

class Kms(Service):
    def __init__(self):
        super().__init__('Kms')
        self.AliasNameType = APIObject('AliasNameType', 'string', r'^[a-zA-Z0-9:/_-]+$', 1, 256)
        self.add_api_object('AliasNameType', self.AliasNameType)
        self.CloudHsmClusterIdType = APIObject('CloudHsmClusterIdType', 'string', r'cluster-[2-7a-zA-Z]{11,16}', 19, 24)
        self.add_api_object('CloudHsmClusterIdType', self.CloudHsmClusterIdType)
        self.GrantNameType = APIObject('GrantNameType', 'string', r'^[a-zA-Z0-9:/_-]+$', 1, 256)
        self.add_api_object('GrantNameType', self.GrantNameType)
        self.MarkerType = APIObject('MarkerType', 'string', r'[\u0020-\u00FF]*', 1, 1024)
        self.add_api_object('MarkerType', self.MarkerType)
        self.PolicyNameType = APIObject('PolicyNameType', 'string', r'[\w]+', 1, 128)
        self.add_api_object('PolicyNameType', self.PolicyNameType)
        self.PolicyType = APIObject('PolicyType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 131072)
        self.add_api_object('PolicyType', self.PolicyType)
        self.PrincipalIdType = APIObject('PrincipalIdType', 'string', r'^[\w+=,.@:/-]+$', 1, 256)
        self.add_api_object('PrincipalIdType', self.PrincipalIdType)
        self.RegionType = APIObject('RegionType', 'string', r'^([a-z]+-){2,3}\d+$', 1, 32)
        self.add_api_object('RegionType', self.RegionType)
        self.XksKeyIdType = APIObject('XksKeyIdType', 'string', r'^[a-zA-Z0-9-_.]+$', 1, 128)
        self.add_api_object('XksKeyIdType', self.XksKeyIdType)
        self.XksProxyAuthenticationAccessKeyIdType = APIObject('XksProxyAuthenticationAccessKeyIdType', 'string', r'^[A-Z2-7]+$', 20, 30)
        self.add_api_object('XksProxyAuthenticationAccessKeyIdType', self.XksProxyAuthenticationAccessKeyIdType)
        self.XksProxyAuthenticationRawSecretAccessKeyType = APIObject('XksProxyAuthenticationRawSecretAccessKeyType', 'string', r'^[a-zA-Z0-9\/+=]+$', 43, 64)
        self.add_api_object('XksProxyAuthenticationRawSecretAccessKeyType', self.XksProxyAuthenticationRawSecretAccessKeyType)
        self.XksProxyUriEndpointType = APIObject('XksProxyUriEndpointType', 'string', r'^https://[a-zA-Z0-9.-]+$', 10, 128)
        self.add_api_object('XksProxyUriEndpointType', self.XksProxyUriEndpointType)
        self.XksProxyUriPathType = APIObject('XksProxyUriPathType', 'string', r'^(/[a-zA-Z0-9\/_-]+/kms/xks/v\d{1,2})$|^(/kms/xks/v\d{1,2})$', 10, 128)
        self.add_api_object('XksProxyUriPathType', self.XksProxyUriPathType)
        self.XksProxyVpcEndpointServiceNameType = APIObject('XksProxyVpcEndpointServiceNameType', 'string', r'^com\.amazonaws\.vpce\.([a-z]+-){2,3}\d+\.vpce-svc-[0-9a-z]+$', 20, 64)
        self.add_api_object('XksProxyVpcEndpointServiceNameType', self.XksProxyVpcEndpointServiceNameType)

class Lakeformation(Service):
    def __init__(self):
        super().__init__('Lakeformation')
        self.AuditContextString = APIObject('AuditContextString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 0, 2048)
        self.add_api_object('AuditContextString', self.AuditContextString)
        self.CatalogIdString = APIObject('CatalogIdString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('CatalogIdString', self.CatalogIdString)
        self.DescriptionString = APIObject('DescriptionString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('DescriptionString', self.DescriptionString)
        self.ETagString = APIObject('ETagString', 'string', r'[\p{L}\p{N}\p{P}]*', 1, 255)
        self.add_api_object('ETagString', self.ETagString)
        self.HashString = APIObject('HashString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('HashString', self.HashString)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'arn:aws:iam::[0-9]*:role/.*', None, None)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.IAMSAMLProviderArn = APIObject('IAMSAMLProviderArn', 'string', r'arn:aws:iam::[0-9]*:saml-provider/.*', None, None)
        self.add_api_object('IAMSAMLProviderArn', self.IAMSAMLProviderArn)
        self.KeyString = APIObject('KeyString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('KeyString', self.KeyString)
        self.LFTagKey = APIObject('LFTagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:\/=+\-@%]*)$', 1, 128)
        self.add_api_object('LFTagKey', self.LFTagKey)
        self.LFTagValue = APIObject('LFTagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:\*\/=+\-@%]*)$', 0, 256)
        self.add_api_object('LFTagValue', self.LFTagValue)
        self.NameString = APIObject('NameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('NameString', self.NameString)
        self.PredicateString = APIObject('PredicateString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 0, 2048)
        self.add_api_object('PredicateString', self.PredicateString)
        self.QueryPlanningContextDatabaseNameString = APIObject('QueryPlanningContextDatabaseNameString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, None)
        self.add_api_object('QueryPlanningContextDatabaseNameString', self.QueryPlanningContextDatabaseNameString)
        self.TransactionIdString = APIObject('TransactionIdString', 'string', r'[\p{L}\p{N}\p{P}]*', 1, 255)
        self.add_api_object('TransactionIdString', self.TransactionIdString)
        self.TrueFalseString = APIObject('TrueFalseString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 5)
        self.add_api_object('TrueFalseString', self.TrueFalseString)
        self.URI = APIObject('URI', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\r\n\t]*', 1, 1024)
        self.add_api_object('URI', self.URI)
        self.VersionString = APIObject('VersionString', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 255)
        self.add_api_object('VersionString', self.VersionString)

class Lambda_(Service):
    def __init__(self):
        super().__init__('Lambda')
        self.FunctionArn = APIObject('FunctionArn', 'string', r'arn:aws:lambda:[a-z]{2}-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(\/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})?', None, None)
        self.add_api_object('FunctionArn', self.FunctionArn)
        self.FunctionName = APIObject('FunctionName', 'string', r'[a-zA-Z0-9-_]+', 1, 64)
        self.add_api_object('FunctionName', self.FunctionName)
        self.Handler = APIObject('Handler', 'string', r'[a-zA-Z0-9./\-_]+', None, None)
        self.add_api_object('Handler', self.Handler)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', None, None)
        self.add_api_object('RoleArn', self.RoleArn)

class LaunchWizard(Service):
    def __init__(self):
        super().__init__('LaunchWizard')
        self.DeploymentId = APIObject('DeploymentId', 'string', r'^[a-zA-Z0-9-]+$', 2, 128)
        self.add_api_object('DeploymentId', self.DeploymentId)
        self.DeploymentName = APIObject('DeploymentName', 'string', r'^[A-Za-z0-9_\s\.-]+$', 1, 25)
        self.add_api_object('DeploymentName', self.DeploymentName)
        self.DeploymentPatternName = APIObject('DeploymentPatternName', 'string', r'^[a-zA-Z0-9-]+$', 1, 256)
        self.add_api_object('DeploymentPatternName', self.DeploymentPatternName)
        self.KeyString = APIObject('KeyString', 'string', r'^[a-zA-Z0-9-:]+$', 3, 256)
        self.add_api_object('KeyString', self.KeyString)
        self.WorkloadName = APIObject('WorkloadName', 'string', r'^[a-zA-Z0-9-]+$', 1, 256)
        self.add_api_object('WorkloadName', self.WorkloadName)
        self.WorkloadVersionName = APIObject('WorkloadVersionName', 'string', r'^[a-zA-Z0-9-]+$', 5, 30)
        self.add_api_object('WorkloadVersionName', self.WorkloadVersionName)

class LexModels(Service):
    def __init__(self):
        super().__init__('LexModels')
        self.AliasName = APIObject('AliasName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('AliasName', self.AliasName)
        self.AliasNameOrListAll = APIObject('AliasNameOrListAll', 'string', r'^(-|^([A-Za-z]_?)+$)$', 1, 100)
        self.add_api_object('AliasNameOrListAll', self.AliasNameOrListAll)
        self.BotChannelName = APIObject('BotChannelName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('BotChannelName', self.BotChannelName)
        self.BotName = APIObject('BotName', 'string', r'^([A-Za-z]_?)+$', 2, 50)
        self.add_api_object('BotName', self.BotName)
        self.CustomOrBuiltinSlotTypeName = APIObject('CustomOrBuiltinSlotTypeName', 'string', r'^((AMAZON\.)_?|[A-Za-z]_?)+', 1, 100)
        self.add_api_object('CustomOrBuiltinSlotTypeName', self.CustomOrBuiltinSlotTypeName)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:[\w\-]+:iam::[\d]{12}:role/.+$', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.InputContextName = APIObject('InputContextName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('InputContextName', self.InputContextName)
        self.IntentName = APIObject('IntentName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('IntentName', self.IntentName)
        self.KendraIndexArn = APIObject('KendraIndexArn', 'string', r'arn:aws:kendra:[a-z]+-[a-z]+-[0-9]:[0-9]{12}:index\/[a-zA-Z0-9][a-zA-Z0-9_-]*', 20, 2048)
        self.add_api_object('KendraIndexArn', self.KendraIndexArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:[\w\-]+:kms:[\w\-]+:[\d]{12}:(?:key\/[\w\-]+|alias\/[a-zA-Z0-9:\/_\-]{1,256})$', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LambdaARN = APIObject('LambdaARN', 'string', r'arn:aws[a-zA-Z-]*:lambda:[a-z]+-[a-z]+(-[a-z]+)*-[0-9]:[0-9]{12}:function:[a-zA-Z0-9-_]+(\/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})?(:[a-zA-Z0-9-_]+)?', 20, 2048)
        self.add_api_object('LambdaARN', self.LambdaARN)
        self.MigrationId = APIObject('MigrationId', 'string', r'^[0-9a-zA-Z]+$', 10, 10)
        self.add_api_object('MigrationId', self.MigrationId)
        self.Name = APIObject('Name', 'string', r'[a-zA-Z_]+', 1, 100)
        self.add_api_object('Name', self.Name)
        self.NumericalVersion = APIObject('NumericalVersion', 'string', r'[0-9]+', 1, 64)
        self.add_api_object('NumericalVersion', self.NumericalVersion)
        self.OutputContextName = APIObject('OutputContextName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('OutputContextName', self.OutputContextName)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:[\w\-]+:(?:logs:[\w\-]+:[\d]{12}:log-group:[\.\-_/#A-Za-z0-9]{1,512}(?::\*)?|s3:::[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9])$', 1, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.SlotName = APIObject('SlotName', 'string', r'^([A-Za-z](-|_|.)?)+$', 1, 100)
        self.add_api_object('SlotName', self.SlotName)
        self.SlotTypeName = APIObject('SlotTypeName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('SlotTypeName', self.SlotTypeName)
        self.V2BotId = APIObject('V2BotId', 'string', r'^[0-9a-zA-Z]+$', 10, 10)
        self.add_api_object('V2BotId', self.V2BotId)
        self.V2BotName = APIObject('V2BotName', 'string', r'^([0-9a-zA-Z][_-]?)+$', 1, 100)
        self.add_api_object('V2BotName', self.V2BotName)
        self.Version = APIObject('Version', 'string', r'\$LATEST|[0-9]+', 1, 64)
        self.add_api_object('Version', self.Version)
        self.roleArn = APIObject('roleArn', 'string', r'arn:aws:iam::[0-9]{12}:role/.*', 20, 2048)
        self.add_api_object('roleArn', self.roleArn)

class LexRuntime(Service):
    def __init__(self):
        super().__init__('LexRuntime')
        self.ActiveContextName = APIObject('ActiveContextName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('ActiveContextName', self.ActiveContextName)
        self.BotVersion = APIObject('BotVersion', 'string', r'[0-9]+|\$LATEST', 1, 64)
        self.add_api_object('BotVersion', self.BotVersion)
        self.IntentSummaryCheckpointLabel = APIObject('IntentSummaryCheckpointLabel', 'string', r'[a-zA-Z0-9-]+', 1, 255)
        self.add_api_object('IntentSummaryCheckpointLabel', self.IntentSummaryCheckpointLabel)
        self.UserId = APIObject('UserId', 'string', r'[0-9a-zA-Z._:-]+', 2, 100)
        self.add_api_object('UserId', self.UserId)

class Lexv2Models(Service):
    def __init__(self):
        super().__init__('Lexv2Models')
        self.ActiveContextName = APIObject('ActiveContextName', 'string', r'^([A-Za-z]_?)+$', 1, 100)
        self.add_api_object('ActiveContextName', self.ActiveContextName)
        self.AnalyticsSessionId = APIObject('AnalyticsSessionId', 'string', r'[0-9a-zA-Z._:-]', None, None)
        self.add_api_object('AnalyticsSessionId', self.AnalyticsSessionId)
        self.AudioFileS3Location = APIObject('AudioFileS3Location', 'string', r'^s3://([a-z0-9\\.-]+)/(.+)$', 1, 1024)
        self.add_api_object('AudioFileS3Location', self.AudioFileS3Location)
        self.BedrockKnowledgeBaseArn = APIObject('BedrockKnowledgeBaseArn', 'string', r'^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,40}:[0-9]{12}:knowledge-base\/[A-Za-z0-9]{10}$|^[A-Za-z0-9]{10}$', 1, 200)
        self.add_api_object('BedrockKnowledgeBaseArn', self.BedrockKnowledgeBaseArn)
        self.BedrockModelArn = APIObject('BedrockModelArn', 'string', r'^arn:aws(-[^:]+)?:bedrock:[a-z0-9-]{1,20}::foundation-model\/[a-z0-9-]{1,63}[.]{1}([a-z0-9-]{1,63}[.]){0,2}[a-z0-9-]{1,63}([:][a-z0-9-]{1,63}){0,2}$', None, None)
        self.add_api_object('BedrockModelArn', self.BedrockModelArn)
        self.BotAliasId = APIObject('BotAliasId', 'string', r'^(\bTSTALIASID\b|[0-9a-zA-Z]+)$', 10, 10)
        self.add_api_object('BotAliasId', self.BotAliasId)
        self.BotAliasName = APIObject('BotAliasName', 'string', r'^(\bAmazonLexTestAlias\b|[0-9a-zA-Z][_-]?)+$', 1, 100)
        self.add_api_object('BotAliasName', self.BotAliasName)
        self.BotVersion = APIObject('BotVersion', 'string', r'^(DRAFT|[0-9]+)$', 1, 5)
        self.add_api_object('BotVersion', self.BotVersion)
        self.BuiltInOrCustomSlotTypeId = APIObject('BuiltInOrCustomSlotTypeId', 'string', r'^((AMAZON\.)[a-zA-Z_]+?|[0-9a-zA-Z]+)$', 1, 25)
        self.add_api_object('BuiltInOrCustomSlotTypeId', self.BuiltInOrCustomSlotTypeId)
        self.CloudWatchLogGroupArn = APIObject('CloudWatchLogGroupArn', 'string', r'^arn:[\w\-]+:logs:[\w\-]+:[\d]{12}:log-group:[\.\-_/#A-Za-z0-9]{1,512}(?::\*)?$', 1, 2048)
        self.add_api_object('CloudWatchLogGroupArn', self.CloudWatchLogGroupArn)
        self.DTMFCharacter = APIObject('DTMFCharacter', 'string', r'^[A-D0-9#*]{1}$', None, None)
        self.add_api_object('DTMFCharacter', self.DTMFCharacter)
        self.DomainEndpoint = APIObject('DomainEndpoint', 'string', r'^(http|https):\/\/+[^\s]+[\w]', None, None)
        self.add_api_object('DomainEndpoint', self.DomainEndpoint)
        self.DraftBotVersion = APIObject('DraftBotVersion', 'string', r'^DRAFT$', 5, 5)
        self.add_api_object('DraftBotVersion', self.DraftBotVersion)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[0-9a-zA-Z_()\s-]+$', 1, 100)
        self.add_api_object('FilterValue', self.FilterValue)
        self.Id = APIObject('Id', 'string', r'^[0-9a-zA-Z]+$', 10, 10)
        self.add_api_object('Id', self.Id)
        self.ImportedResourceId = APIObject('ImportedResourceId', 'string', r'^([0-9a-zA-Z_])+$', 5, 10)
        self.add_api_object('ImportedResourceId', self.ImportedResourceId)
        self.KendraIndexArn = APIObject('KendraIndexArn', 'string', r'^arn:aws:kendra:[a-z]+-[a-z]+-[0-9]:[0-9]{12}:index\/[a-zA-Z0-9][a-zA-Z0-9_-]*$', 32, 2048)
        self.add_api_object('KendraIndexArn', self.KendraIndexArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:[\w\-]+:kms:[\w\-]+:[\d]{12}:(?:key\/[\w\-]+|alias\/[a-zA-Z0-9:\/_\-]{1,256})$', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LambdaARN = APIObject('LambdaARN', 'string', r'arn:aws:lambda:[a-z]+-[a-z]+-[0-9]:[0-9]{12}:function:[a-zA-Z0-9-_]+(/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})?(:[a-zA-Z0-9-_]+)?', 20, 2048)
        self.add_api_object('LambdaARN', self.LambdaARN)
        self.Name = APIObject('Name', 'string', r'^([0-9a-zA-Z][_-]?){1,100}$', 1, 100)
        self.add_api_object('Name', self.Name)
        self.NumericalBotVersion = APIObject('NumericalBotVersion', 'string', r'^[0-9]+$', 1, 5)
        self.add_api_object('NumericalBotVersion', self.NumericalBotVersion)
        self.OSIndexName = APIObject('OSIndexName', 'string', r'^(?![_-])[a-z0-9][a-z0-9_\-]{0,254}$', 1, 255)
        self.add_api_object('OSIndexName', self.OSIndexName)
        self.ObjectPrefix = APIObject('ObjectPrefix', 'string', r'^[\/]?+[a-zA-Z0-9!_.*\'()-]+(\/[a-zA-Z0-9!_.*\'()-]+)*$', 1, None)
        self.add_api_object('ObjectPrefix', self.ObjectPrefix)
        self.Operation = APIObject('Operation', 'string', r'lex:[a-zA-Z*]+$', 5, 50)
        self.add_api_object('Operation', self.Operation)
        self.PrincipalArn = APIObject('PrincipalArn', 'string', r'^arn:aws:iam::[0-9]{12}:(root|(user|role)/.*)$', 30, 1024)
        self.add_api_object('PrincipalArn', self.PrincipalArn)
        self.RevisionId = APIObject('RevisionId', 'string', r'^[0-9]+$', 1, 5)
        self.add_api_object('RevisionId', self.RevisionId)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws:iam::[0-9]{12}:role/.*$', 32, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketArn = APIObject('S3BucketArn', 'string', r'^arn:[\w\-]+:s3:::[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]$', 1, 2048)
        self.add_api_object('S3BucketArn', self.S3BucketArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]$', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectPath = APIObject('S3ObjectPath', 'string', r'''[\.\-\!\*\_\\'\(\)a-zA-Z0-9][\.\-\!\*\_\\'\(\)\/a-zA-Z0-9]*$''', 1, 1024)
        self.add_api_object('S3ObjectPath', self.S3ObjectPath)
        self.ServicePrincipal = APIObject('ServicePrincipal', 'string', r'^[0-9a-zA-Z_.]+$', 15, 1024)
        self.add_api_object('ServicePrincipal', self.ServicePrincipal)
        self.SessionId = APIObject('SessionId', 'string', r'[0-9a-zA-Z._:-]+', 2, 100)
        self.add_api_object('SessionId', self.SessionId)
        self.SubSlotExpression = APIObject('SubSlotExpression', 'string', r'[0-9A-Za-z_\-\s\(\)]+', 0, 640)
        self.add_api_object('SubSlotExpression', self.SubSlotExpression)
        self.TestResultSlotName = APIObject('TestResultSlotName', 'string', r'^([0-9a-zA-Z][_.-]?)+$', 1, 100)
        self.add_api_object('TestResultSlotName', self.TestResultSlotName)
        self.TestSetConversationId = APIObject('TestSetConversationId', 'string', r'^([0-9a-zA-Z][_-]?)+$', 1, 50)
        self.add_api_object('TestSetConversationId', self.TestSetConversationId)
        self.Transcript = APIObject('Transcript', 'string', r'.*', 1, 6000000)
        self.add_api_object('Transcript', self.Transcript)

class Lexv2Runtime(Service):
    def __init__(self):
        super().__init__('Lexv2Runtime')
        self.ActiveContextName = APIObject('ActiveContextName', 'string', r'^([A-Za-z0-9]_?)+$', 1, 100)
        self.add_api_object('ActiveContextName', self.ActiveContextName)
        self.BotIdentifier = APIObject('BotIdentifier', 'string', r'^[0-9a-zA-Z]+$', 10, 10)
        self.add_api_object('BotIdentifier', self.BotIdentifier)
        self.DTMFRegex = APIObject('DTMFRegex', 'string', r'^[A-D0-9#*]{1}$', 1, 1)
        self.add_api_object('DTMFRegex', self.DTMFRegex)
        self.EventId = APIObject('EventId', 'string', r'[0-9a-zA-Z._:-]+', 2, 100)
        self.add_api_object('EventId', self.EventId)
        self.Name = APIObject('Name', 'string', r'^([0-9a-zA-Z][_-]?)+$', 1, 100)
        self.add_api_object('Name', self.Name)
        self.SessionId = APIObject('SessionId', 'string', r'[0-9a-zA-Z._:-]+', 2, 100)
        self.add_api_object('SessionId', self.SessionId)

class LicenseManagerLinuxSubscriptions(Service):
    def __init__(self):
        super().__init__('LicenseManagerLinuxSubscriptions')

class LicenseManagerUserSubscriptions(Service):
    def __init__(self):
        super().__init__('LicenseManagerUserSubscriptions')
        self.SecurityGroup = APIObject('SecurityGroup', 'string', r'^sg-(([0-9a-z]{8})|([0-9a-z]{17}))$', 5, 200)
        self.add_api_object('SecurityGroup', self.SecurityGroup)
        self.Subnet = APIObject('Subnet', 'string', r'subnet-[a-z0-9]{8,17}', None, None)
        self.add_api_object('Subnet', self.Subnet)

class LicenseManager(Service):
    def __init__(self):
        super().__init__('LicenseManager')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws(-(cn|us-gov|iso-b|iso-c|iso-d))?:[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}$', None, 2048)
        self.add_api_object('Arn', self.Arn)
        self.ClientToken = APIObject('ClientToken', 'string', r'\S+', None, 2048)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ISO8601DateTime = APIObject('ISO8601DateTime', 'string', r'^(-?(?:[1-9][0-9]*)?[0-9]{4})-(1[0-2]|0[1-9])-(3[0-1]|0[1-9]|[1-2][0-9])T(2[0-3]|[0-1][0-9]):([0-5][0-9]):([0-5][0-9])(\.[0-9]+)?(Z|[+-](?:2[ 0-3]|[0-1][0-9]):[0-5][0-9])+$', None, 50)
        self.add_api_object('ISO8601DateTime', self.ISO8601DateTime)
        self.LicenseConversionTaskId = APIObject('LicenseConversionTaskId', 'string', r'^lct-[a-zA-Z0-9]*', None, 50)
        self.add_api_object('LicenseConversionTaskId', self.LicenseConversionTaskId)
        self.StatusReasonMessage = APIObject('StatusReasonMessage', 'string', r'[\s\S]+', None, 400)
        self.add_api_object('StatusReasonMessage', self.StatusReasonMessage)
        self.TokenString = APIObject('TokenString', 'string', r'\S+', None, 4096)
        self.add_api_object('TokenString', self.TokenString)

class Lightsail(Service):
    def __init__(self):
        super().__init__('Lightsail')
        self.AutoSnapshotDate = APIObject('AutoSnapshotDate', 'string', r'^[0-9]{4}-[0-9]{2}-[0-9]{2}$', None, None)
        self.add_api_object('AutoSnapshotDate', self.AutoSnapshotDate)
        self.BucketAccessLogPrefix = APIObject('BucketAccessLogPrefix', 'string', r'^[\w/!.*\')(-]+$', 1, 100)
        self.add_api_object('BucketAccessLogPrefix', self.BucketAccessLogPrefix)
        self.BucketName = APIObject('BucketName', 'string', r'^[a-z0-9][a-z0-9-]{1,52}[a-z0-9]$', 3, 54)
        self.add_api_object('BucketName', self.BucketName)
        self.ContainerLabel = APIObject('ContainerLabel', 'string', r'^[a-z0-9]{1,2}|[a-z0-9][a-z0-9-]+[a-z0-9]$', 1, 53)
        self.add_api_object('ContainerLabel', self.ContainerLabel)
        self.ContainerName = APIObject('ContainerName', 'string', r'^[a-z0-9]{1,2}|[a-z0-9][a-z0-9-]+[a-z0-9]$', 1, 53)
        self.add_api_object('ContainerName', self.ContainerName)
        self.ContainerServiceName = APIObject('ContainerServiceName', 'string', r'^[a-z0-9]{1,2}|[a-z0-9][a-z0-9-]+[a-z0-9]$', 1, 63)
        self.add_api_object('ContainerServiceName', self.ContainerServiceName)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'^[\w!#$%&.\'*+\/=?^_\x60{|}~\-]{1,64}@[a-zA-Z0-9\-]{1,63}(\.[a-zA-Z0-9\-]{1,63}){0,8}(\.[a-zA-Z]{2,63})$', 6, 254)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.IAMAccessKeyId = APIObject('IAMAccessKeyId', 'string', r'^[A-Z0-9]{20}$', 20, 20)
        self.add_api_object('IAMAccessKeyId', self.IAMAccessKeyId)
        self.IpAddress = APIObject('IpAddress', 'string', r'([0-9]{1,3}\.){3}[0-9]{1,3}', None, None)
        self.add_api_object('IpAddress', self.IpAddress)
        self.Ipv6Address = APIObject('Ipv6Address', 'string', r'([A-F0-9]{1,4}:){7}[A-F0-9]{1,4}', None, None)
        self.add_api_object('Ipv6Address', self.Ipv6Address)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:(aws[^:]*):([a-zA-Z0-9-]+):([a-z0-9-]+):([0-9]+):([a-zA-Z]+)/([a-zA-Z0-9-]+)$', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceName = APIObject('ResourceName', 'string', r'\w[\w\-]*\w', None, None)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SensitiveNonEmptyString = APIObject('SensitiveNonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('SensitiveNonEmptyString', self.SensitiveNonEmptyString)
        self.SetupDomainName = APIObject('SetupDomainName', 'string', r'^[a-zA-Z0-9\-]{1,63}(\.[a-zA-Z0-9\-]{1,63}){0,8}(\.[a-zA-Z]{2,63})$', 4, 253)
        self.add_api_object('SetupDomainName', self.SetupDomainName)
        self.SetupHistoryPageToken = APIObject('SetupHistoryPageToken', 'string', r'^[A-Za-z0-9+/=]+$', 24, 40)
        self.add_api_object('SetupHistoryPageToken', self.SetupHistoryPageToken)
        self.TimeOfDay = APIObject('TimeOfDay', 'string', r'^(0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$', None, None)
        self.add_api_object('TimeOfDay', self.TimeOfDay)

class Location(Service):
    def __init__(self):
        super().__init__('Location')
        self.ApiKeyAction = APIObject('ApiKeyAction', 'string', r'^geo:\w*\*?$', 5, 200)
        self.add_api_object('ApiKeyAction', self.ApiKeyAction)
        self.Arn = APIObject('Arn', 'string', r'^arn(:[a-z0-9]+([.-][a-z0-9]+)*){2}(:([a-z0-9]+([.-][a-z0-9]+)*)?){2}:([^/].*)?$', 0, 1600)
        self.add_api_object('Arn', self.Arn)
        self.BatchGetDevicePositionRequestTrackerNameString = APIObject('BatchGetDevicePositionRequestTrackerNameString', 'string', r'^[-._\w]+$', 1, None)
        self.add_api_object('BatchGetDevicePositionRequestTrackerNameString', self.BatchGetDevicePositionRequestTrackerNameString)
        self.CountryCode = APIObject('CountryCode', 'string', r'^[A-Z]{3}$', None, None)
        self.add_api_object('CountryCode', self.CountryCode)
        self.CountryCode3 = APIObject('CountryCode3', 'string', r'^[A-Z]{3}$', 3, 3)
        self.add_api_object('CountryCode3', self.CountryCode3)
        self.CountryCode3OrEmpty = APIObject('CountryCode3OrEmpty', 'string', r'^[A-Z]{3}$|^$', 0, 3)
        self.add_api_object('CountryCode3OrEmpty', self.CountryCode3OrEmpty)
        self.CustomLayer = APIObject('CustomLayer', 'string', r'^[-._\w]+$', 1, 100)
        self.add_api_object('CustomLayer', self.CustomLayer)
        self.GeoArn = APIObject('GeoArn', 'string', r'^arn(:[a-z0-9]+([.-][a-z0-9]+)*):geo(:([a-z0-9]+([.-][a-z0-9]+)*))(:[0-9]+):((\*)|([-a-z]+[/][*-._\w]+))$', 0, 1600)
        self.add_api_object('GeoArn', self.GeoArn)
        self.GetMapGlyphsRequestFontUnicodeRangeString = APIObject('GetMapGlyphsRequestFontUnicodeRangeString', 'string', r'^[0-9]+-[0-9]+\.pbf$', None, None)
        self.add_api_object('GetMapGlyphsRequestFontUnicodeRangeString', self.GetMapGlyphsRequestFontUnicodeRangeString)
        self.GetMapSpritesRequestFileNameString = APIObject('GetMapSpritesRequestFileNameString', 'string', r'^sprites(@2x)?\.(png|json)$', None, None)
        self.add_api_object('GetMapSpritesRequestFileNameString', self.GetMapSpritesRequestFileNameString)
        self.GetMapTileRequestXString = APIObject('GetMapTileRequestXString', 'string', r'\d+', None, None)
        self.add_api_object('GetMapTileRequestXString', self.GetMapTileRequestXString)
        self.GetMapTileRequestYString = APIObject('GetMapTileRequestYString', 'string', r'\d+', None, None)
        self.add_api_object('GetMapTileRequestYString', self.GetMapTileRequestYString)
        self.GetMapTileRequestZString = APIObject('GetMapTileRequestZString', 'string', r'\d+', None, None)
        self.add_api_object('GetMapTileRequestZString', self.GetMapTileRequestZString)
        self.Id = APIObject('Id', 'string', r'^[-._\p{L}\p{N}]+$', 1, 100)
        self.add_api_object('Id', self.Id)
        self.MapStyle = APIObject('MapStyle', 'string', r'^[-._\w]+$', 1, 100)
        self.add_api_object('MapStyle', self.MapStyle)
        self.RefererPattern = APIObject('RefererPattern', 'string', r'^([$\-._+!*\x{60}(),;/?:@=&\w]|%([0-9a-fA-F?]{2}|[0-9a-fA-F?]?[*]))+$', 0, 253)
        self.add_api_object('RefererPattern', self.RefererPattern)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[-._\w]+$', 1, 100)
        self.add_api_object('ResourceName', self.ResourceName)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[A-Za-z0-9 _=@:.+-/]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Logs(Service):
    def __init__(self):
        super().__init__('Logs')
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'[\w+=/:,.@-]*', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.AnomalyDetectorArn = APIObject('AnomalyDetectorArn', 'string', r'[\w#+=/:,.@-]*', 1, None)
        self.add_api_object('AnomalyDetectorArn', self.AnomalyDetectorArn)
        self.ClientToken = APIObject('ClientToken', 'string', r'\S{36,128}', 36, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DeliveryDestinationName = APIObject('DeliveryDestinationName', 'string', r'[\w-]*', 1, 60)
        self.add_api_object('DeliveryDestinationName', self.DeliveryDestinationName)
        self.DeliveryId = APIObject('DeliveryId', 'string', r'^[0-9A-Za-z]+$', 1, 64)
        self.add_api_object('DeliveryId', self.DeliveryId)
        self.DeliverySourceName = APIObject('DeliverySourceName', 'string', r'[\w-]*', 1, 60)
        self.add_api_object('DeliverySourceName', self.DeliverySourceName)
        self.DestinationName = APIObject('DestinationName', 'string', r'[^:*]*', 1, 512)
        self.add_api_object('DestinationName', self.DestinationName)
        self.FilterName = APIObject('FilterName', 'string', r'[^:*]*', 1, 512)
        self.add_api_object('FilterName', self.FilterName)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'[\w#+=/:,.@-]*', 1, 2048)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.LogGroupIdentifier = APIObject('LogGroupIdentifier', 'string', r'[\w#+=/:,.@-]*', 1, 2048)
        self.add_api_object('LogGroupIdentifier', self.LogGroupIdentifier)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.LogGroupNamePattern = APIObject('LogGroupNamePattern', 'string', r'[\.\-_/#A-Za-z0-9]*', 0, 512)
        self.add_api_object('LogGroupNamePattern', self.LogGroupNamePattern)
        self.LogStreamName = APIObject('LogStreamName', 'string', r'[^:*]*', 1, 512)
        self.add_api_object('LogStreamName', self.LogStreamName)
        self.LogType = APIObject('LogType', 'string', r'[\w]*', 1, 255)
        self.add_api_object('LogType', self.LogType)
        self.MetricName = APIObject('MetricName', 'string', r'[^:*$]*', None, 255)
        self.add_api_object('MetricName', self.MetricName)
        self.MetricNamespace = APIObject('MetricNamespace', 'string', r'[^:*$]*', None, 255)
        self.add_api_object('MetricNamespace', self.MetricNamespace)
        self.ResourceIdentifier = APIObject('ResourceIdentifier', 'string', r'[\w+=/:,.@\-\*]*', 1, 2048)
        self.add_api_object('ResourceIdentifier', self.ResourceIdentifier)
        self.Service = APIObject('Service', 'string', r'[\w]*', 1, 255)
        self.add_api_object('Service', self.Service)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]+)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', None, 256)
        self.add_api_object('TagValue', self.TagValue)

class Lookoutequipment(Service):
    def __init__(self):
        super().__init__('Lookoutequipment')
        self.BoundedLengthString = APIObject('BoundedLengthString', 'string', r'[\P{M}\p{M}]{1,5000}', 1, 5000)
        self.add_api_object('BoundedLengthString', self.BoundedLengthString)
        self.Comments = APIObject('Comments', 'string', r'[\P{M}\p{M}]{1,2560}', 1, 2560)
        self.add_api_object('Comments', self.Comments)
        self.ComponentName = APIObject('ComponentName', 'string', r'^[0-9a-zA-Z._\-]{1,200}$', 1, 200)
        self.add_api_object('ComponentName', self.ComponentName)
        self.ComponentTimestampDelimiter = APIObject('ComponentTimestampDelimiter', 'string', r'^(\-|\_|\s)?$', 0, 1)
        self.add_api_object('ComponentTimestampDelimiter', self.ComponentTimestampDelimiter)
        self.DatasetArn = APIObject('DatasetArn', 'string', r'arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:dataset\/[0-9a-zA-Z_-]{1,200}\/.+', 20, 2048)
        self.add_api_object('DatasetArn', self.DatasetArn)
        self.DatasetIdentifier = APIObject('DatasetIdentifier', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('DatasetIdentifier', self.DatasetIdentifier)
        self.DatasetName = APIObject('DatasetName', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('DatasetName', self.DatasetName)
        self.Equipment = APIObject('Equipment', 'string', r'[\P{M}\p{M}]{1,200}', 1, 200)
        self.add_api_object('Equipment', self.Equipment)
        self.FaultCode = APIObject('FaultCode', 'string', r'[\P{M}\p{M}]{1,100}', 1, 100)
        self.add_api_object('FaultCode', self.FaultCode)
        self.FileNameTimestampFormat = APIObject('FileNameTimestampFormat', 'string', r'^EPOCH|yyyy-MM-dd-HH-mm-ss|yyyyMMddHHmmss$', None, None)
        self.add_api_object('FileNameTimestampFormat', self.FileNameTimestampFormat)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IdempotenceToken = APIObject('IdempotenceToken', 'string', r'\p{ASCII}{1,256}', 1, 256)
        self.add_api_object('IdempotenceToken', self.IdempotenceToken)
        self.InferenceSchedulerArn = APIObject('InferenceSchedulerArn', 'string', r'arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:inference-scheduler\/.+', 20, 2048)
        self.add_api_object('InferenceSchedulerArn', self.InferenceSchedulerArn)
        self.InferenceSchedulerIdentifier = APIObject('InferenceSchedulerIdentifier', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('InferenceSchedulerIdentifier', self.InferenceSchedulerIdentifier)
        self.InferenceSchedulerName = APIObject('InferenceSchedulerName', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('InferenceSchedulerName', self.InferenceSchedulerName)
        self.IngestionJobId = APIObject('IngestionJobId', 'string', r'[A-Fa-f0-9]{0,32}', None, 32)
        self.add_api_object('IngestionJobId', self.IngestionJobId)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws[a-z\-]*:kms:[a-z0-9\-]*:\d{12}:[\w\-\/]+', 1, 1024)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LabelGroupArn = APIObject('LabelGroupArn', 'string', r'arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:label-group\/.+', 20, 2048)
        self.add_api_object('LabelGroupArn', self.LabelGroupArn)
        self.LabelGroupName = APIObject('LabelGroupName', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('LabelGroupName', self.LabelGroupName)
        self.LabelId = APIObject('LabelId', 'string', r'[A-Fa-f0-9]{0,32}', None, 32)
        self.add_api_object('LabelId', self.LabelId)
        self.LookbackWindow = APIObject('LookbackWindow', 'string', r'^P180D$|^P360D$|^P540D$|^P720D$', None, None)
        self.add_api_object('LookbackWindow', self.LookbackWindow)
        self.ModelArn = APIObject('ModelArn', 'string', r'arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:model\/.+', 20, 2048)
        self.add_api_object('ModelArn', self.ModelArn)
        self.ModelName = APIObject('ModelName', 'string', r'^[0-9a-zA-Z_-]{1,200}$', 1, 200)
        self.add_api_object('ModelName', self.ModelName)
        self.ModelVersionArn = APIObject('ModelVersionArn', 'string', r'^arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:model\/[0-9a-zA-Z_-]{1,200}\/.+\/model-version\/[0-9]{1,}$', 20, 2048)
        self.add_api_object('ModelVersionArn', self.ModelVersionArn)
        self.NameOrArn = APIObject('NameOrArn', 'string', r'^[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,2048}$', 1, 2048)
        self.add_api_object('NameOrArn', self.NameOrArn)
        self.NextToken = APIObject('NextToken', 'string', r'\p{ASCII}{0,8192}', None, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.Policy = APIObject('Policy', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 20000)
        self.add_api_object('Policy', self.Policy)
        self.PolicyRevisionId = APIObject('PolicyRevisionId', 'string', r'[0-9A-Fa-f]+', None, 50)
        self.add_api_object('PolicyRevisionId', self.PolicyRevisionId)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws(-[^:]+)?:lookoutequipment:[a-zA-Z0-9\-]*:[0-9]{12}:.+', 20, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RetrainingFrequency = APIObject('RetrainingFrequency', 'string', r'^P(\dY)?(\d{1,2}M)?(\d{1,3}D)?$', 1, 10)
        self.add_api_object('RetrainingFrequency', self.RetrainingFrequency)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]$', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'[\P{M}\p{M}]{1,1024}[^/]$', 1, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.S3Prefix = APIObject('S3Prefix', 'string', r'(^$)|([\u0009\u000A\u000D\u0020-\u00FF]{1,1023}/$)', 0, 1024)
        self.add_api_object('S3Prefix', self.S3Prefix)
        self.SensorName = APIObject('SensorName', 'string', r'^[0-9a-zA-Z:#$.\-_]{1,200}$', 1, 200)
        self.add_api_object('SensorName', self.SensorName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\w+-=\.:/@]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TimeZoneOffset = APIObject('TimeZoneOffset', 'string', r'^(\+|\-)[0-9]{2}\:[0-9]{2}$', None, None)
        self.add_api_object('TimeZoneOffset', self.TimeZoneOffset)

class Lookoutmetrics(Service):
    def __init__(self):
        super().__init__('Lookoutmetrics')
        self.AlertDescription = APIObject('AlertDescription', 'string', r'.*\S.*', None, 256)
        self.add_api_object('AlertDescription', self.AlertDescription)
        self.AlertName = APIObject('AlertName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('AlertName', self.AlertName)
        self.AnomalyDetectionTaskStatusMessage = APIObject('AnomalyDetectionTaskStatusMessage', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('AnomalyDetectionTaskStatusMessage', self.AnomalyDetectionTaskStatusMessage)
        self.AnomalyDetectorDescription = APIObject('AnomalyDetectorDescription', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('AnomalyDetectorDescription', self.AnomalyDetectorDescription)
        self.AnomalyDetectorName = APIObject('AnomalyDetectorName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('AnomalyDetectorName', self.AnomalyDetectorName)
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):.*:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.AthenaDataCatalog = APIObject('AthenaDataCatalog', 'string', r'[\u0020-\uD7FF\uE000-\uFFFD\uD800\uDC00-\uDBFF\uDFFF\t]*', 1, 256)
        self.add_api_object('AthenaDataCatalog', self.AthenaDataCatalog)
        self.AthenaDatabaseName = APIObject('AthenaDatabaseName', 'string', r'[a-zA-Z0-9_]+', 1, 255)
        self.add_api_object('AthenaDatabaseName', self.AthenaDatabaseName)
        self.AthenaS3ResultsPath = APIObject('AthenaS3ResultsPath', 'string', r'^s3://[a-z0-9].+$', None, 1024)
        self.add_api_object('AthenaS3ResultsPath', self.AthenaS3ResultsPath)
        self.AthenaTableName = APIObject('AthenaTableName', 'string', r'[a-zA-Z0-9_]+', 1, 128)
        self.add_api_object('AthenaTableName', self.AthenaTableName)
        self.AthenaWorkGroupName = APIObject('AthenaWorkGroupName', 'string', r'[a-zA-Z0-9._-]{1,128}', 1, 128)
        self.add_api_object('AthenaWorkGroupName', self.AthenaWorkGroupName)
        self.Charset = APIObject('Charset', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', None, 63)
        self.add_api_object('Charset', self.Charset)
        self.ColumnName = APIObject('ColumnName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('ColumnName', self.ColumnName)
        self.DataQualityMetricDescription = APIObject('DataQualityMetricDescription', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('DataQualityMetricDescription', self.DataQualityMetricDescription)
        self.DatabaseHost = APIObject('DatabaseHost', 'string', r'.*\S.*', 1, 253)
        self.add_api_object('DatabaseHost', self.DatabaseHost)
        self.DateTimeFormat = APIObject('DateTimeFormat', 'string', r'.*\S.*', None, 63)
        self.add_api_object('DateTimeFormat', self.DateTimeFormat)
        self.Delimiter = APIObject('Delimiter', 'string', r'[^\r\n]', None, 1)
        self.add_api_object('Delimiter', self.Delimiter)
        self.FlowName = APIObject('FlowName', 'string', r'[a-zA-Z0-9][\w!@#.-]+', None, 256)
        self.add_api_object('FlowName', self.FlowName)
        self.HistoricalDataPath = APIObject('HistoricalDataPath', 'string', r'^s3://[a-z0-9].+$', None, 1024)
        self.add_api_object('HistoricalDataPath', self.HistoricalDataPath)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws.*:kms:.*:[0-9]{12}:key/[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.MetricName = APIObject('MetricName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', None, 256)
        self.add_api_object('MetricName', self.MetricName)
        self.MetricSetDescription = APIObject('MetricSetDescription', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('MetricSetDescription', self.MetricSetDescription)
        self.MetricSetName = APIObject('MetricSetName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('MetricSetName', self.MetricSetName)
        self.Namespace = APIObject('Namespace', 'string', r'[^:].*', 1, 255)
        self.add_api_object('Namespace', self.Namespace)
        self.NextToken = APIObject('NextToken', 'string', r'.*\S.*', 1, 3000)
        self.add_api_object('NextToken', self.NextToken)
        self.PoirotSecretManagerArn = APIObject('PoirotSecretManagerArn', 'string', r'arn:([a-z\d-]+):.*:.*:secret:AmazonLookoutMetrics-.+', None, 256)
        self.add_api_object('PoirotSecretManagerArn', self.PoirotSecretManagerArn)
        self.QuoteSymbol = APIObject('QuoteSymbol', 'string', r'[^\r\n]|^$', None, 1)
        self.add_api_object('QuoteSymbol', self.QuoteSymbol)
        self.RDSDatabaseIdentifier = APIObject('RDSDatabaseIdentifier', 'string', r'^[a-zA-Z](?!.*--)(?!.*-$)[0-9a-zA-Z\-]*$', 1, 63)
        self.add_api_object('RDSDatabaseIdentifier', self.RDSDatabaseIdentifier)
        self.RDSDatabaseName = APIObject('RDSDatabaseName', 'string', r'[a-zA-Z0-9_.]+', 1, 64)
        self.add_api_object('RDSDatabaseName', self.RDSDatabaseName)
        self.RedshiftClusterIdentifier = APIObject('RedshiftClusterIdentifier', 'string', r'^[a-z](?!.*--)(?!.*-$)[0-9a-z\-]*$', 1, 63)
        self.add_api_object('RedshiftClusterIdentifier', self.RedshiftClusterIdentifier)
        self.RedshiftDatabaseName = APIObject('RedshiftDatabaseName', 'string', r'[a-zA-Z0-9_.]+', 1, 100)
        self.add_api_object('RedshiftDatabaseName', self.RedshiftDatabaseName)
        self.RelatedColumnName = APIObject('RelatedColumnName', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('RelatedColumnName', self.RelatedColumnName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'[-0-9a-zA-Z]+', 1, 255)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'[\-0-9a-zA-Z]+', None, 255)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TableName = APIObject('TableName', 'string', r'^[a-zA-Z][a-zA-Z0-9_.]*$', 1, 100)
        self.add_api_object('TableName', self.TableName)
        self.TemplatedPath = APIObject('TemplatedPath', 'string', r'^s3://[a-zA-Z0-9_\-\/ {}=]+$', None, 1024)
        self.add_api_object('TemplatedPath', self.TemplatedPath)
        self.TimeSeriesId = APIObject('TimeSeriesId', 'string', r'.*\S.*', None, 520)
        self.add_api_object('TimeSeriesId', self.TimeSeriesId)
        self.TimestampString = APIObject('TimestampString', 'string', r'^([12]\d{3})-(1[0-2]|0[1-9])-(0[1-9]|[12]\d|3[01])T([01]\d|2[0-3]):([0-5]\d):([0-5]\d)(Z|(\+|\-)(0\d|1[0-2]):([0-5]\d)(\[[[:alnum:]\/\_]+\])?)$', None, 60)
        self.add_api_object('TimestampString', self.TimestampString)
        self.Timezone = APIObject('Timezone', 'string', r'.*\S.*', None, 60)
        self.add_api_object('Timezone', self.Timezone)
        self.UUID = APIObject('UUID', 'string', r'[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}', None, 63)
        self.add_api_object('UUID', self.UUID)

class Lookoutvision(Service):
    def __init__(self):
        super().__init__('Lookoutvision')
        self.AnomalyClassFilter = APIObject('AnomalyClassFilter', 'string', r'(normal|anomaly)', 1, 10)
        self.add_api_object('AnomalyClassFilter', self.AnomalyClassFilter)
        self.AnomalyName = APIObject('AnomalyName', 'string', r'[a-zA-Z0-9]*', 1, 256)
        self.add_api_object('AnomalyName', self.AnomalyName)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.Color = APIObject('Color', 'string', r'\#[a-zA-Z0-9]{6}', 7, 7)
        self.add_api_object('Color', self.Color)
        self.CompilerOptions = APIObject('CompilerOptions', 'string', r'.*', 3, 1024)
        self.add_api_object('CompilerOptions', self.CompilerOptions)
        self.ComponentDescription = APIObject('ComponentDescription', 'string', r'[a-zA-Z0-9-_. ()\':,;?]+', 1, 256)
        self.add_api_object('ComponentDescription', self.ComponentDescription)
        self.ComponentName = APIObject('ComponentName', 'string', r'[a-zA-Z0-9-_.]+', 1, 128)
        self.add_api_object('ComponentName', self.ComponentName)
        self.ComponentVersion = APIObject('ComponentVersion', 'string', r'^([0-9]{1,6})\.([0-9]{1,6})\.([0-9]{1,6})$', 1, 64)
        self.add_api_object('ComponentVersion', self.ComponentVersion)
        self.ComponentVersionArn = APIObject('ComponentVersionArn', 'string', r'arn:[^:]*:greengrass:[^:]*:aws:components:[^:]+', None, None)
        self.add_api_object('ComponentVersionArn', self.ComponentVersionArn)
        self.ContentType = APIObject('ContentType', 'string', r'.*', 1, 255)
        self.add_api_object('ContentType', self.ContentType)
        self.DatasetEntry = APIObject('DatasetEntry', 'string', r'^\{.*\}$', 2, 8192)
        self.add_api_object('DatasetEntry', self.DatasetEntry)
        self.DatasetType = APIObject('DatasetType', 'string', r'train|test', 1, 10)
        self.add_api_object('DatasetType', self.DatasetType)
        self.ImageSourceType = APIObject('ImageSourceType', 'string', r'direct', None, None)
        self.add_api_object('ImageSourceType', self.ImageSourceType)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,2048}$', 1, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.ModelDescriptionMessage = APIObject('ModelDescriptionMessage', 'string', r'[0-9A-Za-z\.\-_]*', 1, 500)
        self.add_api_object('ModelDescriptionMessage', self.ModelDescriptionMessage)
        self.ModelPackagingJobDescription = APIObject('ModelPackagingJobDescription', 'string', r'[a-zA-Z0-9-_. ()\':,;?]+', 1, 256)
        self.add_api_object('ModelPackagingJobDescription', self.ModelPackagingJobDescription)
        self.ModelPackagingJobName = APIObject('ModelPackagingJobName', 'string', r'[a-zA-Z0-9-]+', 1, 64)
        self.add_api_object('ModelPackagingJobName', self.ModelPackagingJobName)
        self.ModelPackagingMethod = APIObject('ModelPackagingMethod', 'string', r'^[a-zA-Z0-9]+', 1, 32)
        self.add_api_object('ModelPackagingMethod', self.ModelPackagingMethod)
        self.ModelVersion = APIObject('ModelVersion', 'string', r'([1-9][0-9]*|latest)', 1, 10)
        self.add_api_object('ModelVersion', self.ModelVersion)
        self.ModelVersionNoLatest = APIObject('ModelVersionNoLatest', 'string', r'([1-9][0-9]*)', 1, 10)
        self.add_api_object('ModelVersionNoLatest', self.ModelVersionNoLatest)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[a-zA-Z0-9\/\+\=]{0,2048}$', None, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ProjectName = APIObject('ProjectName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_\-]*', 1, 255)
        self.add_api_object('ProjectName', self.ProjectName)
        self.QueryString = APIObject('QueryString', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('QueryString', self.QueryString)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[0-9A-Za-z\.\-_]*', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3KeyPrefix = APIObject('S3KeyPrefix', 'string', r'^([a-zA-Z0-9!_.*\'()-][/a-zA-Z0-9!_.*\'()-]*)?$', None, 1024)
        self.add_api_object('S3KeyPrefix', self.S3KeyPrefix)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'^([a-zA-Z0-9!_.*\'()-][/a-zA-Z0-9!_.*\'()-]*)?$', 1, 1024)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.S3ObjectVersion = APIObject('S3ObjectVersion', 'string', r'.*', 1, 1024)
        self.add_api_object('S3ObjectVersion', self.S3ObjectVersion)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class M2(Service):
    def __init__(self):
        super().__init__('M2')
        self.Arn = APIObject('Arn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-[a-z]{1}|aws-us-gov):[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:([a-z]{2}-((iso[a-z]{0,1}-)|(gov-)){0,1}[a-z]+-[0-9]|):[0-9]{12}:[A-Za-z0-9/][A-Za-z0-9:_/+=,@.-]{0,1023}$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.BatchParamKey = APIObject('BatchParamKey', 'string', r'^[A-Za-z][A-Za-z0-9]{1,7}$', 1, 32)
        self.add_api_object('BatchParamKey', self.BatchParamKey)
        self.EngineVersion = APIObject('EngineVersion', 'string', r'^\S{1,10}$', None, None)
        self.add_api_object('EngineVersion', self.EngineVersion)
        self.EntityName = APIObject('EntityName', 'string', r'^[A-Za-z0-9][A-Za-z0-9_\-]{1,59}$', None, None)
        self.add_api_object('EntityName', self.EntityName)
        self.Identifier = APIObject('Identifier', 'string', r'^\S{1,80}$', None, None)
        self.add_api_object('Identifier', self.Identifier)
        self.NextToken = APIObject('NextToken', 'string', r'^\S{1,2000}$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.String100 = APIObject('String100', 'string', r'^\S{1,100}$', None, None)
        self.add_api_object('String100', self.String100)
        self.String20 = APIObject('String20', 'string', r'^\S{1,20}$', None, None)
        self.add_api_object('String20', self.String20)
        self.String200 = APIObject('String200', 'string', r'^\S{1,200}$', None, None)
        self.add_api_object('String200', self.String200)
        self.String2000 = APIObject('String2000', 'string', r'^\S{1,2000}$', None, None)
        self.add_api_object('String2000', self.String2000)
        self.String50 = APIObject('String50', 'string', r'^\S{1,50}$', None, None)
        self.add_api_object('String50', self.String50)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:).+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Machinelearning(Service):
    def __init__(self):
        super().__init__('Machinelearning')
        self.AwsUserArn = APIObject('AwsUserArn', 'string', r'arn:aws:iam::[0-9]+:((user/.+)|(root))', None, None)
        self.add_api_object('AwsUserArn', self.AwsUserArn)
        self.ComparatorValue = APIObject('ComparatorValue', 'string', r'.*\S.*|^$', None, 1024)
        self.add_api_object('ComparatorValue', self.ComparatorValue)
        self.EntityId = APIObject('EntityId', 'string', r'[a-zA-Z0-9_.-]+', 1, 64)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityName = APIObject('EntityName', 'string', r'.*\S.*|^$', None, 1024)
        self.add_api_object('EntityName', self.EntityName)
        self.RDSInstanceIdentifier = APIObject('RDSInstanceIdentifier', 'string', r'[a-z0-9-]+', 1, 63)
        self.add_api_object('RDSInstanceIdentifier', self.RDSInstanceIdentifier)
        self.RedshiftClusterIdentifier = APIObject('RedshiftClusterIdentifier', 'string', r'[a-z0-9-]+', 1, 63)
        self.add_api_object('RedshiftClusterIdentifier', self.RedshiftClusterIdentifier)
        self.RedshiftDatabaseName = APIObject('RedshiftDatabaseName', 'string', r'[a-z0-9]+', 1, 64)
        self.add_api_object('RedshiftDatabaseName', self.RedshiftDatabaseName)
        self.S3Url = APIObject('S3Url', 'string', r's3://([^/]+)(/.*)?', None, 2048)
        self.add_api_object('S3Url', self.S3Url)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.VipURL = APIObject('VipURL', 'string', r'https://[a-zA-Z0-9-.]*\.amazon(aws)?\.com[/]?', None, 2048)
        self.add_api_object('VipURL', self.VipURL)

class Macie2(Service):
    def __init__(self):
        super().__init__('Macie2')
        self.ClassificationScopeId = APIObject('ClassificationScopeId', 'string', r'^[0-9a-z]*$', None, None)
        self.add_api_object('ClassificationScopeId', self.ClassificationScopeId)
        self.ClassificationScopeName = APIObject('ClassificationScopeName', 'string', r'^[0-9a-zA-Z_\\-]*$', None, None)
        self.add_api_object('ClassificationScopeName', self.ClassificationScopeName)
        self.NextToken = APIObject('NextToken', 'string', r'^.*$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[A-Za-z0-9.\-_]{3,255}$', None, None)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.stringMin1Max1024PatternSS = APIObject('stringMin1Max1024PatternSS', 'string', r'^[\s\S]+$', 1, 1024)
        self.add_api_object('stringMin1Max1024PatternSS', self.stringMin1Max1024PatternSS)
        self.stringMin1Max128Pattern = APIObject('stringMin1Max128Pattern', 'string', r'^.+$', 1, 128)
        self.add_api_object('stringMin1Max128Pattern', self.stringMin1Max128Pattern)
        self.stringMin1Max512PatternSS = APIObject('stringMin1Max512PatternSS', 'string', r'^[\s\S]+$', 1, 512)
        self.add_api_object('stringMin1Max512PatternSS', self.stringMin1Max512PatternSS)
        self.stringMin1Max64PatternW = APIObject('stringMin1Max64PatternW', 'string', r'^[\w+=,.@-]*$', 1, 64)
        self.add_api_object('stringMin1Max64PatternW', self.stringMin1Max64PatternW)
        self.stringMin22Max22PatternAZ0922 = APIObject('stringMin22Max22PatternAZ0922', 'string', r'^[a-z0-9]{22}$', 22, 22)
        self.add_api_object('stringMin22Max22PatternAZ0922', self.stringMin22Max22PatternAZ0922)
        self.stringMin3Max255PatternAZaZ093255 = APIObject('stringMin3Max255PatternAZaZ093255', 'string', r'^[A-Za-z0-9.\-_]{3,255}$', 3, 255)
        self.add_api_object('stringMin3Max255PatternAZaZ093255', self.stringMin3Max255PatternAZaZ093255)
        self.stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922 = APIObject('stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922', 'string', r'^arn:(aws|aws-cn|aws-us-gov):macie2:[a-z1-9-]{9,20}:\d{12}:allow-list\/[a-z0-9]{22}$', 71, 89)
        self.add_api_object('stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922', self.stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922)

class ManagedblockchainQuery(Service):
    def __init__(self):
        super().__init__('ManagedblockchainQuery')
        self.BlockHash = APIObject('BlockHash', 'string', r'(0x[A-Fa-f0-9]{64}|[A-Fa-f0-9]{64})', None, None)
        self.add_api_object('BlockHash', self.BlockHash)
        self.ChainAddress = APIObject('ChainAddress', 'string', r'[-A-Za-z0-9]{13,74}', None, None)
        self.add_api_object('ChainAddress', self.ChainAddress)
        self.QueryTokenId = APIObject('QueryTokenId', 'string', r'[a-zA-Z0-9]{1,66}', None, None)
        self.add_api_object('QueryTokenId', self.QueryTokenId)
        self.QueryTransactionHash = APIObject('QueryTransactionHash', 'string', r'(0x[A-Fa-f0-9]{64}|[A-Fa-f0-9]{64})', None, None)
        self.add_api_object('QueryTransactionHash', self.QueryTransactionHash)
        self.QueryTransactionId = APIObject('QueryTransactionId', 'string', r'(0x[A-Fa-f0-9]{64}|[A-Fa-f0-9]{64})', None, None)
        self.add_api_object('QueryTransactionId', self.QueryTransactionId)

class Managedblockchain(Service):
    def __init__(self):
        super().__init__('Managedblockchain')
        self.ArnString = APIObject('ArnString', 'string', r'^arn:.+:.+:.+:.+:.+', 1, 1011)
        self.add_api_object('ArnString', self.ArnString)
        self.NameString = APIObject('NameString', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('NameString', self.NameString)
        self.NetworkMemberNameString = APIObject('NetworkMemberNameString', 'string', r'^(?!-|[0-9])(?!.*-$)(?!.*?--)[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('NetworkMemberNameString', self.NetworkMemberNameString)
        self.PasswordString = APIObject('PasswordString', 'string', r'^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?!.*[@\'\\"/])[a-zA-Z0-9\S]*$', 8, 32)
        self.add_api_object('PasswordString', self.PasswordString)
        self.UsernameString = APIObject('UsernameString', 'string', r'^[a-zA-Z][a-zA-Z0-9]*$', 1, 16)
        self.add_api_object('UsernameString', self.UsernameString)

class MarketplaceAgreement(Service):
    def __init__(self):
        super().__init__('MarketplaceAgreement')
        self.AWSAccountId = APIObject('AWSAccountId', 'string', r'^[0-9]+$', 1, 32)
        self.add_api_object('AWSAccountId', self.AWSAccountId)
        self.AgreementResourceType = APIObject('AgreementResourceType', 'string', r'^[a-zA-Z]+$', 1, 64)
        self.add_api_object('AgreementResourceType', self.AgreementResourceType)
        self.AgreementType = APIObject('AgreementType', 'string', r'^[A-Za-z]+$', 1, 64)
        self.add_api_object('AgreementType', self.AgreementType)
        self.BoundedString = APIObject('BoundedString', 'string', r'^(.)+$', 1, 4096)
        self.add_api_object('BoundedString', self.BoundedString)
        self.Catalog = APIObject('Catalog', 'string', r'^[a-zA-Z]+$', 1, 64)
        self.add_api_object('Catalog', self.Catalog)
        self.CurrencyCode = APIObject('CurrencyCode', 'string', r'^[A-Z]+$', 3, 3)
        self.add_api_object('CurrencyCode', self.CurrencyCode)
        self.FilterName = APIObject('FilterName', 'string', r'^[A-Za-z_]+$', 1, 32)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[A-Za-z0-9+:_-]+$', 1, 64)
        self.add_api_object('FilterValue', self.FilterValue)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z0-9+/=]+$', 0, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.OfferId = APIObject('OfferId', 'string', r'^\S{1,64}$', 1, 64)
        self.add_api_object('OfferId', self.OfferId)
        self.RequestId = APIObject('RequestId', 'string', r'^[A-Za-z0-9-]+$', 1, 128)
        self.add_api_object('RequestId', self.RequestId)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[A-Za-z0-9_/-]+$', 1, 64)
        self.add_api_object('ResourceId', self.ResourceId)
        self.SortBy = APIObject('SortBy', 'string', r'^[A-Za-z_]+$', 1, 255)
        self.add_api_object('SortBy', self.SortBy)
        self.UnversionedTermType = APIObject('UnversionedTermType', 'string', r'^[A-Za-z]+$', 1, 4096)
        self.add_api_object('UnversionedTermType', self.UnversionedTermType)

class MarketplaceCatalog(Service):
    def __init__(self):
        super().__init__('MarketplaceCatalog')
        self.ARN = APIObject('ARN', 'string', r'^[a-zA-Z0-9:*/-]+$', 1, 2048)
        self.add_api_object('ARN', self.ARN)
        self.AmiProductEntityIdString = APIObject('AmiProductEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('AmiProductEntityIdString', self.AmiProductEntityIdString)
        self.AmiProductTitleString = APIObject('AmiProductTitleString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('AmiProductTitleString', self.AmiProductTitleString)
        self.BatchDescribeErrorCodeString = APIObject('BatchDescribeErrorCodeString', 'string', r'^[a-zA-Z_]+$', 1, 72)
        self.add_api_object('BatchDescribeErrorCodeString', self.BatchDescribeErrorCodeString)
        self.BatchDescribeErrorMessageContent = APIObject('BatchDescribeErrorMessageContent', 'string', r'^(.)+$', 1, 2048)
        self.add_api_object('BatchDescribeErrorMessageContent', self.BatchDescribeErrorMessageContent)
        self.Catalog = APIObject('Catalog', 'string', r'^[a-zA-Z]+$', 1, 64)
        self.add_api_object('Catalog', self.Catalog)
        self.ChangeName = APIObject('ChangeName', 'string', r'^[a-zA-Z]$', 1, 72)
        self.add_api_object('ChangeName', self.ChangeName)
        self.ChangeSetName = APIObject('ChangeSetName', 'string', r'^[\w\s+=.:@-]+$', 1, 100)
        self.add_api_object('ChangeSetName', self.ChangeSetName)
        self.ChangeType = APIObject('ChangeType', 'string', r'^[A-Z][\w]*$', 1, 255)
        self.add_api_object('ChangeType', self.ChangeType)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[!-~]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.ContainerProductEntityIdString = APIObject('ContainerProductEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('ContainerProductEntityIdString', self.ContainerProductEntityIdString)
        self.ContainerProductTitleString = APIObject('ContainerProductTitleString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ContainerProductTitleString', self.ContainerProductTitleString)
        self.DataProductEntityIdString = APIObject('DataProductEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('DataProductEntityIdString', self.DataProductEntityIdString)
        self.DataProductTitleString = APIObject('DataProductTitleString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('DataProductTitleString', self.DataProductTitleString)
        self.DateTimeISO8601 = APIObject('DateTimeISO8601', 'string', r'^([\d]{4})\-(1[0-2]|0[1-9])\-(3[01]|0[1-9]|[12][\d])T(2[0-3]|[01][\d]):([0-5][\d]):([0-5][\d])Z$', 20, 20)
        self.add_api_object('DateTimeISO8601', self.DateTimeISO8601)
        self.EntityId = APIObject('EntityId', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityNameString = APIObject('EntityNameString', 'string', r'^\\S+[\\S\\s]*', 1, 255)
        self.add_api_object('EntityNameString', self.EntityNameString)
        self.EntityType = APIObject('EntityType', 'string', r'^[a-zA-Z]+$', 1, 255)
        self.add_api_object('EntityType', self.EntityType)
        self.ErrorCodeString = APIObject('ErrorCodeString', 'string', r'^[a-zA-Z_]+$', 1, 72)
        self.add_api_object('ErrorCodeString', self.ErrorCodeString)
        self.ExceptionMessageContent = APIObject('ExceptionMessageContent', 'string', r'^(.)+$', 1, 2048)
        self.add_api_object('ExceptionMessageContent', self.ExceptionMessageContent)
        self.FilterName = APIObject('FilterName', 'string', r'^[a-zA-Z]+$', 1, 255)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValueContent = APIObject('FilterValueContent', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('FilterValueContent', self.FilterValueContent)
        self.Identifier = APIObject('Identifier', 'string', r'^[\w\-@]+$', 1, 255)
        self.add_api_object('Identifier', self.Identifier)
        self.Json = APIObject('Json', 'string', r'^[\s]*\{[\s\S]*\}[\s]*$', 2, 16384)
        self.add_api_object('Json', self.Json)
        self.NextToken = APIObject('NextToken', 'string', r'^[\w+=.:@\-\/]$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.OfferBuyerAccountsFilterWildcard = APIObject('OfferBuyerAccountsFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('OfferBuyerAccountsFilterWildcard', self.OfferBuyerAccountsFilterWildcard)
        self.OfferBuyerAccountsString = APIObject('OfferBuyerAccountsString', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('OfferBuyerAccountsString', self.OfferBuyerAccountsString)
        self.OfferEntityIdString = APIObject('OfferEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('OfferEntityIdString', self.OfferEntityIdString)
        self.OfferNameString = APIObject('OfferNameString', 'string', r'^(.)+$', 1, 150)
        self.add_api_object('OfferNameString', self.OfferNameString)
        self.OfferProductIdString = APIObject('OfferProductIdString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('OfferProductIdString', self.OfferProductIdString)
        self.OfferResaleAuthorizationIdString = APIObject('OfferResaleAuthorizationIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('OfferResaleAuthorizationIdString', self.OfferResaleAuthorizationIdString)
        self.ResaleAuthorizationEntityIdString = APIObject('ResaleAuthorizationEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('ResaleAuthorizationEntityIdString', self.ResaleAuthorizationEntityIdString)
        self.ResaleAuthorizationManufacturerAccountIdFilterWildcard = APIObject('ResaleAuthorizationManufacturerAccountIdFilterWildcard', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('ResaleAuthorizationManufacturerAccountIdFilterWildcard', self.ResaleAuthorizationManufacturerAccountIdFilterWildcard)
        self.ResaleAuthorizationManufacturerAccountIdString = APIObject('ResaleAuthorizationManufacturerAccountIdString', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('ResaleAuthorizationManufacturerAccountIdString', self.ResaleAuthorizationManufacturerAccountIdString)
        self.ResaleAuthorizationManufacturerLegalNameFilterWildcard = APIObject('ResaleAuthorizationManufacturerLegalNameFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationManufacturerLegalNameFilterWildcard', self.ResaleAuthorizationManufacturerLegalNameFilterWildcard)
        self.ResaleAuthorizationManufacturerLegalNameString = APIObject('ResaleAuthorizationManufacturerLegalNameString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationManufacturerLegalNameString', self.ResaleAuthorizationManufacturerLegalNameString)
        self.ResaleAuthorizationNameFilterWildcard = APIObject('ResaleAuthorizationNameFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationNameFilterWildcard', self.ResaleAuthorizationNameFilterWildcard)
        self.ResaleAuthorizationNameString = APIObject('ResaleAuthorizationNameString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationNameString', self.ResaleAuthorizationNameString)
        self.ResaleAuthorizationOfferExtendedStatusString = APIObject('ResaleAuthorizationOfferExtendedStatusString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationOfferExtendedStatusString', self.ResaleAuthorizationOfferExtendedStatusString)
        self.ResaleAuthorizationProductIdFilterWildcard = APIObject('ResaleAuthorizationProductIdFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationProductIdFilterWildcard', self.ResaleAuthorizationProductIdFilterWildcard)
        self.ResaleAuthorizationProductIdString = APIObject('ResaleAuthorizationProductIdString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationProductIdString', self.ResaleAuthorizationProductIdString)
        self.ResaleAuthorizationProductNameFilterWildcard = APIObject('ResaleAuthorizationProductNameFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationProductNameFilterWildcard', self.ResaleAuthorizationProductNameFilterWildcard)
        self.ResaleAuthorizationProductNameString = APIObject('ResaleAuthorizationProductNameString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationProductNameString', self.ResaleAuthorizationProductNameString)
        self.ResaleAuthorizationResellerAccountIDFilterWildcard = APIObject('ResaleAuthorizationResellerAccountIDFilterWildcard', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('ResaleAuthorizationResellerAccountIDFilterWildcard', self.ResaleAuthorizationResellerAccountIDFilterWildcard)
        self.ResaleAuthorizationResellerAccountIDString = APIObject('ResaleAuthorizationResellerAccountIDString', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('ResaleAuthorizationResellerAccountIDString', self.ResaleAuthorizationResellerAccountIDString)
        self.ResaleAuthorizationResellerLegalNameFilterWildcard = APIObject('ResaleAuthorizationResellerLegalNameFilterWildcard', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationResellerLegalNameFilterWildcard', self.ResaleAuthorizationResellerLegalNameFilterWildcard)
        self.ResaleAuthorizationResellerLegalNameString = APIObject('ResaleAuthorizationResellerLegalNameString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('ResaleAuthorizationResellerLegalNameString', self.ResaleAuthorizationResellerLegalNameString)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'^arn:[\w+=/,.@-]+:aws-marketplace:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=,.@-]+)*$', 1, 255)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[\w\-]+$', 1, 255)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourcePolicyJson = APIObject('ResourcePolicyJson', 'string', r'^[\u0009\u000A\u000D\u0020-\u00FF]+$', 1, 10240)
        self.add_api_object('ResourcePolicyJson', self.ResourcePolicyJson)
        self.SaaSProductEntityIdString = APIObject('SaaSProductEntityIdString', 'string', r'^[a-zA-Z0-9][.a-zA-Z0-9/-]+[a-zA-Z0-9]$', 1, 255)
        self.add_api_object('SaaSProductEntityIdString', self.SaaSProductEntityIdString)
        self.SaaSProductTitleString = APIObject('SaaSProductTitleString', 'string', r'^(.)+$', 1, 255)
        self.add_api_object('SaaSProductTitleString', self.SaaSProductTitleString)
        self.SortBy = APIObject('SortBy', 'string', r'^[a-zA-Z]+$', 1, 255)
        self.add_api_object('SortBy', self.SortBy)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.VisibilityValue = APIObject('VisibilityValue', 'string', r'^[a-zA-Z]+$', 1, 64)
        self.add_api_object('VisibilityValue', self.VisibilityValue)

class MarketplaceDeployment(Service):
    def __init__(self):
        super().__init__('MarketplaceDeployment')
        self.Catalog = APIObject('Catalog', 'string', r'^[a-zA-Z_-]+$', 1, 64)
        self.add_api_object('Catalog', self.Catalog)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9/_+=.:@-]+$', 32, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DeploymentParameterName = APIObject('DeploymentParameterName', 'string', r'^[a-zA-Z0-9/_+=.@-]+$', 1, 400)
        self.add_api_object('DeploymentParameterName', self.DeploymentParameterName)
        self.DeploymentParameterResourceIdentifier = APIObject('DeploymentParameterResourceIdentifier', 'string', r'^dp-[a-zA-Z0-9]+$', 1, 32)
        self.add_api_object('DeploymentParameterResourceIdentifier', self.DeploymentParameterResourceIdentifier)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^[a-zA-Z0-9:*/-]+$', 1, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[A-Za-z0-9_/-]+$', 1, 64)
        self.add_api_object('ResourceId', self.ResourceId)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z0-9/_+=.:@-]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[a-zA-Z0-9/_+=.:@-]+$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)

class MarketplaceEntitlement(Service):
    def __init__(self):
        super().__init__('MarketplaceEntitlement')
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'\S+', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)

class Marketplacecommerceanalytics(Service):
    def __init__(self):
        super().__init__('Marketplacecommerceanalytics')

class Mediaconnect(Service):
    def __init__(self):
        super().__init__('Mediaconnect')

class Mediaconvert(Service):
    def __init__(self):
        super().__init__('Mediaconvert')
        self.stringMin11Max11Pattern01D20305D205D = APIObject('stringMin11Max11Pattern01D20305D205D', 'string', r'^((([0-1]\d)|(2[0-3]))(:[0-5]\d){2}([:;][0-5]\d))$', 11, 11)
        self.add_api_object('stringMin11Max11Pattern01D20305D205D', self.stringMin11Max11Pattern01D20305D205D)
        self.stringMin14PatternS3BmpBMPPngPNGHttpsBmpBMPPngPNG = APIObject('stringMin14PatternS3BmpBMPPngPNGHttpsBmpBMPPngPNG', 'string', r'^((s3://(.*?)\.(bmp|BMP|png|PNG))|(https?://(.*?)\.(bmp|BMP|png|PNG)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3BmpBMPPngPNGHttpsBmpBMPPngPNG', self.stringMin14PatternS3BmpBMPPngPNGHttpsBmpBMPPngPNG)
        self.stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA = APIObject('stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA', 'string', r'^((s3://(.*?)\.(bmp|BMP|png|PNG|tga|TGA))|(https?://(.*?)\.(bmp|BMP|png|PNG|tga|TGA)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA', self.stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA)
        self.stringMin14PatternS3CubeCUBEHttpsCubeCUBE = APIObject('stringMin14PatternS3CubeCUBEHttpsCubeCUBE', 'string', r'^((s3://(.*?)\.(cube|CUBE))|(https?://(.*?)\.(cube|CUBE)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3CubeCUBEHttpsCubeCUBE', self.stringMin14PatternS3CubeCUBEHttpsCubeCUBE)
        self.stringMin14PatternS3Mov09PngHttpsMov09Png = APIObject('stringMin14PatternS3Mov09PngHttpsMov09Png', 'string', r'^((s3://(.*)(\.mov|[0-9]+\.png))|(https?://(.*)(\.mov|[0-9]+\.png)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3Mov09PngHttpsMov09Png', self.stringMin14PatternS3Mov09PngHttpsMov09Png)
        self.stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT = APIObject('stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT', 'string', r'^((s3://(.*?)\.(scc|SCC|ttml|TTML|dfxp|DFXP|stl|STL|srt|SRT|xml|XML|smi|SMI|vtt|VTT|webvtt|WEBVTT))|(https?://(.*?)\.(scc|SCC|ttml|TTML|dfxp|DFXP|stl|STL|srt|SRT|xml|XML|smi|SMI|vtt|VTT|webvtt|WEBVTT)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT', self.stringMin14PatternS3SccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTTHttpsSccSCCTtmlTTMLDfxpDFXPStlSTLSrtSRTXmlXMLSmiSMIVttVTTWebvttWEBVTT)
        self.stringMin14PatternS3XmlXMLHttpsXmlXML = APIObject('stringMin14PatternS3XmlXMLHttpsXmlXML', 'string', r'^((s3://(.*?)\.(xml|XML))|(https?://(.*?)\.(xml|XML)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', 14, None)
        self.add_api_object('stringMin14PatternS3XmlXMLHttpsXmlXML', self.stringMin14PatternS3XmlXMLHttpsXmlXML)
        self.stringMin16Max24PatternAZaZ0922AZaZ0916 = APIObject('stringMin16Max24PatternAZaZ0922AZaZ0916', 'string', r'^[A-Za-z0-9+\/]{22}==$|^[A-Za-z0-9+\/]{16}$', 16, 24)
        self.add_api_object('stringMin16Max24PatternAZaZ0922AZaZ0916', self.stringMin16Max24PatternAZaZ0922AZaZ0916)
        self.stringMin1Max50PatternAZAZ09 = APIObject('stringMin1Max50PatternAZAZ09', 'string', r'^[a-zA-Z0-9_\/_+=.@-]*$', 1, 50)
        self.add_api_object('stringMin1Max50PatternAZAZ09', self.stringMin1Max50PatternAZAZ09)
        self.stringMin1Max512PatternAZAZ09 = APIObject('stringMin1Max512PatternAZAZ09', 'string', r'^[a-zA-Z0-9_\/_+=.@-]*$', 1, 512)
        self.add_api_object('stringMin1Max512PatternAZAZ09', self.stringMin1Max512PatternAZAZ09)
        self.stringMin24Max512PatternAZaZ0902 = APIObject('stringMin24Max512PatternAZaZ0902', 'string', r'^[A-Za-z0-9+\/]+={0,2}$', 24, 512)
        self.add_api_object('stringMin24Max512PatternAZaZ0902', self.stringMin24Max512PatternAZaZ0902)
        self.stringMin32Max32Pattern09aFAF32 = APIObject('stringMin32Max32Pattern09aFAF32', 'string', r'^[0-9a-fA-F]{32}$', 32, 32)
        self.add_api_object('stringMin32Max32Pattern09aFAF32', self.stringMin32Max32Pattern09aFAF32)
        self.stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12 = APIObject('stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12', self.stringMin36Max36Pattern09aFAF809aFAF409aFAF409aFAF409aFAF12)
        self.stringMin3Max3Pattern1809aFAF09aEAE = APIObject('stringMin3Max3Pattern1809aFAF09aEAE', 'string', r'^[1-8][0-9a-fA-F][0-9a-eA-E]$', 3, 3)
        self.add_api_object('stringMin3Max3Pattern1809aFAF09aEAE', self.stringMin3Max3Pattern1809aFAF09aEAE)
        self.stringMin3Max3PatternAZaZ3 = APIObject('stringMin3Max3PatternAZaZ3', 'string', r'^[A-Za-z]{3}$', 3, 3)
        self.add_api_object('stringMin3Max3PatternAZaZ3', self.stringMin3Max3PatternAZaZ3)
        self.stringMin6Max8Pattern09aFAF609aFAF2 = APIObject('stringMin6Max8Pattern09aFAF609aFAF2', 'string', r'^[0-9a-fA-F]{6}([0-9a-fA-F]{2})?$', 6, 8)
        self.add_api_object('stringMin6Max8Pattern09aFAF609aFAF2', self.stringMin6Max8Pattern09aFAF609aFAF2)
        self.stringMin9Max19PatternAZ26EastWestCentralNorthSouthEastWest1912 = APIObject('stringMin9Max19PatternAZ26EastWestCentralNorthSouthEastWest1912', 'string', r'^[a-z-]{2,6}-(east|west|central|((north|south)(east|west)?))-[1-9]{1,2}$', 9, 19)
        self.add_api_object('stringMin9Max19PatternAZ26EastWestCentralNorthSouthEastWest1912', self.stringMin9Max19PatternAZ26EastWestCentralNorthSouthEastWest1912)
        self.stringPattern = APIObject('stringPattern', 'string', r'^[ -~]+$', None, None)
        self.add_api_object('stringPattern', self.stringPattern)
        self.stringPattern010920405090509092 = APIObject('stringPattern010920405090509092', 'string', r'^([01][0-9]|2[0-4]):[0-5][0-9]:[0-5][0-9][:;][0-9]{2}$', None, None)
        self.add_api_object('stringPattern010920405090509092', self.stringPattern010920405090509092)
        self.stringPattern01D20305D205D = APIObject('stringPattern01D20305D205D', 'string', r'^((([0-1]\d)|(2[0-3]))(:[0-5]\d){2}([:;][0-5]\d))$', None, None)
        self.add_api_object('stringPattern01D20305D205D', self.stringPattern01D20305D205D)
        self.stringPattern0940191020191209301 = APIObject('stringPattern0940191020191209301', 'string', r'^([0-9]{4})-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])$', None, None)
        self.add_api_object('stringPattern0940191020191209301', self.stringPattern0940191020191209301)
        self.stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12 = APIObject('stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', None, None)
        self.add_api_object('stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12', self.stringPattern09aFAF809aFAF409aFAF409aFAF409aFAF12)
        self.stringPattern0xAFaF0908190908 = APIObject('stringPattern0xAFaF0908190908', 'string', r'(^0x[A-Fa-f0-9]{0,8}$|^[1-9][0-9]{0,8}$)', None, None)
        self.add_api_object('stringPattern0xAFaF0908190908', self.stringPattern0xAFaF0908190908)
        self.stringPatternAZaZ0902 = APIObject('stringPatternAZaZ0902', 'string', r'^[A-Za-z0-9+\/]+={0,2}$', None, None)
        self.add_api_object('stringPatternAZaZ0902', self.stringPatternAZaZ0902)
        self.stringPatternAZaZ0932 = APIObject('stringPatternAZaZ0932', 'string', r'^[A-Za-z0-9]{32}$', None, None)
        self.add_api_object('stringPatternAZaZ0932', self.stringPatternAZaZ0932)
        self.stringPatternAZaZ23AZaZ = APIObject('stringPatternAZaZ23AZaZ', 'string', r'^[A-Za-z]{2,3}(-[A-Za-z-]+)?$', None, None)
        self.add_api_object('stringPatternAZaZ23AZaZ', self.stringPatternAZaZ23AZaZ)
        self.stringPatternAZaZ23AZaZ09 = APIObject('stringPatternAZaZ23AZaZ09', 'string', r'^[A-Za-z]{2,3}(-[A-Za-z0-9-]+)?$', None, None)
        self.add_api_object('stringPatternAZaZ23AZaZ09', self.stringPatternAZaZ23AZaZ09)
        self.stringPatternArnAwsUsGovAcm = APIObject('stringPatternArnAwsUsGovAcm', 'string', r'^arn:aws(-us-gov)?:acm:', None, None)
        self.add_api_object('stringPatternArnAwsUsGovAcm', self.stringPatternArnAwsUsGovAcm)
        self.stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932 = APIObject('stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932', 'string', r'^arn:aws(-us-gov|-cn)?:kms:[a-z-]{2,6}-(east|west|central|((north|south)(east|west)?))-[1-9]{1,2}:\d{12}:key/([a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}|mrk-[a-fA-F0-9]{32})$', None, None)
        self.add_api_object('stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932', self.stringPatternArnAwsUsGovCnKmsAZ26EastWestCentralNorthSouthEastWest1912D12KeyAFAF098AFAF094AFAF094AFAF094AFAF0912MrkAFAF0932)
        self.stringPatternDD = APIObject('stringPatternDD', 'string', r'^(\d+(\/\d+)*)$', None, None)
        self.add_api_object('stringPatternDD', self.stringPatternDD)
        self.stringPatternHttps = APIObject('stringPatternHttps', 'string', r'^https:\/\/', None, None)
        self.add_api_object('stringPatternHttps', self.stringPatternHttps)
        self.stringPatternHttpsD = APIObject('stringPatternHttpsD', 'string', r'^https:\/\/[^:@\/]*(:\d*)?(\/.*)?$', None, None)
        self.add_api_object('stringPatternHttpsD', self.stringPatternHttpsD)
        self.stringPatternHttpsKantarmedia = APIObject('stringPatternHttpsKantarmedia', 'string', r'^https:\/\/.*.kantarmedia.*$', None, None)
        self.add_api_object('stringPatternHttpsKantarmedia', self.stringPatternHttpsKantarmedia)
        self.stringPatternIdentityAZaZ26AZaZ09163 = APIObject('stringPatternIdentityAZaZ26AZaZ09163', 'string', r'^(identity|[A-Za-z]{2,6}(\.[A-Za-z0-9-]{1,63})+)$', None, None)
        self.add_api_object('stringPatternIdentityAZaZ26AZaZ09163', self.stringPatternIdentityAZaZ26AZaZ09163)
        self.stringPatternS3 = APIObject('stringPatternS3', 'string', r'^s3:\/\/', None, None)
        self.add_api_object('stringPatternS3', self.stringPatternS3)
        self.stringPatternS3ASSETMAPXml = APIObject('stringPatternS3ASSETMAPXml', 'string', r'^s3:\/\/.*\/(ASSETMAP.xml)?$', None, None)
        self.add_api_object('stringPatternS3ASSETMAPXml', self.stringPatternS3ASSETMAPXml)
        self.stringPatternS3Https = APIObject('stringPatternS3Https', 'string', r'^s3://([^\/]+\/+)+((([^\/]*)))|^https?://[^\/].*[^&]$', None, None)
        self.add_api_object('stringPatternS3Https', self.stringPatternS3Https)
        self.stringPatternS3TtfHttpsTtf = APIObject('stringPatternS3TtfHttpsTtf', 'string', r'^((s3://(.*?)\.(ttf))|(https?://(.*?)\.(ttf)(\?([^&=]+=[^&]+&)*[^&=]+=[^&]+)?))$', None, None)
        self.add_api_object('stringPatternS3TtfHttpsTtf', self.stringPatternS3TtfHttpsTtf)
        self.stringPatternSNManifestConfirmConditionNotificationNS = APIObject('stringPatternSNManifestConfirmConditionNotificationNS', 'string', r'^\s*<(.|\n)*ManifestConfirmConditionNotification(.|\n)*>\s*$', None, None)
        self.add_api_object('stringPatternSNManifestConfirmConditionNotificationNS', self.stringPatternSNManifestConfirmConditionNotificationNS)
        self.stringPatternSNSignalProcessingNotificationNS = APIObject('stringPatternSNSignalProcessingNotificationNS', 'string', r'^\s*<(.|\n)*SignalProcessingNotification(.|\n)*>\s*$', None, None)
        self.add_api_object('stringPatternSNSignalProcessingNotificationNS', self.stringPatternSNSignalProcessingNotificationNS)
        self.stringPatternW = APIObject('stringPatternW', 'string', r'^[\w-]+$', None, None)
        self.add_api_object('stringPatternW', self.stringPatternW)
        self.stringPatternWS = APIObject('stringPatternWS', 'string', r'^[\w\s]*$', None, None)
        self.add_api_object('stringPatternWS', self.stringPatternWS)

class Medialive(Service):
    def __init__(self):
        super().__init__('Medialive')
        self.stringPattern010920300 = APIObject('stringPattern010920300', 'string', r'^([0,1]?[0-9]|2[0-3]):00$', None, None)
        self.add_api_object('stringPattern010920300', self.stringPattern010920300)
        self.stringMin1Max2048PatternArn = APIObject('stringMin1Max2048PatternArn', 'string', r'^arn.+$', 1, 2048)
        self.add_api_object('stringMin1Max2048PatternArn', self.stringMin1Max2048PatternArn)
        self.stringMin1Max255PatternS = APIObject('stringMin1Max255PatternS', 'string', r'^[^\s]+$', 1, 255)
        self.add_api_object('stringMin1Max255PatternS', self.stringMin1Max255PatternS)
        self.stringMin7Max11PatternAws097 = APIObject('stringMin7Max11PatternAws097', 'string', r'^(aws-)?[0-9]{7}$', 7, 11)
        self.add_api_object('stringMin7Max11PatternAws097', self.stringMin7Max11PatternAws097)
        self.stringPatternArnMedialiveCloudwatchAlarmTemplate = APIObject('stringPatternArnMedialiveCloudwatchAlarmTemplate', 'string', r'^arn:.+:medialive:.+:cloudwatch-alarm-template:.+$', None, None)
        self.add_api_object('stringPatternArnMedialiveCloudwatchAlarmTemplate', self.stringPatternArnMedialiveCloudwatchAlarmTemplate)
        self.stringPatternArnMedialiveCloudwatchAlarmTemplateGroup = APIObject('stringPatternArnMedialiveCloudwatchAlarmTemplateGroup', 'string', r'^arn:.+:medialive:.+:cloudwatch-alarm-template-group:.+$', None, None)
        self.add_api_object('stringPatternArnMedialiveCloudwatchAlarmTemplateGroup', self.stringPatternArnMedialiveCloudwatchAlarmTemplateGroup)
        self.stringPatternArnMedialiveEventbridgeRuleTemplate = APIObject('stringPatternArnMedialiveEventbridgeRuleTemplate', 'string', r'^arn:.+:medialive:.+:eventbridge-rule-template:.+$', None, None)
        self.add_api_object('stringPatternArnMedialiveEventbridgeRuleTemplate', self.stringPatternArnMedialiveEventbridgeRuleTemplate)
        self.stringPatternArnMedialiveEventbridgeRuleTemplateGroup = APIObject('stringPatternArnMedialiveEventbridgeRuleTemplateGroup', 'string', r'^arn:.+:medialive:.+:eventbridge-rule-template-group:.+$', None, None)
        self.add_api_object('stringPatternArnMedialiveEventbridgeRuleTemplateGroup', self.stringPatternArnMedialiveEventbridgeRuleTemplateGroup)
        self.stringPatternArnMedialiveSignalMap = APIObject('stringPatternArnMedialiveSignalMap', 'string', r'^arn:.+:medialive:.+:signal-map:.+$', None, None)
        self.add_api_object('stringPatternArnMedialiveSignalMap', self.stringPatternArnMedialiveSignalMap)
        self.stringPatternS = APIObject('stringPatternS', 'string', r'^[^\s]+$', None, None)
        self.add_api_object('stringPatternS', self.stringPatternS)

class MediapackageVod(Service):
    def __init__(self):
        super().__init__('MediapackageVod')

class Mediapackage(Service):
    def __init__(self):
        super().__init__('Mediapackage')

class Mediapackagev2(Service):
    def __init__(self):
        super().__init__('Mediapackagev2')
        self.EncryptionConstantInitializationVectorString = APIObject('EncryptionConstantInitializationVectorString', 'string', r'[0-9a-fA-F]+', 32, 32)
        self.add_api_object('EncryptionConstantInitializationVectorString', self.EncryptionConstantInitializationVectorString)
        self.EntityTag = APIObject('EntityTag', 'string', r'[\S]+', 1, 256)
        self.add_api_object('EntityTag', self.EntityTag)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[\S]+', 1, 256)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.ManifestName = APIObject('ManifestName', 'string', r'[a-zA-Z0-9-]+', 1, 256)
        self.add_api_object('ManifestName', self.ManifestName)
        self.ResourceName = APIObject('ResourceName', 'string', r'[a-zA-Z0-9_-]+', 1, 256)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SegmentSegmentNameString = APIObject('SegmentSegmentNameString', 'string', r'[a-zA-Z0-9_-]+', 1, 256)
        self.add_api_object('SegmentSegmentNameString', self.SegmentSegmentNameString)
        self.SpekeKeyProviderResourceIdString = APIObject('SpekeKeyProviderResourceIdString', 'string', r'[0-9a-zA-Z_-]+', 1, 256)
        self.add_api_object('SpekeKeyProviderResourceIdString', self.SpekeKeyProviderResourceIdString)

class MediastoreData(Service):
    def __init__(self):
        super().__init__('MediastoreData')
        self.ContentRangePattern = APIObject('ContentRangePattern', 'string', r'^bytes=\d+\-\d+/\d+$', None, None)
        self.add_api_object('ContentRangePattern', self.ContentRangePattern)
        self.ContentType = APIObject('ContentType', 'string', r'^[\w\-\/\.\+]{1,255}$', None, None)
        self.add_api_object('ContentType', self.ContentType)
        self.ETag = APIObject('ETag', 'string', r'[0-9A-Fa-f]+', 1, 64)
        self.add_api_object('ETag', self.ETag)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'[ \w:\.\?-]+', 1, 255)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.ItemName = APIObject('ItemName', 'string', r'[A-Za-z0-9_\.\-\~]+', None, None)
        self.add_api_object('ItemName', self.ItemName)
        self.ListPathNaming = APIObject('ListPathNaming', 'string', r'/?(?:[A-Za-z0-9_\.\-\~]+/){0,10}(?:[A-Za-z0-9_\.\-\~]+)?/?', 0, 900)
        self.add_api_object('ListPathNaming', self.ListPathNaming)
        self.PathNaming = APIObject('PathNaming', 'string', r'(?:[A-Za-z0-9_\.\-\~]+/){0,10}[A-Za-z0-9_\.\-\~]+', 1, 900)
        self.add_api_object('PathNaming', self.PathNaming)
        self.RangePattern = APIObject('RangePattern', 'string', r'^bytes=(?:\d+\-\d*|\d*\-\d+)$', None, None)
        self.add_api_object('RangePattern', self.RangePattern)
        self.SHA256Hash = APIObject('SHA256Hash', 'string', r'[0-9A-Fa-f]{64}', 64, 64)
        self.add_api_object('SHA256Hash', self.SHA256Hash)

class Mediastore(Service):
    def __init__(self):
        super().__init__('Mediastore')
        self.ContainerARN = APIObject('ContainerARN', 'string', r'arn:aws:mediastore:[a-z]+-[a-z]+-\d:\d{12}:container/[\w-]{1,255}', 1, 1024)
        self.add_api_object('ContainerARN', self.ContainerARN)
        self.ContainerName = APIObject('ContainerName', 'string', r'[\w-]+', 1, 255)
        self.add_api_object('ContainerName', self.ContainerName)
        self.ContainerPolicy = APIObject('ContainerPolicy', 'string', r'[\x00-\x7F]+', 1, 8192)
        self.add_api_object('ContainerPolicy', self.ContainerPolicy)
        self.Endpoint = APIObject('Endpoint', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 255)
        self.add_api_object('Endpoint', self.Endpoint)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'[ \w:\.\?-]+', 1, 255)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.Header = APIObject('Header', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 8192)
        self.add_api_object('Header', self.Header)
        self.LifecyclePolicy = APIObject('LifecyclePolicy', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 0, 8192)
        self.add_api_object('LifecyclePolicy', self.LifecyclePolicy)
        self.ObjectGroup = APIObject('ObjectGroup', 'string', r'/?(?:[A-Za-z0-9_=:\.\-\~\*]+/){0,10}(?:[A-Za-z0-9_=:\.\-\~\*]+)?/?', 1, 900)
        self.add_api_object('ObjectGroup', self.ObjectGroup)
        self.ObjectGroupName = APIObject('ObjectGroupName', 'string', r'[a-zA-Z0-9_]+', 1, 30)
        self.add_api_object('ObjectGroupName', self.ObjectGroupName)
        self.Origin = APIObject('Origin', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 2048)
        self.add_api_object('Origin', self.Origin)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[0-9A-Za-z=/+]+', 1, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.TagKey = APIObject('TagKey', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Mediatailor(Service):
    def __init__(self):
        super().__init__('Mediatailor')

class MedicalImaging(Service):
    def __init__(self):
        super().__init__('MedicalImaging')
        self.Arn = APIObject('Arn', 'string', r'arn:aws((-us-gov)|(-iso)|(-iso-b)|(-cn))?:medical-imaging:[a-z0-9-]+:[0-9]{12}:datastore/[0-9a-z]{32}(/imageset/[0-9a-z]{32})?', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ClientToken = APIObject('ClientToken', 'string', r'[A-Za-z0-9._-]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DICOMSeriesInstanceUID = APIObject('DICOMSeriesInstanceUID', 'string', r'(?:[1-9][0-9]*|0)(\.(?:[1-9][0-9]*|0))*', 0, 64)
        self.add_api_object('DICOMSeriesInstanceUID', self.DICOMSeriesInstanceUID)
        self.DICOMStudyInstanceUID = APIObject('DICOMStudyInstanceUID', 'string', r'(?:[1-9][0-9]*|0)(\.(?:[1-9][0-9]*|0))*', 0, 64)
        self.add_api_object('DICOMStudyInstanceUID', self.DICOMStudyInstanceUID)
        self.DatastoreId = APIObject('DatastoreId', 'string', r'[0-9a-z]{32}', None, None)
        self.add_api_object('DatastoreId', self.DatastoreId)
        self.DatastoreName = APIObject('DatastoreName', 'string', r'[A-Za-z0-9._/#-]+', 1, 256)
        self.add_api_object('DatastoreName', self.DatastoreName)
        self.ImageFrameId = APIObject('ImageFrameId', 'string', r'[0-9a-z]{32}', None, None)
        self.add_api_object('ImageFrameId', self.ImageFrameId)
        self.ImageSetExternalVersionId = APIObject('ImageSetExternalVersionId', 'string', r'\d+', None, None)
        self.add_api_object('ImageSetExternalVersionId', self.ImageSetExternalVersionId)
        self.ImageSetId = APIObject('ImageSetId', 'string', r'[0-9a-z]{32}', None, None)
        self.add_api_object('ImageSetId', self.ImageSetId)
        self.JobId = APIObject('JobId', 'string', r'[0-9a-z]+', 1, 32)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'[A-Za-z0-9._/#-]+', 1, 64)
        self.add_api_object('JobName', self.JobName)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws[a-zA-Z-]{0,16}:kms:[a-z]{2}(-[a-z]{1,16}){1,3}-\d{1}:\d{12}:((key/[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12})|(alias/[a-zA-Z0-9:/_-]{1,256}))', 1, 512)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.Message = APIObject('Message', 'string', r'[\w -:]+', 1, 2048)
        self.add_api_object('Message', self.Message)
        self.NextToken = APIObject('NextToken', 'string', r'\p{ASCII}{0,8192}', 1, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', 1, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Memorydb(Service):
    def __init__(self):
        super().__init__('Memorydb')
        self.ACLName = APIObject('ACLName', 'string', r'[a-zA-Z][a-zA-Z0-9\-]*', 1, None)
        self.add_api_object('ACLName', self.ACLName)
        self.AccessString = APIObject('AccessString', 'string', r'.*\S.*', None, None)
        self.add_api_object('AccessString', self.AccessString)
        self.FilterName = APIObject('FilterName', 'string', r'.*\S.*', None, None)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValue = APIObject('FilterValue', 'string', r'.*\S.*', None, None)
        self.add_api_object('FilterValue', self.FilterValue)
        self.TargetBucket = APIObject('TargetBucket', 'string', r'^[A-Za-z0-9._-]+$', None, 255)
        self.add_api_object('TargetBucket', self.TargetBucket)
        self.UserName = APIObject('UserName', 'string', r'[a-zA-Z][a-zA-Z0-9\-]*', 1, None)
        self.add_api_object('UserName', self.UserName)

class Meteringmarketplace(Service):
    def __init__(self):
        super().__init__('Meteringmarketplace')
        self.CustomerAWSAccountId = APIObject('CustomerAWSAccountId', 'string', r'^[0-9]+$', 1, 255)
        self.add_api_object('CustomerAWSAccountId', self.CustomerAWSAccountId)
        self.CustomerIdentifier = APIObject('CustomerIdentifier', 'string', r'[\s\S]+', 1, 255)
        self.add_api_object('CustomerIdentifier', self.CustomerIdentifier)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'[\s\S]+', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.Nonce = APIObject('Nonce', 'string', r'[\s\S]*', None, 255)
        self.add_api_object('Nonce', self.Nonce)
        self.ProductCode = APIObject('ProductCode', 'string', r'^[-a-zA-Z0-9/=:_.@]*$', 1, 255)
        self.add_api_object('ProductCode', self.ProductCode)
        self.TagKey = APIObject('TagKey', 'string', r'^[a-zA-Z0-9+ -=._:\/@]+$', 1, 100)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[a-zA-Z0-9+ -=._:\/@]+$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UsageDimension = APIObject('UsageDimension', 'string', r'[\s\S]+', 1, 255)
        self.add_api_object('UsageDimension', self.UsageDimension)

class Mgh(Service):
    def __init__(self):
        super().__init__('Mgh')
        self.ApplicationId = APIObject('ApplicationId', 'string', r'^.{1,1600}$', 1, 1600)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ConfigurationId = APIObject('ConfigurationId', 'string', r'^.{1,1600}$', 1, 1600)
        self.add_api_object('ConfigurationId', self.ConfigurationId)
        self.CreatedArtifactDescription = APIObject('CreatedArtifactDescription', 'string', r'^.{0,500}$', 0, 500)
        self.add_api_object('CreatedArtifactDescription', self.CreatedArtifactDescription)
        self.CreatedArtifactName = APIObject('CreatedArtifactName', 'string', r'arn:[a-z-]+:[a-z0-9-]+:(?:[a-z0-9-]+|):(?:[0-9]{12}|):.*', 1, 1600)
        self.add_api_object('CreatedArtifactName', self.CreatedArtifactName)
        self.DiscoveredResourceDescription = APIObject('DiscoveredResourceDescription', 'string', r'^.{0,500}$', 0, 500)
        self.add_api_object('DiscoveredResourceDescription', self.DiscoveredResourceDescription)
        self.MigrationTaskName = APIObject('MigrationTaskName', 'string', r'[^:|]+', 1, 256)
        self.add_api_object('MigrationTaskName', self.MigrationTaskName)
        self.ProgressUpdateStream = APIObject('ProgressUpdateStream', 'string', r'[^/:|\000-\037]+', 1, 50)
        self.add_api_object('ProgressUpdateStream', self.ProgressUpdateStream)
        self.ResourceAttributeValue = APIObject('ResourceAttributeValue', 'string', r'^.{1,256}$', 1, 256)
        self.add_api_object('ResourceAttributeValue', self.ResourceAttributeValue)
        self.ResourceName = APIObject('ResourceName', 'string', r'^.{1,1600}$', 1, 1600)
        self.add_api_object('ResourceName', self.ResourceName)
        self.StatusDetail = APIObject('StatusDetail', 'string', r'^.{0,500}$', 0, 500)
        self.add_api_object('StatusDetail', self.StatusDetail)
        self.Token = APIObject('Token', 'string', r'^[a-zA-Z0-9\/\+\=]{0,2048}$', 0, 2048)
        self.add_api_object('Token', self.Token)

class Mgn(Service):
    def __init__(self):
        super().__init__('Mgn')
        self.AccountID = APIObject('AccountID', 'string', r'[0-9]{12,}', 12, 12)
        self.add_api_object('AccountID', self.AccountID)
        self.ActionDescription = APIObject('ActionDescription', 'string', r'^[0-9a-zA-Z ():/.,\'-_#*; ]*$', 0, 256)
        self.add_api_object('ActionDescription', self.ActionDescription)
        self.ActionID = APIObject('ActionID', 'string', r'[0-9a-zA-Z]$', 1, 64)
        self.add_api_object('ActionID', self.ActionID)
        self.ActionName = APIObject('ActionName', 'string', r'^[^\s\x00]( *[^\s\x00])*$', 1, 256)
        self.add_api_object('ActionName', self.ActionName)
        self.ApplicationDescription = APIObject('ApplicationDescription', 'string', r'^[^\x00]*$', 0, 600)
        self.add_api_object('ApplicationDescription', self.ApplicationDescription)
        self.ApplicationID = APIObject('ApplicationID', 'string', r'^app-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('ApplicationID', self.ApplicationID)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'^[^\s\x00]( *[^\s\x00])*$', 1, 256)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.CloudWatchLogGroupName = APIObject('CloudWatchLogGroupName', 'string', r'^[\.\-_/#A-Za-z0-9]+$', 1, 512)
        self.add_api_object('CloudWatchLogGroupName', self.CloudWatchLogGroupName)
        self.ConnectorArn = APIObject('ConnectorArn', 'string', r'^arn:[\w-]+:mgn:([a-z]{2}-(gov-)?[a-z]+-\d{1})?:(\d{12})?:connector\/(connector-[0-9a-zA-Z]{17})$', 27, 100)
        self.add_api_object('ConnectorArn', self.ConnectorArn)
        self.ConnectorID = APIObject('ConnectorID', 'string', r'^connector-[0-9a-zA-Z]{17}$', 27, 27)
        self.add_api_object('ConnectorID', self.ConnectorID)
        self.ConnectorName = APIObject('ConnectorName', 'string', r'^[A-Za-z0-9_-]+$', 1, 256)
        self.add_api_object('ConnectorName', self.ConnectorName)
        self.DocumentVersion = APIObject('DocumentVersion', 'string', r'^(\$DEFAULT|\$LATEST|[0-9]+)$', None, None)
        self.add_api_object('DocumentVersion', self.DocumentVersion)
        self.EC2InstanceID = APIObject('EC2InstanceID', 'string', r'^i-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('EC2InstanceID', self.EC2InstanceID)
        self.EC2LaunchConfigurationTemplateID = APIObject('EC2LaunchConfigurationTemplateID', 'string', r'^lt-[0-9a-z]{17}$', 20, 20)
        self.add_api_object('EC2LaunchConfigurationTemplateID', self.EC2LaunchConfigurationTemplateID)
        self.ExportID = APIObject('ExportID', 'string', r'^export-[0-9a-zA-Z]{17}$', 24, 24)
        self.add_api_object('ExportID', self.ExportID)
        self.ISO8601DatetimeString = APIObject('ISO8601DatetimeString', 'string', r'^[1-9][0-9]*-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]+)?Z$', 19, 32)
        self.add_api_object('ISO8601DatetimeString', self.ISO8601DatetimeString)
        self.ImportID = APIObject('ImportID', 'string', r'^import-[0-9a-zA-Z]{17}$', 24, 24)
        self.add_api_object('ImportID', self.ImportID)
        self.JmesPathString = APIObject('JmesPathString', 'string', r'^[a-zA-Z0-9_]+(\.[a-zA-Z0-9_\[\]]+)*$', 1, 1011)
        self.add_api_object('JmesPathString', self.JmesPathString)
        self.JobID = APIObject('JobID', 'string', r'^mgnjob-[0-9a-zA-Z]{17}$', 24, 24)
        self.add_api_object('JobID', self.JobID)
        self.LaunchConfigurationTemplateID = APIObject('LaunchConfigurationTemplateID', 'string', r'^lct-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('LaunchConfigurationTemplateID', self.LaunchConfigurationTemplateID)
        self.OperatingSystemString = APIObject('OperatingSystemString', 'string', r'^(linux|windows)$', None, None)
        self.add_api_object('OperatingSystemString', self.OperatingSystemString)
        self.ReplicationConfigurationTemplateID = APIObject('ReplicationConfigurationTemplateID', 'string', r'^rct-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('ReplicationConfigurationTemplateID', self.ReplicationConfigurationTemplateID)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^[a-zA-Z0-9.\-_]{1,255}$', None, None)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3Key = APIObject('S3Key', 'string', r'^[^\x00]{1,1020}\.csv$', None, None)
        self.add_api_object('S3Key', self.S3Key)
        self.SecretArn = APIObject('SecretArn', 'string', r'^arn:[\w-]+:secretsmanager:([a-z]{2}-(gov-)?[a-z]+-\d{1})?:(\d{12})?:secret:(.+)$', 20, 100)
        self.add_api_object('SecretArn', self.SecretArn)
        self.SecurityGroupID = APIObject('SecurityGroupID', 'string', r'^sg-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('SecurityGroupID', self.SecurityGroupID)
        self.SourceServerID = APIObject('SourceServerID', 'string', r'^s-[0-9a-zA-Z]{17}$', 19, 19)
        self.add_api_object('SourceServerID', self.SourceServerID)
        self.SsmDocumentName = APIObject('SsmDocumentName', 'string', r'^([A-Za-z0-9/:_\.-])+$', 3, 172)
        self.add_api_object('SsmDocumentName', self.SsmDocumentName)
        self.SsmDocumentParameterName = APIObject('SsmDocumentParameterName', 'string', r'^([A-Za-z0-9])+$', 1, 1011)
        self.add_api_object('SsmDocumentParameterName', self.SsmDocumentParameterName)
        self.SsmInstanceID = APIObject('SsmInstanceID', 'string', r'(^i-[0-9a-zA-Z]{17}$)|(^mi-[0-9a-zA-Z]{17}$)', 19, 20)
        self.add_api_object('SsmInstanceID', self.SsmInstanceID)
        self.SsmParameterStoreParameterName = APIObject('SsmParameterStoreParameterName', 'string', r'^([A-Za-z0-9_\.-])+$', 1, 1011)
        self.add_api_object('SsmParameterStoreParameterName', self.SsmParameterStoreParameterName)
        self.SubnetID = APIObject('SubnetID', 'string', r'^subnet-[0-9a-fA-F]{8,}$', 0, 255)
        self.add_api_object('SubnetID', self.SubnetID)
        self.VcenterClientID = APIObject('VcenterClientID', 'string', r'^vcc-[0-9a-zA-Z]{17}$', 21, 21)
        self.add_api_object('VcenterClientID', self.VcenterClientID)
        self.WaveDescription = APIObject('WaveDescription', 'string', r'^[^\x00]*$', 0, 600)
        self.add_api_object('WaveDescription', self.WaveDescription)
        self.WaveID = APIObject('WaveID', 'string', r'^wave-[0-9a-zA-Z]{17}$', 22, 22)
        self.add_api_object('WaveID', self.WaveID)
        self.WaveName = APIObject('WaveName', 'string', r'^[^\s\x00]( *[^\s\x00])*$', 1, 256)
        self.add_api_object('WaveName', self.WaveName)

class MigrationHubRefactorSpaces(Service):
    def __init__(self):
        super().__init__('MigrationHubRefactorSpaces')
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.ApiGatewayId = APIObject('ApiGatewayId', 'string', r'^[a-z0-9]{10}$', 10, 10)
        self.add_api_object('ApiGatewayId', self.ApiGatewayId)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'^app-[0-9A-Za-z]{10}$', 14, 14)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'^(?!app-)[a-zA-Z0-9]+[a-zA-Z0-9-_ ]+$', 3, 63)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[\x20-\x7E]{1,64}$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.Description = APIObject('Description', 'string', r'''^[a-zA-Z0-9-_\s\.\!\*\#\@\\']+$''', 1, 256)
        self.add_api_object('Description', self.Description)
        self.Ec2TagValue = APIObject('Ec2TagValue', 'string', r'^.*$', 0, 255)
        self.add_api_object('Ec2TagValue', self.Ec2TagValue)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'^env-[0-9A-Za-z]{10}$', 14, 14)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'^(?!env-)[a-zA-Z0-9]+[a-zA-Z0-9-_ ]+$', 3, 63)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^[\p{Alnum}\p{Punct}\p{Blank}]*$', 0, 255)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(:(\$LATEST|[a-zA-Z0-9-_]+))?$', 1, 2048)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z0-9/\+\=]{0,2048}$', 1, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.NlbArn = APIObject('NlbArn', 'string', r'^arn:aws:elasticloadbalancing:[a-zA-Z0-9\-]+:\w{12}:[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('NlbArn', self.NlbArn)
        self.NlbName = APIObject('NlbName', 'string', r'^(?!internal-)[a-zA-Z0-9]+[a-zA-Z0-9-_ ]+.*[^-]$', 1, 32)
        self.add_api_object('NlbName', self.NlbName)
        self.PathResourceToIdValue = APIObject('PathResourceToIdValue', 'string', r'^[a-z0-9]{10}$', 10, 10)
        self.add_api_object('PathResourceToIdValue', self.PathResourceToIdValue)
        self.PolicyString = APIObject('PolicyString', 'string', r'^.*\S.*$', 1, 300000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws:refactor-spaces:[a-zA-Z0-9\-]+:\w{12}:[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceIdentifier = APIObject('ResourceIdentifier', 'string', r'(^(env|svc|pxy|rte|app)-([0-9A-Za-z]{10}$))', 3, 63)
        self.add_api_object('ResourceIdentifier', self.ResourceIdentifier)
        self.ResourcePolicyIdentifier = APIObject('ResourcePolicyIdentifier', 'string', r'^arn:aws:refactor-spaces:[a-zA-Z0-9\-]+:\w{12}:[a-zA-Z_0-9+=,.@\-_/]+$', 20, 2048)
        self.add_api_object('ResourcePolicyIdentifier', self.ResourcePolicyIdentifier)
        self.RouteId = APIObject('RouteId', 'string', r'^rte-[0-9A-Za-z]{10}$', 14, 14)
        self.add_api_object('RouteId', self.RouteId)
        self.ServiceId = APIObject('ServiceId', 'string', r'^svc-[0-9A-Za-z]{10}$', 14, 14)
        self.add_api_object('ServiceId', self.ServiceId)
        self.ServiceName = APIObject('ServiceName', 'string', r'^(?!svc-)[a-zA-Z0-9]+[a-zA-Z0-9-_ ]+$', 3, 63)
        self.add_api_object('ServiceName', self.ServiceName)
        self.StageName = APIObject('StageName', 'string', r'^[-a-zA-Z0-9_]*$', 1, 128)
        self.add_api_object('StageName', self.StageName)
        self.TagMapKeyString = APIObject('TagMapKeyString', 'string', r'^(?!aws:).+', 1, 128)
        self.add_api_object('TagMapKeyString', self.TagMapKeyString)
        self.TransitGatewayId = APIObject('TransitGatewayId', 'string', r'^tgw-[-a-f0-9]{17}$', 21, 21)
        self.add_api_object('TransitGatewayId', self.TransitGatewayId)
        self.Uri = APIObject('Uri', 'string', r'^https?://[-a-zA-Z0-9+\x38@#/%?=~_|!:,.;]*[-a-zA-Z0-9+\x38@#/%=~_|]$', 1, 2048)
        self.add_api_object('Uri', self.Uri)
        self.UriPath = APIObject('UriPath', 'string', r'^(/([a-zA-Z0-9._:-]+|\{[a-zA-Z0-9._:-]+\}))+$', 1, 2048)
        self.add_api_object('UriPath', self.UriPath)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-[-a-f0-9]{8}([-a-f0-9]{9})?$', 12, 21)
        self.add_api_object('VpcId', self.VpcId)
        self.VpcLinkId = APIObject('VpcLinkId', 'string', r'^[a-z0-9]{10}$', 10, 10)
        self.add_api_object('VpcLinkId', self.VpcLinkId)

class MigrationhubConfig(Service):
    def __init__(self):
        super().__init__('MigrationhubConfig')
        self.ControlId = APIObject('ControlId', 'string', r'^hrc-[a-z0-9]{12}$', 1, 50)
        self.add_api_object('ControlId', self.ControlId)
        self.HomeRegion = APIObject('HomeRegion', 'string', r'^([a-z]+)-([a-z]+)-([0-9]+)$', 1, 50)
        self.add_api_object('HomeRegion', self.HomeRegion)
        self.TargetId = APIObject('TargetId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('TargetId', self.TargetId)
        self.Token = APIObject('Token', 'string', r'^[a-zA-Z0-9\/\+\=]{0,2048}$', 0, 2048)
        self.add_api_object('Token', self.Token)

class Migrationhuborchestrator(Service):
    def __init__(self):
        super().__init__('Migrationhuborchestrator')
        self.ApplicationConfigurationName = APIObject('ApplicationConfigurationName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('ApplicationConfigurationName', self.ApplicationConfigurationName)
        self.ClientToken = APIObject('ClientToken', 'string', r'[-a-zA-Z0-9]*', 1, 256)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CreateMigrationWorkflowRequestApplicationConfigurationIdString = APIObject('CreateMigrationWorkflowRequestApplicationConfigurationIdString', 'string', r'[-a-zA-Z0-9_.+]*', 0, 100)
        self.add_api_object('CreateMigrationWorkflowRequestApplicationConfigurationIdString', self.CreateMigrationWorkflowRequestApplicationConfigurationIdString)
        self.CreateMigrationWorkflowRequestDescriptionString = APIObject('CreateMigrationWorkflowRequestDescriptionString', 'string', r'[-a-zA-Z0-9_.+, ]*', 0, 500)
        self.add_api_object('CreateMigrationWorkflowRequestDescriptionString', self.CreateMigrationWorkflowRequestDescriptionString)
        self.CreateMigrationWorkflowRequestNameString = APIObject('CreateMigrationWorkflowRequestNameString', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('CreateMigrationWorkflowRequestNameString', self.CreateMigrationWorkflowRequestNameString)
        self.CreateMigrationWorkflowRequestTemplateIdString = APIObject('CreateMigrationWorkflowRequestTemplateIdString', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('CreateMigrationWorkflowRequestTemplateIdString', self.CreateMigrationWorkflowRequestTemplateIdString)
        self.CreateTemplateRequestTemplateDescriptionString = APIObject('CreateTemplateRequestTemplateDescriptionString', 'string', r'.*', 0, 250)
        self.add_api_object('CreateTemplateRequestTemplateDescriptionString', self.CreateTemplateRequestTemplateDescriptionString)
        self.CreateTemplateRequestTemplateNameString = APIObject('CreateTemplateRequestTemplateNameString', 'string', r'[ a-zA-Z0-9]*', 1, 128)
        self.add_api_object('CreateTemplateRequestTemplateNameString', self.CreateTemplateRequestTemplateNameString)
        self.IPAddress = APIObject('IPAddress', 'string', r'(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])', 0, 15)
        self.add_api_object('IPAddress', self.IPAddress)
        self.MigrationWorkflowDescription = APIObject('MigrationWorkflowDescription', 'string', r'[-a-zA-Z0-9_.+, ]*', 0, 500)
        self.add_api_object('MigrationWorkflowDescription', self.MigrationWorkflowDescription)
        self.MigrationWorkflowId = APIObject('MigrationWorkflowId', 'string', r'[a-zA-Z0-9-]+', 1, 100)
        self.add_api_object('MigrationWorkflowId', self.MigrationWorkflowId)
        self.MigrationWorkflowName = APIObject('MigrationWorkflowName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('MigrationWorkflowName', self.MigrationWorkflowName)
        self.NextToken = APIObject('NextToken', 'string', r'.*\S.*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.PluginId = APIObject('PluginId', 'string', r'.*\S.*', 1, 60)
        self.add_api_object('PluginId', self.PluginId)
        self.PluginVersion = APIObject('PluginVersion', 'string', r'.*', 0, 1024)
        self.add_api_object('PluginVersion', self.PluginVersion)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws:migrationhub-orchestrator:[a-z0-9-]+:[0-9]+:(template|workflow)/[.]*', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.StepDescription = APIObject('StepDescription', 'string', r'[-a-zA-Z0-9_.+, ]*', 0, 500)
        self.add_api_object('StepDescription', self.StepDescription)
        self.StepGroupDescription = APIObject('StepGroupDescription', 'string', r'[-a-zA-Z0-9_.+, ]*', 0, 500)
        self.add_api_object('StepGroupDescription', self.StepGroupDescription)
        self.StepGroupId = APIObject('StepGroupId', 'string', r'[a-zA-Z0-9-]+', 1, 100)
        self.add_api_object('StepGroupId', self.StepGroupId)
        self.StepGroupName = APIObject('StepGroupName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('StepGroupName', self.StepGroupName)
        self.StepId = APIObject('StepId', 'string', r'[a-zA-Z0-9-]+', 1, 100)
        self.add_api_object('StepId', self.StepId)
        self.StepInputParametersKey = APIObject('StepInputParametersKey', 'string', r'[a-zA-Z0-9-_ ()]+', 1, 100)
        self.add_api_object('StepInputParametersKey', self.StepInputParametersKey)
        self.StepName = APIObject('StepName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('StepName', self.StepName)
        self.StringMapKey = APIObject('StringMapKey', 'string', r'[a-zA-Z0-9-_ ()]+', 1, 100)
        self.add_api_object('StringMapKey', self.StringMapKey)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TemplateId = APIObject('TemplateId', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('TemplateId', self.TemplateId)
        self.TemplateInputName = APIObject('TemplateInputName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('TemplateInputName', self.TemplateInputName)
        self.TemplateName = APIObject('TemplateName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('TemplateName', self.TemplateName)
        self.UpdateMigrationWorkflowRequestDescriptionString = APIObject('UpdateMigrationWorkflowRequestDescriptionString', 'string', r'[-a-zA-Z0-9_.+, ]*', 0, 500)
        self.add_api_object('UpdateMigrationWorkflowRequestDescriptionString', self.UpdateMigrationWorkflowRequestDescriptionString)
        self.UpdateMigrationWorkflowRequestNameString = APIObject('UpdateMigrationWorkflowRequestNameString', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('UpdateMigrationWorkflowRequestNameString', self.UpdateMigrationWorkflowRequestNameString)
        self.UpdateTemplateRequestTemplateDescriptionString = APIObject('UpdateTemplateRequestTemplateDescriptionString', 'string', r'.*', 0, 250)
        self.add_api_object('UpdateTemplateRequestTemplateDescriptionString', self.UpdateTemplateRequestTemplateDescriptionString)
        self.UpdateTemplateRequestTemplateNameString = APIObject('UpdateTemplateRequestTemplateNameString', 'string', r'[ a-zA-Z0-9]*', 1, 128)
        self.add_api_object('UpdateTemplateRequestTemplateNameString', self.UpdateTemplateRequestTemplateNameString)
        self.WorkflowStepOutputName = APIObject('WorkflowStepOutputName', 'string', r'[-a-zA-Z0-9_.+]+[-a-zA-Z0-9_.+ ]*', 1, 100)
        self.add_api_object('WorkflowStepOutputName', self.WorkflowStepOutputName)

class Migrationhubstrategy(Service):
    def __init__(self):
        super().__init__('Migrationhubstrategy')
        self.ApplicationComponentId = APIObject('ApplicationComponentId', 'string', r'[0-9a-zA-Z-]+', 0, 44)
        self.add_api_object('ApplicationComponentId', self.ApplicationComponentId)
        self.AssessmentStatusMessage = APIObject('AssessmentStatusMessage', 'string', r'.*\S.*', 0, 512)
        self.add_api_object('AssessmentStatusMessage', self.AssessmentStatusMessage)
        self.AsyncTaskId = APIObject('AsyncTaskId', 'string', r'[0-9a-z-:]+', 0, 52)
        self.add_api_object('AsyncTaskId', self.AsyncTaskId)
        self.IPAddress = APIObject('IPAddress', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$', 0, 15)
        self.add_api_object('IPAddress', self.IPAddress)
        self.InterfaceName = APIObject('InterfaceName', 'string', r'.*', 0, 1024)
        self.add_api_object('InterfaceName', self.InterfaceName)
        self.ListApplicationComponentsRequestFilterValueString = APIObject('ListApplicationComponentsRequestFilterValueString', 'string', r'.*\S.*', 0, 256)
        self.add_api_object('ListApplicationComponentsRequestFilterValueString', self.ListApplicationComponentsRequestFilterValueString)
        self.Location = APIObject('Location', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('Location', self.Location)
        self.MacAddress = APIObject('MacAddress', 'string', r'^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})|([0-9a-fA-F]{4}\\.[0-9a-fA-F]{4}\\.[0-9a-fA-F]{4})$”$', 0, 17)
        self.add_api_object('MacAddress', self.MacAddress)
        self.NetMask = APIObject('NetMask', 'string', r'.*', 0, 1024)
        self.add_api_object('NetMask', self.NetMask)
        self.NextToken = APIObject('NextToken', 'string', r'.*\S.*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.OSVersion = APIObject('OSVersion', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('OSVersion', self.OSVersion)
        self.ProjectName = APIObject('ProjectName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ProjectName', self.ProjectName)
        self.RecommendationReportStatusMessage = APIObject('RecommendationReportStatusMessage', 'string', r'.*\S.*', 0, 512)
        self.add_api_object('RecommendationReportStatusMessage', self.RecommendationReportStatusMessage)
        self.RecommendationTaskId = APIObject('RecommendationTaskId', 'string', r'[0-9a-z-:]+', 0, 52)
        self.add_api_object('RecommendationTaskId', self.RecommendationTaskId)
        self.ResourceId = APIObject('ResourceId', 'string', r'^[0-9a-b]+', 0, 44)
        self.add_api_object('ResourceId', self.ResourceId)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.SecretsManagerKey = APIObject('SecretsManagerKey', 'string', r'.*', 1, 512)
        self.add_api_object('SecretsManagerKey', self.SecretsManagerKey)
        self.ServerId = APIObject('ServerId', 'string', r'.*\S.*', 1, 27)
        self.add_api_object('ServerId', self.ServerId)
        self.SourceVersion = APIObject('SourceVersion', 'string', r'.*\S.*', 1, 40)
        self.add_api_object('SourceVersion', self.SourceVersion)
        self.StartAssessmentRequestS3bucketForAnalysisDataString = APIObject('StartAssessmentRequestS3bucketForAnalysisDataString', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('StartAssessmentRequestS3bucketForAnalysisDataString', self.StartAssessmentRequestS3bucketForAnalysisDataString)
        self.StartAssessmentRequestS3bucketForReportDataString = APIObject('StartAssessmentRequestS3bucketForReportDataString', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('StartAssessmentRequestS3bucketForReportDataString', self.StartAssessmentRequestS3bucketForReportDataString)
        self.StartImportFileTaskRequestNameString = APIObject('StartImportFileTaskRequestNameString', 'string', r'[a-zA-Z0-9_-]+', 1, 50)
        self.add_api_object('StartImportFileTaskRequestNameString', self.StartImportFileTaskRequestNameString)
        self.StartImportFileTaskRequestS3bucketForReportDataString = APIObject('StartImportFileTaskRequestS3bucketForReportDataString', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('StartImportFileTaskRequestS3bucketForReportDataString', self.StartImportFileTaskRequestS3bucketForReportDataString)
        self.StatusMessage = APIObject('StatusMessage', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('StatusMessage', self.StatusMessage)
        self.String = APIObject('String', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('String', self.String)
        self.TranformationToolDescription = APIObject('TranformationToolDescription', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('TranformationToolDescription', self.TranformationToolDescription)
        self.TranformationToolInstallationLink = APIObject('TranformationToolInstallationLink', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('TranformationToolInstallationLink', self.TranformationToolInstallationLink)
        self.importS3Bucket = APIObject('importS3Bucket', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 0, 63)
        self.add_api_object('importS3Bucket', self.importS3Bucket)
        self.importS3Key = APIObject('importS3Key', 'string', r'.*\S.*', 0, 1024)
        self.add_api_object('importS3Key', self.importS3Key)

class Mobile(Service):
    def __init__(self):
        super().__init__('Mobile')

class Mq(Service):
    def __init__(self):
        super().__init__('Mq')

class Mturk(Service):
    def __init__(self):
        super().__init__('Mturk')
        self.CurrencyAmount = APIObject('CurrencyAmount', 'string', r'^[0-9]+(\.)?[0-9]{0,2}$', None, None)
        self.add_api_object('CurrencyAmount', self.CurrencyAmount)
        self.CustomerId = APIObject('CustomerId', 'string', r'^A[A-Z0-9]+$', 1, 64)
        self.add_api_object('CustomerId', self.CustomerId)
        self.EntityId = APIObject('EntityId', 'string', r'^[A-Z0-9]+$', 1, 64)
        self.add_api_object('EntityId', self.EntityId)

class Mwaa(Service):
    def __init__(self):
        super().__init__('Mwaa')
        self.AirflowVersion = APIObject('AirflowVersion', 'string', r'^[0-9a-z.]+$', 1, 32)
        self.add_api_object('AirflowVersion', self.AirflowVersion)
        self.CeleryExecutorQueue = APIObject('CeleryExecutorQueue', 'string', r'^arn:aws(-[a-z]+)?:sqs:[a-z0-9\-]+:\d{12}:[a-zA-Z_0-9+=,.@\-_/]+$', 1, 1224)
        self.add_api_object('CeleryExecutorQueue', self.CeleryExecutorQueue)
        self.CloudWatchLogGroupArn = APIObject('CloudWatchLogGroupArn', 'string', r'^arn:aws(-[a-z]+)?:logs:[a-z0-9\-]+:\d{12}:log-group:\w+', 1, 1224)
        self.add_api_object('CloudWatchLogGroupArn', self.CloudWatchLogGroupArn)
        self.ConfigKey = APIObject('ConfigKey', 'string', r'^[a-z]+([a-z0-9._]*[a-z0-9_]+)?$', 1, 64)
        self.add_api_object('ConfigKey', self.ConfigKey)
        self.ConfigValue = APIObject('ConfigValue', 'string', r'^[ -~]+$', 1, 65536)
        self.add_api_object('ConfigValue', self.ConfigValue)
        self.EnvironmentArn = APIObject('EnvironmentArn', 'string', r'^arn:aws(-[a-z]+)?:airflow:[a-z0-9\-]+:\d{12}:environment/\w+', 1, 1224)
        self.add_api_object('EnvironmentArn', self.EnvironmentArn)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'^[a-zA-Z][0-9a-zA-Z-_]*$', 1, 80)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^.+$', 1, 1024)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.Hostname = APIObject('Hostname', 'string', r'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$', 1, 255)
        self.add_api_object('Hostname', self.Hostname)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:aws(-[a-z]+)?:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', 1, 1224)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.KmsKey = APIObject('KmsKey', 'string', r'^(((arn:aws(-[a-z]+)?:kms:[a-z]{2}-[a-z]+-\d:\d+:)?key\/)?[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}|(arn:aws(-[a-z]+)?:kms:[a-z]{2}-[a-z]+-\d:\d+:)?alias/.+)$', 1, 1224)
        self.add_api_object('KmsKey', self.KmsKey)
        self.RelativePath = APIObject('RelativePath', 'string', r'.*', 1, 1024)
        self.add_api_object('RelativePath', self.RelativePath)
        self.S3BucketArn = APIObject('S3BucketArn', 'string', r'^arn:aws(-[a-z]+)?:s3:::[a-z0-9.\-]+$', 1, 1224)
        self.add_api_object('S3BucketArn', self.S3BucketArn)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-[a-zA-Z0-9\-._]+$', 1, 1024)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[a-zA-Z0-9\-._]+$', 1, 1024)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UpdateSource = APIObject('UpdateSource', 'string', r'^.+$', 1, 256)
        self.add_api_object('UpdateSource', self.UpdateSource)
        self.VpcEndpointServiceName = APIObject('VpcEndpointServiceName', 'string', r'^([a-z.-]+)?com\.amazonaws\.vpce\.[a-z0-9\-]+\.[a-zA-Z_0-9+=,.@\-_/]+$', 1, 1224)
        self.add_api_object('VpcEndpointServiceName', self.VpcEndpointServiceName)
        self.WebserverUrl = APIObject('WebserverUrl', 'string', r'^https://.+$', 1, 256)
        self.add_api_object('WebserverUrl', self.WebserverUrl)
        self.WeeklyMaintenanceWindowStart = APIObject('WeeklyMaintenanceWindowStart', 'string', r'(MON|TUE|WED|THU|FRI|SAT|SUN):([01]\d|2[0-3]):(00|30)', 1, 9)
        self.add_api_object('WeeklyMaintenanceWindowStart', self.WeeklyMaintenanceWindowStart)

class NeptuneGraph(Service):
    def __init__(self):
        super().__init__('NeptuneGraph')
        self.Arn = APIObject('Arn', 'string', r'arn:.+', 1, 1011)
        self.add_api_object('Arn', self.Arn)
        self.GraphId = APIObject('GraphId', 'string', r'g-[a-z0-9]{10}', None, None)
        self.add_api_object('GraphId', self.GraphId)
        self.GraphIdentifier = APIObject('GraphIdentifier', 'string', r'g-[a-z0-9]{10}', None, None)
        self.add_api_object('GraphIdentifier', self.GraphIdentifier)
        self.GraphName = APIObject('GraphName', 'string', r'(?!g-)[a-z][a-z0-9]*(-[a-z0-9]+)*', 1, 63)
        self.add_api_object('GraphName', self.GraphName)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws(|-cn|-us-gov):kms:[a-zA-Z0-9-]*:[0-9]{12}:key/[a-zA-Z0-9-]{36}', 1, 1024)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws[^:]*:iam::\d{12}:(role|role/service-role)/[\w+=,.@-]*', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'sg-[a-z0-9]+', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'gs-[a-z0-9]{10}', None, None)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.SnapshotIdentifier = APIObject('SnapshotIdentifier', 'string', r'gs-[a-z0-9]{10}', None, None)
        self.add_api_object('SnapshotIdentifier', self.SnapshotIdentifier)
        self.SnapshotName = APIObject('SnapshotName', 'string', r'(?!gs-)[a-z][a-z0-9]*(-[a-z0-9]+)*', 1, 63)
        self.add_api_object('SnapshotName', self.SnapshotName)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-[a-z0-9]+', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TaskId = APIObject('TaskId', 'string', r't-[a-z0-9]{10}', None, None)
        self.add_api_object('TaskId', self.TaskId)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'vpce-[0-9a-f]{17}', None, None)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-[a-z0-9]+', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Neptune(Service):
    def __init__(self):
        super().__init__('Neptune')
        self.GlobalClusterIdentifier = APIObject('GlobalClusterIdentifier', 'string', r'[A-Za-z][0-9A-Za-z-:._]*', 1, 255)
        self.add_api_object('GlobalClusterIdentifier', self.GlobalClusterIdentifier)

class Neptunedata(Service):
    def __init__(self):
        super().__init__('Neptunedata')

class NetworkFirewall(Service):
    def __init__(self):
        super().__init__('NetworkFirewall')
        self.ActionName = APIObject('ActionName', 'string', r'^[a-zA-Z0-9]+$', 1, 128)
        self.add_api_object('ActionName', self.ActionName)
        self.AddressDefinition = APIObject('AddressDefinition', 'string', r'^([a-fA-F\d:\.]+($|/\d{1,3}))$', 1, 255)
        self.add_api_object('AddressDefinition', self.AddressDefinition)
        self.AzSubnet = APIObject('AzSubnet', 'string', r'^subnet-[0-9a-f]+$', 1, 128)
        self.add_api_object('AzSubnet', self.AzSubnet)
        self.Description = APIObject('Description', 'string', r'^.*$', None, 512)
        self.add_api_object('Description', self.Description)
        self.Destination = APIObject('Destination', 'string', r'^.*$', 1, 1024)
        self.add_api_object('Destination', self.Destination)
        self.DimensionValue = APIObject('DimensionValue', 'string', r'^[a-zA-Z0-9-_ ]+$', 1, 128)
        self.add_api_object('DimensionValue', self.DimensionValue)
        self.HashMapKey = APIObject('HashMapKey', 'string', r'^[0-9A-Za-z.\-_@\/]+$', 3, 50)
        self.add_api_object('HashMapKey', self.HashMapKey)
        self.HashMapValue = APIObject('HashMapValue', 'string', r'[\s\S]*$', 1, 1024)
        self.add_api_object('HashMapValue', self.HashMapValue)
        self.IPSetReferenceName = APIObject('IPSetReferenceName', 'string', r'^[A-Za-z][A-Za-z0-9_]*$', 1, 32)
        self.add_api_object('IPSetReferenceName', self.IPSetReferenceName)
        self.KeyId = APIObject('KeyId', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('KeyId', self.KeyId)
        self.Keyword = APIObject('Keyword', 'string', r'.*', 1, 128)
        self.add_api_object('Keyword', self.Keyword)
        self.LogDestinationType = APIObject('LogDestinationType', 'string', r'[0-9A-Za-z]+', 2, 30)
        self.add_api_object('LogDestinationType', self.LogDestinationType)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[0-9A-Za-z:\/+=]+$', 1, 4096)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PolicyString = APIObject('PolicyString', 'string', r'.*\S.*', 1, 395000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.Port = APIObject('Port', 'string', r'^.*$', 1, 1024)
        self.add_api_object('Port', self.Port)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws.*', 1, 256)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'^([0-9a-f]{8})-([0-9a-f]{4}-){3}([0-9a-f]{12})$', 36, 36)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[a-zA-Z0-9-]+$', 1, 128)
        self.add_api_object('ResourceName', self.ResourceName)
        self.RuleVariableName = APIObject('RuleVariableName', 'string', r'^[A-Za-z][A-Za-z0-9_]*$', 1, 32)
        self.add_api_object('RuleVariableName', self.RuleVariableName)
        self.Setting = APIObject('Setting', 'string', r'.*', 1, 8192)
        self.add_api_object('Setting', self.Setting)
        self.Source = APIObject('Source', 'string', r'^.*$', 1, 1024)
        self.add_api_object('Source', self.Source)
        self.StatusReason = APIObject('StatusReason', 'string', r'^[a-zA-Z0-9- ]+$', 1, 256)
        self.add_api_object('StatusReason', self.StatusReason)
        self.TagKey = APIObject('TagKey', 'string', r'^.*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^.*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UpdateToken = APIObject('UpdateToken', 'string', r'^([0-9a-f]{8})-([0-9a-f]{4}-){3}([0-9a-f]{12})$', 1, 1024)
        self.add_api_object('UpdateToken', self.UpdateToken)
        self.VariableDefinition = APIObject('VariableDefinition', 'string', r'^.*$', 1, None)
        self.add_api_object('VariableDefinition', self.VariableDefinition)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-[0-9a-f]+$', 1, 128)
        self.add_api_object('VpcId', self.VpcId)

class Networkmanager(Service):
    def __init__(self):
        super().__init__('Networkmanager')
        self.AWSAccountId = APIObject('AWSAccountId', 'string', r'[\s\S]*', 12, 12)
        self.add_api_object('AWSAccountId', self.AWSAccountId)
        self.AttachmentId = APIObject('AttachmentId', 'string', r'^attachment-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('AttachmentId', self.AttachmentId)
        self.ClientToken = APIObject('ClientToken', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ConnectPeerId = APIObject('ConnectPeerId', 'string', r'^connect-peer-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('ConnectPeerId', self.ConnectPeerId)
        self.ConnectionArn = APIObject('ConnectionArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('ConnectionArn', self.ConnectionArn)
        self.ConnectionId = APIObject('ConnectionId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('ConnectionId', self.ConnectionId)
        self.ConstrainedString = APIObject('ConstrainedString', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('ConstrainedString', self.ConstrainedString)
        self.CoreNetworkArn = APIObject('CoreNetworkArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('CoreNetworkArn', self.CoreNetworkArn)
        self.CoreNetworkId = APIObject('CoreNetworkId', 'string', r'^core-network-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('CoreNetworkId', self.CoreNetworkId)
        self.CoreNetworkPolicyDocument = APIObject('CoreNetworkPolicyDocument', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('CoreNetworkPolicyDocument', self.CoreNetworkPolicyDocument)
        self.CustomerGatewayArn = APIObject('CustomerGatewayArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('CustomerGatewayArn', self.CustomerGatewayArn)
        self.DeviceArn = APIObject('DeviceArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('DeviceArn', self.DeviceArn)
        self.DeviceId = APIObject('DeviceId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('DeviceId', self.DeviceId)
        self.ExternalRegionCode = APIObject('ExternalRegionCode', 'string', r'[\s\S]*', 1, 63)
        self.add_api_object('ExternalRegionCode', self.ExternalRegionCode)
        self.FilterName = APIObject('FilterName', 'string', r'^[0-9a-zA-Z\.-]*$', None, 128)
        self.add_api_object('FilterName', self.FilterName)
        self.FilterValue = APIObject('FilterValue', 'string', r'^[0-9a-zA-Z\*\.\\/\?-]*$', None, 255)
        self.add_api_object('FilterValue', self.FilterValue)
        self.GlobalNetworkArn = APIObject('GlobalNetworkArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('GlobalNetworkArn', self.GlobalNetworkArn)
        self.GlobalNetworkId = APIObject('GlobalNetworkId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('GlobalNetworkId', self.GlobalNetworkId)
        self.IPAddress = APIObject('IPAddress', 'string', r'[\s\S]*', 1, 50)
        self.add_api_object('IPAddress', self.IPAddress)
        self.LinkArn = APIObject('LinkArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('LinkArn', self.LinkArn)
        self.LinkId = APIObject('LinkId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('LinkId', self.LinkId)
        self.NextToken = APIObject('NextToken', 'string', r'[\s\S]*', 0, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.OrganizationId = APIObject('OrganizationId', 'string', r'^o-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('OrganizationId', self.OrganizationId)
        self.PeeringId = APIObject('PeeringId', 'string', r'^peering-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('PeeringId', self.PeeringId)
        self.ReasonContextKey = APIObject('ReasonContextKey', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('ReasonContextKey', self.ReasonContextKey)
        self.ReasonContextValue = APIObject('ReasonContextValue', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('ReasonContextValue', self.ReasonContextValue)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'[\s\S]*', 0, 1500)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourcePolicyDocument = APIObject('ResourcePolicyDocument', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('ResourcePolicyDocument', self.ResourcePolicyDocument)
        self.ServerSideString = APIObject('ServerSideString', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('ServerSideString', self.ServerSideString)
        self.SiteArn = APIObject('SiteArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('SiteArn', self.SiteArn)
        self.SiteId = APIObject('SiteId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('SiteId', self.SiteId)
        self.SubnetArn = APIObject('SubnetArn', 'string', r'^arn:[^:]{1,63}:ec2:[^:]{0,63}:[^:]{0,63}:subnet\/subnet-[0-9a-f]{8,17}$|^$', 0, 500)
        self.add_api_object('SubnetArn', self.SubnetArn)
        self.TagKey = APIObject('TagKey', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\S]*', 0, 10000000)
        self.add_api_object('TagValue', self.TagValue)
        self.TransitGatewayArn = APIObject('TransitGatewayArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('TransitGatewayArn', self.TransitGatewayArn)
        self.TransitGatewayAttachmentArn = APIObject('TransitGatewayAttachmentArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('TransitGatewayAttachmentArn', self.TransitGatewayAttachmentArn)
        self.TransitGatewayAttachmentId = APIObject('TransitGatewayAttachmentId', 'string', r'[\s\S]*', 0, 50)
        self.add_api_object('TransitGatewayAttachmentId', self.TransitGatewayAttachmentId)
        self.TransitGatewayConnectPeerArn = APIObject('TransitGatewayConnectPeerArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('TransitGatewayConnectPeerArn', self.TransitGatewayConnectPeerArn)
        self.TransitGatewayPeeringAttachmentId = APIObject('TransitGatewayPeeringAttachmentId', 'string', r'^tgw-attach-([0-9a-f]{8,17})$', 0, 50)
        self.add_api_object('TransitGatewayPeeringAttachmentId', self.TransitGatewayPeeringAttachmentId)
        self.TransitGatewayRouteTableArn = APIObject('TransitGatewayRouteTableArn', 'string', r'[\s\S]*', 0, 500)
        self.add_api_object('TransitGatewayRouteTableArn', self.TransitGatewayRouteTableArn)
        self.VpcArn = APIObject('VpcArn', 'string', r'^arn:[^:]{1,63}:ec2:[^:]{0,63}:[^:]{0,63}:vpc\/vpc-[0-9a-f]{8,17}$', 0, 500)
        self.add_api_object('VpcArn', self.VpcArn)
        self.VpnConnectionArn = APIObject('VpnConnectionArn', 'string', r'^arn:[^:]{1,63}:ec2:[^:]{0,63}:[^:]{0,63}:vpn-connection\/vpn-[0-9a-f]{8,17}$', 0, 500)
        self.add_api_object('VpnConnectionArn', self.VpnConnectionArn)

class Networkmonitor(Service):
    def __init__(self):
        super().__init__('Networkmonitor')
        self.Arn = APIObject('Arn', 'string', r'arn:.*', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.MonitorArn = APIObject('MonitorArn', 'string', r'arn:.*', 20, 512)
        self.add_api_object('MonitorArn', self.MonitorArn)
        self.ProbeId = APIObject('ProbeId', 'string', r'probe-[a-z0-9A-Z-]{21,64}', None, None)
        self.add_api_object('ProbeId', self.ProbeId)
        self.ResourceName = APIObject('ResourceName', 'string', r'[a-zA-Z0-9_-]+', 1, 200)
        self.add_api_object('ResourceName', self.ResourceName)
        self.VpcId = APIObject('VpcId', 'string', r'vpc-[a-zA-Z0-9]{8,32}', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Nimble(Service):
    def __init__(self):
        super().__init__('Nimble')
        self.EC2ImageId = APIObject('EC2ImageId', 'string', r'^ami-[0-9A-z]+$', None, None)
        self.add_api_object('EC2ImageId', self.EC2ImageId)
        self.EulaAcceptanceId = APIObject('EulaAcceptanceId', 'string', r'^[a-zA-Z0-9-_]*$', 0, 22)
        self.add_api_object('EulaAcceptanceId', self.EulaAcceptanceId)
        self.EulaId = APIObject('EulaId', 'string', r'^[a-zA-Z0-9-_]*$', 0, 22)
        self.add_api_object('EulaId', self.EulaId)
        self.LaunchProfileId = APIObject('LaunchProfileId', 'string', r'^[a-zA-Z0-9-_]*$', 0, 22)
        self.add_api_object('LaunchProfileId', self.LaunchProfileId)
        self.LaunchProfileProtocolVersion = APIObject('LaunchProfileProtocolVersion', 'string', r'^2021\-03\-31$', 0, 10)
        self.add_api_object('LaunchProfileProtocolVersion', self.LaunchProfileProtocolVersion)
        self.LaunchPurpose = APIObject('LaunchPurpose', 'string', r'^[A-Z0-9_]+$', 0, 64)
        self.add_api_object('LaunchPurpose', self.LaunchPurpose)
        self.LinuxMountPoint = APIObject('LinuxMountPoint', 'string', r'^(/?|(\$HOME)?(/[^/\n\s\\]+)*)$', 0, 128)
        self.add_api_object('LinuxMountPoint', self.LinuxMountPoint)
        self.Region = APIObject('Region', 'string', r'[a-z]{2}-?(iso|gov)?-{1}[a-z]*-{1}[0-9]', 0, 50)
        self.add_api_object('Region', self.Region)
        self.ScriptParameterKey = APIObject('ScriptParameterKey', 'string', r'^[a-zA-Z_][a-zA-Z0-9_]+$', 1, 64)
        self.add_api_object('ScriptParameterKey', self.ScriptParameterKey)
        self.StreamingImageEncryptionConfigurationKeyArn = APIObject('StreamingImageEncryptionConfigurationKeyArn', 'string', r'^arn:.*', 4, None)
        self.add_api_object('StreamingImageEncryptionConfigurationKeyArn', self.StreamingImageEncryptionConfigurationKeyArn)
        self.StreamingImageId = APIObject('StreamingImageId', 'string', r'^[a-zA-Z0-9-_]*$', 0, 22)
        self.add_api_object('StreamingImageId', self.StreamingImageId)
        self.StreamingImagePlatform = APIObject('StreamingImagePlatform', 'string', r'^[a-zA-Z]*$', None, None)
        self.add_api_object('StreamingImagePlatform', self.StreamingImagePlatform)
        self.StreamingSessionStorageRootPathLinux = APIObject('StreamingSessionStorageRootPathLinux', 'string', r'^(\$HOME|/)[/]?([A-Za-z0-9-_]+/)*([A-Za-z0-9_-]+)$', 1, 128)
        self.add_api_object('StreamingSessionStorageRootPathLinux', self.StreamingSessionStorageRootPathLinux)
        self.StreamingSessionStorageRootPathWindows = APIObject('StreamingSessionStorageRootPathWindows', 'string', r'^((\%HOMEPATH\%)|[a-zA-Z]:)[\\/](?:[a-zA-Z0-9_-]+[\\/])*[a-zA-Z0-9_-]+$', 1, 128)
        self.add_api_object('StreamingSessionStorageRootPathWindows', self.StreamingSessionStorageRootPathWindows)
        self.StudioComponentId = APIObject('StudioComponentId', 'string', r'^[a-zA-Z0-9-_]*$', 0, 22)
        self.add_api_object('StudioComponentId', self.StudioComponentId)
        self.StudioEncryptionConfigurationKeyArn = APIObject('StudioEncryptionConfigurationKeyArn', 'string', r'^arn:.*', 4, None)
        self.add_api_object('StudioEncryptionConfigurationKeyArn', self.StudioEncryptionConfigurationKeyArn)
        self.StudioName = APIObject('StudioName', 'string', r'^[a-z0-9]*$', 3, 64)
        self.add_api_object('StudioName', self.StudioName)
        self.WindowsMountDrive = APIObject('WindowsMountDrive', 'string', r'^[A-Z]$', None, None)
        self.add_api_object('WindowsMountDrive', self.WindowsMountDrive)

class Oam(Service):
    def __init__(self):
        super().__init__('Oam')
        self.Arn = APIObject('Arn', 'string', r'^arn:(\w|-)+:oam:.+:.+:.+', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ResourceIdentifier = APIObject('ResourceIdentifier', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_:\.\-\/]{0,2047}$', None, None)
        self.add_api_object('ResourceIdentifier', self.ResourceIdentifier)
        self.SinkName = APIObject('SinkName', 'string', r'^[a-zA-Z0-9_\.\-]{1,255}$', None, None)
        self.add_api_object('SinkName', self.SinkName)

class Omics(Service):
    def __init__(self):
        super().__init__('Omics')
        self.ActivationJobId = APIObject('ActivationJobId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ActivationJobId', self.ActivationJobId)
        self.Arn = APIObject('Arn', 'string', r'arn:([^: ]*):([^: ]*):([^: ]*):([0-9]{12}):([^: ]*)', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.ClientToken = APIObject('ClientToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CompleteReadSetUploadPartListItemChecksumString = APIObject('CompleteReadSetUploadPartListItemChecksumString', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 100)
        self.add_api_object('CompleteReadSetUploadPartListItemChecksumString', self.CompleteReadSetUploadPartListItemChecksumString)
        self.EngineLogStream = APIObject('EngineLogStream', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('EngineLogStream', self.EngineLogStream)
        self.ExportJobId = APIObject('ExportJobId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ExportJobId', self.ExportJobId)
        self.GeneratedFrom = APIObject('GeneratedFrom', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('GeneratedFrom', self.GeneratedFrom)
        self.ImportJobId = APIObject('ImportJobId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ImportJobId', self.ImportJobId)
        self.JobStatusMessage = APIObject('JobStatusMessage', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('JobStatusMessage', self.JobStatusMessage)
        self.Md5 = APIObject('Md5', 'string', r'[\p{L}||\p{N}]+', 1, 255)
        self.add_api_object('Md5', self.Md5)
        self.NextToken = APIObject('NextToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 6144)
        self.add_api_object('NextToken', self.NextToken)
        self.Range = APIObject('Range', 'string', r'[\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('Range', self.Range)
        self.ReadSetArn = APIObject('ReadSetArn', 'string', r'arn:.+', 1, 127)
        self.add_api_object('ReadSetArn', self.ReadSetArn)
        self.ReadSetDescription = APIObject('ReadSetDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 255)
        self.add_api_object('ReadSetDescription', self.ReadSetDescription)
        self.ReadSetId = APIObject('ReadSetId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ReadSetId', self.ReadSetId)
        self.ReadSetName = APIObject('ReadSetName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('ReadSetName', self.ReadSetName)
        self.ReadSetStatusMessage = APIObject('ReadSetStatusMessage', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 255)
        self.add_api_object('ReadSetStatusMessage', self.ReadSetStatusMessage)
        self.ReferenceArn = APIObject('ReferenceArn', 'string', r'arn:.+', 1, 127)
        self.add_api_object('ReferenceArn', self.ReferenceArn)
        self.ReferenceArnFilter = APIObject('ReferenceArnFilter', 'string', r'$|^arn:.+', 0, 127)
        self.add_api_object('ReferenceArnFilter', self.ReferenceArnFilter)
        self.ReferenceDescription = APIObject('ReferenceDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 255)
        self.add_api_object('ReferenceDescription', self.ReferenceDescription)
        self.ReferenceId = APIObject('ReferenceId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ReferenceId', self.ReferenceId)
        self.ReferenceName = APIObject('ReferenceName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 3, 255)
        self.add_api_object('ReferenceName', self.ReferenceName)
        self.ReferenceStoreArn = APIObject('ReferenceStoreArn', 'string', r'arn:.+', 1, 127)
        self.add_api_object('ReferenceStoreArn', self.ReferenceStoreArn)
        self.ReferenceStoreDescription = APIObject('ReferenceStoreDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 255)
        self.add_api_object('ReferenceStoreDescription', self.ReferenceStoreDescription)
        self.ReferenceStoreId = APIObject('ReferenceStoreId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('ReferenceStoreId', self.ReferenceStoreId)
        self.ReferenceStoreName = APIObject('ReferenceStoreName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('ReferenceStoreName', self.ReferenceStoreName)
        self.ResourceId = APIObject('ResourceId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:.*', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.RunArn = APIObject('RunArn', 'string', r'arn:.+', 1, 128)
        self.add_api_object('RunArn', self.RunArn)
        self.RunFailureReason = APIObject('RunFailureReason', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 64)
        self.add_api_object('RunFailureReason', self.RunFailureReason)
        self.RunGroupArn = APIObject('RunGroupArn', 'string', r'arn:.+', 1, 128)
        self.add_api_object('RunGroupArn', self.RunGroupArn)
        self.RunGroupId = APIObject('RunGroupId', 'string', r'[0-9]+', 1, 18)
        self.add_api_object('RunGroupId', self.RunGroupId)
        self.RunGroupListToken = APIObject('RunGroupListToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunGroupListToken', self.RunGroupListToken)
        self.RunGroupName = APIObject('RunGroupName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunGroupName', self.RunGroupName)
        self.RunGroupRequestId = APIObject('RunGroupRequestId', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunGroupRequestId', self.RunGroupRequestId)
        self.RunId = APIObject('RunId', 'string', r'[0-9]+', 1, 18)
        self.add_api_object('RunId', self.RunId)
        self.RunListToken = APIObject('RunListToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunListToken', self.RunListToken)
        self.RunLogStream = APIObject('RunLogStream', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('RunLogStream', self.RunLogStream)
        self.RunName = APIObject('RunName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunName', self.RunName)
        self.RunOutputUri = APIObject('RunOutputUri', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 750)
        self.add_api_object('RunOutputUri', self.RunOutputUri)
        self.RunRequestId = APIObject('RunRequestId', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunRequestId', self.RunRequestId)
        self.RunResourceDigest = APIObject('RunResourceDigest', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 0, 64)
        self.add_api_object('RunResourceDigest', self.RunResourceDigest)
        self.RunResourceDigestKey = APIObject('RunResourceDigestKey', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 256)
        self.add_api_object('RunResourceDigestKey', self.RunResourceDigestKey)
        self.RunRoleArn = APIObject('RunRoleArn', 'string', r'arn:.+', 1, 128)
        self.add_api_object('RunRoleArn', self.RunRoleArn)
        self.RunStatusMessage = APIObject('RunStatusMessage', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('RunStatusMessage', self.RunStatusMessage)
        self.RunUuid = APIObject('RunUuid', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('RunUuid', self.RunUuid)
        self.S3AccessPointArn = APIObject('S3AccessPointArn', 'string', r'arn:[^:]*:s3:[^:]*:[^:]*:accesspoint/.*', 1, 1024)
        self.add_api_object('S3AccessPointArn', self.S3AccessPointArn)
        self.S3Destination = APIObject('S3Destination', 'string', r's3://([a-z0-9][a-z0-9-.]{1,61}[a-z0-9])/?((.{1,1024})/)?', None, None)
        self.add_api_object('S3Destination', self.S3Destination)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://([a-z0-9][a-z0-9-.]{1,61}[a-z0-9])/(.{1,1024})', None, None)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SampleId = APIObject('SampleId', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('SampleId', self.SampleId)
        self.SchemaItemKeyString = APIObject('SchemaItemKeyString', 'string', r'[a-z0-9_]{1,255}', None, None)
        self.add_api_object('SchemaItemKeyString', self.SchemaItemKeyString)
        self.SequenceStoreArn = APIObject('SequenceStoreArn', 'string', r'arn:.+', 1, 127)
        self.add_api_object('SequenceStoreArn', self.SequenceStoreArn)
        self.SequenceStoreDescription = APIObject('SequenceStoreDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 255)
        self.add_api_object('SequenceStoreDescription', self.SequenceStoreDescription)
        self.SequenceStoreId = APIObject('SequenceStoreId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('SequenceStoreId', self.SequenceStoreId)
        self.SequenceStoreName = APIObject('SequenceStoreName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('SequenceStoreName', self.SequenceStoreName)
        self.ShareName = APIObject('ShareName', 'string', r'[a-zA-Z0-9_-]+', 1, 256)
        self.add_api_object('ShareName', self.ShareName)
        self.SseConfigKeyArnString = APIObject('SseConfigKeyArnString', 'string', r'.*arn:([^: ]*):([^: ]*):([^: ]*):([0-9]{12}):([^: ]*).*', 20, 2048)
        self.add_api_object('SseConfigKeyArnString', self.SseConfigKeyArnString)
        self.StoreName = APIObject('StoreName', 'string', r'([a-z]){1}([a-z0-9_]){2,254}', 3, 255)
        self.add_api_object('StoreName', self.StoreName)
        self.SubjectId = APIObject('SubjectId', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 127)
        self.add_api_object('SubjectId', self.SubjectId)
        self.TagArn = APIObject('TagArn', 'string', r'arn:.+', 1, 128)
        self.add_api_object('TagArn', self.TagArn)
        self.TaskFailureReason = APIObject('TaskFailureReason', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 64)
        self.add_api_object('TaskFailureReason', self.TaskFailureReason)
        self.TaskId = APIObject('TaskId', 'string', r'[0-9]+', 1, 18)
        self.add_api_object('TaskId', self.TaskId)
        self.TaskInstanceType = APIObject('TaskInstanceType', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('TaskInstanceType', self.TaskInstanceType)
        self.TaskListToken = APIObject('TaskListToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('TaskListToken', self.TaskListToken)
        self.TaskLogStream = APIObject('TaskLogStream', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('TaskLogStream', self.TaskLogStream)
        self.TaskStatusMessage = APIObject('TaskStatusMessage', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('TaskStatusMessage', self.TaskStatusMessage)
        self.UploadId = APIObject('UploadId', 'string', r'[0-9]+', 10, 36)
        self.add_api_object('UploadId', self.UploadId)
        self.VersionName = APIObject('VersionName', 'string', r'([a-z]){1}([a-z0-9_]){2,254}', 3, 255)
        self.add_api_object('VersionName', self.VersionName)
        self.WorkflowArn = APIObject('WorkflowArn', 'string', r'arn:.+', 1, 128)
        self.add_api_object('WorkflowArn', self.WorkflowArn)
        self.WorkflowDefinition = APIObject('WorkflowDefinition', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 256)
        self.add_api_object('WorkflowDefinition', self.WorkflowDefinition)
        self.WorkflowDescription = APIObject('WorkflowDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 256)
        self.add_api_object('WorkflowDescription', self.WorkflowDescription)
        self.WorkflowId = APIObject('WorkflowId', 'string', r'[0-9]+', 1, 18)
        self.add_api_object('WorkflowId', self.WorkflowId)
        self.WorkflowListToken = APIObject('WorkflowListToken', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('WorkflowListToken', self.WorkflowListToken)
        self.WorkflowMain = APIObject('WorkflowMain', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('WorkflowMain', self.WorkflowMain)
        self.WorkflowName = APIObject('WorkflowName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('WorkflowName', self.WorkflowName)
        self.WorkflowOwnerId = APIObject('WorkflowOwnerId', 'string', r'[0-9]{12}', None, None)
        self.add_api_object('WorkflowOwnerId', self.WorkflowOwnerId)
        self.WorkflowParameterDescription = APIObject('WorkflowParameterDescription', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 0, 256)
        self.add_api_object('WorkflowParameterDescription', self.WorkflowParameterDescription)
        self.WorkflowParameterName = APIObject('WorkflowParameterName', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('WorkflowParameterName', self.WorkflowParameterName)
        self.WorkflowRequestId = APIObject('WorkflowRequestId', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', 1, 128)
        self.add_api_object('WorkflowRequestId', self.WorkflowRequestId)
        self.WorkflowStatusMessage = APIObject('WorkflowStatusMessage', 'string', r'[\p{L}||\p{M}||\p{Z}||\p{S}||\p{N}||\p{P}]+', None, None)
        self.add_api_object('WorkflowStatusMessage', self.WorkflowStatusMessage)

class Opensearch(Service):
    def __init__(self):
        super().__init__('Opensearch')
        self.ARN = APIObject('ARN', 'string', r'.*', 20, 2048)
        self.add_api_object('ARN', self.ARN)
        self.AWSAccount = APIObject('AWSAccount', 'string', r'^[0-9]+$', None, None)
        self.add_api_object('AWSAccount', self.AWSAccount)
        self.CloudWatchLogsLogGroupArn = APIObject('CloudWatchLogsLogGroupArn', 'string', r'.*', 20, 2048)
        self.add_api_object('CloudWatchLogsLogGroupArn', self.CloudWatchLogsLogGroupArn)
        self.ConnectionAlias = APIObject('ConnectionAlias', 'string', r'[a-zA-Z][a-zA-Z0-9\-\_]+', 2, 100)
        self.add_api_object('ConnectionAlias', self.ConnectionAlias)
        self.ConnectionId = APIObject('ConnectionId', 'string', r'[a-z][a-z0-9\-]+', 10, 256)
        self.add_api_object('ConnectionId', self.ConnectionId)
        self.DataSourceDescription = APIObject('DataSourceDescription', 'string', r'^([a-zA-Z0-9_])*[\\a-zA-Z0-9_@#%*+=:?./!\s-]*$', None, 1000)
        self.add_api_object('DataSourceDescription', self.DataSourceDescription)
        self.DataSourceName = APIObject('DataSourceName', 'string', r'[a-z][a-z0-9_]+', 3, 80)
        self.add_api_object('DataSourceName', self.DataSourceName)
        self.DescribePackagesFilterValue = APIObject('DescribePackagesFilterValue', 'string', r'^[0-9a-zA-Z\*\.\_\\\/\?-]+$', None, None)
        self.add_api_object('DescribePackagesFilterValue', self.DescribePackagesFilterValue)
        self.DomainArn = APIObject('DomainArn', 'string', r'arn:aws[a-z\-]*:[a-z]+:[a-z0-9\-]+:[0-9]+:domain\/[a-z0-9\-]+', 1, 512)
        self.add_api_object('DomainArn', self.DomainArn)
        self.DomainName = APIObject('DomainName', 'string', r'[a-z][a-z0-9\-]+', 3, 28)
        self.add_api_object('DomainName', self.DomainName)
        self.DomainNameFqdn = APIObject('DomainNameFqdn', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', 1, 255)
        self.add_api_object('DomainNameFqdn', self.DomainNameFqdn)
        self.Endpoint = APIObject('Endpoint', 'string', r'^[A-Za-z0-9\-\.]+$', None, None)
        self.add_api_object('Endpoint', self.Endpoint)
        self.EngineVersion = APIObject('EngineVersion', 'string', r'^Elasticsearch_[0-9]{1}\.[0-9]{1,2}$|^OpenSearch_[0-9]{1,2}\.[0-9]{1,2}$', None, None)
        self.add_api_object('EngineVersion', self.EngineVersion)
        self.GUID = APIObject('GUID', 'string', r'\p{XDigit}{8}-\p{XDigit}{4}-\p{XDigit}{4}-\p{XDigit}{4}-\p{XDigit}{12}', 36, 36)
        self.add_api_object('GUID', self.GUID)
        self.IdentityPoolId = APIObject('IdentityPoolId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityPoolId', self.IdentityPoolId)
        self.InstanceTypeString = APIObject('InstanceTypeString', 'string', r'^.*\..*\.search$', 10, 40)
        self.add_api_object('InstanceTypeString', self.InstanceTypeString)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'.*', 1, 500)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.MaintenanceStatusMessage = APIObject('MaintenanceStatusMessage', 'string', r'^([\s\S]*)$', 0, 1000)
        self.add_api_object('MaintenanceStatusMessage', self.MaintenanceStatusMessage)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'[a-zA-Z0-9\-\_\.]+', 1, 100)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.NumberOfAZs = APIObject('NumberOfAZs', 'string', r'^((\d+)|(NotAvailable))$', None, None)
        self.add_api_object('NumberOfAZs', self.NumberOfAZs)
        self.NumberOfNodes = APIObject('NumberOfNodes', 'string', r'^((\d+)|(NotAvailable))$', None, None)
        self.add_api_object('NumberOfNodes', self.NumberOfNodes)
        self.NumberOfShards = APIObject('NumberOfShards', 'string', r'^((\d+)|(NotAvailable))$', None, None)
        self.add_api_object('NumberOfShards', self.NumberOfShards)
        self.OwnerId = APIObject('OwnerId', 'string', r'[0-9]+', 12, 12)
        self.add_api_object('OwnerId', self.OwnerId)
        self.PackageID = APIObject('PackageID', 'string', r'^([FG][0-9]+)$', None, None)
        self.add_api_object('PackageID', self.PackageID)
        self.PackageName = APIObject('PackageName', 'string', r'[a-z][a-z0-9\-]+', 3, 256)
        self.add_api_object('PackageName', self.PackageName)
        self.Password = APIObject('Password', 'string', r'.*', 8, 128)
        self.add_api_object('Password', self.Password)
        self.PolicyDocument = APIObject('PolicyDocument', 'string', r'.*', 0, 102400)
        self.add_api_object('PolicyDocument', self.PolicyDocument)
        self.Region = APIObject('Region', 'string', r'[a-z][a-z0-9\-]+', 5, 30)
        self.add_api_object('Region', self.Region)
        self.RequestId = APIObject('RequestId', 'string', r'^([\s\S]*)$', 1, 100)
        self.add_api_object('RequestId', self.RequestId)
        self.ReservationToken = APIObject('ReservationToken', 'string', r'.*', 5, 64)
        self.add_api_object('ReservationToken', self.ReservationToken)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:(aws|aws\-cn|aws\-us\-gov|aws\-iso|aws\-iso\-b):iam::[0-9]+:role\/.*', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.TagKey = APIObject('TagKey', 'string', r'.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UserPoolId = APIObject('UserPoolId', 'string', r'[\w-]+_[0-9a-zA-Z]+', 1, 55)
        self.add_api_object('UserPoolId', self.UserPoolId)
        self.Username = APIObject('Username', 'string', r'.*', 1, 64)
        self.add_api_object('Username', self.Username)
        self.VersionString = APIObject('VersionString', 'string', r'^Elasticsearch_[0-9]{1}\.[0-9]{1,2}$|^OpenSearch_[0-9]{1,2}\.[0-9]{1,2}$', 14, 18)
        self.add_api_object('VersionString', self.VersionString)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'^aos-[a-zA-Z0-9]*$', 5, 256)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)

class Opensearchserverless(Service):
    def __init__(self):
        super().__init__('Opensearchserverless')
        self.CollectionId = APIObject('CollectionId', 'string', r'^[a-z0-9]{3,40}$', 3, 40)
        self.add_api_object('CollectionId', self.CollectionId)
        self.CollectionName = APIObject('CollectionName', 'string', r'^[a-z][a-z0-9-]+$', 3, 32)
        self.add_api_object('CollectionName', self.CollectionName)
        self.ConfigName = APIObject('ConfigName', 'string', r'^[a-z][a-z0-9-]+$', 3, 32)
        self.add_api_object('ConfigName', self.ConfigName)
        self.PolicyDocument = APIObject('PolicyDocument', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u00A1-\u00FF]+', 1, 20480)
        self.add_api_object('PolicyDocument', self.PolicyDocument)
        self.PolicyName = APIObject('PolicyName', 'string', r'^[a-z][a-z0-9-]+$', 3, 32)
        self.add_api_object('PolicyName', self.PolicyName)
        self.PolicyVersion = APIObject('PolicyVersion', 'string', r'^([0-9a-zA-Z+/]{4})*(([0-9a-zA-Z+/]{2}==)|([0-9a-zA-Z+/]{3}=))?$', 20, 36)
        self.add_api_object('PolicyVersion', self.PolicyVersion)
        self.ResourceName = APIObject('ResourceName', 'string', r'^index/[a-z][a-z0-9-]{3,32}/([a-z;0-9&$%][+.~=\-_a-z;0-9&$%]*|\*)$', None, None)
        self.add_api_object('ResourceName', self.ResourceName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^[\w+\-]+$', 1, 128)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-([0-9a-f]{8}|[0-9a-f]{17})$', 1, 32)
        self.add_api_object('SubnetId', self.SubnetId)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'^vpce-[0-9a-z]*$', 1, 255)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)
        self.VpcEndpointName = APIObject('VpcEndpointName', 'string', r'^[a-z][a-z0-9-]+$', 3, 32)
        self.add_api_object('VpcEndpointName', self.VpcEndpointName)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-[0-9a-z]*$', 1, 255)
        self.add_api_object('VpcId', self.VpcId)
        self.samlGroupAttribute = APIObject('samlGroupAttribute', 'string', r'[\w+=,.@-]+', 1, 2048)
        self.add_api_object('samlGroupAttribute', self.samlGroupAttribute)
        self.samlMetadata = APIObject('samlMetadata', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u00A1-\u00FF]+', 1, 51200)
        self.add_api_object('samlMetadata', self.samlMetadata)
        self.samlUserAttribute = APIObject('samlUserAttribute', 'string', r'[\w+=,.@-]+', 1, 2048)
        self.add_api_object('samlUserAttribute', self.samlUserAttribute)

class Opsworks(Service):
    def __init__(self):
        super().__init__('Opsworks')

class Opsworkscm(Service):
    def __init__(self):
        super().__init__('Opsworkscm')
        self.AWSOpsWorksCMResourceArn = APIObject('AWSOpsWorksCMResourceArn', 'string', r'arn:aws.*:opsworks-cm:.*:[0-9]{12}:.*', None, None)
        self.add_api_object('AWSOpsWorksCMResourceArn', self.AWSOpsWorksCMResourceArn)
        self.AttributeName = APIObject('AttributeName', 'string', r'[A-Z][A-Z0-9_]*', 1, 64)
        self.add_api_object('AttributeName', self.AttributeName)
        self.AttributeValue = APIObject('AttributeValue', 'string', r'(?s).*', None, 10000)
        self.add_api_object('AttributeValue', self.AttributeValue)
        self.BackupId = APIObject('BackupId', 'string', r'[a-zA-Z][a-zA-Z0-9\-\.\:]*', None, 79)
        self.add_api_object('BackupId', self.BackupId)
        self.CustomCertificate = APIObject('CustomCertificate', 'string', r'(?s)\s*-----BEGIN CERTIFICATE-----.+-----END CERTIFICATE-----\s*', None, 2097152)
        self.add_api_object('CustomCertificate', self.CustomCertificate)
        self.CustomDomain = APIObject('CustomDomain', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', None, 253)
        self.add_api_object('CustomDomain', self.CustomDomain)
        self.CustomPrivateKey = APIObject('CustomPrivateKey', 'string', r'(?ms)\s*^-----BEGIN (?-s:.*)PRIVATE KEY-----$.*?^-----END (?-s:.*)PRIVATE KEY-----$\s*', None, 4096)
        self.add_api_object('CustomPrivateKey', self.CustomPrivateKey)
        self.EngineAttributeName = APIObject('EngineAttributeName', 'string', r'(?s).*', None, 10000)
        self.add_api_object('EngineAttributeName', self.EngineAttributeName)
        self.EngineAttributeValue = APIObject('EngineAttributeValue', 'string', r'(?s).*', None, 10000)
        self.add_api_object('EngineAttributeValue', self.EngineAttributeValue)
        self.InstanceProfileArn = APIObject('InstanceProfileArn', 'string', r'arn:aws:iam::[0-9]{12}:instance-profile/.*', None, 10000)
        self.add_api_object('InstanceProfileArn', self.InstanceProfileArn)
        self.KeyPair = APIObject('KeyPair', 'string', r'.*', None, 10000)
        self.add_api_object('KeyPair', self.KeyPair)
        self.NextToken = APIObject('NextToken', 'string', r'(?s).*', None, 10000)
        self.add_api_object('NextToken', self.NextToken)
        self.NodeAssociationStatusToken = APIObject('NodeAssociationStatusToken', 'string', r'(?s).*', None, 10000)
        self.add_api_object('NodeAssociationStatusToken', self.NodeAssociationStatusToken)
        self.NodeName = APIObject('NodeName', 'string', r'^[\-\p{Alnum}_:.]+$', None, 10000)
        self.add_api_object('NodeName', self.NodeName)
        self.ServerName = APIObject('ServerName', 'string', r'[a-zA-Z][a-zA-Z0-9\-]*', 1, 40)
        self.add_api_object('ServerName', self.ServerName)
        self.ServiceRoleArn = APIObject('ServiceRoleArn', 'string', r'arn:aws:iam::[0-9]{12}:role/.*', None, 10000)
        self.add_api_object('ServiceRoleArn', self.ServiceRoleArn)
        self.String = APIObject('String', 'string', r'(?s).*', None, 10000)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TimeWindowDefinition = APIObject('TimeWindowDefinition', 'string', r'^((Mon|Tue|Wed|Thu|Fri|Sat|Sun):)?([0-1][0-9]|2[0-3]):[0-5][0-9]$', None, 10000)
        self.add_api_object('TimeWindowDefinition', self.TimeWindowDefinition)

class Organizations(Service):
    def __init__(self):
        super().__init__('Organizations')
        self.AccountArn = APIObject('AccountArn', 'string', r'^arn:aws:organizations::\d{12}:account\/o-[a-z0-9]{10,32}\/\d{12}', None, None)
        self.add_api_object('AccountArn', self.AccountArn)
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', None, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AccountName = APIObject('AccountName', 'string', r'[\s\S]*', 1, 128)
        self.add_api_object('AccountName', self.AccountName)
        self.ChildId = APIObject('ChildId', 'string', r'^(\d{12})|(ou-[0-9a-z]{4,32}-[a-z0-9]{8,32})$', None, 100)
        self.add_api_object('ChildId', self.ChildId)
        self.CreateAccountName = APIObject('CreateAccountName', 'string', r'[\u0020-\u007E]+', 1, 50)
        self.add_api_object('CreateAccountName', self.CreateAccountName)
        self.CreateAccountRequestId = APIObject('CreateAccountRequestId', 'string', r'^car-[a-z0-9]{8,32}$', None, 36)
        self.add_api_object('CreateAccountRequestId', self.CreateAccountRequestId)
        self.Email = APIObject('Email', 'string', r'[^\s@]+@[^\s@]+\.[^\s@]+', 6, 64)
        self.add_api_object('Email', self.Email)
        self.GenericArn = APIObject('GenericArn', 'string', r'^arn:aws:organizations::.+:.+', None, None)
        self.add_api_object('GenericArn', self.GenericArn)
        self.HandshakeArn = APIObject('HandshakeArn', 'string', r'^arn:aws:organizations::\d{12}:handshake\/o-[a-z0-9]{10,32}\/[a-z_]{1,32}\/h-[0-9a-z]{8,32}', None, None)
        self.add_api_object('HandshakeArn', self.HandshakeArn)
        self.HandshakeId = APIObject('HandshakeId', 'string', r'^h-[0-9a-z]{8,32}$', None, 34)
        self.add_api_object('HandshakeId', self.HandshakeId)
        self.HandshakeNotes = APIObject('HandshakeNotes', 'string', r'[\s\S]*', None, 1024)
        self.add_api_object('HandshakeNotes', self.HandshakeNotes)
        self.HandshakePartyId = APIObject('HandshakePartyId', 'string', r'[\s\S]*', 1, 64)
        self.add_api_object('HandshakePartyId', self.HandshakePartyId)
        self.NextToken = APIObject('NextToken', 'string', r'[\s\S]*', None, 100000)
        self.add_api_object('NextToken', self.NextToken)
        self.OrganizationArn = APIObject('OrganizationArn', 'string', r'^arn:aws:organizations::\d{12}:organization\/o-[a-z0-9]{10,32}', None, None)
        self.add_api_object('OrganizationArn', self.OrganizationArn)
        self.OrganizationId = APIObject('OrganizationId', 'string', r'^o-[a-z0-9]{10,32}$', None, None)
        self.add_api_object('OrganizationId', self.OrganizationId)
        self.OrganizationalUnitArn = APIObject('OrganizationalUnitArn', 'string', r'^arn:aws:organizations::\d{12}:ou\/o-[a-z0-9]{10,32}\/ou-[0-9a-z]{4,32}-[0-9a-z]{8,32}', None, None)
        self.add_api_object('OrganizationalUnitArn', self.OrganizationalUnitArn)
        self.OrganizationalUnitId = APIObject('OrganizationalUnitId', 'string', r'^ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$', None, 68)
        self.add_api_object('OrganizationalUnitId', self.OrganizationalUnitId)
        self.OrganizationalUnitName = APIObject('OrganizationalUnitName', 'string', r'[\s\S]*', 1, 128)
        self.add_api_object('OrganizationalUnitName', self.OrganizationalUnitName)
        self.ParentId = APIObject('ParentId', 'string', r'^(r-[0-9a-z]{4,32})|(ou-[0-9a-z]{4,32}-[a-z0-9]{8,32})$', None, 100)
        self.add_api_object('ParentId', self.ParentId)
        self.PolicyArn = APIObject('PolicyArn', 'string', r'^(arn:aws:organizations::\d{12}:policy\/o-[a-z0-9]{10,32}\/[0-9a-z_]+\/p-[0-9a-z]{10,32})|(arn:aws:organizations::aws:policy\/[0-9a-z_]+\/p-[0-9a-zA-Z_]{10,128})', None, None)
        self.add_api_object('PolicyArn', self.PolicyArn)
        self.PolicyContent = APIObject('PolicyContent', 'string', r'[\s\S]*', 1, None)
        self.add_api_object('PolicyContent', self.PolicyContent)
        self.PolicyDescription = APIObject('PolicyDescription', 'string', r'[\s\S]*', None, 512)
        self.add_api_object('PolicyDescription', self.PolicyDescription)
        self.PolicyId = APIObject('PolicyId', 'string', r'^p-[0-9a-zA-Z_]{8,128}$', None, 130)
        self.add_api_object('PolicyId', self.PolicyId)
        self.PolicyName = APIObject('PolicyName', 'string', r'[\s\S]*', 1, 128)
        self.add_api_object('PolicyName', self.PolicyName)
        self.PolicyTargetId = APIObject('PolicyTargetId', 'string', r'^(r-[0-9a-z]{4,32})|(\d{12})|(ou-[0-9a-z]{4,32}-[a-z0-9]{8,32})$', None, 100)
        self.add_api_object('PolicyTargetId', self.PolicyTargetId)
        self.ResourcePolicyArn = APIObject('ResourcePolicyArn', 'string', r'^arn:[a-z0-9][a-z0-9-.]{0,62}:organizations::\d{12}:resourcepolicy\/o-[a-z0-9]{10,32}\/rp-[0-9a-zA-Z_]{4,128}', None, None)
        self.add_api_object('ResourcePolicyArn', self.ResourcePolicyArn)
        self.ResourcePolicyContent = APIObject('ResourcePolicyContent', 'string', r'[\s\S]*', 1, 40000)
        self.add_api_object('ResourcePolicyContent', self.ResourcePolicyContent)
        self.ResourcePolicyId = APIObject('ResourcePolicyId', 'string', r'^rp-[0-9a-zA-Z_]{4,128}$', None, 131)
        self.add_api_object('ResourcePolicyId', self.ResourcePolicyId)
        self.RoleName = APIObject('RoleName', 'string', r'[\w+=,.@-]{1,64}', None, 64)
        self.add_api_object('RoleName', self.RoleName)
        self.RootArn = APIObject('RootArn', 'string', r'^arn:aws:organizations::\d{12}:root\/o-[a-z0-9]{10,32}\/r-[0-9a-z]{4,32}', None, None)
        self.add_api_object('RootArn', self.RootArn)
        self.RootId = APIObject('RootId', 'string', r'^r-[0-9a-z]{4,32}$', None, 34)
        self.add_api_object('RootId', self.RootId)
        self.ServicePrincipal = APIObject('ServicePrincipal', 'string', r'[\w+=,.@-]*', 1, 128)
        self.add_api_object('ServicePrincipal', self.ServicePrincipal)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaggableResourceId = APIObject('TaggableResourceId', 'string', r'^(r-[0-9a-z]{4,32})|(\d{12})|(ou-[0-9a-z]{4,32}-[a-z0-9]{8,32})|(^p-[0-9a-zA-Z_]{8,128})|(^rp-[0-9a-zA-Z_]{4,128})$', None, 130)
        self.add_api_object('TaggableResourceId', self.TaggableResourceId)

class Osis(Service):
    def __init__(self):
        super().__init__('Osis')
        self.LogGroup = APIObject('LogGroup', 'string', r'\/aws\/vendedlogs\/[\.\-_/#A-Za-z0-9]+', 1, 512)
        self.add_api_object('LogGroup', self.LogGroup)
        self.NextToken = APIObject('NextToken', 'string', r'^([\s\S]*)$', 0, 3000)
        self.add_api_object('NextToken', self.NextToken)
        self.PipelineArn = APIObject('PipelineArn', 'string', r'^arn:(aws|aws\-cn|aws\-us\-gov|aws\-iso|aws\-iso\-b):osis:.+:pipeline\/.+$', 46, 76)
        self.add_api_object('PipelineArn', self.PipelineArn)
        self.PipelineName = APIObject('PipelineName', 'string', r'[a-z][a-z0-9\-]+', 3, 28)
        self.add_api_object('PipelineName', self.PipelineName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'sg-\w{8}(\w{9})?', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'subnet-\w{8}(\w{9})?', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Outposts(Service):
    def __init__(self):
        super().__init__('Outposts')
        self.AccountId = APIObject('AccountId', 'string', r'\d{12}', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AddressLine1 = APIObject('AddressLine1', 'string', r'^\S[\S ]*$', 1, 180)
        self.add_api_object('AddressLine1', self.AddressLine1)
        self.AddressLine2 = APIObject('AddressLine2', 'string', r'^\S[\S ]*$', 0, 60)
        self.add_api_object('AddressLine2', self.AddressLine2)
        self.AddressLine3 = APIObject('AddressLine3', 'string', r'^\S[\S ]*$', 0, 60)
        self.add_api_object('AddressLine3', self.AddressLine3)
        self.Arn = APIObject('Arn', 'string', r'^(arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:([a-z\d-]+)/)[a-z]{2,8}-[a-f0-9]{17}$', None, 1011)
        self.add_api_object('Arn', self.Arn)
        self.AssetId = APIObject('AssetId', 'string', r'^(\w+)$', 1, 100)
        self.add_api_object('AssetId', self.AssetId)
        self.AvailabilityZone = APIObject('AvailabilityZone', 'string', r'^([a-zA-Z]+-){1,3}([a-zA-Z]+)?(\d+[a-zA-Z]?)?$', 1, 1000)
        self.add_api_object('AvailabilityZone', self.AvailabilityZone)
        self.AvailabilityZoneId = APIObject('AvailabilityZoneId', 'string', r'^[a-zA-Z]+\d-[a-zA-Z]+\d$', 1, 255)
        self.add_api_object('AvailabilityZoneId', self.AvailabilityZoneId)
        self.CIDR = APIObject('CIDR', 'string', r'^([0-9]{1,3}\.){3}[0-9]{1,3}/[0-9]{1,2}$', 9, 18)
        self.add_api_object('CIDR', self.CIDR)
        self.CapacityTaskId = APIObject('CapacityTaskId', 'string', r'^cap-[a-f0-9]{17}$', 21, 21)
        self.add_api_object('CapacityTaskId', self.CapacityTaskId)
        self.City = APIObject('City', 'string', r'^\S[\S ]*$', 1, 50)
        self.add_api_object('City', self.City)
        self.ConnectionId = APIObject('ConnectionId', 'string', r'^[a-zA-Z0-9+/=]{1,1024}$', 1, 1024)
        self.add_api_object('ConnectionId', self.ConnectionId)
        self.ContactName = APIObject('ContactName', 'string', r'^\S[\S ]*$', 1, 255)
        self.add_api_object('ContactName', self.ContactName)
        self.ContactPhoneNumber = APIObject('ContactPhoneNumber', 'string', r'^[\S ]+$', 1, 20)
        self.add_api_object('ContactPhoneNumber', self.ContactPhoneNumber)
        self.CountryCode = APIObject('CountryCode', 'string', r'^[A-Z]{2}$', 2, 2)
        self.add_api_object('CountryCode', self.CountryCode)
        self.DeviceSerialNumber = APIObject('DeviceSerialNumber', 'string', r'^(\w+)$', 1, 100)
        self.add_api_object('DeviceSerialNumber', self.DeviceSerialNumber)
        self.DistrictOrCounty = APIObject('DistrictOrCounty', 'string', r'^\S[\S ]*', 1, 60)
        self.add_api_object('DistrictOrCounty', self.DistrictOrCounty)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'^[\S \n]+$', 1, 1000)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.Family = APIObject('Family', 'string', r'[a-z0-9]+', 1, 10)
        self.add_api_object('Family', self.Family)
        self.HostId = APIObject('HostId', 'string', r'^[A-Za-z0-9-]*$', 1, 50)
        self.add_api_object('HostId', self.HostId)
        self.InstanceFamilyName = APIObject('InstanceFamilyName', 'string', r'^(?:.{1,200}/)?(?:[a-z0-9-_A-Z])+$', 1, 200)
        self.add_api_object('InstanceFamilyName', self.InstanceFamilyName)
        self.InstanceTypeName = APIObject('InstanceTypeName', 'string', r'^[a-z0-9\-]+\.[a-z0-9\-]+$', 1, 64)
        self.add_api_object('InstanceTypeName', self.InstanceTypeName)
        self.LifeCycleStatus = APIObject('LifeCycleStatus', 'string', r'^[ A-Za-z]+$', 1, 20)
        self.add_api_object('LifeCycleStatus', self.LifeCycleStatus)
        self.LineItemId = APIObject('LineItemId', 'string', r'ooi-[a-f0-9]{17}', None, None)
        self.add_api_object('LineItemId', self.LineItemId)
        self.MacAddress = APIObject('MacAddress', 'string', r'^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$', 17, 17)
        self.add_api_object('MacAddress', self.MacAddress)
        self.Municipality = APIObject('Municipality', 'string', r'^\S[\S ]*$', 0, 180)
        self.add_api_object('Municipality', self.Municipality)
        self.OrderId = APIObject('OrderId', 'string', r'oo-[a-f0-9]{17}$', 1, 20)
        self.add_api_object('OrderId', self.OrderId)
        self.OutpostArn = APIObject('OutpostArn', 'string', r'^arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/op-[a-f0-9]{17}$', 1, 255)
        self.add_api_object('OutpostArn', self.OutpostArn)
        self.OutpostDescription = APIObject('OutpostDescription', 'string', r'^[\S ]*$', 0, 1000)
        self.add_api_object('OutpostDescription', self.OutpostDescription)
        self.OutpostId = APIObject('OutpostId', 'string', r'^(arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/)?op-[a-f0-9]{17}$', 1, 180)
        self.add_api_object('OutpostId', self.OutpostId)
        self.OutpostIdOnly = APIObject('OutpostIdOnly', 'string', r'^op-[a-f0-9]{17}$', 1, 20)
        self.add_api_object('OutpostIdOnly', self.OutpostIdOnly)
        self.OutpostIdentifier = APIObject('OutpostIdentifier', 'string', r'^(arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/)?op-[a-f0-9]{17}$', 1, 180)
        self.add_api_object('OutpostIdentifier', self.OutpostIdentifier)
        self.OutpostName = APIObject('OutpostName', 'string', r'^[\S ]+$', 1, 255)
        self.add_api_object('OutpostName', self.OutpostName)
        self.OwnerId = APIObject('OwnerId', 'string', r'\d{12}', 12, 12)
        self.add_api_object('OwnerId', self.OwnerId)
        self.PostalCode = APIObject('PostalCode', 'string', r'^[a-zA-Z0-9 -]+$', 1, 20)
        self.add_api_object('PostalCode', self.PostalCode)
        self.RackId = APIObject('RackId', 'string', r'^[\S \n]+$', 5, 20)
        self.add_api_object('RackId', self.RackId)
        self.ServerEndpoint = APIObject('ServerEndpoint', 'string', r'^([0-9]{1,3}\.){3}[0-9]{1,3}:[0-9]{1,5}$', 9, 21)
        self.add_api_object('ServerEndpoint', self.ServerEndpoint)
        self.SiteArn = APIObject('SiteArn', 'string', r'^arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:site/(os-[a-f0-9]{17})$', 1, 255)
        self.add_api_object('SiteArn', self.SiteArn)
        self.SiteDescription = APIObject('SiteDescription', 'string', r'^[\S ]+$', 1, 1001)
        self.add_api_object('SiteDescription', self.SiteDescription)
        self.SiteId = APIObject('SiteId', 'string', r'^(arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:site/)?(os-[a-f0-9]{17})$', 1, 255)
        self.add_api_object('SiteId', self.SiteId)
        self.SiteName = APIObject('SiteName', 'string', r'^[\S ]+$', 1, 1000)
        self.add_api_object('SiteName', self.SiteName)
        self.SiteNotes = APIObject('SiteNotes', 'string', r'^[\S \n]+$', 1, 2000)
        self.add_api_object('SiteNotes', self.SiteNotes)
        self.SkuCode = APIObject('SkuCode', 'string', r'OR-[A-Z0-9]{7}', 1, 10)
        self.add_api_object('SkuCode', self.SkuCode)
        self.StateOrRegion = APIObject('StateOrRegion', 'string', r'^\S[\S ]*$', 1, 50)
        self.add_api_object('StateOrRegion', self.StateOrRegion)
        self.String = APIObject('String', 'string', r'^[\S \n]+$', 1, 1000)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\S \n]+$', None, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Token = APIObject('Token', 'string', r'^(\d+)##(\S+)$', 1, 2048)
        self.add_api_object('Token', self.Token)
        self.TrackingId = APIObject('TrackingId', 'string', r'^[a-zA-Z0-9]+$', 6, 42)
        self.add_api_object('TrackingId', self.TrackingId)
        self.UnderlayIpAddress = APIObject('UnderlayIpAddress', 'string', r'^([0-9]{1,3}\.){3}[0-9]{1,3}$', 7, 15)
        self.add_api_object('UnderlayIpAddress', self.UnderlayIpAddress)
        self.WireGuardPublicKey = APIObject('WireGuardPublicKey', 'string', r'^[a-zA-Z0-9/+]{43}=$', 44, 44)
        self.add_api_object('WireGuardPublicKey', self.WireGuardPublicKey)

class Panorama(Service):
    def __init__(self):
        super().__init__('Panorama')
        self.ApplicationInstanceId = APIObject('ApplicationInstanceId', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('ApplicationInstanceId', self.ApplicationInstanceId)
        self.ApplicationInstanceName = APIObject('ApplicationInstanceName', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('ApplicationInstanceName', self.ApplicationInstanceName)
        self.BucketName = APIObject('BucketName', 'string', r'^.+$', 1, 255)
        self.add_api_object('BucketName', self.BucketName)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DefaultGateway = APIObject('DefaultGateway', 'string', r'^.+$', 1, 255)
        self.add_api_object('DefaultGateway', self.DefaultGateway)
        self.DefaultRuntimeContextDevice = APIObject('DefaultRuntimeContextDevice', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('DefaultRuntimeContextDevice', self.DefaultRuntimeContextDevice)
        self.Description = APIObject('Description', 'string', r'^.*$', 0, 255)
        self.add_api_object('Description', self.Description)
        self.DeviceId = APIObject('DeviceId', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('DeviceId', self.DeviceId)
        self.DeviceName = APIObject('DeviceName', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('DeviceName', self.DeviceName)
        self.DeviceSerialNumber = APIObject('DeviceSerialNumber', 'string', r'^[0-9]{1,20}$', None, None)
        self.add_api_object('DeviceSerialNumber', self.DeviceSerialNumber)
        self.Dns = APIObject('Dns', 'string', r'^.+$', 1, 255)
        self.add_api_object('Dns', self.Dns)
        self.ImageVersion = APIObject('ImageVersion', 'string', r'^.+$', 1, 255)
        self.add_api_object('ImageVersion', self.ImageVersion)
        self.IpAddress = APIObject('IpAddress', 'string', r'^((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d))(:(6553[0-5]|655[0-2]\d|65[0-4]\d{2}|6[0-4]\d{3}|[1-5]\d{4}|[1-9]\d{0,3}))?$', 1, 255)
        self.add_api_object('IpAddress', self.IpAddress)
        self.IpAddressOrServerName = APIObject('IpAddressOrServerName', 'string', r'(^([a-z0-9]+(-[a-z0-9]+)*\.)+[a-z]{2,}$)|(^((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d))(:(6553[0-5]|655[0-2]\d|65[0-4]\d{2}|6[0-4]\d{3}|[1-5]\d{4}|[1-9]\d{0,3}))?$)', 1, 255)
        self.add_api_object('IpAddressOrServerName', self.IpAddressOrServerName)
        self.JobId = APIObject('JobId', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('JobId', self.JobId)
        self.ManifestOverridesPayloadData = APIObject('ManifestOverridesPayloadData', 'string', r'^.*$', 0, 51200)
        self.add_api_object('ManifestOverridesPayloadData', self.ManifestOverridesPayloadData)
        self.ManifestPayloadData = APIObject('ManifestPayloadData', 'string', r'^.+$', 1, 51200)
        self.add_api_object('ManifestPayloadData', self.ManifestPayloadData)
        self.Mask = APIObject('Mask', 'string', r'^.+$', 1, 255)
        self.add_api_object('Mask', self.Mask)
        self.NextToken = APIObject('NextToken', 'string', r'^.+$', 1, 4096)
        self.add_api_object('NextToken', self.NextToken)
        self.NodeAssetName = APIObject('NodeAssetName', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 255)
        self.add_api_object('NodeAssetName', self.NodeAssetName)
        self.NodeId = APIObject('NodeId', 'string', r'^[a-zA-Z0-9\-\_\.]+$', 1, 255)
        self.add_api_object('NodeId', self.NodeId)
        self.NodeInstanceId = APIObject('NodeInstanceId', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 128)
        self.add_api_object('NodeInstanceId', self.NodeInstanceId)
        self.NodeName = APIObject('NodeName', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 128)
        self.add_api_object('NodeName', self.NodeName)
        self.NodePackageId = APIObject('NodePackageId', 'string', r'^[a-zA-Z0-9\-\_\/]+$', 1, 255)
        self.add_api_object('NodePackageId', self.NodePackageId)
        self.NodePackageName = APIObject('NodePackageName', 'string', r'^[a-zA-Z0-9\-\_]+$', 1, 128)
        self.add_api_object('NodePackageName', self.NodePackageName)
        self.NodePackagePatchVersion = APIObject('NodePackagePatchVersion', 'string', r'^[a-z0-9]+$', 1, 255)
        self.add_api_object('NodePackagePatchVersion', self.NodePackagePatchVersion)
        self.NodePackageVersion = APIObject('NodePackageVersion', 'string', r'^([0-9]+)\.([0-9]+)$', 1, 255)
        self.add_api_object('NodePackageVersion', self.NodePackageVersion)
        self.ObjectKey = APIObject('ObjectKey', 'string', r'^.+$', 1, 255)
        self.add_api_object('ObjectKey', self.ObjectKey)
        self.PackageOwnerAccount = APIObject('PackageOwnerAccount', 'string', r'^[0-9a-z\_]+$', 1, 12)
        self.add_api_object('PackageOwnerAccount', self.PackageOwnerAccount)
        self.PortName = APIObject('PortName', 'string', r'^[a-zA-Z0-9\_]+$', 1, 50)
        self.add_api_object('PortName', self.PortName)
        self.PrincipalArn = APIObject('PrincipalArn', 'string', r'^arn:[a-z0-9][-.a-z0-9]{0,62}:iam::[0-9]{12}:[a-zA-Z0-9+=,.@\-_/]+$', 1, 255)
        self.add_api_object('PrincipalArn', self.PrincipalArn)
        self.Region = APIObject('Region', 'string', r'^.+$', 1, 255)
        self.add_api_object('Region', self.Region)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^.+$', 1, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RuntimeContextName = APIObject('RuntimeContextName', 'string', r'^.+$', 1, 255)
        self.add_api_object('RuntimeContextName', self.RuntimeContextName)
        self.RuntimeRoleArn = APIObject('RuntimeRoleArn', 'string', r'^arn:[a-z0-9][-.a-z0-9]{0,62}:iam::[0-9]{12}:role/.+$', 1, 255)
        self.add_api_object('RuntimeRoleArn', self.RuntimeRoleArn)
        self.TagKey = APIObject('TagKey', 'string', r'^.+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^.*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TemplateKey = APIObject('TemplateKey', 'string', r'^.+$', 1, 255)
        self.add_api_object('TemplateKey', self.TemplateKey)
        self.TemplateValue = APIObject('TemplateValue', 'string', r'^.+$', 1, 255)
        self.add_api_object('TemplateValue', self.TemplateValue)
        self.Token = APIObject('Token', 'string', r'^.+$', 1, 4096)
        self.add_api_object('Token', self.Token)

class PaymentCryptographyData(Service):
    def __init__(self):
        super().__init__('PaymentCryptographyData')
        self.HexEvenLengthBetween16And32 = APIObject('HexEvenLengthBetween16And32', 'string', r'^(?:[0-9a-fA-F][0-9a-fA-F])+$', 16, 32)
        self.add_api_object('HexEvenLengthBetween16And32', self.HexEvenLengthBetween16And32)
        self.HexEvenLengthBetween16And4064 = APIObject('HexEvenLengthBetween16And4064', 'string', r'^(?:[0-9a-fA-F][0-9a-fA-F])+$', 16, 4064)
        self.add_api_object('HexEvenLengthBetween16And4064', self.HexEvenLengthBetween16And4064)
        self.HexEvenLengthBetween16And4096 = APIObject('HexEvenLengthBetween16And4096', 'string', r'^(?:[0-9a-fA-F][0-9a-fA-F])+$', 16, 4096)
        self.add_api_object('HexEvenLengthBetween16And4096', self.HexEvenLengthBetween16And4096)
        self.HexEvenLengthBetween2And4096 = APIObject('HexEvenLengthBetween2And4096', 'string', r'^(?:[0-9a-fA-F][0-9a-fA-F])+$', 2, 4096)
        self.add_api_object('HexEvenLengthBetween2And4096', self.HexEvenLengthBetween2And4096)
        self.HexEvenLengthBetween4And128 = APIObject('HexEvenLengthBetween4And128', 'string', r'^(?:[0-9a-fA-F][0-9a-fA-F])+$', 4, 128)
        self.add_api_object('HexEvenLengthBetween4And128', self.HexEvenLengthBetween4And128)
        self.HexLength16Or32 = APIObject('HexLength16Or32', 'string', r'^(?:[0-9a-fA-F]{16}|[0-9a-fA-F]{32})$', 16, 32)
        self.add_api_object('HexLength16Or32', self.HexLength16Or32)
        self.HexLengthBetween10And24 = APIObject('HexLengthBetween10And24', 'string', r'^[0-9a-fA-F]+$', 10, 24)
        self.add_api_object('HexLengthBetween10And24', self.HexLengthBetween10And24)
        self.HexLengthBetween16And32 = APIObject('HexLengthBetween16And32', 'string', r'^[0-9a-fA-F]+$', 16, 32)
        self.add_api_object('HexLengthBetween16And32', self.HexLengthBetween16And32)
        self.HexLengthBetween1And16 = APIObject('HexLengthBetween1And16', 'string', r'^[0-9a-fA-F]+$', 1, 16)
        self.add_api_object('HexLengthBetween1And16', self.HexLengthBetween1And16)
        self.HexLengthBetween2And1024 = APIObject('HexLengthBetween2And1024', 'string', r'^[0-9a-fA-F]+$', 2, 1024)
        self.add_api_object('HexLengthBetween2And1024', self.HexLengthBetween2And1024)
        self.HexLengthBetween2And160 = APIObject('HexLengthBetween2And160', 'string', r'^[0-9a-fA-F]+$', 2, 160)
        self.add_api_object('HexLengthBetween2And160', self.HexLengthBetween2And160)
        self.HexLengthBetween2And4 = APIObject('HexLengthBetween2And4', 'string', r'^[0-9a-fA-F]+$', 2, 4)
        self.add_api_object('HexLengthBetween2And4', self.HexLengthBetween2And4)
        self.HexLengthBetween2And8 = APIObject('HexLengthBetween2And8', 'string', r'^[0-9a-fA-F]+$', 2, 8)
        self.add_api_object('HexLengthBetween2And8', self.HexLengthBetween2And8)
        self.HexLengthBetween4And128 = APIObject('HexLengthBetween4And128', 'string', r'^[0-9a-fA-F]+$', 4, 128)
        self.add_api_object('HexLengthBetween4And128', self.HexLengthBetween4And128)
        self.HexLengthEquals1 = APIObject('HexLengthEquals1', 'string', r'^[0-9A-F]+$', 1, 1)
        self.add_api_object('HexLengthEquals1', self.HexLengthEquals1)
        self.HexLengthEquals16 = APIObject('HexLengthEquals16', 'string', r'^[0-9a-fA-F]+$', 16, 16)
        self.add_api_object('HexLengthEquals16', self.HexLengthEquals16)
        self.HexLengthEquals2 = APIObject('HexLengthEquals2', 'string', r'^[0-9a-fA-F]+$', 2, 2)
        self.add_api_object('HexLengthEquals2', self.HexLengthEquals2)
        self.HexLengthEquals4 = APIObject('HexLengthEquals4', 'string', r'^[0-9a-fA-F]+$', 4, 4)
        self.add_api_object('HexLengthEquals4', self.HexLengthEquals4)
        self.HexLengthEquals8 = APIObject('HexLengthEquals8', 'string', r'^[0-9a-fA-F]+$', 8, 8)
        self.add_api_object('HexLengthEquals8', self.HexLengthEquals8)
        self.KeyArn = APIObject('KeyArn', 'string', r'^arn:aws:payment-cryptography:[a-z]{2}-[a-z]{1,16}-[0-9]+:[0-9]{12}:key/[0-9a-zA-Z]{16,64}$', 70, 150)
        self.add_api_object('KeyArn', self.KeyArn)
        self.KeyArnOrKeyAliasType = APIObject('KeyArnOrKeyAliasType', 'string', r'^arn:aws:payment-cryptography:[a-z]{2}-[a-z]{1,16}-[0-9]+:[0-9]{12}:(key/[0-9a-zA-Z]{16,64}|alias/[a-zA-Z0-9/_-]+)$|^alias/[a-zA-Z0-9/_-]+$', 7, 322)
        self.add_api_object('KeyArnOrKeyAliasType', self.KeyArnOrKeyAliasType)
        self.KeyCheckValue = APIObject('KeyCheckValue', 'string', r'^[0-9a-fA-F]+$', 4, 16)
        self.add_api_object('KeyCheckValue', self.KeyCheckValue)
        self.NumberLengthBetween12And19 = APIObject('NumberLengthBetween12And19', 'string', r'^[0-9]+$', 12, 19)
        self.add_api_object('NumberLengthBetween12And19', self.NumberLengthBetween12And19)
        self.NumberLengthBetween3And5 = APIObject('NumberLengthBetween3And5', 'string', r'^[0-9]+$', 3, 5)
        self.add_api_object('NumberLengthBetween3And5', self.NumberLengthBetween3And5)
        self.NumberLengthBetween4And12 = APIObject('NumberLengthBetween4And12', 'string', r'^[0-9]+$', 4, 12)
        self.add_api_object('NumberLengthBetween4And12', self.NumberLengthBetween4And12)
        self.NumberLengthBetween4And16 = APIObject('NumberLengthBetween4And16', 'string', r'^[0-9]+$', 4, 16)
        self.add_api_object('NumberLengthBetween4And16', self.NumberLengthBetween4And16)
        self.NumberLengthEquals16 = APIObject('NumberLengthEquals16', 'string', r'^[0-9]+$', 16, 16)
        self.add_api_object('NumberLengthEquals16', self.NumberLengthEquals16)
        self.NumberLengthEquals3 = APIObject('NumberLengthEquals3', 'string', r'^[0-9]+$', 3, 3)
        self.add_api_object('NumberLengthEquals3', self.NumberLengthEquals3)
        self.NumberLengthEquals4 = APIObject('NumberLengthEquals4', 'string', r'^[0-9]+$', 4, 4)
        self.add_api_object('NumberLengthEquals4', self.NumberLengthEquals4)

class PaymentCryptography(Service):
    def __init__(self):
        super().__init__('PaymentCryptography')
        self.AliasName = APIObject('AliasName', 'string', r'alias/[a-zA-Z0-9/_-]+', 7, 256)
        self.add_api_object('AliasName', self.AliasName)
        self.CertificateType = APIObject('CertificateType', 'string', r'[^\[;\]<>]+', 1, 32768)
        self.add_api_object('CertificateType', self.CertificateType)
        self.ExportTokenId = APIObject('ExportTokenId', 'string', r'export-token-[0-9a-zA-Z]{16,64}', None, None)
        self.add_api_object('ExportTokenId', self.ExportTokenId)
        self.HexLength16 = APIObject('HexLength16', 'string', r'[0-9A-F]+', 16, 16)
        self.add_api_object('HexLength16', self.HexLength16)
        self.HexLength20Or24 = APIObject('HexLength20Or24', 'string', r'[0-9A-F]{20}$|^[0-9A-F]{24}', 20, 24)
        self.add_api_object('HexLength20Or24', self.HexLength20Or24)
        self.ImportTokenId = APIObject('ImportTokenId', 'string', r'import-token-[0-9a-zA-Z]{16,64}', None, None)
        self.add_api_object('ImportTokenId', self.ImportTokenId)
        self.KeyArn = APIObject('KeyArn', 'string', r'arn:aws:payment-cryptography:[a-z]{2}-[a-z]{1,16}-[0-9]+:[0-9]{12}:key/[0-9a-zA-Z]{16,64}', 70, 150)
        self.add_api_object('KeyArn', self.KeyArn)
        self.KeyArnOrKeyAliasType = APIObject('KeyArnOrKeyAliasType', 'string', r'arn:aws:payment-cryptography:[a-z]{2}-[a-z]{1,16}-[0-9]+:[0-9]{12}:(key/[0-9a-zA-Z]{16,64}|alias/[a-zA-Z0-9/_-]+)$|^alias/[a-zA-Z0-9/_-]+', 7, 322)
        self.add_api_object('KeyArnOrKeyAliasType', self.KeyArnOrKeyAliasType)
        self.KeyCheckValue = APIObject('KeyCheckValue', 'string', r'[0-9a-fA-F]+', 4, 16)
        self.add_api_object('KeyCheckValue', self.KeyCheckValue)
        self.KeyVersion = APIObject('KeyVersion', 'string', r'[0-9A-Z]{2}+', 2, 2)
        self.add_api_object('KeyVersion', self.KeyVersion)
        self.OptionalBlockId = APIObject('OptionalBlockId', 'string', r'[0-9A-Z]{2}+', 2, 2)
        self.add_api_object('OptionalBlockId', self.OptionalBlockId)
        self.OptionalBlockValue = APIObject('OptionalBlockValue', 'string', r'[0-9A-Z]+', 1, 108)
        self.add_api_object('OptionalBlockValue', self.OptionalBlockValue)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws:payment-cryptography:[a-z]{2}-[a-z]{1,16}-[0-9]+:[0-9]{12}:key/[0-9a-zA-Z]{16,64}', 70, 150)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.Tr31WrappedKeyBlock = APIObject('Tr31WrappedKeyBlock', 'string', r'[0-9A-Z]+', 56, 9984)
        self.add_api_object('Tr31WrappedKeyBlock', self.Tr31WrappedKeyBlock)
        self.Tr34WrappedKeyBlock = APIObject('Tr34WrappedKeyBlock', 'string', r'[0-9A-F]+', 2, 4096)
        self.add_api_object('Tr34WrappedKeyBlock', self.Tr34WrappedKeyBlock)
        self.WrappedKeyCryptogram = APIObject('WrappedKeyCryptogram', 'string', r'[0-9A-F]+', 16, 4096)
        self.add_api_object('WrappedKeyCryptogram', self.WrappedKeyCryptogram)

class PcaConnectorAd(Service):
    def __init__(self):
        super().__init__('PcaConnectorAd')
        self.CertificateAuthorityArn = APIObject('CertificateAuthorityArn', 'string', r'^arn:[\w-]+:acm-pca:[\w-]+:[0-9]+:certificate-authority\/[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}$', 5, 200)
        self.add_api_object('CertificateAuthorityArn', self.CertificateAuthorityArn)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[!-~]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ConnectorArn = APIObject('ConnectorArn', 'string', r'^arn:[\w-]+:pca-connector-ad:[\w-]+:[0-9]+:connector\/[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}$', 5, 200)
        self.add_api_object('ConnectorArn', self.ConnectorArn)
        self.CustomObjectIdentifier = APIObject('CustomObjectIdentifier', 'string', r'^([0-2])\.([0-9]|([0-3][0-9]))(\.([0-9]+)){0,126}$', 1, 64)
        self.add_api_object('CustomObjectIdentifier', self.CustomObjectIdentifier)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', None, None)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.DirectoryRegistrationArn = APIObject('DirectoryRegistrationArn', 'string', r'^arn:[\w-]+:pca-connector-ad:[\w-]+:[0-9]+:directory-registration\/d-[0-9a-f]{10}$', 5, 200)
        self.add_api_object('DirectoryRegistrationArn', self.DirectoryRegistrationArn)
        self.DisplayName = APIObject('DisplayName', 'string', r'^[\x20-\x7E]+$', 0, 256)
        self.add_api_object('DisplayName', self.DisplayName)
        self.GroupSecurityIdentifier = APIObject('GroupSecurityIdentifier', 'string', r'^S-[0-9]-([0-9]+-){1,14}[0-9]+$', 7, 256)
        self.add_api_object('GroupSecurityIdentifier', self.GroupSecurityIdentifier)
        self.NextToken = APIObject('NextToken', 'string', r'^(?:[A-Za-z0-9_-]{4})*(?:[A-Za-z0-9_-]{2}==|[A-Za-z0-9_-]{3}=)?$', 1, 1000)
        self.add_api_object('NextToken', self.NextToken)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^(?:sg-[0-9a-f]{8}|sg-[0-9a-f]{17})$', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.TemplateArn = APIObject('TemplateArn', 'string', r'^arn:[\w-]+:pca-connector-ad:[\w-]+:[0-9]+:connector\/[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}\/template\/[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}$', 5, 200)
        self.add_api_object('TemplateArn', self.TemplateArn)
        self.TemplateName = APIObject('TemplateName', 'string', r'^(?!^\s+$)((?![\x5c\'\x2b,;<=>#\x22])([\x20-\x7E]))+$', 1, 64)
        self.add_api_object('TemplateName', self.TemplateName)

class PersonalizeEvents(Service):
    def __init__(self):
        super().__init__('PersonalizeEvents')
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):personalize:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.EventAttributionSource = APIObject('EventAttributionSource', 'string', r'^[\x20-\x7E]*[\x21-\x7E]+[\x20-\x7E]*$', None, 1024)
        self.add_api_object('EventAttributionSource', self.EventAttributionSource)

class PersonalizeRuntime(Service):
    def __init__(self):
        super().__init__('PersonalizeRuntime')
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):personalize:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.AttributeName = APIObject('AttributeName', 'string', r'[A-Za-z\d_]+', None, 150)
        self.add_api_object('AttributeName', self.AttributeName)
        self.FilterAttributeName = APIObject('FilterAttributeName', 'string', r'[A-Za-z0-9_]+', None, 50)
        self.add_api_object('FilterAttributeName', self.FilterAttributeName)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('Name', self.Name)

class Personalize(Service):
    def __init__(self):
        super().__init__('Personalize')
        self.Arn = APIObject('Arn', 'string', r'arn:([a-z\d-]+):personalize:.*:.*:.+', None, 256)
        self.add_api_object('Arn', self.Arn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws.*:kms:.*:[0-9]{12}:key/.*', None, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9\-_]*', 1, 63)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'\p{ASCII}{0,1500}', None, 1500)
        self.add_api_object('NextToken', self.NextToken)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:([a-z\d-]+):iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', None, 256)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Location = APIObject('S3Location', 'string', r'(s3|http|https)://.+', None, 256)
        self.add_api_object('S3Location', self.S3Location)
        self.SchedulingExpression = APIObject('SchedulingExpression', 'string', r'rate\(\d+ days?\)', 1, 16)
        self.add_api_object('SchedulingExpression', self.SchedulingExpression)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Pi(Service):
    def __init__(self):
        super().__init__('Pi')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:.*:pi:.*$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.AnalysisReportId = APIObject('AnalysisReportId', 'string', r'report-[0-9a-f]{17}', 1, 100)
        self.add_api_object('AnalysisReportId', self.AnalysisReportId)
        self.DescriptiveString = APIObject('DescriptiveString', 'string', r'^.*$', 1, 2000)
        self.add_api_object('DescriptiveString', self.DescriptiveString)
        self.IdentifierString = APIObject('IdentifierString', 'string', r'^[a-zA-Z0-9-]+$', 0, 256)
        self.add_api_object('IdentifierString', self.IdentifierString)
        self.MarkdownString = APIObject('MarkdownString', 'string', r'(.|\n)*', 0, 8000)
        self.add_api_object('MarkdownString', self.MarkdownString)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z0-9_=-]+$', 1, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.RequestString = APIObject('RequestString', 'string', r'.*\S.*', 0, 256)
        self.add_api_object('RequestString', self.RequestString)
        self.String = APIObject('String', 'string', r'.*\S.*', 0, 256)
        self.add_api_object('String', self.String)
        self.TagKey = APIObject('TagKey', 'string', r'^.*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^.*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class PinpointEmail(Service):
    def __init__(self):
        super().__init__('PinpointEmail')

class PinpointSmsVoiceV2(Service):
    def __init__(self):
        super().__init__('PinpointSmsVoiceV2')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'arn:[A-Za-z0-9_:/-]+', 20, 256)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.AttachmentUrl = APIObject('AttachmentUrl', 'string', r'\S+', 1, 2048)
        self.add_api_object('AttachmentUrl', self.AttachmentUrl)
        self.ClientToken = APIObject('ClientToken', 'string', r'[!-~]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ConfigurationSetName = APIObject('ConfigurationSetName', 'string', r'[A-Za-z0-9_-]+', 1, 64)
        self.add_api_object('ConfigurationSetName', self.ConfigurationSetName)
        self.ConfigurationSetNameOrArn = APIObject('ConfigurationSetNameOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('ConfigurationSetNameOrArn', self.ConfigurationSetNameOrArn)
        self.ContextKey = APIObject('ContextKey', 'string', r'\S+', 1, 100)
        self.add_api_object('ContextKey', self.ContextKey)
        self.ContextValue = APIObject('ContextValue', 'string', r'(?!\s)^[\s\S]+(?<!\s)', 1, 800)
        self.add_api_object('ContextValue', self.ContextValue)
        self.DeliveryStreamArn = APIObject('DeliveryStreamArn', 'string', r'arn:\S+', 20, 2048)
        self.add_api_object('DeliveryStreamArn', self.DeliveryStreamArn)
        self.DestinationCountryParameterValue = APIObject('DestinationCountryParameterValue', 'string', r'\S+', 1, 64)
        self.add_api_object('DestinationCountryParameterValue', self.DestinationCountryParameterValue)
        self.EventDestinationName = APIObject('EventDestinationName', 'string', r'[A-Za-z0-9_-]+', 1, 64)
        self.add_api_object('EventDestinationName', self.EventDestinationName)
        self.FieldPath = APIObject('FieldPath', 'string', r'[A-Za-z0-9_\.]+', 1, 100)
        self.add_api_object('FieldPath', self.FieldPath)
        self.FilterValue = APIObject('FilterValue', 'string', r'[/\.:A-Za-z0-9_-]+', 1, 128)
        self.add_api_object('FilterValue', self.FilterValue)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:\S+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IsoCountryCode = APIObject('IsoCountryCode', 'string', r'[A-Z]{2}', 2, 2)
        self.add_api_object('IsoCountryCode', self.IsoCountryCode)
        self.Keyword = APIObject('Keyword', 'string', r'[ \S]+', 1, 30)
        self.add_api_object('Keyword', self.Keyword)
        self.KeywordMessage = APIObject('KeywordMessage', 'string', r'(?!\s*$)[\s\S]+', 1, 1600)
        self.add_api_object('KeywordMessage', self.KeywordMessage)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'arn:\S+', 20, 2048)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.MaxPrice = APIObject('MaxPrice', 'string', r'[0-9]{0,2}\.[0-9]{1,5}', 2, 8)
        self.add_api_object('MaxPrice', self.MaxPrice)
        self.MediaMessageOriginationIdentity = APIObject('MediaMessageOriginationIdentity', 'string', r'[A-Za-z0-9_:/\+-]+', 1, 256)
        self.add_api_object('MediaMessageOriginationIdentity', self.MediaMessageOriginationIdentity)
        self.MediaUrlValue = APIObject('MediaUrlValue', 'string', r's3://([a-z0-9\.-]{3,63})/(.+)', 1, 2048)
        self.add_api_object('MediaUrlValue', self.MediaUrlValue)
        self.NextToken = APIObject('NextToken', 'string', r'.+', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.OptOutListName = APIObject('OptOutListName', 'string', r'[A-Za-z0-9_-]+', 1, 64)
        self.add_api_object('OptOutListName', self.OptOutListName)
        self.OptOutListNameOrArn = APIObject('OptOutListNameOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('OptOutListNameOrArn', self.OptOutListNameOrArn)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'\+?[1-9][0-9]{1,18}', 1, 20)
        self.add_api_object('PhoneNumber', self.PhoneNumber)
        self.PhoneNumberIdOrArn = APIObject('PhoneNumberIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('PhoneNumberIdOrArn', self.PhoneNumberIdOrArn)
        self.PhoneOrPoolIdOrArn = APIObject('PhoneOrPoolIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('PhoneOrPoolIdOrArn', self.PhoneOrPoolIdOrArn)
        self.PhoneOrSenderIdOrArn = APIObject('PhoneOrSenderIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('PhoneOrSenderIdOrArn', self.PhoneOrSenderIdOrArn)
        self.PoolIdOrArn = APIObject('PoolIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('PoolIdOrArn', self.PoolIdOrArn)
        self.ProtectConfigurationArn = APIObject('ProtectConfigurationArn', 'string', r'arn:\S+', 1, 256)
        self.add_api_object('ProtectConfigurationArn', self.ProtectConfigurationArn)
        self.ProtectConfigurationId = APIObject('ProtectConfigurationId', 'string', r'[A-Za-z0-9_-]+', 1, 64)
        self.add_api_object('ProtectConfigurationId', self.ProtectConfigurationId)
        self.ProtectConfigurationIdOrArn = APIObject('ProtectConfigurationIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('ProtectConfigurationIdOrArn', self.ProtectConfigurationIdOrArn)
        self.RegistrationAttachmentIdOrArn = APIObject('RegistrationAttachmentIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('RegistrationAttachmentIdOrArn', self.RegistrationAttachmentIdOrArn)
        self.RegistrationIdOrArn = APIObject('RegistrationIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('RegistrationIdOrArn', self.RegistrationIdOrArn)
        self.RegistrationType = APIObject('RegistrationType', 'string', r'[A-Za-z0-9_]+', 1, 64)
        self.add_api_object('RegistrationType', self.RegistrationType)
        self.ResourceIdOrArn = APIObject('ResourceIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('ResourceIdOrArn', self.ResourceIdOrArn)
        self.SectionPath = APIObject('SectionPath', 'string', r'[A-Za-z0-9_]+', 1, 100)
        self.add_api_object('SectionPath', self.SectionPath)
        self.SenderId = APIObject('SenderId', 'string', r'[A-Za-z0-9_-]+', 1, 11)
        self.add_api_object('SenderId', self.SenderId)
        self.SenderIdOrArn = APIObject('SenderIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('SenderIdOrArn', self.SenderIdOrArn)
        self.SnsTopicArn = APIObject('SnsTopicArn', 'string', r'arn:\S+', 20, 2048)
        self.add_api_object('SnsTopicArn', self.SnsTopicArn)
        self.TagKey = APIObject('TagKey', 'string', r'.+', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TextMessageBody = APIObject('TextMessageBody', 'string', r'(?!\s*$)[\s\S]+', 1, 1600)
        self.add_api_object('TextMessageBody', self.TextMessageBody)
        self.TextMessageOriginationIdentity = APIObject('TextMessageOriginationIdentity', 'string', r'[A-Za-z0-9_:/\+-]+', 1, 256)
        self.add_api_object('TextMessageOriginationIdentity', self.TextMessageOriginationIdentity)
        self.TwoWayChannelArn = APIObject('TwoWayChannelArn', 'string', r'\S+', 20, 2048)
        self.add_api_object('TwoWayChannelArn', self.TwoWayChannelArn)
        self.VerificationCode = APIObject('VerificationCode', 'string', r'[A-Za-z0-9]+', 1, 20)
        self.add_api_object('VerificationCode', self.VerificationCode)
        self.VerificationMessageOriginationIdentity = APIObject('VerificationMessageOriginationIdentity', 'string', r'[A-Za-z0-9_:/\+-]+', 1, 256)
        self.add_api_object('VerificationMessageOriginationIdentity', self.VerificationMessageOriginationIdentity)
        self.VerifiedDestinationNumberIdOrArn = APIObject('VerifiedDestinationNumberIdOrArn', 'string', r'[A-Za-z0-9_:/-]+', 1, 256)
        self.add_api_object('VerifiedDestinationNumberIdOrArn', self.VerifiedDestinationNumberIdOrArn)
        self.VoiceMessageBody = APIObject('VoiceMessageBody', 'string', r'(?!\s*$)[\s\S]+', 1, 6000)
        self.add_api_object('VoiceMessageBody', self.VoiceMessageBody)
        self.VoiceMessageOriginationIdentity = APIObject('VoiceMessageOriginationIdentity', 'string', r'[A-Za-z0-9_:/\+-]+', 1, 256)
        self.add_api_object('VoiceMessageOriginationIdentity', self.VoiceMessageOriginationIdentity)

class PinpointSmsVoice(Service):
    def __init__(self):
        super().__init__('PinpointSmsVoice')

class Pinpoint(Service):
    def __init__(self):
        super().__init__('Pinpoint')

class Pipes(Service):
    def __init__(self):
        super().__init__('Pipes')
        self.Arn = APIObject('Arn', 'string', r'^arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-]+):([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1})?:(\d{12})?:(.+)$', 1, 1600)
        self.add_api_object('Arn', self.Arn)
        self.ArnOrJsonPath = APIObject('ArnOrJsonPath', 'string', r'^arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-]+):([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1})?:(\d{12})?:(.+)|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 1, 1600)
        self.add_api_object('ArnOrJsonPath', self.ArnOrJsonPath)
        self.ArnOrUrl = APIObject('ArnOrUrl', 'string', r'^smk://(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9]):[0-9]{1,5}|arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-]+):([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1})?:(\d{12})?:(.+)$', 1, 1600)
        self.add_api_object('ArnOrUrl', self.ArnOrUrl)
        self.CloudwatchLogGroupArn = APIObject('CloudwatchLogGroupArn', 'string', r'^(^arn:aws([a-z]|\-)*:logs:([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}):(\d{12}):log-group:[\.\-_/#A-Za-z0-9]{1,512}(:\*)?)$', 1, 1600)
        self.add_api_object('CloudwatchLogGroupArn', self.CloudwatchLogGroupArn)
        self.EndpointString = APIObject('EndpointString', 'string', r'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9]):[0-9]{1,5}$', 1, 300)
        self.add_api_object('EndpointString', self.EndpointString)
        self.EventBridgeEndpointId = APIObject('EventBridgeEndpointId', 'string', r'^[A-Za-z0-9\-]+[\.][A-Za-z0-9\-]+$', 1, 50)
        self.add_api_object('EventBridgeEndpointId', self.EventBridgeEndpointId)
        self.EventBridgeEventSource = APIObject('EventBridgeEventSource', 'string', r'(?=[/\.\-_A-Za-z0-9]+)((?!aws\.).*)|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)', 1, 256)
        self.add_api_object('EventBridgeEventSource', self.EventBridgeEventSource)
        self.FirehoseArn = APIObject('FirehoseArn', 'string', r'^(^arn:aws([a-z]|\-)*:firehose:([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}):(\d{12}):deliverystream/[a-zA-Z0-9_.-]{1,64})$', 1, 1600)
        self.add_api_object('FirehoseArn', self.FirehoseArn)
        self.HeaderKey = APIObject('HeaderKey', 'string', r'^[!#$%&\'*+-.^_`|~0-9a-zA-Z]+|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 0, 512)
        self.add_api_object('HeaderKey', self.HeaderKey)
        self.HeaderValue = APIObject('HeaderValue', 'string', r'^[ \t]*[\x20-\x7E]+([ \t]+[\x20-\x7E]+)*[ \t]*|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 0, 512)
        self.add_api_object('HeaderValue', self.HeaderValue)
        self.JsonPath = APIObject('JsonPath', 'string', r'^\$(\.[\w/_-]+(\[(\d+|\*)\])*)*$', 1, 256)
        self.add_api_object('JsonPath', self.JsonPath)
        self.KafkaTopicName = APIObject('KafkaTopicName', 'string', r'^[^.]([a-zA-Z0-9\-_.]+)$', 1, 249)
        self.add_api_object('KafkaTopicName', self.KafkaTopicName)
        self.MQBrokerQueueName = APIObject('MQBrokerQueueName', 'string', r'^[\s\S]*$', 1, 1000)
        self.add_api_object('MQBrokerQueueName', self.MQBrokerQueueName)
        self.OptionalArn = APIObject('OptionalArn', 'string', r'^$|arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-]+):([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1})?:(\d{12})?:(.+)$', 0, 1600)
        self.add_api_object('OptionalArn', self.OptionalArn)
        self.PathParameter = APIObject('PathParameter', 'string', r'^(?!\s*$).+|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', None, None)
        self.add_api_object('PathParameter', self.PathParameter)
        self.PipeArn = APIObject('PipeArn', 'string', r'^arn:aws([a-z]|\-)*:([a-zA-Z0-9\-]+):([a-z]|\d|\-)*:([0-9]{12})?:(.+)$', 1, 1600)
        self.add_api_object('PipeArn', self.PipeArn)
        self.PipeDescription = APIObject('PipeDescription', 'string', r'^.*$', 0, 512)
        self.add_api_object('PipeDescription', self.PipeDescription)
        self.PipeName = APIObject('PipeName', 'string', r'^[\.\-_A-Za-z0-9]+$', 1, 64)
        self.add_api_object('PipeName', self.PipeName)
        self.PipeStateReason = APIObject('PipeStateReason', 'string', r'^.*$', 0, 512)
        self.add_api_object('PipeStateReason', self.PipeStateReason)
        self.QueryStringKey = APIObject('QueryStringKey', 'string', r'^[^\x00-\x1F\x7F]+|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 0, 512)
        self.add_api_object('QueryStringKey', self.QueryStringKey)
        self.QueryStringValue = APIObject('QueryStringValue', 'string', r'^[^\x00-\x09\x0B\x0C\x0E-\x1F\x7F]+|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 0, 512)
        self.add_api_object('QueryStringValue', self.QueryStringValue)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:iam::\d{12}:role/?[a-zA-Z0-9+=,.@\-_/]+$', 1, 1600)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3LogDestinationParametersBucketOwnerString = APIObject('S3LogDestinationParametersBucketOwnerString', 'string', r'^\d{12}$', None, None)
        self.add_api_object('S3LogDestinationParametersBucketOwnerString', self.S3LogDestinationParametersBucketOwnerString)
        self.SageMakerPipelineParameterName = APIObject('SageMakerPipelineParameterName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 1, 256)
        self.add_api_object('SageMakerPipelineParameterName', self.SageMakerPipelineParameterName)
        self.SecretManagerArn = APIObject('SecretManagerArn', 'string', r'^(^arn:aws([a-z]|\-)*:secretsmanager:([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}):(\d{12}):secret:.+)$', 1, 1600)
        self.add_api_object('SecretManagerArn', self.SecretManagerArn)
        self.SecretManagerArnOrJsonPath = APIObject('SecretManagerArnOrJsonPath', 'string', r'^(^arn:aws([a-z]|\-)*:secretsmanager:([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}):(\d{12}):secret:.+)|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 1, 1600)
        self.add_api_object('SecretManagerArnOrJsonPath', self.SecretManagerArnOrJsonPath)
        self.SecurityGroup = APIObject('SecurityGroup', 'string', r'^sg-[0-9a-zA-Z]*|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 1, 1024)
        self.add_api_object('SecurityGroup', self.SecurityGroup)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-[0-9a-zA-Z]*$', 1, 1024)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.Subnet = APIObject('Subnet', 'string', r'^subnet-[0-9a-z]*|(\$(\.[\w/_-]+(\[(\d+|\*)\])*)*)$', 1, 1024)
        self.add_api_object('Subnet', self.Subnet)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-[0-9a-z]*$', 1, 1024)
        self.add_api_object('SubnetId', self.SubnetId)
        self.URI = APIObject('URI', 'string', r'^[a-zA-Z0-9-\/*:_+=.@-]*$', 1, 200)
        self.add_api_object('URI', self.URI)

class Polly(Service):
    def __init__(self):
        super().__init__('Polly')
        self.LexiconName = APIObject('LexiconName', 'string', r'[0-9A-Za-z]{1,20}', None, None)
        self.add_api_object('LexiconName', self.LexiconName)
        self.OutputS3BucketName = APIObject('OutputS3BucketName', 'string', r'^[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]$', None, None)
        self.add_api_object('OutputS3BucketName', self.OutputS3BucketName)
        self.OutputS3KeyPrefix = APIObject('OutputS3KeyPrefix', 'string', r'''^[0-9a-zA-Z\/\!\-_\.\*\\'\(\):;\$@=+\,\?&]{0,800}$''', None, None)
        self.add_api_object('OutputS3KeyPrefix', self.OutputS3KeyPrefix)
        self.SnsTopicArn = APIObject('SnsTopicArn', 'string', r'^arn:aws(-(cn|iso(-b)?|us-gov))?:sns:[a-z0-9_-]{1,50}:\d{12}:[a-zA-Z0-9_-]{1,251}([a-zA-Z0-9_-]{0,5}|\.fifo)$', None, None)
        self.add_api_object('SnsTopicArn', self.SnsTopicArn)
        self.TaskId = APIObject('TaskId', 'string', r'^[a-zA-Z0-9_-]{1,100}$', None, None)
        self.add_api_object('TaskId', self.TaskId)

class Pricing(Service):
    def __init__(self):
        super().__init__('Pricing')
        self.CurrencyCode = APIObject('CurrencyCode', 'string', r'[A-Z]{3}', None, None)
        self.add_api_object('CurrencyCode', self.CurrencyCode)
        self.PriceListArn = APIObject('PriceListArn', 'string', r'arn:[A-Za-z0-9][-.A-Za-z0-9]{0,62}:pricing:::price-list/[A-Za-z0-9+_/.-]{1,1023}', 18, 2048)
        self.add_api_object('PriceListArn', self.PriceListArn)

class Privatenetworks(Service):
    def __init__(self):
        super().__init__('Privatenetworks')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws:private-networks:[a-z0-9-]+:[^:]*:.*$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.DeviceIdentifierImsiString = APIObject('DeviceIdentifierImsiString', 'string', r'^[0-9]{15}$', None, None)
        self.add_api_object('DeviceIdentifierImsiString', self.DeviceIdentifierImsiString)
        self.Name = APIObject('Name', 'string', r'^[0-9a-zA-Z-]*$', 1, 64)
        self.add_api_object('Name', self.Name)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[^\x00-\x1f\x22]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[^\x00-\x1f\x22]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Proton(Service):
    def __init__(self):
        super().__init__('Proton')
        self.Arn = APIObject('Arn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):[a-zA-Z0-9-]+:[a-zA-Z0-9-]*:\d{12}:([\w+=,.@-]+[/:])*[\w+=,.@-]+$', 1, 200)
        self.add_api_object('Arn', self.Arn)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[!-~]*$', 0, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DeploymentId = APIObject('DeploymentId', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', None, None)
        self.add_api_object('DeploymentId', self.DeploymentId)
        self.EnvironmentAccountConnectionId = APIObject('EnvironmentAccountConnectionId', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', None, None)
        self.add_api_object('EnvironmentAccountConnectionId', self.EnvironmentAccountConnectionId)
        self.FullTemplateVersionNumber = APIObject('FullTemplateVersionNumber', 'string', r'^(0|([1-9]{1}\d*)).(0|([1-9]{1}\d*))$', 1, 10)
        self.add_api_object('FullTemplateVersionNumber', self.FullTemplateVersionNumber)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z0-9+=/]+$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.RepositoryName = APIObject('RepositoryName', 'string', r'[A-Za-z0-9_.-].*/[A-Za-z0-9_.-].*', 1, 100)
        self.add_api_object('RepositoryName', self.RepositoryName)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[0-9A-Za-z]+[0-9A-Za-z_\-]*$', 1, 100)
        self.add_api_object('ResourceName', self.ResourceName)
        self.ResourceNameOrEmpty = APIObject('ResourceNameOrEmpty', 'string', r'(^$)|^[0-9A-Za-z]+[0-9A-Za-z_\-]*$', 0, 100)
        self.add_api_object('ResourceNameOrEmpty', self.ResourceNameOrEmpty)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov):iam::\d{12}:role/([\w+=,.@-]{1,512}[/:])*([\w+=,.@-]{1,64})$', 1, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.RoleArnOrEmptyString = APIObject('RoleArnOrEmptyString', 'string', r'(^$)|(^arn:(aws|aws-cn|aws-us-gov):iam::\d{12}:role/([\w+=,.@-]{1,512}[/:])*([\w+=,.@-]{1,64})$)', 0, 2048)
        self.add_api_object('RoleArnOrEmptyString', self.RoleArnOrEmptyString)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[a-z0-9]+[a-z0-9-\.]+[a-z0-9]+$', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.TemplateVersionPart = APIObject('TemplateVersionPart', 'string', r'^(0|([1-9]{1}\d*))$', 1, 20)
        self.add_api_object('TemplateVersionPart', self.TemplateVersionPart)

class Qbusiness(Service):
    def __init__(self):
        super().__init__('Qbusiness')
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ApplicationName = APIObject('ApplicationName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('ApplicationName', self.ApplicationName)
        self.AttachmentName = APIObject('AttachmentName', 'string', r'\P{C}*', 1, 1000)
        self.add_api_object('AttachmentName', self.AttachmentName)
        self.BlockedPhrase = APIObject('BlockedPhrase', 'string', r'\P{C}*', 0, 36)
        self.add_api_object('BlockedPhrase', self.BlockedPhrase)
        self.ConversationId = APIObject('ConversationId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('ConversationId', self.ConversationId)
        self.DataSourceArn = APIObject('DataSourceArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('DataSourceArn', self.DataSourceArn)
        self.DataSourceId = APIObject('DataSourceId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('DataSourceId', self.DataSourceId)
        self.DataSourceName = APIObject('DataSourceName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('DataSourceName', self.DataSourceName)
        self.DataSourceUserId = APIObject('DataSourceUserId', 'string', r'\P{C}*', 1, 1024)
        self.add_api_object('DataSourceUserId', self.DataSourceUserId)
        self.Description = APIObject('Description', 'string', r'\P{C}*', 0, 1000)
        self.add_api_object('Description', self.Description)
        self.DocumentAttributeKey = APIObject('DocumentAttributeKey', 'string', r'[a-zA-Z0-9_][a-zA-Z0-9_-]*', 1, 200)
        self.add_api_object('DocumentAttributeKey', self.DocumentAttributeKey)
        self.DocumentId = APIObject('DocumentId', 'string', r'\P{C}*', 1, 1825)
        self.add_api_object('DocumentId', self.DocumentId)
        self.DocumentMetadataConfigurationName = APIObject('DocumentMetadataConfigurationName', 'string', r'[a-zA-Z0-9_][a-zA-Z0-9_-]*', 1, 30)
        self.add_api_object('DocumentMetadataConfigurationName', self.DocumentMetadataConfigurationName)
        self.ErrorMessage = APIObject('ErrorMessage', 'string', r'\P{C}*', 1, 2048)
        self.add_api_object('ErrorMessage', self.ErrorMessage)
        self.ExampleChatMessage = APIObject('ExampleChatMessage', 'string', r'\P{C}*', 0, 350)
        self.add_api_object('ExampleChatMessage', self.ExampleChatMessage)
        self.ExecutionId = APIObject('ExecutionId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('ExecutionId', self.ExecutionId)
        self.GroupName = APIObject('GroupName', 'string', r'\P{C}*', 1, 1024)
        self.add_api_object('GroupName', self.GroupName)
        self.IdcApplicationArn = APIObject('IdcApplicationArn', 'string', r'arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16}', 10, 1224)
        self.add_api_object('IdcApplicationArn', self.IdcApplicationArn)
        self.IndexArn = APIObject('IndexArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('IndexArn', self.IndexArn)
        self.IndexId = APIObject('IndexId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('IndexId', self.IndexId)
        self.IndexName = APIObject('IndexName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('IndexName', self.IndexName)
        self.InstanceArn = APIObject('InstanceArn', 'string', r'arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso:::instance/(sso)?ins-[a-zA-Z0-9-.]{16}', 10, 1224)
        self.add_api_object('InstanceArn', self.InstanceArn)
        self.KendraIndexId = APIObject('KendraIndexId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('KendraIndexId', self.KendraIndexId)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'arn:aws[a-zA-Z-]*:lambda:[a-z-]*-[0-9]:[0-9]{12}:function:[a-zA-Z0-9-_]+(/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})?(:[a-zA-Z0-9-_]+)?', 1, 2048)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.MessageBody = APIObject('MessageBody', 'string', r'\P{C}*$}', 0, 1000)
        self.add_api_object('MessageBody', self.MessageBody)
        self.MessageId = APIObject('MessageId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('MessageId', self.MessageId)
        self.MessageUsefulnessComment = APIObject('MessageUsefulnessComment', 'string', r'\P{C}*', 0, 1000)
        self.add_api_object('MessageUsefulnessComment', self.MessageUsefulnessComment)
        self.MetricValue = APIObject('MetricValue', 'string', r'(([1-9][0-9]*)|0)', None, None)
        self.add_api_object('MetricValue', self.MetricValue)
        self.PluginArn = APIObject('PluginArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('PluginArn', self.PluginArn)
        self.PluginId = APIObject('PluginId', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 36, 36)
        self.add_api_object('PluginId', self.PluginId)
        self.PluginName = APIObject('PluginName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 100)
        self.add_api_object('PluginName', self.PluginName)
        self.RetrieverArn = APIObject('RetrieverArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('RetrieverArn', self.RetrieverArn)
        self.RetrieverId = APIObject('RetrieverId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('RetrieverId', self.RetrieverId)
        self.RetrieverName = APIObject('RetrieverName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 1000)
        self.add_api_object('RetrieverName', self.RetrieverName)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', 1, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.SamlMetadataXML = APIObject('SamlMetadataXML', 'string', r'.*', 1000, 10000000)
        self.add_api_object('SamlMetadataXML', self.SamlMetadataXML)
        self.SecretArn = APIObject('SecretArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('SecretArn', self.SecretArn)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'[-0-9a-zA-Z]+', 1, 200)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'[-0-9a-zA-Z]+', 1, 200)
        self.add_api_object('SubnetId', self.SubnetId)
        self.SyncSchedule = APIObject('SyncSchedule', 'string', r'\P{C}*', 0, 998)
        self.add_api_object('SyncSchedule', self.SyncSchedule)
        self.SystemMessageId = APIObject('SystemMessageId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{35}', 36, 36)
        self.add_api_object('SystemMessageId', self.SystemMessageId)
        self.SystemMessageOverride = APIObject('SystemMessageOverride', 'string', r'\P{C}*', 0, 350)
        self.add_api_object('SystemMessageOverride', self.SystemMessageOverride)
        self.TopicConfigurationName = APIObject('TopicConfigurationName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]{0,35}', 1, 36)
        self.add_api_object('TopicConfigurationName', self.TopicConfigurationName)
        self.TopicDescription = APIObject('TopicDescription', 'string', r'\P{C}*', 0, 350)
        self.add_api_object('TopicDescription', self.TopicDescription)
        self.Url = APIObject('Url', 'string', r'(https?|ftp|file)://([^\s]*)', 1, 2048)
        self.add_api_object('Url', self.Url)
        self.UserId = APIObject('UserId', 'string', r'\P{C}*', 1, 1024)
        self.add_api_object('UserId', self.UserId)
        self.WebExperienceArn = APIObject('WebExperienceArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 0, 1284)
        self.add_api_object('WebExperienceArn', self.WebExperienceArn)
        self.WebExperienceId = APIObject('WebExperienceId', 'string', r'[a-zA-Z0-9][a-zA-Z0-9-]*', 36, 36)
        self.add_api_object('WebExperienceId', self.WebExperienceId)
        self.WebExperienceSubtitle = APIObject('WebExperienceSubtitle', 'string', r'\P{C}*', 0, 500)
        self.add_api_object('WebExperienceSubtitle', self.WebExperienceSubtitle)
        self.WebExperienceTitle = APIObject('WebExperienceTitle', 'string', r'\P{C}*', 0, 500)
        self.add_api_object('WebExperienceTitle', self.WebExperienceTitle)

class Qconnect(Service):
    def __init__(self):
        super().__init__('Qconnect')
        self.Arn = APIObject('Arn', 'string', r'^arn:[a-z-]*?:wisdom:[a-z0-9-]*?:[0-9]{12}:[a-z-]*?/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}(?:/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})?$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ContentType = APIObject('ContentType', 'string', r'^(text/(plain|html|csv))|(application/(pdf|vnd\.openxmlformats-officedocument\.wordprocessingml\.document))|(application/x\.wisdom-json;source=(salesforce|servicenow|zendesk))$', None, None)
        self.add_api_object('ContentType', self.ContentType)
        self.Description = APIObject('Description', 'string', r'^[a-zA-Z0-9\s_.,-]+', 1, 255)
        self.add_api_object('Description', self.Description)
        self.GenericArn = APIObject('GenericArn', 'string', r'^arn:[a-z-]+?:[a-z-]+?:[a-z0-9-]*?:([0-9]{12})?:[a-zA-Z0-9-:/]+$', 1, 2048)
        self.add_api_object('GenericArn', self.GenericArn)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9\s_.,-]+', 1, 255)
        self.add_api_object('Name', self.Name)
        self.QuickResponseType = APIObject('QuickResponseType', 'string', r'^(application/x\.quickresponse;format=(plain|markdown))$', None, None)
        self.add_api_object('QuickResponseType', self.QuickResponseType)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Uuid = APIObject('Uuid', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('Uuid', self.Uuid)
        self.UuidOrArn = APIObject('UuidOrArn', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$|^arn:[a-z-]*?:wisdom:[a-z0-9-]*?:[0-9]{12}:[a-z-]*?/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}(?:/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})?$', None, None)
        self.add_api_object('UuidOrArn', self.UuidOrArn)

class QldbSession(Service):
    def __init__(self):
        super().__init__('QldbSession')
        self.LedgerName = APIObject('LedgerName', 'string', r'(?!^.*--)(?!^[0-9]+$)(?!^-)(?!.*-$)^[A-Za-z0-9-]+$', 1, 32)
        self.add_api_object('LedgerName', self.LedgerName)
        self.PageToken = APIObject('PageToken', 'string', r'^[A-Za-z-0-9+/=]+$', 4, 1024)
        self.add_api_object('PageToken', self.PageToken)
        self.SessionToken = APIObject('SessionToken', 'string', r'^[A-Za-z-0-9+/=]+$', 4, 1024)
        self.add_api_object('SessionToken', self.SessionToken)
        self.TransactionId = APIObject('TransactionId', 'string', r'^[A-Za-z-0-9]+$', 22, 22)
        self.add_api_object('TransactionId', self.TransactionId)

class Qldb(Service):
    def __init__(self):
        super().__init__('Qldb')
        self.LedgerName = APIObject('LedgerName', 'string', r'(?!^.*--)(?!^[0-9]+$)(?!^-)(?!.*-$)^[A-Za-z0-9-]+$', 1, 32)
        self.add_api_object('LedgerName', self.LedgerName)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z-0-9+/=]+$', 4, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'^[A-Za-z-0-9-_.]+$', 3, 255)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.StreamName = APIObject('StreamName', 'string', r'(?!^.*--)(?!^[0-9]+$)(?!^-)(?!.*-$)^[A-Za-z0-9-]+$', 1, 32)
        self.add_api_object('StreamName', self.StreamName)
        self.UniqueId = APIObject('UniqueId', 'string', r'^[A-Za-z-0-9]+$', 22, 22)
        self.add_api_object('UniqueId', self.UniqueId)

class Ram(Service):
    def __init__(self):
        super().__init__('Ram')
        self.PermissionName = APIObject('PermissionName', 'string', r'[\w.-]*', 1, 36)
        self.add_api_object('PermissionName', self.PermissionName)

class Rbin(Service):
    def __init__(self):
        super().__init__('Rbin')
        self.Description = APIObject('Description', 'string', r'^[\S ]{0,255}$', None, None)
        self.add_api_object('Description', self.Description)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z0-9+/=]{1,2048}$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceTagKey = APIObject('ResourceTagKey', 'string', r'^[\S\s]{1,128}$', None, None)
        self.add_api_object('ResourceTagKey', self.ResourceTagKey)
        self.ResourceTagValue = APIObject('ResourceTagValue', 'string', r'^[\S\s]{0,256}$', None, None)
        self.add_api_object('ResourceTagValue', self.ResourceTagValue)
        self.RuleArn = APIObject('RuleArn', 'string', r'^arn:aws(-[a-z]{1,3}){0,2}:rbin:[a-z\-0-9]{0,63}:[0-9]{12}:rule/[0-9a-zA-Z]{11}{0,1011}$', 0, 1011)
        self.add_api_object('RuleArn', self.RuleArn)
        self.RuleIdentifier = APIObject('RuleIdentifier', 'string', r'[0-9a-zA-Z]{11}', None, None)
        self.add_api_object('RuleIdentifier', self.RuleIdentifier)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class RdsData(Service):
    def __init__(self):
        super().__init__('RdsData')

class Rds(Service):
    def __init__(self):
        super().__init__('Rds')

class RedshiftData(Service):
    def __init__(self):
        super().__init__('RedshiftData')
        self.ParameterName = APIObject('ParameterName', 'string', r'^[0-9a-zA-Z_]+$', None, None)
        self.add_api_object('ParameterName', self.ParameterName)
        self.StatementId = APIObject('StatementId', 'string', r'^[a-z0-9]{8}(-[a-z0-9]{4}){3}-[a-z0-9]{12}(:\d+)?$', None, None)
        self.add_api_object('StatementId', self.StatementId)
        self.WorkgroupNameString = APIObject('WorkgroupNameString', 'string', r'^(([a-z0-9-]+)|(arn:(aws(-[a-z]+)*):redshift-serverless:[a-z]{2}(-gov)?-[a-z]+-\d{1}:\d{12}:workgroup/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}))$', 3, 128)
        self.add_api_object('WorkgroupNameString', self.WorkgroupNameString)

class RedshiftServerless(Service):
    def __init__(self):
        super().__init__('RedshiftServerless')
        self.CustomDomainCertificateArnString = APIObject('CustomDomainCertificateArnString', 'string', r'arn:[\w+=/,.@-]+:acm:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=,.@-]+)*', 20, 2048)
        self.add_api_object('CustomDomainCertificateArnString', self.CustomDomainCertificateArnString)
        self.CustomDomainName = APIObject('CustomDomainName', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', 1, 253)
        self.add_api_object('CustomDomainName', self.CustomDomainName)
        self.NamespaceName = APIObject('NamespaceName', 'string', r'^[a-z0-9-]+$', 3, 64)
        self.add_api_object('NamespaceName', self.NamespaceName)
        self.OwnerAccount = APIObject('OwnerAccount', 'string', r'(\d{12})', 1, 12)
        self.add_api_object('OwnerAccount', self.OwnerAccount)
        self.ScheduledActionName = APIObject('ScheduledActionName', 'string', r'^[a-z0-9-]+$', 3, 60)
        self.add_api_object('ScheduledActionName', self.ScheduledActionName)
        self.WorkgroupName = APIObject('WorkgroupName', 'string', r'^[a-z0-9-]+$', 3, 64)
        self.add_api_object('WorkgroupName', self.WorkgroupName)

class Redshift(Service):
    def __init__(self):
        super().__init__('Redshift')
        self.AuthenticationProfileNameString = APIObject('AuthenticationProfileNameString', 'string', r'^[a-zA-Z0-9\-]+$', None, 63)
        self.add_api_object('AuthenticationProfileNameString', self.AuthenticationProfileNameString)
        self.CustomDomainCertificateArnString = APIObject('CustomDomainCertificateArnString', 'string', r'arn:[\w+=/,.@-]+:acm:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=,.@-]+)*', 20, 2048)
        self.add_api_object('CustomDomainCertificateArnString', self.CustomDomainCertificateArnString)
        self.CustomDomainNameString = APIObject('CustomDomainNameString', 'string', r'^(((?!-)[A-Za-z0-9-]{0,62}[A-Za-z0-9])\.)+((?!-)[A-Za-z0-9-]{1,62}[A-Za-z0-9])$', 1, 253)
        self.add_api_object('CustomDomainNameString', self.CustomDomainNameString)
        self.IdcDisplayNameString = APIObject('IdcDisplayNameString', 'string', r'[\w+=,.@-]+', 1, 127)
        self.add_api_object('IdcDisplayNameString', self.IdcDisplayNameString)
        self.IdentityNamespaceString = APIObject('IdentityNamespaceString', 'string', r'^[a-zA-Z0-9_+.#@$-]+$', 1, 127)
        self.add_api_object('IdentityNamespaceString', self.IdentityNamespaceString)
        self.PartnerIntegrationAccountId = APIObject('PartnerIntegrationAccountId', 'string', r'^[0-9]+$', 12, 12)
        self.add_api_object('PartnerIntegrationAccountId', self.PartnerIntegrationAccountId)
        self.PartnerIntegrationClusterIdentifier = APIObject('PartnerIntegrationClusterIdentifier', 'string', r'^[a-zA-Z0-9\-]+$', None, 63)
        self.add_api_object('PartnerIntegrationClusterIdentifier', self.PartnerIntegrationClusterIdentifier)
        self.PartnerIntegrationDatabaseName = APIObject('PartnerIntegrationDatabaseName', 'string', r'^[\p{L}_][\p{L}\p{N}@$#_]+$', None, 127)
        self.add_api_object('PartnerIntegrationDatabaseName', self.PartnerIntegrationDatabaseName)
        self.PartnerIntegrationPartnerName = APIObject('PartnerIntegrationPartnerName', 'string', r'^[a-zA-Z0-9\-_]+$', None, 255)
        self.add_api_object('PartnerIntegrationPartnerName', self.PartnerIntegrationPartnerName)
        self.PartnerIntegrationStatusMessage = APIObject('PartnerIntegrationStatusMessage', 'string', r'^[\x20-\x7E]+$', None, 262144)
        self.add_api_object('PartnerIntegrationStatusMessage', self.PartnerIntegrationStatusMessage)
        self.RedshiftIdcApplicationName = APIObject('RedshiftIdcApplicationName', 'string', r'[a-z][a-z0-9]*(-[a-z0-9]+)*', 1, 63)
        self.add_api_object('RedshiftIdcApplicationName', self.RedshiftIdcApplicationName)

class Rekognition(Service):
    def __init__(self):
        super().__init__('Rekognition')
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.CollectionId = APIObject('CollectionId', 'string', r'[a-zA-Z0-9_.\-]+', 1, 255)
        self.add_api_object('CollectionId', self.CollectionId)
        self.DatasetArn = APIObject('DatasetArn', 'string', r'(^arn:[a-z\d-]+:rekognition:[a-z\d-]+:\d{12}:project\/[a-zA-Z0-9_.\-]{1,255}\/dataset\/(train|test)\/[0-9]+$)', 20, 2048)
        self.add_api_object('DatasetArn', self.DatasetArn)
        self.DatasetEntry = APIObject('DatasetEntry', 'string', r'^\{.*\}$', 1, 100000)
        self.add_api_object('DatasetEntry', self.DatasetEntry)
        self.DatasetLabel = APIObject('DatasetLabel', 'string', r'.{1,}', 1, 255)
        self.add_api_object('DatasetLabel', self.DatasetLabel)
        self.ExternalImageId = APIObject('ExternalImageId', 'string', r'[a-zA-Z0-9_.\-:]+', 1, 255)
        self.add_api_object('ExternalImageId', self.ExternalImageId)
        self.FaceId = APIObject('FaceId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('FaceId', self.FaceId)
        self.GeneralLabelsFilterValue = APIObject('GeneralLabelsFilterValue', 'string', r'[A-Za-z0-9àâèçñó\'-_(). ]*', 0, 50)
        self.add_api_object('GeneralLabelsFilterValue', self.GeneralLabelsFilterValue)
        self.HumanLoopName = APIObject('HumanLoopName', 'string', r'^[a-z0-9](-*[a-z0-9])*', 1, 63)
        self.add_api_object('HumanLoopName', self.HumanLoopName)
        self.ImageId = APIObject('ImageId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', None, None)
        self.add_api_object('ImageId', self.ImageId)
        self.IndexFacesModelVersion = APIObject('IndexFacesModelVersion', 'string', r'[0-9\.]+', None, None)
        self.add_api_object('IndexFacesModelVersion', self.IndexFacesModelVersion)
        self.JobId = APIObject('JobId', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('JobId', self.JobId)
        self.JobTag = APIObject('JobTag', 'string', r'[a-zA-Z0-9_.\-:+=\/]+', 1, 1024)
        self.add_api_object('JobTag', self.JobTag)
        self.KinesisDataArn = APIObject('KinesisDataArn', 'string', r'(^arn:([a-z\d-]+):kinesis:([a-z\d-]+):\d{12}:.+$)', None, None)
        self.add_api_object('KinesisDataArn', self.KinesisDataArn)
        self.KinesisVideoArn = APIObject('KinesisVideoArn', 'string', r'(^arn:([a-z\d-]+):kinesisvideo:([a-z\d-]+):\d{12}:.+$)', None, None)
        self.add_api_object('KinesisVideoArn', self.KinesisVideoArn)
        self.KinesisVideoStreamFragmentNumber = APIObject('KinesisVideoStreamFragmentNumber', 'string', r'^[0-9]+$', 1, 128)
        self.add_api_object('KinesisVideoStreamFragmentNumber', self.KinesisVideoStreamFragmentNumber)
        self.KmsKeyId = APIObject('KmsKeyId', 'string', r'^[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,2048}$', 1, 2048)
        self.add_api_object('KmsKeyId', self.KmsKeyId)
        self.LivenessS3KeyPrefix = APIObject('LivenessS3KeyPrefix', 'string', r'\S*', None, 950)
        self.add_api_object('LivenessS3KeyPrefix', self.LivenessS3KeyPrefix)
        self.LivenessSessionId = APIObject('LivenessSessionId', 'string', r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 36, 36)
        self.add_api_object('LivenessSessionId', self.LivenessSessionId)
        self.MediaAnalysisJobId = APIObject('MediaAnalysisJobId', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('MediaAnalysisJobId', self.MediaAnalysisJobId)
        self.MediaAnalysisJobName = APIObject('MediaAnalysisJobName', 'string', r'[a-zA-Z0-9_.\-]+', 1, 64)
        self.add_api_object('MediaAnalysisJobName', self.MediaAnalysisJobName)
        self.MediaAnalysisS3KeyPrefix = APIObject('MediaAnalysisS3KeyPrefix', 'string', r'\S*', None, 800)
        self.add_api_object('MediaAnalysisS3KeyPrefix', self.MediaAnalysisS3KeyPrefix)
        self.ProjectArn = APIObject('ProjectArn', 'string', r'(^arn:[a-z\d-]+:rekognition:[a-z\d-]+:\d{12}:project\/[a-zA-Z0-9_.\-]{1,255}\/[0-9]+$)', 20, 2048)
        self.add_api_object('ProjectArn', self.ProjectArn)
        self.ProjectName = APIObject('ProjectName', 'string', r'[a-zA-Z0-9_.\-]+', 1, 255)
        self.add_api_object('ProjectName', self.ProjectName)
        self.ProjectPolicyDocument = APIObject('ProjectPolicyDocument', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 2000)
        self.add_api_object('ProjectPolicyDocument', self.ProjectPolicyDocument)
        self.ProjectPolicyName = APIObject('ProjectPolicyName', 'string', r'[a-zA-Z0-9_.\-]+', 1, 128)
        self.add_api_object('ProjectPolicyName', self.ProjectPolicyName)
        self.ProjectPolicyRevisionId = APIObject('ProjectPolicyRevisionId', 'string', r'[0-9A-Fa-f]+', None, 64)
        self.add_api_object('ProjectPolicyRevisionId', self.ProjectPolicyRevisionId)
        self.ProjectVersionArn = APIObject('ProjectVersionArn', 'string', r'(^arn:[a-z\d-]+:rekognition:[a-z\d-]+:\d{12}:project\/[a-zA-Z0-9_.\-]{1,255}\/version\/[a-zA-Z0-9_.\-]{1,255}\/[0-9]+$)', 20, 2048)
        self.add_api_object('ProjectVersionArn', self.ProjectVersionArn)
        self.ProjectVersionId = APIObject('ProjectVersionId', 'string', r'(^arn:[a-z\d-]+:rekognition:[a-z\d-]+:\d{12}:project\/[a-zA-Z0-9_.\-]{1,255}\/version\/[a-zA-Z0-9_.\-]{1,255}\/[0-9]+$)', 20, 2048)
        self.add_api_object('ProjectVersionId', self.ProjectVersionId)
        self.QueryString = APIObject('QueryString', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('QueryString', self.QueryString)
        self.RekognitionUniqueId = APIObject('RekognitionUniqueId', 'string', r'[0-9A-Za-z]*', None, None)
        self.add_api_object('RekognitionUniqueId', self.RekognitionUniqueId)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[0-9A-Za-z\.\-_]*', 3, 255)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.SNSTopicArn = APIObject('SNSTopicArn', 'string', r'(^arn:aws:sns:.*:\w{12}:.+$)', None, None)
        self.add_api_object('SNSTopicArn', self.SNSTopicArn)
        self.StreamProcessorArn = APIObject('StreamProcessorArn', 'string', r'(^arn:[a-z\d-]+:rekognition:[a-z\d-]+:\d{12}:streamprocessor\/.+$)', None, None)
        self.add_api_object('StreamProcessorArn', self.StreamProcessorArn)
        self.StreamProcessorName = APIObject('StreamProcessorName', 'string', r'[a-zA-Z0-9_.\-]+', 1, 128)
        self.add_api_object('StreamProcessorName', self.StreamProcessorName)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[\p{L}\p{Z}\p{N}_.:/=+\-@]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UserId = APIObject('UserId', 'string', r'[a-zA-Z0-9_.\-:]+', 1, 128)
        self.add_api_object('UserId', self.UserId)
        self.VersionDescription = APIObject('VersionDescription', 'string', r'[a-zA-Z0-9-_. ()\':,;?]+', 1, 255)
        self.add_api_object('VersionDescription', self.VersionDescription)
        self.VersionName = APIObject('VersionName', 'string', r'[a-zA-Z0-9_.\-]+', 1, 255)
        self.add_api_object('VersionName', self.VersionName)

class Repostspace(Service):
    def __init__(self):
        super().__init__('Repostspace')
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Resiliencehub(Service):
    def __init__(self):
        super().__init__('Resiliencehub')
        self.AppTemplateBody = APIObject('AppTemplateBody', 'string', r'^[\w\s:,-\.\'\/{}\[\]:"\\]+$', 0, 409600)
        self.add_api_object('AppTemplateBody', self.AppTemplateBody)
        self.Arn = APIObject('Arn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-[a-z]{1}|aws-us-gov):[A-Za-z0-9][A-Za-z0-9_/.-]{0,62}:([a-z]{2}-((iso[a-z]{0,1}-)|(gov-)){0,1}[a-z]+-[0-9]):[0-9]{12}:[A-Za-z0-9/][A-Za-z0-9:_/+.-]{0,1023}$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.AwsRegion = APIObject('AwsRegion', 'string', r'^[a-z]{2}-((iso[a-z]{0,1}-)|(gov-)){0,1}[a-z]+-[0-9]$', None, None)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[A-za-z0-9_.-]{0,63}$', 1, 63)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CustomerId = APIObject('CustomerId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('CustomerId', self.CustomerId)
        self.EksNamespace = APIObject('EksNamespace', 'string', r'^[a-z0-9]([-a-z0-9]*[a-z0-9])?$', 1, 63)
        self.add_api_object('EksNamespace', self.EksNamespace)
        self.EntityId = APIObject('EntityId', 'string', r'^\S{1,255}$', None, None)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityName = APIObject('EntityName', 'string', r'^[A-Za-z0-9][A-Za-z0-9_\-]{1,59}$', None, None)
        self.add_api_object('EntityName', self.EntityName)
        self.EntityVersion = APIObject('EntityVersion', 'string', r'^\S{1,50}$', None, None)
        self.add_api_object('EntityVersion', self.EntityVersion)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-[a-z]{1}|aws-us-gov):iam::[0-9]{12}:role/(([^/][!-~]+/){1,511})?[A-Za-z0-9_+=,.@-]{1,64}$', None, None)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IamRoleName = APIObject('IamRoleName', 'string', r'^([^/]([!-~]+/){1,511})?[A-Za-z0-9_+=,.@-]{1,64}$', None, None)
        self.add_api_object('IamRoleName', self.IamRoleName)
        self.NextToken = APIObject('NextToken', 'string', r'^\S{1,2000}$', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceId = APIObject('ResourceId', 'string', r'.*', None, None)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceType = APIObject('ResourceType', 'string', r'.*', None, None)
        self.add_api_object('ResourceType', self.ResourceType)
        self.S3Url = APIObject('S3Url', 'string', r'^((https://([^/]+)\.s3((-|\.)[^/]+)?\.amazonaws\.com(.cn)?)|(s3://([^/]+)))/\S{1,2000}$', 0, 2000)
        self.add_api_object('S3Url', self.S3Url)
        self.String128WithoutWhitespace = APIObject('String128WithoutWhitespace', 'string', r'^\S{1,128}$', None, None)
        self.add_api_object('String128WithoutWhitespace', self.String128WithoutWhitespace)
        self.TagKey = APIObject('TagKey', 'string', r'^[^\x00-\x1f\x22]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[^\x00-\x1f\x22]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.Uuid = APIObject('Uuid', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-5][0-9a-f]{3}-[089ab][0-9a-f]{3}-[0-9a-f]{12}$', None, None)
        self.add_api_object('Uuid', self.Uuid)

class ResourceExplorer2(Service):
    def __init__(self):
        super().__init__('ResourceExplorer2')
        self.ViewName = APIObject('ViewName', 'string', r'^[a-zA-Z0-9\-]{1,64}$', None, None)
        self.add_api_object('ViewName', self.ViewName)

class ResourceGroups(Service):
    def __init__(self):
        super().__init__('ResourceGroups')
        self.Description = APIObject('Description', 'string', r'[\sa-zA-Z0-9_\.-]*', None, 1024)
        self.add_api_object('Description', self.Description)
        self.GroupArn = APIObject('GroupArn', 'string', r'arn:aws(-[a-z]+)*:resource-groups:[a-z]{2}(-[a-z]+)+-\d{1}:[0-9]{12}:group/[a-zA-Z0-9_\.-]{1,300}', 12, 1600)
        self.add_api_object('GroupArn', self.GroupArn)
        self.GroupConfigurationParameterName = APIObject('GroupConfigurationParameterName', 'string', r'[a-z-]+', 1, 80)
        self.add_api_object('GroupConfigurationParameterName', self.GroupConfigurationParameterName)
        self.GroupConfigurationParameterValue = APIObject('GroupConfigurationParameterValue', 'string', r'[a-zA-Z0-9:\/\._-]+', 1, 256)
        self.add_api_object('GroupConfigurationParameterValue', self.GroupConfigurationParameterValue)
        self.GroupConfigurationType = APIObject('GroupConfigurationType', 'string', r'AWS::[a-zA-Z0-9]+::[a-zA-Z0-9]+', None, 40)
        self.add_api_object('GroupConfigurationType', self.GroupConfigurationType)
        self.GroupFilterValue = APIObject('GroupFilterValue', 'string', r'AWS::(AllSupported|[a-zA-Z0-9]+::[a-zA-Z0-9]+)', 1, 128)
        self.add_api_object('GroupFilterValue', self.GroupFilterValue)
        self.GroupName = APIObject('GroupName', 'string', r'[a-zA-Z0-9_\.-]+', 1, 300)
        self.add_api_object('GroupName', self.GroupName)
        self.GroupString = APIObject('GroupString', 'string', r'(arn:aws(-[a-z]+)*:resource-groups:[a-z]{2}(-[a-z]+)+-\d{1}:[0-9]{12}:group/)?[a-zA-Z0-9_\.-]{1,300}', 1, 1600)
        self.add_api_object('GroupString', self.GroupString)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z0-9+/]*={0,2}$', 0, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.Query = APIObject('Query', 'string', r'[\s\S]*', None, 4096)
        self.add_api_object('Query', self.Query)
        self.QueryType = APIObject('QueryType', 'string', r'^\w+$', 1, 128)
        self.add_api_object('QueryType', self.QueryType)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws(-[a-z]+)*:[a-z0-9\-]*:([a-z]{2}(-[a-z]+)+-\d{1})?:([0-9]{12})?:.+', None, None)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceFilterValue = APIObject('ResourceFilterValue', 'string', r'AWS::[a-zA-Z0-9]+::[a-zA-Z0-9]+', 1, 128)
        self.add_api_object('ResourceFilterValue', self.ResourceFilterValue)
        self.ResourceType = APIObject('ResourceType', 'string', r'AWS::[a-zA-Z0-9]+::\w+', None, None)
        self.add_api_object('ResourceType', self.ResourceType)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Resourcegroupstaggingapi(Service):
    def __init__(self):
        super().__init__('Resourcegroupstaggingapi')
        self.AmazonResourceType = APIObject('AmazonResourceType', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('AmazonResourceType', self.AmazonResourceType)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[\s\S]*', 0, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.Region = APIObject('Region', 'string', r'[\s\S]*', 1, 256)
        self.add_api_object('Region', self.Region)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'[\s\S]*', 1, 1011)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[a-z0-9.-]*', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.TagKey = APIObject('TagKey', 'string', r'[\s\S]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[\s\S]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetId = APIObject('TargetId', 'string', r'[a-zA-Z0-9-]*', 6, 68)
        self.add_api_object('TargetId', self.TargetId)

class Robomaker(Service):
    def __init__(self):
        super().__init__('Robomaker')
        self.Arn = APIObject('Arn', 'string', r'arn:.*', 1, 1224)
        self.add_api_object('Arn', self.Arn)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'[a-zA-Z0-9_\-=]*', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.Command = APIObject('Command', 'string', r'[a-zA-Z0-9_.\-]*', 1, 1024)
        self.add_api_object('Command', self.Command)
        self.DeploymentVersion = APIObject('DeploymentVersion', 'string', r'[0-9]*', 1, 255)
        self.add_api_object('DeploymentVersion', self.DeploymentVersion)
        self.EnvironmentVariableKey = APIObject('EnvironmentVariableKey', 'string', r'[A-Z_][A-Z0-9_]*', 1, 1024)
        self.add_api_object('EnvironmentVariableKey', self.EnvironmentVariableKey)
        self.EnvironmentVariableValue = APIObject('EnvironmentVariableValue', 'string', r'.*', 1, 1024)
        self.add_api_object('EnvironmentVariableValue', self.EnvironmentVariableValue)
        self.GenericString = APIObject('GenericString', 'string', r'.*', 0, 1024)
        self.add_api_object('GenericString', self.GenericString)
        self.IamRole = APIObject('IamRole', 'string', r'arn:aws:iam::\w+:role/.*', 1, 255)
        self.add_api_object('IamRole', self.IamRole)
        self.Id = APIObject('Id', 'string', r'.*', 1, 1224)
        self.add_api_object('Id', self.Id)
        self.ImageDigest = APIObject('ImageDigest', 'string', r'[Ss][Hh][Aa]256:[0-9a-fA-F]{64}', 0, 72)
        self.add_api_object('ImageDigest', self.ImageDigest)
        self.Json = APIObject('Json', 'string', r'[\S\s]+', 1, 262144)
        self.add_api_object('Json', self.Json)
        self.Name = APIObject('Name', 'string', r'[a-zA-Z0-9_\-]*', 1, 255)
        self.add_api_object('Name', self.Name)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.+', 1, 255)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'[a-zA-Z0-9_.\-\/+=]*', 1, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.Path = APIObject('Path', 'string', r'.*', 1, 1024)
        self.add_api_object('Path', self.Path)
        self.RenderingEngineVersionType = APIObject('RenderingEngineVersionType', 'string', r'1.x', 1, 4)
        self.add_api_object('RenderingEngineVersionType', self.RenderingEngineVersionType)
        self.RepositoryUrl = APIObject('RepositoryUrl', 'string', r'.+', 1, 1024)
        self.add_api_object('RepositoryUrl', self.RepositoryUrl)
        self.RevisionId = APIObject('RevisionId', 'string', r'[a-zA-Z0-9_.\-]*', 1, 40)
        self.add_api_object('RevisionId', self.RevisionId)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[a-z0-9][a-z0-9.\-]*[a-z0-9]', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Key = APIObject('S3Key', 'string', r'.*', 1, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.S3KeyOrPrefix = APIObject('S3KeyOrPrefix', 'string', r'.*', 0, 1024)
        self.add_api_object('S3KeyOrPrefix', self.S3KeyOrPrefix)
        self.SimulationSoftwareSuiteVersionType = APIObject('SimulationSoftwareSuiteVersionType', 'string', r'7|9|11|Kinetic|Melodic|Dashing|Foxy', 0, 1024)
        self.add_api_object('SimulationSoftwareSuiteVersionType', self.SimulationSoftwareSuiteVersionType)
        self.TagKey = APIObject('TagKey', 'string', r'[a-zA-Z0-9 _.\-\/+=:]*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'[a-zA-Z0-9 _.\-\/+=:]*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TemplateName = APIObject('TemplateName', 'string', r'.*', 0, 255)
        self.add_api_object('TemplateName', self.TemplateName)
        self.UnrestrictedCommand = APIObject('UnrestrictedCommand', 'string', r'.*', 1, 1024)
        self.add_api_object('UnrestrictedCommand', self.UnrestrictedCommand)
        self.Version = APIObject('Version', 'string', r'(\$LATEST)|[0-9]*', 1, 255)
        self.add_api_object('Version', self.Version)
        self.VersionQualifier = APIObject('VersionQualifier', 'string', r'ALL', 1, 255)
        self.add_api_object('VersionQualifier', self.VersionQualifier)

class Rolesanywhere(Service):
    def __init__(self):
        super().__init__('Rolesanywhere')
        self.ProfileArn = APIObject('ProfileArn', 'string', r'^arn:aws(-[^:]+)?:rolesanywhere(:.*){2}(:profile.*)$', 1, 1011)
        self.add_api_object('ProfileArn', self.ProfileArn)
        self.ResourceName = APIObject('ResourceName', 'string', r'^[ a-zA-Z0-9-_]*$', 1, 255)
        self.add_api_object('ResourceName', self.ResourceName)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws(-[^:]+)?:iam(:.*){2}(:role.*)$', 1, 1011)
        self.add_api_object('RoleArn', self.RoleArn)
        self.TagKey = APIObject('TagKey', 'string', r'^[ a-zA-Z0-9_.:/=+@-]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[ a-zA-Z0-9_.:/=+@-]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TrustAnchorArn = APIObject('TrustAnchorArn', 'string', r'^arn:aws(-[^:]+)?:rolesanywhere(:.*){2}(:trust-anchor.*)$', 1, 1011)
        self.add_api_object('TrustAnchorArn', self.TrustAnchorArn)
        self.Uuid = APIObject('Uuid', 'string', r'[a-f0-9]{8}-([a-z0-9]{4}-){3}[a-z0-9]{12}', 36, 36)
        self.add_api_object('Uuid', self.Uuid)

class Route53RecoveryCluster(Service):
    def __init__(self):
        super().__init__('Route53RecoveryCluster')
        self.Arn = APIObject('Arn', 'string', r'^[A-Za-z0-9:.\/_-]*$', 1, 255)
        self.add_api_object('Arn', self.Arn)
        self.ControlPanelName = APIObject('ControlPanelName', 'string', r'^\S+$', 1, 64)
        self.add_api_object('ControlPanelName', self.ControlPanelName)
        self.Owner = APIObject('Owner', 'string', r'^\S+$', 12, 1024)
        self.add_api_object('Owner', self.Owner)
        self.PageToken = APIObject('PageToken', 'string', r'[\S]*', 1, 8096)
        self.add_api_object('PageToken', self.PageToken)
        self.RoutingControlName = APIObject('RoutingControlName', 'string', r'^\S+$', 1, 64)
        self.add_api_object('RoutingControlName', self.RoutingControlName)

class Route53RecoveryControlConfig(Service):
    def __init__(self):
        super().__init__('Route53RecoveryControlConfig')
        self.stringMax36PatternS = APIObject('stringMax36PatternS', 'string', r'^\S+$', None, 36)
        self.add_api_object('stringMax36PatternS', self.stringMax36PatternS)
        self.stringMin0Max256PatternS = APIObject('stringMin0Max256PatternS', 'string', r'^\S+$', 0, 256)
        self.add_api_object('stringMin0Max256PatternS', self.stringMin0Max256PatternS)
        self.stringMin12Max12PatternD12 = APIObject('stringMin12Max12PatternD12', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('stringMin12Max12PatternD12', self.stringMin12Max12PatternD12)
        self.stringMin1Max128PatternAZaZ09 = APIObject('stringMin1Max128PatternAZaZ09', 'string', r'^[A-Za-z0-9:.\/_-]*$', 1, 128)
        self.add_api_object('stringMin1Max128PatternAZaZ09', self.stringMin1Max128PatternAZaZ09)
        self.stringMin1Max256PatternAZaZ09 = APIObject('stringMin1Max256PatternAZaZ09', 'string', r'^[A-Za-z0-9:\/_-]*$', 1, 256)
        self.add_api_object('stringMin1Max256PatternAZaZ09', self.stringMin1Max256PatternAZaZ09)
        self.stringMin1Max32PatternS = APIObject('stringMin1Max32PatternS', 'string', r'^\S+$', 1, 32)
        self.add_api_object('stringMin1Max32PatternS', self.stringMin1Max32PatternS)
        self.stringMin1Max64PatternS = APIObject('stringMin1Max64PatternS', 'string', r'^\S+$', 1, 64)
        self.add_api_object('stringMin1Max64PatternS', self.stringMin1Max64PatternS)
        self.stringMin1Max8096PatternS = APIObject('stringMin1Max8096PatternS', 'string', r'[\S]*', 1, 8096)
        self.add_api_object('stringMin1Max8096PatternS', self.stringMin1Max8096PatternS)
        self.policy = APIObject('policy', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u00A1-\u00FF]+', 2, 10240)
        self.add_api_object('policy', self.policy)

class Route53RecoveryReadiness(Service):
    def __init__(self):
        super().__init__('Route53RecoveryReadiness')
        self.stringMax64PatternAAZAZ09Z = APIObject('stringMax64PatternAAZAZ09Z', 'string', r'\A[a-zA-Z0-9_]+\z', None, 64)
        self.add_api_object('stringMax64PatternAAZAZ09Z', self.stringMax64PatternAAZAZ09Z)
        self.stringPatternAWSAZaZ09AZaZ09 = APIObject('stringPatternAWSAZaZ09AZaZ09', 'string', r'AWS::[A-Za-z0-9]+::[A-Za-z0-9]+', None, None)
        self.add_api_object('stringPatternAWSAZaZ09AZaZ09', self.stringPatternAWSAZaZ09AZaZ09)

class Route53(Service):
    def __init__(self):
        super().__init__('Route53')
        self.ARN = APIObject('ARN', 'string', r'.*\S.*', 20, 2048)
        self.add_api_object('ARN', self.ARN)
        self.Cidr = APIObject('Cidr', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('Cidr', self.Cidr)
        self.CidrLocationNameDefaultAllowed = APIObject('CidrLocationNameDefaultAllowed', 'string', r'[0-9A-Za-z_\-\*]+', 1, 16)
        self.add_api_object('CidrLocationNameDefaultAllowed', self.CidrLocationNameDefaultAllowed)
        self.CidrLocationNameDefaultNotAllowed = APIObject('CidrLocationNameDefaultNotAllowed', 'string', r'[0-9A-Za-z_\-]+', 1, 16)
        self.add_api_object('CidrLocationNameDefaultNotAllowed', self.CidrLocationNameDefaultNotAllowed)
        self.CidrNonce = APIObject('CidrNonce', 'string', r'\p{ASCII}+', 1, 64)
        self.add_api_object('CidrNonce', self.CidrNonce)
        self.CollectionName = APIObject('CollectionName', 'string', r'[0-9A-Za-z_\-]+', 1, 64)
        self.add_api_object('CollectionName', self.CollectionName)
        self.IPAddress = APIObject('IPAddress', 'string', r'(^((([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5]))$|^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$)', None, 45)
        self.add_api_object('IPAddress', self.IPAddress)
        self.Latitude = APIObject('Latitude', 'string', r'[-+]?[0-9]{1,2}(\.[0-9]{0,2})?', 1, 6)
        self.add_api_object('Latitude', self.Latitude)
        self.Longitude = APIObject('Longitude', 'string', r'[-+]?[0-9]{1,3}(\.[0-9]{0,2})?', 1, 7)
        self.add_api_object('Longitude', self.Longitude)
        self.UUID = APIObject('UUID', 'string', r'[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}', None, None)
        self.add_api_object('UUID', self.UUID)

class Route53domains(Service):
    def __init__(self):
        super().__init__('Route53domains')
        self.AccountId = APIObject('AccountId', 'string', r'^(\d{12})$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.HostName = APIObject('HostName', 'string', r'[a-zA-Z0-9_\-.]*', None, 255)
        self.add_api_object('HostName', self.HostName)

class Route53profiles(Service):
    def __init__(self):
        super().__init__('Route53profiles')
        self.Name = APIObject('Name', 'string', r'^(?!^[0-9]+$)([a-zA-Z0-9\-_\' \']+)$', 0, 64)
        self.add_api_object('Name', self.Name)

class Route53resolver(Service):
    def __init__(self):
        super().__init__('Route53resolver')
        self.Name = APIObject('Name', 'string', r'(?!^[0-9]+$)([a-zA-Z0-9\-_\' \']+)', None, 64)
        self.add_api_object('Name', self.Name)
        self.OutpostArn = APIObject('OutpostArn', 'string', r'^arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/op-[a-f0-9]{17}$', 1, 255)
        self.add_api_object('OutpostArn', self.OutpostArn)
        self.ResolverQueryLogConfigName = APIObject('ResolverQueryLogConfigName', 'string', r'(?!^[0-9]+$)([a-zA-Z0-9\-_\' \']+)', 1, 64)
        self.add_api_object('ResolverQueryLogConfigName', self.ResolverQueryLogConfigName)

class Rum(Service):
    def __init__(self):
        super().__init__('Rum')
        self.AppMonitorDomain = APIObject('AppMonitorDomain', 'string', r'^(localhost)|^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$|^(?![-.])([A-Za-z0-9-\.\-]{0,63})((?![-])([a-zA-Z0-9]{1}|^[a-zA-Z0-9]{0,1}))\.(?![-])[A-Za-z-0-9]{1,63}((?![-])([a-zA-Z0-9]{1}|^[a-zA-Z0-9]{0,1}))|^(\*\.)(?![-.])([A-Za-z0-9-\.\-]{0,63})((?![-])([a-zA-Z0-9]{1}|^[a-zA-Z0-9]{0,1}))\.(?![-])[A-Za-z-0-9]{1,63}((?![-])([a-zA-Z0-9]{1}|^[a-zA-Z0-9]{0,1}))', 1, 253)
        self.add_api_object('AppMonitorDomain', self.AppMonitorDomain)
        self.AppMonitorId = APIObject('AppMonitorId', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('AppMonitorId', self.AppMonitorId)
        self.AppMonitorName = APIObject('AppMonitorName', 'string', r'^(?!\.)[\.\-_#A-Za-z0-9]+$', 1, 255)
        self.add_api_object('AppMonitorName', self.AppMonitorName)
        self.Arn = APIObject('Arn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', None, None)
        self.add_api_object('Arn', self.Arn)
        self.DestinationArn = APIObject('DestinationArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', 0, 2048)
        self.add_api_object('DestinationArn', self.DestinationArn)
        self.DimensionName = APIObject('DimensionName', 'string', r'^(?!:).*[^\s].*', 1, 255)
        self.add_api_object('DimensionName', self.DimensionName)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', None, None)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.IdentityPoolId = APIObject('IdentityPoolId', 'string', r'[\w-]+:[0-9a-f-]+', 1, 55)
        self.add_api_object('IdentityPoolId', self.IdentityPoolId)
        self.Namespace = APIObject('Namespace', 'string', r'[a-zA-Z0-9-._/#:]+$', 1, 237)
        self.add_api_object('Namespace', self.Namespace)
        self.PutRumEventsRequestBatchIdString = APIObject('PutRumEventsRequestBatchIdString', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('PutRumEventsRequestBatchIdString', self.PutRumEventsRequestBatchIdString)
        self.PutRumEventsRequestIdString = APIObject('PutRumEventsRequestIdString', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('PutRumEventsRequestIdString', self.PutRumEventsRequestIdString)
        self.RumEventIdString = APIObject('RumEventIdString', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('RumEventIdString', self.RumEventIdString)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Url = APIObject('Url', 'string', r'https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&*//=]*)', 1, 1260)
        self.add_api_object('Url', self.Url)
        self.UserDetailsSessionIdString = APIObject('UserDetailsSessionIdString', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('UserDetailsSessionIdString', self.UserDetailsSessionIdString)
        self.UserDetailsUserIdString = APIObject('UserDetailsUserIdString', 'string', r'^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', 36, 36)
        self.add_api_object('UserDetailsUserIdString', self.UserDetailsUserIdString)

class S3(Service):
    def __init__(self):
        super().__init__('S3')
        self.CopySource = APIObject('CopySource', 'string', r'\/.+\/.+', None, None)
        self.add_api_object('CopySource', self.CopySource)

class S3control(Service):
    def __init__(self):
        super().__init__('S3control')
        self.AccessGrantArn = APIObject('AccessGrantArn', 'string', r'arn:[a-z\-]+:s3:[a-z0-9\-]+:\d{12}:access\-grants\/grant/[a-zA-Z0-9\-]+', 1, 2048)
        self.add_api_object('AccessGrantArn', self.AccessGrantArn)
        self.AccessGrantId = APIObject('AccessGrantId', 'string', r'[a-zA-Z0-9\-]+', 1, 64)
        self.add_api_object('AccessGrantId', self.AccessGrantId)
        self.AccessGrantsInstanceArn = APIObject('AccessGrantsInstanceArn', 'string', r'arn:[a-z\-]+:s3:[a-z0-9\-]+:\d{12}:access\-grants\/[a-zA-Z0-9\-]+', 1, 2048)
        self.add_api_object('AccessGrantsInstanceArn', self.AccessGrantsInstanceArn)
        self.AccessGrantsInstanceId = APIObject('AccessGrantsInstanceId', 'string', r'[a-zA-Z0-9\-]+', 1, 64)
        self.add_api_object('AccessGrantsInstanceId', self.AccessGrantsInstanceId)
        self.AccessGrantsLocationArn = APIObject('AccessGrantsLocationArn', 'string', r'arn:[a-z\-]+:s3:[a-z0-9\-]+:\d{12}:access\-grants\/location/[a-zA-Z0-9\-]+', 1, 2048)
        self.add_api_object('AccessGrantsLocationArn', self.AccessGrantsLocationArn)
        self.AccessGrantsLocationId = APIObject('AccessGrantsLocationId', 'string', r'[a-zA-Z0-9\-]+', 1, 64)
        self.add_api_object('AccessGrantsLocationId', self.AccessGrantsLocationId)
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', None, 64)
        self.add_api_object('AccountId', self.AccountId)
        self.Alias = APIObject('Alias', 'string', r'^[0-9a-z\\-]{63}', None, 63)
        self.add_api_object('Alias', self.Alias)
        self.AsyncRequestTokenARN = APIObject('AsyncRequestTokenARN', 'string', r'arn:.+', 1, 1024)
        self.add_api_object('AsyncRequestTokenARN', self.AsyncRequestTokenARN)
        self.AwsOrgArn = APIObject('AwsOrgArn', 'string', r'arn:[a-z\-]+:organizations::\d{12}:organization\/o-[a-z0-9]{10,32}', 1, 1024)
        self.add_api_object('AwsOrgArn', self.AwsOrgArn)
        self.ConfigId = APIObject('ConfigId', 'string', r'[a-zA-Z0-9\-\_\.]+', 1, 64)
        self.add_api_object('ConfigId', self.ConfigId)
        self.FunctionArnString = APIObject('FunctionArnString', 'string', r'(arn:(aws[a-zA-Z-]*)?:lambda:)?([a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:)?(\d{12}:)?(function:)?([a-zA-Z0-9-_]+)(:(\$LATEST|[a-zA-Z0-9-_]+))?', 1, 1024)
        self.add_api_object('FunctionArnString', self.FunctionArnString)
        self.IAMRoleArn = APIObject('IAMRoleArn', 'string', r'arn:[^:]+:iam::\d{12}:role/.*', 1, 2048)
        self.add_api_object('IAMRoleArn', self.IAMRoleArn)
        self.IdentityCenterApplicationArn = APIObject('IdentityCenterApplicationArn', 'string', r'arn:[^:]+:sso:.*$', 10, 1224)
        self.add_api_object('IdentityCenterApplicationArn', self.IdentityCenterApplicationArn)
        self.IdentityCenterArn = APIObject('IdentityCenterArn', 'string', r'arn:[^:]+:sso::(\d{12}){0,1}:instance/.*$', 10, 1224)
        self.add_api_object('IdentityCenterArn', self.IdentityCenterArn)
        self.JobArn = APIObject('JobArn', 'string', r'arn:[^:]+:s3:[a-zA-Z0-9\-]+:\d{12}:job\/.*', 1, 1024)
        self.add_api_object('JobArn', self.JobArn)
        self.JobId = APIObject('JobId', 'string', r'[a-zA-Z0-9\-\_]+', 5, 36)
        self.add_api_object('JobId', self.JobId)
        self.MultiRegionAccessPointAlias = APIObject('MultiRegionAccessPointAlias', 'string', r'^[a-z][a-z0-9]*[.]mrap$', None, 63)
        self.add_api_object('MultiRegionAccessPointAlias', self.MultiRegionAccessPointAlias)
        self.MultiRegionAccessPointClientToken = APIObject('MultiRegionAccessPointClientToken', 'string', r'\S+', None, 64)
        self.add_api_object('MultiRegionAccessPointClientToken', self.MultiRegionAccessPointClientToken)
        self.MultiRegionAccessPointId = APIObject('MultiRegionAccessPointId', 'string', r'^[a-zA-Z0-9\:.-]{3,200}$', None, 200)
        self.add_api_object('MultiRegionAccessPointId', self.MultiRegionAccessPointId)
        self.MultiRegionAccessPointName = APIObject('MultiRegionAccessPointName', 'string', r'^[a-z0-9][-a-z0-9]{1,48}[a-z0-9]$', None, 50)
        self.add_api_object('MultiRegionAccessPointName', self.MultiRegionAccessPointName)
        self.ObjectLambdaAccessPointAliasValue = APIObject('ObjectLambdaAccessPointAliasValue', 'string', r'^[0-9a-z\\-]{3,63}', 3, 63)
        self.add_api_object('ObjectLambdaAccessPointAliasValue', self.ObjectLambdaAccessPointAliasValue)
        self.ObjectLambdaAccessPointArn = APIObject('ObjectLambdaAccessPointArn', 'string', r'arn:[^:]+:s3-object-lambda:[^:]*:\d{12}:accesspoint/.*', 1, 2048)
        self.add_api_object('ObjectLambdaAccessPointArn', self.ObjectLambdaAccessPointArn)
        self.ObjectLambdaAccessPointName = APIObject('ObjectLambdaAccessPointName', 'string', r'^[a-z0-9]([a-z0-9\-]*[a-z0-9])?$', 3, 45)
        self.add_api_object('ObjectLambdaAccessPointName', self.ObjectLambdaAccessPointName)
        self.ObjectLambdaSupportingAccessPointArn = APIObject('ObjectLambdaSupportingAccessPointArn', 'string', r'arn:[^:]+:s3:[^:]*:\d{12}:accesspoint/.*', 1, 2048)
        self.add_api_object('ObjectLambdaSupportingAccessPointArn', self.ObjectLambdaSupportingAccessPointArn)
        self.Organization = APIObject('Organization', 'string', r'^o-[a-z0-9]{10,32}$', 12, 34)
        self.add_api_object('Organization', self.Organization)
        self.S3AWSRegion = APIObject('S3AWSRegion', 'string', r'[a-z0-9\-]+', 5, 30)
        self.add_api_object('S3AWSRegion', self.S3AWSRegion)
        self.S3BucketArnString = APIObject('S3BucketArnString', 'string', r'arn:[^:]+:s3:.*', 1, 128)
        self.add_api_object('S3BucketArnString', self.S3BucketArnString)
        self.S3KeyArnString = APIObject('S3KeyArnString', 'string', r'arn:[^:]+:s3:.*', 1, 2000)
        self.add_api_object('S3KeyArnString', self.S3KeyArnString)
        self.S3Prefix = APIObject('S3Prefix', 'string', r'^.+$', 1, 2000)
        self.add_api_object('S3Prefix', self.S3Prefix)
        self.S3RegionalOrS3ExpressBucketArnString = APIObject('S3RegionalOrS3ExpressBucketArnString', 'string', r'arn:[^:]+:(s3|s3express):.*', 1, 128)
        self.add_api_object('S3RegionalOrS3ExpressBucketArnString', self.S3RegionalOrS3ExpressBucketArnString)
        self.S3ResourceArn = APIObject('S3ResourceArn', 'string', r'arn:[^:]+:s3:[^:].*', None, 1011)
        self.add_api_object('S3ResourceArn', self.S3ResourceArn)
        self.StorageLensArn = APIObject('StorageLensArn', 'string', r'arn:[a-z\-]+:s3:[a-z0-9\-]+:\d{12}:storage\-lens\/.*', 1, 1024)
        self.add_api_object('StorageLensArn', self.StorageLensArn)
        self.StorageLensGroupArn = APIObject('StorageLensGroupArn', 'string', r'arn:[a-z\-]+:s3:[a-z0-9\-]+:\d{12}:storage\-lens\-group\/.*', 4, 1024)
        self.add_api_object('StorageLensGroupArn', self.StorageLensGroupArn)
        self.StorageLensGroupName = APIObject('StorageLensGroupName', 'string', r'[a-zA-Z0-9\-\_]+', 1, 64)
        self.add_api_object('StorageLensGroupName', self.StorageLensGroupName)
        self.StringForNextToken = APIObject('StringForNextToken', 'string', r'^[A-Za-z0-9\+\:\/\=\?\#-_]+$', 1, 1024)
        self.add_api_object('StringForNextToken', self.StringForNextToken)
        self.TagKeyString = APIObject('TagKeyString', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKeyString', self.TagKeyString)
        self.TagValueString = APIObject('TagValueString', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValueString', self.TagValueString)

class S3outposts(Service):
    def __init__(self):
        super().__init__('S3outposts')
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.CustomerOwnedIpv4Pool = APIObject('CustomerOwnedIpv4Pool', 'string', r'^ipv4pool-coip-([0-9a-f]{17})$', None, None)
        self.add_api_object('CustomerOwnedIpv4Pool', self.CustomerOwnedIpv4Pool)
        self.EndpointArn = APIObject('EndpointArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):s3-outposts:[a-z\-0-9]*:[0-9]{12}:outpost/(op-[a-f0-9]{17}|ec2)/endpoint/[a-zA-Z0-9]{19}$', None, None)
        self.add_api_object('EndpointArn', self.EndpointArn)
        self.EndpointId = APIObject('EndpointId', 'string', r'^[a-zA-Z0-9]{19}$', None, None)
        self.add_api_object('EndpointId', self.EndpointId)
        self.NextToken = APIObject('NextToken', 'string', r'^[A-Za-z0-9\+\:\/\=\?\#-_]+$', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.OutpostArn = APIObject('OutpostArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):outposts:[a-z\-0-9]*:[0-9]{12}:outpost/(op-[a-f0-9]{17}|ec2)$', None, None)
        self.add_api_object('OutpostArn', self.OutpostArn)
        self.OutpostId = APIObject('OutpostId', 'string', r'^(op-[a-f0-9]{17}|\d{12}|ec2)$', None, None)
        self.add_api_object('OutpostId', self.OutpostId)
        self.S3OutpostArn = APIObject('S3OutpostArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso|aws-iso-b):s3-outposts:[a-z\-0-9]*:[0-9]{12}:outpost/(op-[a-f0-9]{17}|\d{12})/s3$', None, None)
        self.add_api_object('S3OutpostArn', self.S3OutpostArn)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-([0-9a-f]{8}|[0-9a-f]{17})$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-([0-9a-f]{8}|[0-9a-f]{17})$', None, None)
        self.add_api_object('SubnetId', self.SubnetId)

class SagemakerA2iRuntime(Service):
    def __init__(self):
        super().__init__('SagemakerA2iRuntime')
        self.FlowDefinitionArn = APIObject('FlowDefinitionArn', 'string', r'arn:aws[a-z\-]*:sagemaker:[a-z0-9\-]*:[0-9]{12}:flow-definition/.*', None, 1024)
        self.add_api_object('FlowDefinitionArn', self.FlowDefinitionArn)
        self.HumanLoopArn = APIObject('HumanLoopArn', 'string', r'arn:aws[a-z\-]*:sagemaker:[a-z0-9\-]*:[0-9]{12}:human-loop/.*', None, 1024)
        self.add_api_object('HumanLoopArn', self.HumanLoopArn)
        self.HumanLoopName = APIObject('HumanLoopName', 'string', r'^[a-z0-9](-*[a-z0-9])*$', 1, 63)
        self.add_api_object('HumanLoopName', self.HumanLoopName)
        self.NextToken = APIObject('NextToken', 'string', r'.*', None, 8192)
        self.add_api_object('NextToken', self.NextToken)

class SagemakerEdge(Service):
    def __init__(self):
        super().__init__('SagemakerEdge')
        self.ChecksumString = APIObject('ChecksumString', 'string', r'^[a-z0-9](-*[a-z0-9])*$', 1, 63)
        self.add_api_object('ChecksumString', self.ChecksumString)
        self.DeviceFleetName = APIObject('DeviceFleetName', 'string', r'^[a-zA-Z0-9](-*_*[a-zA-Z0-9])*$', 1, 63)
        self.add_api_object('DeviceFleetName', self.DeviceFleetName)
        self.DeviceName = APIObject('DeviceName', 'string', r'^[a-zA-Z0-9](-*_*[a-zA-Z0-9])*$', 1, 63)
        self.add_api_object('DeviceName', self.DeviceName)
        self.Dimension = APIObject('Dimension', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9\/])*$', 1, 1000)
        self.add_api_object('Dimension', self.Dimension)
        self.EntityName = APIObject('EntityName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', 1, 63)
        self.add_api_object('EntityName', self.EntityName)
        self.Metric = APIObject('Metric', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', 4, 100)
        self.add_api_object('Metric', self.Metric)
        self.ModelName = APIObject('ModelName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*$', 4, 255)
        self.add_api_object('ModelName', self.ModelName)
        self.S3Uri = APIObject('S3Uri', 'string', r'^s3://([^/]+)/?(.*)$', None, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.Version = APIObject('Version', 'string', r'[a-zA-Z0-9\ \_\.]+', 1, 64)
        self.add_api_object('Version', self.Version)

class SagemakerFeaturestoreRuntime(Service):
    def __init__(self):
        super().__init__('SagemakerFeaturestoreRuntime')
        self.FeatureGroupNameOrArn = APIObject('FeatureGroupNameOrArn', 'string', r'(arn:aws[a-z\-]*:sagemaker:[a-z0-9\-]*:[0-9]{12}:feature-group/)?([a-zA-Z0-9]([-_]*[a-zA-Z0-9]){0,63})', 1, 150)
        self.add_api_object('FeatureGroupNameOrArn', self.FeatureGroupNameOrArn)
        self.FeatureName = APIObject('FeatureName', 'string', r'^[a-zA-Z0-9]([-_]*[a-zA-Z0-9]){0,63}', 1, 64)
        self.add_api_object('FeatureName', self.FeatureName)
        self.ValueAsString = APIObject('ValueAsString', 'string', r'.*', None, 358400)
        self.add_api_object('ValueAsString', self.ValueAsString)

class SagemakerGeospatial(Service):
    def __init__(self):
        super().__init__('SagemakerGeospatial')
        self.DataCollectionArn = APIObject('DataCollectionArn', 'string', r'^arn:aws[a-z-]{0,12}:sagemaker-geospatial:[a-z0-9-]{1,25}:[0-9]{12}:raster-data-collection/(public|premium|user)/[a-z0-9]{12,}$', None, None)
        self.add_api_object('DataCollectionArn', self.DataCollectionArn)
        self.EarthObservationJobArn = APIObject('EarthObservationJobArn', 'string', r'^arn:aws[a-z-]{0,12}:sagemaker-geospatial:[a-z0-9-]{1,25}:[0-9]{12}:earth-observation-job/[a-z0-9]{12,}$', None, None)
        self.add_api_object('EarthObservationJobArn', self.EarthObservationJobArn)
        self.ExecutionRoleArn = APIObject('ExecutionRoleArn', 'string', r'^arn:(aws[a-z-]*):iam::([0-9]{12}):role/[a-zA-Z0-9+=,.@_/-]+$', 20, 2048)
        self.add_api_object('ExecutionRoleArn', self.ExecutionRoleArn)
        self.S3Uri = APIObject('S3Uri', 'string', r'^s3://([^/]+)/?(.*)$', None, None)
        self.add_api_object('S3Uri', self.S3Uri)
        self.VectorEnrichmentJobArn = APIObject('VectorEnrichmentJobArn', 'string', r'^arn:aws[a-z-]{0,12}:sagemaker-geospatial:[a-z0-9-]{1,25}:[0-9]{12}:vector-enrichment-job/[a-z0-9]{12,}$', None, None)
        self.add_api_object('VectorEnrichmentJobArn', self.VectorEnrichmentJobArn)

class SagemakerMetrics(Service):
    def __init__(self):
        super().__init__('SagemakerMetrics')
        self.ExperimentEntityName = APIObject('ExperimentEntityName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9]){0,119}', 1, 120)
        self.add_api_object('ExperimentEntityName', self.ExperimentEntityName)
        self.MetricName = APIObject('MetricName', 'string', r'.+', 1, 255)
        self.add_api_object('MetricName', self.MetricName)

class SagemakerRuntime(Service):
    def __init__(self):
        super().__init__('SagemakerRuntime')
        self.CustomAttributesHeader = APIObject('CustomAttributesHeader', 'string', r'\p{ASCII}*', None, 1024)
        self.add_api_object('CustomAttributesHeader', self.CustomAttributesHeader)
        self.EnableExplanationsHeader = APIObject('EnableExplanationsHeader', 'string', r'.*', 1, 64)
        self.add_api_object('EnableExplanationsHeader', self.EnableExplanationsHeader)
        self.EndpointName = APIObject('EndpointName', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 63)
        self.add_api_object('EndpointName', self.EndpointName)
        self.Header = APIObject('Header', 'string', r'\p{ASCII}*', None, 1024)
        self.add_api_object('Header', self.Header)
        self.InferenceComponentHeader = APIObject('InferenceComponentHeader', 'string', r'^[a-zA-Z0-9]([\-a-zA-Z0-9]*[a-zA-Z0-9])?$', None, 63)
        self.add_api_object('InferenceComponentHeader', self.InferenceComponentHeader)
        self.InferenceId = APIObject('InferenceId', 'string', r'\A\S[\p{Print}]*\z', 1, 64)
        self.add_api_object('InferenceId', self.InferenceId)
        self.InputLocationHeader = APIObject('InputLocationHeader', 'string', r'^(https|s3)://([^/]+)/?(.*)$', 1, 1024)
        self.add_api_object('InputLocationHeader', self.InputLocationHeader)
        self.TargetContainerHostnameHeader = APIObject('TargetContainerHostnameHeader', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 63)
        self.add_api_object('TargetContainerHostnameHeader', self.TargetContainerHostnameHeader)
        self.TargetModelHeader = APIObject('TargetModelHeader', 'string', r'\A\S[\p{Print}]*\z', 1, 1024)
        self.add_api_object('TargetModelHeader', self.TargetModelHeader)
        self.TargetVariantHeader = APIObject('TargetVariantHeader', 'string', r'^[a-zA-Z0-9](-*[a-zA-Z0-9])*', None, 63)
        self.add_api_object('TargetVariantHeader', self.TargetVariantHeader)

class Savingsplans(Service):
    def __init__(self):
        super().__init__('Savingsplans')
        self.JsonSafeFilterValueString = APIObject('JsonSafeFilterValueString', 'string', r'^[a-zA-Z0-9_ \/.\:\-\(\)]+$', None, None)
        self.add_api_object('JsonSafeFilterValueString', self.JsonSafeFilterValueString)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[A-Za-z0-9/=\+]+$', None, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.SavingsPlanArn = APIObject('SavingsPlanArn', 'string', r'arn:aws:[a-z]+:([a-z]{2}-[a-z]+-\d{1}|):(\d{12}):savingsplan\/([0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12})$', None, None)
        self.add_api_object('SavingsPlanArn', self.SavingsPlanArn)
        self.SavingsPlanDescription = APIObject('SavingsPlanDescription', 'string', r'^[a-zA-Z0-9_\- ]+$', None, None)
        self.add_api_object('SavingsPlanDescription', self.SavingsPlanDescription)
        self.SavingsPlanOperation = APIObject('SavingsPlanOperation', 'string', r'^[a-zA-Z0-9_ \/.:-]*$', None, 255)
        self.add_api_object('SavingsPlanOperation', self.SavingsPlanOperation)
        self.SavingsPlanRateOperation = APIObject('SavingsPlanRateOperation', 'string', r'^[a-zA-Z0-9_ \/.:-]*$', None, 255)
        self.add_api_object('SavingsPlanRateOperation', self.SavingsPlanRateOperation)
        self.SavingsPlanRateUsageType = APIObject('SavingsPlanRateUsageType', 'string', r'^[a-zA-Z0-9_ \/.:-]+$', None, 255)
        self.add_api_object('SavingsPlanRateUsageType', self.SavingsPlanRateUsageType)
        self.SavingsPlanServiceCode = APIObject('SavingsPlanServiceCode', 'string', r'^[a-zA-Z]+$', None, 255)
        self.add_api_object('SavingsPlanServiceCode', self.SavingsPlanServiceCode)
        self.SavingsPlanUsageType = APIObject('SavingsPlanUsageType', 'string', r'^[a-zA-Z0-9_ \/.:-]+$', None, 255)
        self.add_api_object('SavingsPlanUsageType', self.SavingsPlanUsageType)
        self.UUID = APIObject('UUID', 'string', r'[a-f0-9]+(-[a-f0-9]+)*', None, None)
        self.add_api_object('UUID', self.UUID)

class Scheduler(Service):
    def __init__(self):
        super().__init__('Scheduler')
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.DeadLetterConfigArnString = APIObject('DeadLetterConfigArnString', 'string', r'^arn:aws(-[a-z]+)?:sqs:[a-z0-9\-]+:\d{12}:[a-zA-Z0-9\-_]+$', 1, 1600)
        self.add_api_object('DeadLetterConfigArnString', self.DeadLetterConfigArnString)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'^arn:aws(-[a-z]+)?:kms:[a-z0-9\-]+:\d{12}:(key|alias)\/[0-9a-zA-Z-_]*$', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.Name = APIObject('Name', 'string', r'^[0-9a-zA-Z-_.]+$', 1, 64)
        self.add_api_object('Name', self.Name)
        self.NamePrefix = APIObject('NamePrefix', 'string', r'^[0-9a-zA-Z-_.]+$', 1, 64)
        self.add_api_object('NamePrefix', self.NamePrefix)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws(-[a-z]+)?:iam::\d{12}:role\/[\w+=,.@\/-]+$', 1, 1600)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SageMakerPipelineParameterName = APIObject('SageMakerPipelineParameterName', 'string', r'^[A-Za-z0-9\-_]*$', 1, 256)
        self.add_api_object('SageMakerPipelineParameterName', self.SageMakerPipelineParameterName)
        self.ScheduleArn = APIObject('ScheduleArn', 'string', r'^arn:aws(-[a-z]+)?:scheduler:[a-z0-9\-]+:\d{12}:schedule\/[0-9a-zA-Z-_.]+\/[0-9a-zA-Z-_.]+$', 1, 1224)
        self.add_api_object('ScheduleArn', self.ScheduleArn)
        self.ScheduleGroupArn = APIObject('ScheduleGroupArn', 'string', r'^arn:aws(-[a-z]+)?:scheduler:[a-z0-9\-]+:\d{12}:schedule-group\/[0-9a-zA-Z-_.]+$', 1, 1224)
        self.add_api_object('ScheduleGroupArn', self.ScheduleGroupArn)
        self.ScheduleGroupName = APIObject('ScheduleGroupName', 'string', r'^[0-9a-zA-Z-_.]+$', 1, 64)
        self.add_api_object('ScheduleGroupName', self.ScheduleGroupName)
        self.ScheduleGroupNamePrefix = APIObject('ScheduleGroupNamePrefix', 'string', r'^[0-9a-zA-Z-_.]+$', 1, 64)
        self.add_api_object('ScheduleGroupNamePrefix', self.ScheduleGroupNamePrefix)
        self.Source = APIObject('Source', 'string', r'^(?=[/\.\-_A-Za-z0-9]+)((?!aws\.).*)|(\$(\.[\w_-]+(\[(\d+|\*)\])*)*)$', 1, 256)
        self.add_api_object('Source', self.Source)
        self.TagResourceArn = APIObject('TagResourceArn', 'string', r'^arn:aws(-[a-z]+)?:scheduler:[a-z0-9\-]+:\d{12}:schedule-group\/[0-9a-zA-Z-_.]+$', 1, 1011)
        self.add_api_object('TagResourceArn', self.TagResourceArn)

class Schemas(Service):
    def __init__(self):
        super().__init__('Schemas')

class Sdb(Service):
    def __init__(self):
        super().__init__('Sdb')

class Secretsmanager(Service):
    def __init__(self):
        super().__init__('Secretsmanager')
        self.DurationType = APIObject('DurationType', 'string', r'[0-9h]+', 2, 3)
        self.add_api_object('DurationType', self.DurationType)
        self.FilterValueStringType = APIObject('FilterValueStringType', 'string', r'^\!?[a-zA-Z0-9 :_@\/\+\=\.\-\!]*$', None, 512)
        self.add_api_object('FilterValueStringType', self.FilterValueStringType)
        self.RegionType = APIObject('RegionType', 'string', r'^([a-z]+-)+\d+$', 1, 128)
        self.add_api_object('RegionType', self.RegionType)
        self.ScheduleExpressionType = APIObject('ScheduleExpressionType', 'string', r'[0-9A-Za-z\(\)#\?\*\-\/, ]+', 1, 256)
        self.add_api_object('ScheduleExpressionType', self.ScheduleExpressionType)

class Securitylake(Service):
    def __init__(self):
        super().__init__('Securitylake')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:aws:securitylake:[A-za-z0-9_/.\-]{0,63}:[A-za-z0-9_/.\-]{0,63}:[A-Za-z0-9][A-za-z0-9_/.\-]{0,127}$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.AwsLogSourceVersion = APIObject('AwsLogSourceVersion', 'string', r'^(latest|[0-9]\.[0-9])$', None, None)
        self.add_api_object('AwsLogSourceVersion', self.AwsLogSourceVersion)
        self.AwsPrincipal = APIObject('AwsPrincipal', 'string', r'^([0-9]{12}|[a-z0-9\.\-]*\.(amazonaws|amazon)\.com)$', None, None)
        self.add_api_object('AwsPrincipal', self.AwsPrincipal)
        self.CustomLogSourceName = APIObject('CustomLogSourceName', 'string', r'^[\\\w\-_:/.]*$', 1, 64)
        self.add_api_object('CustomLogSourceName', self.CustomLogSourceName)
        self.CustomLogSourceVersion = APIObject('CustomLogSourceVersion', 'string', r'^[A-Za-z0-9\-\.\_]*$', 1, 32)
        self.add_api_object('CustomLogSourceVersion', self.CustomLogSourceVersion)
        self.DescriptionString = APIObject('DescriptionString', 'string', r'^[\\\w\s\-_:/,.@=+]*$', None, None)
        self.add_api_object('DescriptionString', self.DescriptionString)
        self.ExternalId = APIObject('ExternalId', 'string', r'^[\w+=,.@:\/-]*$', 2, 1224)
        self.add_api_object('ExternalId', self.ExternalId)
        self.HttpsNotificationConfigurationEndpointString = APIObject('HttpsNotificationConfigurationEndpointString', 'string', r'^https?://.+$', None, None)
        self.add_api_object('HttpsNotificationConfigurationEndpointString', self.HttpsNotificationConfigurationEndpointString)
        self.OcsfEventClass = APIObject('OcsfEventClass', 'string', r'^[A-Z\_0-9]*$', None, None)
        self.add_api_object('OcsfEventClass', self.OcsfEventClass)
        self.Region = APIObject('Region', 'string', r'^(af|ap|ca|eu|me|sa|us)-(central|north|(north(?:east|west))|south|south(?:east|west)|east|west)-\d+$', None, None)
        self.add_api_object('Region', self.Region)
        self.ResourceShareName = APIObject('ResourceShareName', 'string', r'^LakeFormation(?:-V[0-9]+)-([a-zA-Z0-9]+)-([\\\w\-_:/.@=+]*)$', None, None)
        self.add_api_object('ResourceShareName', self.ResourceShareName)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:(aws[a-zA-Z-]*)?:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+$', None, None)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3URI = APIObject('S3URI', 'string', r'^s3[an]?://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/[^/].*)+$', 0, 1024)
        self.add_api_object('S3URI', self.S3URI)
        self.SafeString = APIObject('SafeString', 'string', r'^[\\\w\-_:/.@=+]*$', None, None)
        self.add_api_object('SafeString', self.SafeString)
        self.SubscriptionProtocol = APIObject('SubscriptionProtocol', 'string', r'^[a-z\-]*$', None, None)
        self.add_api_object('SubscriptionProtocol', self.SubscriptionProtocol)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('UUID', self.UUID)
        self.UpdateSubscriberRequestSubscriberNameString = APIObject('UpdateSubscriberRequestSubscriberNameString', 'string', r'^[\\\w\-_:/.@=+]*$', 0, 64)
        self.add_api_object('UpdateSubscriberRequestSubscriberNameString', self.UpdateSubscriberRequestSubscriberNameString)

class Serverlessrepo(Service):
    def __init__(self):
        super().__init__('Serverlessrepo')

class ServiceQuotas(Service):
    def __init__(self):
        super().__init__('ServiceQuotas')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'arn:aws(-[\w]+)*:*:.+:[0-9]{12}:.+', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.AwsRegion = APIObject('AwsRegion', 'string', r'[a-zA-Z][a-zA-Z0-9-]{1,128}', 1, 64)
        self.add_api_object('AwsRegion', self.AwsRegion)
        self.NextToken = APIObject('NextToken', 'string', r'^[a-zA-Z0-9/+]*={0,2}$', None, 2048)
        self.add_api_object('NextToken', self.NextToken)
        self.QuotaCode = APIObject('QuotaCode', 'string', r'[a-zA-Z][a-zA-Z0-9-]{1,128}', 1, 128)
        self.add_api_object('QuotaCode', self.QuotaCode)
        self.RequestId = APIObject('RequestId', 'string', r'[0-9a-zA-Z][a-zA-Z0-9-]{1,128}', 1, 128)
        self.add_api_object('RequestId', self.RequestId)
        self.ServiceCode = APIObject('ServiceCode', 'string', r'[a-zA-Z][a-zA-Z0-9-]{1,63}', 1, 63)
        self.add_api_object('ServiceCode', self.ServiceCode)
        self.Statistic = APIObject('Statistic', 'string', r'(Sum|Maximum)', 1, 256)
        self.add_api_object('Statistic', self.Statistic)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class ServicecatalogAppregistry(Service):
    def __init__(self):
        super().__init__('ServicecatalogAppregistry')
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'arn:aws[-a-z]*:servicecatalog:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:/applications/[a-z0-9]+', None, None)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'[a-z0-9]+', 26, 26)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.ApplicationSpecifier = APIObject('ApplicationSpecifier', 'string', r'([-.\w]+)|(arn:aws[-a-z]*:servicecatalog:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:/applications/[-.\w]+)', 1, 256)
        self.add_api_object('ApplicationSpecifier', self.ApplicationSpecifier)
        self.Arn = APIObject('Arn', 'string', r'arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-])+:([a-z]{2}(-gov)?-[a-z]+-\d{1})?:(\d{12})?:(.*)', 1, 1600)
        self.add_api_object('Arn', self.Arn)
        self.AttributeGroupArn = APIObject('AttributeGroupArn', 'string', r'arn:aws[-a-z]*:servicecatalog:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:/attribute-groups/[-.\w]+', None, None)
        self.add_api_object('AttributeGroupArn', self.AttributeGroupArn)
        self.AttributeGroupId = APIObject('AttributeGroupId', 'string', r'[-.\w]+', 1, 256)
        self.add_api_object('AttributeGroupId', self.AttributeGroupId)
        self.AttributeGroupSpecifier = APIObject('AttributeGroupSpecifier', 'string', r'([-.\w]+)|(arn:aws[-a-z]*:servicecatalog:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:/attribute-groups/[-.\w]+)', 1, 512)
        self.add_api_object('AttributeGroupSpecifier', self.AttributeGroupSpecifier)
        self.Attributes = APIObject('Attributes', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 8000)
        self.add_api_object('Attributes', self.Attributes)
        self.ClientToken = APIObject('ClientToken', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.CreatedBy = APIObject('CreatedBy', 'string', r'^(?!-)([a-z0-9-]+\.)+(aws\.internal|amazonaws\.com(\.cn)?)$', 1, 128)
        self.add_api_object('CreatedBy', self.CreatedBy)
        self.Name = APIObject('Name', 'string', r'[-.\w]+', 1, 256)
        self.add_api_object('Name', self.Name)
        self.NextToken = APIObject('NextToken', 'string', r'[A-Za-z0-9+/=]+', 1, 2024)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceItemType = APIObject('ResourceItemType', 'string', r'AWS::[a-zA-Z0-9]+::\w+', None, None)
        self.add_api_object('ResourceItemType', self.ResourceItemType)
        self.ResourceSpecifier = APIObject('ResourceSpecifier', 'string', r'\S+', 1, 256)
        self.add_api_object('ResourceSpecifier', self.ResourceSpecifier)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:\/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagKeyConfig = APIObject('TagKeyConfig', 'string', r'^(?!\s+$)[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 0, 128)
        self.add_api_object('TagKeyConfig', self.TagKeyConfig)
        self.TagValue = APIObject('TagValue', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', None, 256)
        self.add_api_object('TagValue', self.TagValue)

class Servicecatalog(Service):
    def __init__(self):
        super().__init__('Servicecatalog')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.CodeStarConnectionArn = APIObject('CodeStarConnectionArn', 'string', r'arn:[a-z0-9][-.a-z0-9]{0,62}:codestar-connections:([a-z0-9][-.a-z0-9]{0,62})?:([a-z0-9][-.a-z0-9]{0,62})?:[^/].{0,1023}$', 1, 1224)
        self.add_api_object('CodeStarConnectionArn', self.CodeStarConnectionArn)
        self.EngineWorkflowFailureReason = APIObject('EngineWorkflowFailureReason', 'string', r'[\u0009\u000a\u000d\u0020-\uD7FF\uE000-\uFFFD]*', 1, 2048)
        self.add_api_object('EngineWorkflowFailureReason', self.EngineWorkflowFailureReason)
        self.EngineWorkflowToken = APIObject('EngineWorkflowToken', 'string', r'[0-9A-Za-z+\/=]+', 1, 20000)
        self.add_api_object('EngineWorkflowToken', self.EngineWorkflowToken)
        self.Id = APIObject('Id', 'string', r'^[a-zA-Z0-9_\-]*', 1, 100)
        self.add_api_object('Id', self.Id)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[a-zA-Z0-9][a-zA-Z0-9_-]*', 1, 128)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.NotificationArn = APIObject('NotificationArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 1, 1224)
        self.add_api_object('NotificationArn', self.NotificationArn)
        self.OrganizationNodeValue = APIObject('OrganizationNodeValue', 'string', r'(^[0-9]{12}$)|(^arn:aws:organizations::\d{12}:organization\/o-[a-z0-9]{10,32})|(^o-[a-z0-9]{10,32}$)|(^arn:aws:organizations::\d{12}:ou\/o-[a-z0-9]{10,32}\/ou-[0-9a-z]{4,32}-[0-9a-z]{8,32}$)|(^ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$)', None, None)
        self.add_api_object('OrganizationNodeValue', self.OrganizationNodeValue)
        self.PageToken = APIObject('PageToken', 'string', r'[\u0009\u000a\u000d\u0020-\uD7FF\uE000-\uFFFD]*', None, 2024)
        self.add_api_object('PageToken', self.PageToken)
        self.ProductArn = APIObject('ProductArn', 'string', r'arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 1, 1224)
        self.add_api_object('ProductArn', self.ProductArn)
        self.ProvisionedProductName = APIObject('ProvisionedProductName', 'string', r'[a-zA-Z0-9][a-zA-Z0-9._-]*', 1, 128)
        self.add_api_object('ProvisionedProductName', self.ProvisionedProductName)
        self.ProvisionedProductNameOrArn = APIObject('ProvisionedProductNameOrArn', 'string', r'[a-zA-Z0-9][a-zA-Z0-9._-]{0,127}|arn:[a-z0-9-\.]{1,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:[^/].{0,1023}', 1, 1224)
        self.add_api_object('ProvisionedProductNameOrArn', self.ProvisionedProductNameOrArn)
        self.ProvisioningArtifactOutputKey = APIObject('ProvisioningArtifactOutputKey', 'string', r'[a-zA-Z0-9]*', 1, 255)
        self.add_api_object('ProvisioningArtifactOutputKey', self.ProvisioningArtifactOutputKey)
        self.RecordTagKey = APIObject('RecordTagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 128)
        self.add_api_object('RecordTagKey', self.RecordTagKey)
        self.RecordTagValue = APIObject('RecordTagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 256)
        self.add_api_object('RecordTagValue', self.RecordTagValue)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:[a-z0-9-\.]{1,63}:iam::[a-z0-9-\.]{0,63}:role\/.{0,1023}', 1, 1224)
        self.add_api_object('RoleArn', self.RoleArn)
        self.ServiceActionName = APIObject('ServiceActionName', 'string', r'^[a-zA-Z0-9_\-.]*', 1, 256)
        self.add_api_object('ServiceActionName', self.ServiceActionName)
        self.StatusMessage = APIObject('StatusMessage', 'string', r'[\u0009\u000a\u000d\u0020-\uD7FF\uE000-\uFFFD]*', None, None)
        self.add_api_object('StatusMessage', self.StatusMessage)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagOptionKey = APIObject('TagOptionKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagOptionKey', self.TagOptionKey)
        self.TagOptionValue = APIObject('TagOptionValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 256)
        self.add_api_object('TagOptionValue', self.TagOptionValue)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UniqueTagKey = APIObject('UniqueTagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:\/=+\-@]*)$', 1, 128)
        self.add_api_object('UniqueTagKey', self.UniqueTagKey)
        self.UniqueTagValue = APIObject('UniqueTagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:\/=+\-@]*)$', 1, 256)
        self.add_api_object('UniqueTagValue', self.UniqueTagValue)

class Servicediscovery(Service):
    def __init__(self):
        super().__init__('Servicediscovery')
        self.AttrKey = APIObject('AttrKey', 'string', r'^[a-zA-Z0-9!-~]+$', None, 255)
        self.add_api_object('AttrKey', self.AttrKey)
        self.AttrValue = APIObject('AttrValue', 'string', r'^([a-zA-Z0-9!-~][ \ta-zA-Z0-9!-~]*){0,1}[a-zA-Z0-9!-~]{0,1}$', None, 1024)
        self.add_api_object('AttrValue', self.AttrValue)
        self.InstanceId = APIObject('InstanceId', 'string', r'^[0-9a-zA-Z_/:.@-]+$', None, 64)
        self.add_api_object('InstanceId', self.InstanceId)
        self.NamespaceNameHttp = APIObject('NamespaceNameHttp', 'string', r'^[!-~]{1,1024}$', None, 1024)
        self.add_api_object('NamespaceNameHttp', self.NamespaceNameHttp)
        self.NamespaceNamePrivate = APIObject('NamespaceNamePrivate', 'string', r'^[!-~]{1,253}$', None, 253)
        self.add_api_object('NamespaceNamePrivate', self.NamespaceNamePrivate)
        self.NamespaceNamePublic = APIObject('NamespaceNamePublic', 'string', r'^([a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?$', None, 253)
        self.add_api_object('NamespaceNamePublic', self.NamespaceNamePublic)
        self.ServiceName = APIObject('ServiceName', 'string', r'((?=^.{1,127}$)^([a-zA-Z0-9_][a-zA-Z0-9-_]{0,61}[a-zA-Z0-9_]|[a-zA-Z0-9])(\.([a-zA-Z0-9_][a-zA-Z0-9-_]{0,61}[a-zA-Z0-9_]|[a-zA-Z0-9]))*$)|(^\.$)', None, None)
        self.add_api_object('ServiceName', self.ServiceName)

class Ses(Service):
    def __init__(self):
        super().__init__('Ses')

class Sesv2(Service):
    def __init__(self):
        super().__init__('Sesv2')
        self.AdditionalContactEmailAddress = APIObject('AdditionalContactEmailAddress', 'string', r'^(.+)@(.+)$', 6, 254)
        self.add_api_object('AdditionalContactEmailAddress', self.AdditionalContactEmailAddress)
        self.MessageHeaderName = APIObject('MessageHeaderName', 'string', r'^[!-9;-@A-~]+$', 1, 126)
        self.add_api_object('MessageHeaderName', self.MessageHeaderName)
        self.MessageHeaderValue = APIObject('MessageHeaderValue', 'string', r'[ -~]*', 1, 870)
        self.add_api_object('MessageHeaderValue', self.MessageHeaderValue)
        self.PrivateKey = APIObject('PrivateKey', 'string', r'^[a-zA-Z0-9+\/]+={0,2}$', 1, 20480)
        self.add_api_object('PrivateKey', self.PrivateKey)
        self.S3Url = APIObject('S3Url', 'string', r'^s3:\/\/([^\/]+)\/(.*?([^\/]+)\/?)$', None, None)
        self.add_api_object('S3Url', self.S3Url)
        self.Selector = APIObject('Selector', 'string', r'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9]))$', 1, 63)
        self.add_api_object('Selector', self.Selector)
        self.WebsiteURL = APIObject('WebsiteURL', 'string', r'^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?', 1, 1000)
        self.add_api_object('WebsiteURL', self.WebsiteURL)

class Shield(Service):
    def __init__(self):
        super().__init__('Shield')
        self.AttackId = APIObject('AttackId', 'string', r'[a-zA-Z0-9\\-]*', 1, 128)
        self.add_api_object('AttackId', self.AttackId)
        self.ContactNotes = APIObject('ContactNotes', 'string', r'^[\w\s\.\-,:/()+@]*$', 1, 1024)
        self.add_api_object('ContactNotes', self.ContactNotes)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'^\S+@\S+\.\S+$', 1, 150)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.HealthCheckArn = APIObject('HealthCheckArn', 'string', r'^arn:aws:route53:::healthcheck/\S{36}$', 1, 2048)
        self.add_api_object('HealthCheckArn', self.HealthCheckArn)
        self.LogBucket = APIObject('LogBucket', 'string', r'^([a-z]|(\d(?!\d{0,2}\.\d{1,3}\.\d{1,3}\.\d{1,3})))([a-z\d]|(\.(?!(\.|-)))|(-(?!\.))){1,61}[a-z\d]$', 3, 63)
        self.add_api_object('LogBucket', self.LogBucket)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'^\+[1-9]\d{1,14}$', 1, 16)
        self.add_api_object('PhoneNumber', self.PhoneNumber)
        self.ProtectionGroupId = APIObject('ProtectionGroupId', 'string', r'[a-zA-Z0-9\\-]*', 1, 36)
        self.add_api_object('ProtectionGroupId', self.ProtectionGroupId)
        self.ProtectionId = APIObject('ProtectionId', 'string', r'[a-zA-Z0-9\\-]*', 36, 36)
        self.add_api_object('ProtectionId', self.ProtectionId)
        self.ProtectionName = APIObject('ProtectionName', 'string', r'[ a-zA-Z0-9_\\.\\-]*', 1, 128)
        self.add_api_object('ProtectionName', self.ProtectionName)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn:aws.*', 1, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', 1, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.Token = APIObject('Token', 'string', r'^.*$', 1, 4096)
        self.add_api_object('Token', self.Token)

class Signer(Service):
    def __init__(self):
        super().__init__('Signer')
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.ProfileName = APIObject('ProfileName', 'string', r'^[a-zA-Z0-9_]{2,}', 2, 64)
        self.add_api_object('ProfileName', self.ProfileName)
        self.ProfileVersion = APIObject('ProfileVersion', 'string', r'^[a-zA-Z0-9]{10}$', 10, 10)
        self.add_api_object('ProfileVersion', self.ProfileVersion)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)

class Simspaceweaver(Service):
    def __init__(self):
        super().__init__('Simspaceweaver')
        self.ClientToken = APIObject('ClientToken', 'string', r'^[a-zA-Z0-9-]+$', 32, 128)
        self.add_api_object('ClientToken', self.ClientToken)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'^arn:(?:aws|aws-cn|aws-us-gov):log-group:([a-z]{2}-[a-z]+-\d{1}):(\d{12})?:role\/(.+)$', 0, 1600)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:(?:aws|aws-cn|aws-us-gov):iam::(\d{12})?:role\/(.+)$', 0, 1600)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SimSpaceWeaverArn = APIObject('SimSpaceWeaverArn', 'string', r'^arn:(?:aws|aws-cn|aws-us-gov):simspaceweaver:([a-z]{2}-[a-z]+-\d{1}):(\d{12})?:([a-z]+)\/(.+)$', 0, 1600)
        self.add_api_object('SimSpaceWeaverArn', self.SimSpaceWeaverArn)
        self.SimSpaceWeaverLongResourceName = APIObject('SimSpaceWeaverLongResourceName', 'string', r'^[a-zA-Z0-9_.-]+$', 1, 256)
        self.add_api_object('SimSpaceWeaverLongResourceName', self.SimSpaceWeaverLongResourceName)
        self.SimSpaceWeaverResourceName = APIObject('SimSpaceWeaverResourceName', 'string', r'^[a-zA-Z0-9_.-]+$', 1, 64)
        self.add_api_object('SimSpaceWeaverResourceName', self.SimSpaceWeaverResourceName)
        self.TimeToLiveString = APIObject('TimeToLiveString', 'string', r'^\d{1,5}[mhdMHD]$', 2, 6)
        self.add_api_object('TimeToLiveString', self.TimeToLiveString)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 36, None)
        self.add_api_object('UUID', self.UUID)

class SmsVoice(Service):
    def __init__(self):
        super().__init__('SmsVoice')

class Sms(Service):
    def __init__(self):
        super().__init__('Sms')
        self.AppIdWithValidation = APIObject('AppIdWithValidation', 'string', r'^app-[0-9a-f]{17}$', None, None)
        self.add_api_object('AppIdWithValidation', self.AppIdWithValidation)
        self.InstanceId = APIObject('InstanceId', 'string', r'(^i-(\w{8}|\w{17})$)|(^mi-\w{17}$)', None, None)
        self.add_api_object('InstanceId', self.InstanceId)
        self.NonEmptyStringWithMaxLen255 = APIObject('NonEmptyStringWithMaxLen255', 'string', r'^[\S]+$', 1, 255)
        self.add_api_object('NonEmptyStringWithMaxLen255', self.NonEmptyStringWithMaxLen255)
        self.ValidationId = APIObject('ValidationId', 'string', r'^val-[0-9a-f]{17}$', None, None)
        self.add_api_object('ValidationId', self.ValidationId)

class SnowDeviceManagement(Service):
    def __init__(self):
        super().__init__('SnowDeviceManagement')
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[!-~]+', 1, 64)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.NextToken = APIObject('NextToken', 'string', r'[a-zA-Z0-9+/=]*', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.TaskDescriptionString = APIObject('TaskDescriptionString', 'string', r'[A-Za-z0-9 _.,!#]*', 1, 128)
        self.add_api_object('TaskDescriptionString', self.TaskDescriptionString)

class Snowball(Service):
    def __init__(self):
        super().__init__('Snowball')
        self.AddressId = APIObject('AddressId', 'string', r'ADID[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 40, 40)
        self.add_api_object('AddressId', self.AddressId)
        self.AmiId = APIObject('AmiId', 'string', r'(ami-[0-9a-f]{8})|(ami-[0-9a-f]{17})', 12, 21)
        self.add_api_object('AmiId', self.AmiId)
        self.ClusterId = APIObject('ClusterId', 'string', r'CID[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 39, 39)
        self.add_api_object('ClusterId', self.ClusterId)
        self.DevicePickupId = APIObject('DevicePickupId', 'string', r'DPID[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 40, 40)
        self.add_api_object('DevicePickupId', self.DevicePickupId)
        self.Email = APIObject('Email', 'string', r'^(?=.{3,100}$).+@.+[.].+$', 3, 320)
        self.add_api_object('Email', self.Email)
        self.GSTIN = APIObject('GSTIN', 'string', r'\d{2}[A-Z]{5}\d{4}[A-Z]{1}[A-Z\d]{1}[Z]{1}[A-Z\d]{1}', 15, 15)
        self.add_api_object('GSTIN', self.GSTIN)
        self.JobId = APIObject('JobId', 'string', r'(M|J)ID[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 39, 39)
        self.add_api_object('JobId', self.JobId)
        self.KmsKeyARN = APIObject('KmsKeyARN', 'string', r'arn:aws.*:kms:.*:[0-9]{12}:key/.*', None, 255)
        self.add_api_object('KmsKeyARN', self.KmsKeyARN)
        self.LongTermPricingId = APIObject('LongTermPricingId', 'string', r'LTPID[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', 41, 41)
        self.add_api_object('LongTermPricingId', self.LongTermPricingId)
        self.PhoneNumber = APIObject('PhoneNumber', 'string', r'^\s*(?:\+?(\d{1,3}))?[-. (]*(\d{3})[-. )]*(\d{3})[-. ]*(\d{4})(?: *x(\d+))?\s*$', 7, 30)
        self.add_api_object('PhoneNumber', self.PhoneNumber)
        self.ResourceARN = APIObject('ResourceARN', 'string', r'arn:aws.*:*', None, 255)
        self.add_api_object('ResourceARN', self.ResourceARN)
        self.RoleARN = APIObject('RoleARN', 'string', r'arn:aws.*:iam::[0-9]{12}:role/.*', None, 255)
        self.add_api_object('RoleARN', self.RoleARN)
        self.SnsTopicARN = APIObject('SnsTopicARN', 'string', r'arn:aws.*:sns:.*:[0-9]{12}:.*', None, 255)
        self.add_api_object('SnsTopicARN', self.SnsTopicARN)
        self.String = APIObject('String', 'string', r'.*', 1, 1024)
        self.add_api_object('String', self.String)

class Sns(Service):
    def __init__(self):
        super().__init__('Sns')
        self.Iso2CountryCode = APIObject('Iso2CountryCode', 'string', r'^[A-Za-z]{2}$', None, 2)
        self.add_api_object('Iso2CountryCode', self.Iso2CountryCode)
        self.OTPCode = APIObject('OTPCode', 'string', r'^[0-9]+$', 5, 8)
        self.add_api_object('OTPCode', self.OTPCode)
        self.PhoneNumberString = APIObject('PhoneNumberString', 'string', r'^(\+[0-9]{8,}|[0-9]{0,9})$', None, 20)
        self.add_api_object('PhoneNumberString', self.PhoneNumberString)

class Sqs(Service):
    def __init__(self):
        super().__init__('Sqs')

class SsmContacts(Service):
    def __init__(self):
        super().__init__('SsmContacts')
        self.AcceptCode = APIObject('AcceptCode', 'string', r'^[0-9]*$', 6, 10)
        self.add_api_object('AcceptCode', self.AcceptCode)
        self.ActivationCode = APIObject('ActivationCode', 'string', r'^[0-9]*$', 6, 10)
        self.add_api_object('ActivationCode', self.ActivationCode)
        self.ChannelName = APIObject('ChannelName', 'string', r'^[\p{L}\p{Z}\p{N}_.\-]*$', 1, 255)
        self.add_api_object('ChannelName', self.ChannelName)
        self.ContactAlias = APIObject('ContactAlias', 'string', r'^[a-z0-9_\-]*$', 1, 255)
        self.add_api_object('ContactAlias', self.ContactAlias)
        self.ContactName = APIObject('ContactName', 'string', r'^[\p{L}\p{Z}\p{N}_.\-]*$', 0, 255)
        self.add_api_object('ContactName', self.ContactName)
        self.Content = APIObject('Content', 'string', r'^[.\s\S]*$', 1, 8192)
        self.add_api_object('Content', self.Content)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'^[\\\/a-zA-Z0-9_+=\-]*$', None, 2048)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.IncidentId = APIObject('IncidentId', 'string', r'^[\\a-zA-Z0-9_@#%*+=:?.\/!\s-]*$', None, 1024)
        self.add_api_object('IncidentId', self.IncidentId)
        self.Member = APIObject('Member', 'string', r'.*\S.*', 1, 512)
        self.add_api_object('Member', self.Member)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^[\\\/a-zA-Z0-9_+=\-]*$', None, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.Policy = APIObject('Policy', 'string', r'.*\S.*', 1, 395000)
        self.add_api_object('Policy', self.Policy)
        self.PublicContent = APIObject('PublicContent', 'string', r'^[.\s\S]*$', 1, 8192)
        self.add_api_object('PublicContent', self.PublicContent)
        self.PublicSubject = APIObject('PublicSubject', 'string', r'^[.\s\S]*$', 1, 2048)
        self.add_api_object('PublicSubject', self.PublicSubject)
        self.ReceiptInfo = APIObject('ReceiptInfo', 'string', r'^[.\s\S]*$', 1, 2048)
        self.add_api_object('ReceiptInfo', self.ReceiptInfo)
        self.RotationName = APIObject('RotationName', 'string', r'^[a-zA-Z0-9_\-\s\.]*$', 1, 255)
        self.add_api_object('RotationName', self.RotationName)
        self.Sender = APIObject('Sender', 'string', r'^[\\a-zA-Z0-9_@#%*+=:?.\/!\s-]*$', None, 255)
        self.add_api_object('Sender', self.Sender)
        self.SsmContactsArn = APIObject('SsmContactsArn', 'string', r'arn:(aws|aws-cn|aws-us-gov):ssm-contacts:[-\w+=\/,.@]*:[0-9]+:([\w+=\/,.@:-]+)*', 1, 2048)
        self.add_api_object('SsmContactsArn', self.SsmContactsArn)
        self.StopReason = APIObject('StopReason', 'string', r'^[.\s\S]*$', None, 255)
        self.add_api_object('StopReason', self.StopReason)
        self.Subject = APIObject('Subject', 'string', r'^[.\s\S]*$', 1, 2048)
        self.add_api_object('Subject', self.Subject)
        self.TagKey = APIObject('TagKey', 'string', r'^[\\\/a-zA-Z0-9_+=\-]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[\p{L}\p{Z}\p{N}_.:\/=+\-@]*$', 1, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TimeZoneId = APIObject('TimeZoneId', 'string', r'^[:a-zA-Z0-9_\-\s\.\\/]*$', 1, 255)
        self.add_api_object('TimeZoneId', self.TimeZoneId)
        self.Uuid = APIObject('Uuid', 'string', r'([a-fA-Z0-9]{8,11}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}){1}', 36, 39)
        self.add_api_object('Uuid', self.Uuid)

class SsmIncidents(Service):
    def __init__(self):
        super().__init__('SsmIncidents')
        self.Arn = APIObject('Arn', 'string', r'^arn:aws(-cn|-us-gov)?:[a-z0-9-]*:[a-z0-9-]*:([0-9]{12})?:.+$', 0, 1000)
        self.add_api_object('Arn', self.Arn)
        self.GeneratedId = APIObject('GeneratedId', 'string', r'^related-item/(ANALYSIS|INCIDENT|METRIC|PARENT|ATTACHMENT|OTHER|AUTOMATION|INVOLVED_RESOURCE|TASK)/([0-9]|[A-F]){32}$', 0, 200)
        self.add_api_object('GeneratedId', self.GeneratedId)
        self.ResponsePlanName = APIObject('ResponsePlanName', 'string', r'^[a-zA-Z0-9-_]*$', 1, 200)
        self.add_api_object('ResponsePlanName', self.ResponsePlanName)
        self.RoleArn = APIObject('RoleArn', 'string', r'^arn:aws(-cn|-us-gov)?:iam::([0-9]{12})?:role/.+$', 0, 1000)
        self.add_api_object('RoleArn', self.RoleArn)
        self.SsmAutomationDocumentNameString = APIObject('SsmAutomationDocumentNameString', 'string', r'^[a-zA-Z0-9_\-.:/]{3,128}$', None, None)
        self.add_api_object('SsmAutomationDocumentNameString', self.SsmAutomationDocumentNameString)
        self.SsmContactsArn = APIObject('SsmContactsArn', 'string', r'^arn:aws(-cn|-us-gov)?:ssm-contacts:[a-z0-9-]*:([0-9]{12}):contact/[a-z0-9_-]+$', 0, 2048)
        self.add_api_object('SsmContactsArn', self.SsmContactsArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[A-Za-z0-9 _=@:.+-/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^[A-Za-z0-9 _=@:.+-/]*$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class SsmSap(Service):
    def __init__(self):
        super().__init__('SsmSap')
        self.AppRegistryArn = APIObject('AppRegistryArn', 'string', r'arn:aws:servicecatalog:[a-z0-9:\/-]+', None, None)
        self.add_api_object('AppRegistryArn', self.AppRegistryArn)
        self.ApplicationId = APIObject('ApplicationId', 'string', r'[\w\d]{1,50}', None, None)
        self.add_api_object('ApplicationId', self.ApplicationId)
        self.Arn = APIObject('Arn', 'string', r'arn:(.+:){2,4}.+$|^arn:(.+:){1,3}.+\/.+', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ComponentId = APIObject('ComponentId', 'string', r'[\w\d-]+', None, None)
        self.add_api_object('ComponentId', self.ComponentId)
        self.DatabaseId = APIObject('DatabaseId', 'string', r'.*[\w\d]+', None, None)
        self.add_api_object('DatabaseId', self.DatabaseId)
        self.InstanceId = APIObject('InstanceId', 'string', r'i-[\w\d]{8}$|^i-[\w\d]{17}', None, None)
        self.add_api_object('InstanceId', self.InstanceId)
        self.NextToken = APIObject('NextToken', 'string', r'.{16,1024}', None, None)
        self.add_api_object('NextToken', self.NextToken)
        self.OperationEventResourceType = APIObject('OperationEventResourceType', 'string', r'[\w]+::[\w]+::[\w]+', None, None)
        self.add_api_object('OperationEventResourceType', self.OperationEventResourceType)
        self.OperationId = APIObject('OperationId', 'string', r'[{]?[0-9a-fA-F]{8}-([0-9a-fA-F]{4}-){3}[0-9a-fA-F]{12}[}]?', None, None)
        self.add_api_object('OperationId', self.OperationId)
        self.SAPInstanceNumber = APIObject('SAPInstanceNumber', 'string', r'[0-9]{2}', None, None)
        self.add_api_object('SAPInstanceNumber', self.SAPInstanceNumber)
        self.SID = APIObject('SID', 'string', r'[A-Z][A-Z0-9]{2}', None, None)
        self.add_api_object('SID', self.SID)
        self.SsmSapArn = APIObject('SsmSapArn', 'string', r'arn:(.+:){2,4}.+$|^arn:(.+:){1,3}.+\/.+', None, None)
        self.add_api_object('SsmSapArn', self.SsmSapArn)
        self.TagKey = APIObject('TagKey', 'string', r'(?!aws:)[a-zA-Z+-=._:/]+', None, None)
        self.add_api_object('TagKey', self.TagKey)

class Ssm(Service):
    def __init__(self):
        super().__init__('Ssm')
        self.AccountId = APIObject('AccountId', 'string', r'(?i)all|[0-9]{12}', None, None)
        self.add_api_object('AccountId', self.AccountId)
        self.ActivationId = APIObject('ActivationId', 'string', r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$', None, None)
        self.add_api_object('ActivationId', self.ActivationId)
        self.AlarmName = APIObject('AlarmName', 'string', r'^(?!\s*$).+', 1, 255)
        self.add_api_object('AlarmName', self.AlarmName)
        self.AssociationExecutionId = APIObject('AssociationExecutionId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('AssociationExecutionId', self.AssociationExecutionId)
        self.AssociationId = APIObject('AssociationId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('AssociationId', self.AssociationId)
        self.AssociationName = APIObject('AssociationName', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', None, None)
        self.add_api_object('AssociationName', self.AssociationName)
        self.AssociationVersion = APIObject('AssociationVersion', 'string', r'([$]LATEST)|([1-9][0-9]*)', None, None)
        self.add_api_object('AssociationVersion', self.AssociationVersion)
        self.AttachmentIdentifier = APIObject('AttachmentIdentifier', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', None, None)
        self.add_api_object('AttachmentIdentifier', self.AttachmentIdentifier)
        self.AttachmentName = APIObject('AttachmentName', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', None, None)
        self.add_api_object('AttachmentName', self.AttachmentName)
        self.AutomationActionName = APIObject('AutomationActionName', 'string', r'^aws:[a-zA-Z]{3,25}$', None, None)
        self.add_api_object('AutomationActionName', self.AutomationActionName)
        self.BaselineId = APIObject('BaselineId', 'string', r'^[a-zA-Z0-9_\-:/]{20,128}$', 20, 128)
        self.add_api_object('BaselineId', self.BaselineId)
        self.BaselineName = APIObject('BaselineName', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', 3, 128)
        self.add_api_object('BaselineName', self.BaselineName)
        self.ComplianceTypeName = APIObject('ComplianceTypeName', 'string', r'[A-Za-z0-9_\-]\w+|Custom:[a-zA-Z0-9_\-]\w+', 1, 100)
        self.add_api_object('ComplianceTypeName', self.ComplianceTypeName)
        self.DefaultInstanceName = APIObject('DefaultInstanceName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('DefaultInstanceName', self.DefaultInstanceName)
        self.DocumentARN = APIObject('DocumentARN', 'string', r'^[a-zA-Z0-9_\-.:/]{3,128}$', None, None)
        self.add_api_object('DocumentARN', self.DocumentARN)
        self.DocumentDisplayName = APIObject('DocumentDisplayName', 'string', r'^[\w\.\-\:\/ ]*$', None, 1024)
        self.add_api_object('DocumentDisplayName', self.DocumentDisplayName)
        self.DocumentName = APIObject('DocumentName', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', None, None)
        self.add_api_object('DocumentName', self.DocumentName)
        self.DocumentReviewComment = APIObject('DocumentReviewComment', 'string', r'^(?!\s*$).+', 1, 1024)
        self.add_api_object('DocumentReviewComment', self.DocumentReviewComment)
        self.DocumentSchemaVersion = APIObject('DocumentSchemaVersion', 'string', r'([0-9]+)\.([0-9]+)', None, None)
        self.add_api_object('DocumentSchemaVersion', self.DocumentSchemaVersion)
        self.DocumentVersion = APIObject('DocumentVersion', 'string', r'([$]LATEST|[$]DEFAULT|^[1-9][0-9]*$)', None, None)
        self.add_api_object('DocumentVersion', self.DocumentVersion)
        self.DocumentVersionName = APIObject('DocumentVersionName', 'string', r'^[a-zA-Z0-9_\-.]{1,128}$', None, None)
        self.add_api_object('DocumentVersionName', self.DocumentVersionName)
        self.DocumentVersionNumber = APIObject('DocumentVersionNumber', 'string', r'(^[1-9][0-9]*$)', None, None)
        self.add_api_object('DocumentVersionNumber', self.DocumentVersionNumber)
        self.ExecutionRoleName = APIObject('ExecutionRoleName', 'string', r'[\w+=,.@/-]+', 1, 64)
        self.add_api_object('ExecutionRoleName', self.ExecutionRoleName)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}', 36, 36)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.InstallOverrideList = APIObject('InstallOverrideList', 'string', r'^https://.+$|^s3://([^/]+)/(.*?([^/]+))$', 1, 256)
        self.add_api_object('InstallOverrideList', self.InstallOverrideList)
        self.InstanceId = APIObject('InstanceId', 'string', r'(^i-(\w{8}|\w{17})$)|(^mi-\w{17}$)', None, None)
        self.add_api_object('InstanceId', self.InstanceId)
        self.InstancePropertyFilterValue = APIObject('InstancePropertyFilterValue', 'string', r'^.{1,100000}$', 1, 100000)
        self.add_api_object('InstancePropertyFilterValue', self.InstancePropertyFilterValue)
        self.InstancePropertyStringFilterKey = APIObject('InstancePropertyStringFilterKey', 'string', r'^.{1,100000}$', 1, 100000)
        self.add_api_object('InstancePropertyStringFilterKey', self.InstancePropertyStringFilterKey)
        self.InventoryItemCaptureTime = APIObject('InventoryItemCaptureTime', 'string', r'^(20)[0-9][0-9]-(0[1-9]|1[012])-([12][0-9]|3[01]|0[1-9])(T)(2[0-3]|[0-1][0-9])(:[0-5][0-9])(:[0-5][0-9])(Z)$', None, None)
        self.add_api_object('InventoryItemCaptureTime', self.InventoryItemCaptureTime)
        self.InventoryItemSchemaVersion = APIObject('InventoryItemSchemaVersion', 'string', r'^([0-9]{1,6})(\.[0-9]{1,6})$', None, None)
        self.add_api_object('InventoryItemSchemaVersion', self.InventoryItemSchemaVersion)
        self.InventoryItemTypeName = APIObject('InventoryItemTypeName', 'string', r'^(AWS|Custom):.*$', 1, 100)
        self.add_api_object('InventoryItemTypeName', self.InventoryItemTypeName)
        self.MaintenanceWindowExecutionId = APIObject('MaintenanceWindowExecutionId', 'string', r'^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('MaintenanceWindowExecutionId', self.MaintenanceWindowExecutionId)
        self.MaintenanceWindowExecutionTaskId = APIObject('MaintenanceWindowExecutionTaskId', 'string', r'^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('MaintenanceWindowExecutionTaskId', self.MaintenanceWindowExecutionTaskId)
        self.MaintenanceWindowExecutionTaskInvocationId = APIObject('MaintenanceWindowExecutionTaskInvocationId', 'string', r'^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('MaintenanceWindowExecutionTaskInvocationId', self.MaintenanceWindowExecutionTaskInvocationId)
        self.MaintenanceWindowId = APIObject('MaintenanceWindowId', 'string', r'^mw-[0-9a-f]{17}$', 20, 20)
        self.add_api_object('MaintenanceWindowId', self.MaintenanceWindowId)
        self.MaintenanceWindowName = APIObject('MaintenanceWindowName', 'string', r'^[a-zA-Z0-9_\-.]{3,128}$', 3, 128)
        self.add_api_object('MaintenanceWindowName', self.MaintenanceWindowName)
        self.MaintenanceWindowTargetId = APIObject('MaintenanceWindowTargetId', 'string', r'^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('MaintenanceWindowTargetId', self.MaintenanceWindowTargetId)
        self.MaintenanceWindowTaskId = APIObject('MaintenanceWindowTaskId', 'string', r'^[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('MaintenanceWindowTaskId', self.MaintenanceWindowTaskId)
        self.ManagedInstanceId = APIObject('ManagedInstanceId', 'string', r'(^mi-[0-9a-f]{17}$)|(^eks_c:[0-9A-Za-z][A-Za-z0-9\-_]{0,99}_\w{17}$)', 20, 124)
        self.add_api_object('ManagedInstanceId', self.ManagedInstanceId)
        self.MaxConcurrency = APIObject('MaxConcurrency', 'string', r'^([1-9][0-9]*|[1-9][0-9]%|[1-9]%|100%)$', 1, 7)
        self.add_api_object('MaxConcurrency', self.MaxConcurrency)
        self.MaxErrors = APIObject('MaxErrors', 'string', r'^([1-9][0-9]*|[0]|[1-9][0-9]%|[0-9]%|100%)$', 1, 7)
        self.add_api_object('MaxErrors', self.MaxErrors)
        self.MaxSessionDuration = APIObject('MaxSessionDuration', 'string', r'^([1-9]|[1-9][0-9]|[1-9][0-9][0-9]|1[0-4][0-3][0-9]|1440)$', 1, 4)
        self.add_api_object('MaxSessionDuration', self.MaxSessionDuration)
        self.MetadataKey = APIObject('MetadataKey', 'string', r'^(?!\s*$).+', 1, 256)
        self.add_api_object('MetadataKey', self.MetadataKey)
        self.OpsAggregatorType = APIObject('OpsAggregatorType', 'string', r'^(range|count|sum)', 1, 20)
        self.add_api_object('OpsAggregatorType', self.OpsAggregatorType)
        self.OpsDataTypeName = APIObject('OpsDataTypeName', 'string', r'^(AWS|Custom):.*$', 1, 100)
        self.add_api_object('OpsDataTypeName', self.OpsDataTypeName)
        self.OpsEntityItemCaptureTime = APIObject('OpsEntityItemCaptureTime', 'string', r'^(20)[0-9][0-9]-(0[1-9]|1[012])-([12][0-9]|3[01]|0[1-9])(T)(2[0-3]|[0-1][0-9])(:[0-5][0-9])(:[0-5][0-9])(Z)$', None, None)
        self.add_api_object('OpsEntityItemCaptureTime', self.OpsEntityItemCaptureTime)
        self.OpsItemAccountId = APIObject('OpsItemAccountId', 'string', r'^[0-9]{12}$', None, None)
        self.add_api_object('OpsItemAccountId', self.OpsItemAccountId)
        self.OpsItemArn = APIObject('OpsItemArn', 'string', r'arn:(aws[a-zA-Z-]*)?:ssm:[a-z0-9-\.]{0,63}:[0-9]{12}:opsitem.*', 20, 2048)
        self.add_api_object('OpsItemArn', self.OpsItemArn)
        self.OpsItemCategory = APIObject('OpsItemCategory', 'string', r'^(?!\s*$).+', 1, 64)
        self.add_api_object('OpsItemCategory', self.OpsItemCategory)
        self.OpsItemDataKey = APIObject('OpsItemDataKey', 'string', r'^(?!\s*$).+', 1, 128)
        self.add_api_object('OpsItemDataKey', self.OpsItemDataKey)
        self.OpsItemDataValueString = APIObject('OpsItemDataValueString', 'string', r'[\s\S]*\S[\s\S]*', None, None)
        self.add_api_object('OpsItemDataValueString', self.OpsItemDataValueString)
        self.OpsItemDescription = APIObject('OpsItemDescription', 'string', r'[\s\S]*\S[\s\S]*', 1, 2048)
        self.add_api_object('OpsItemDescription', self.OpsItemDescription)
        self.OpsItemEventFilterValue = APIObject('OpsItemEventFilterValue', 'string', r'^(oi)-[0-9a-f]{12}$', 1, 15)
        self.add_api_object('OpsItemEventFilterValue', self.OpsItemEventFilterValue)
        self.OpsItemId = APIObject('OpsItemId', 'string', r'^(oi)-[0-9a-f]{12}$', None, None)
        self.add_api_object('OpsItemId', self.OpsItemId)
        self.OpsItemSeverity = APIObject('OpsItemSeverity', 'string', r'^(?!\s*$).+', 1, 64)
        self.add_api_object('OpsItemSeverity', self.OpsItemSeverity)
        self.OpsItemSource = APIObject('OpsItemSource', 'string', r'^(?!\s*$).+', 1, 128)
        self.add_api_object('OpsItemSource', self.OpsItemSource)
        self.OpsItemTitle = APIObject('OpsItemTitle', 'string', r'^(?!\s*$).+', 1, 1024)
        self.add_api_object('OpsItemTitle', self.OpsItemTitle)
        self.OpsMetadataArn = APIObject('OpsMetadataArn', 'string', r'arn:(aws[a-zA-Z-]*)?:ssm:[a-z0-9-\.]{0,63}:[a-z0-9-\.]{0,63}:opsmetadata\/([a-zA-Z0-9-_\.\/]*)', 1, 1011)
        self.add_api_object('OpsMetadataArn', self.OpsMetadataArn)
        self.OpsMetadataFilterKey = APIObject('OpsMetadataFilterKey', 'string', r'^(?!\s*$).+', 1, 128)
        self.add_api_object('OpsMetadataFilterKey', self.OpsMetadataFilterKey)
        self.OpsMetadataResourceId = APIObject('OpsMetadataResourceId', 'string', r'^(?!\s*$).+', 1, 1024)
        self.add_api_object('OpsMetadataResourceId', self.OpsMetadataResourceId)
        self.ParameterKeyId = APIObject('ParameterKeyId', 'string', r'^([a-zA-Z0-9:/_-]+)$', 1, 256)
        self.add_api_object('ParameterKeyId', self.ParameterKeyId)
        self.ParameterStringFilterKey = APIObject('ParameterStringFilterKey', 'string', r'tag:.+|Name|Type|KeyId|Path|Label|Tier|DataType', 1, 132)
        self.add_api_object('ParameterStringFilterKey', self.ParameterStringFilterKey)
        self.PatchGroup = APIObject('PatchGroup', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 256)
        self.add_api_object('PatchGroup', self.PatchGroup)
        self.PatchSourceName = APIObject('PatchSourceName', 'string', r'^[a-zA-Z0-9_\-.]{3,50}$', None, None)
        self.add_api_object('PatchSourceName', self.PatchSourceName)
        self.Policy = APIObject('Policy', 'string', r'^(?!\s*$).+', None, None)
        self.add_api_object('Policy', self.Policy)
        self.RegistrationMetadataKey = APIObject('RegistrationMetadataKey', 'string', r'^(?!\s*$).+', 1, 128)
        self.add_api_object('RegistrationMetadataKey', self.RegistrationMetadataKey)
        self.RegistrationMetadataValue = APIObject('RegistrationMetadataValue', 'string', r'^(?!\s*$).+', 1, 2048)
        self.add_api_object('RegistrationMetadataValue', self.RegistrationMetadataValue)
        self.RequireType = APIObject('RequireType', 'string', r'^[a-zA-Z0-9_\-.]{1,128}$', None, 128)
        self.add_api_object('RequireType', self.RequireType)
        self.ResourceDataSyncAWSKMSKeyARN = APIObject('ResourceDataSyncAWSKMSKeyARN', 'string', r'arn:.*', 1, 512)
        self.add_api_object('ResourceDataSyncAWSKMSKeyARN', self.ResourceDataSyncAWSKMSKeyARN)
        self.ResourceDataSyncOrganizationalUnitId = APIObject('ResourceDataSyncOrganizationalUnitId', 'string', r'^ou-[0-9a-z]{4,32}-[a-z0-9]{8,32}$', 1, 128)
        self.add_api_object('ResourceDataSyncOrganizationalUnitId', self.ResourceDataSyncOrganizationalUnitId)
        self.Reviewer = APIObject('Reviewer', 'string', r'^[a-zA-Z0-9_\-.]{1,128}$', None, 50)
        self.add_api_object('Reviewer', self.Reviewer)
        self.SessionReason = APIObject('SessionReason', 'string', r'^.{1,256}$', 1, 256)
        self.add_api_object('SessionReason', self.SessionReason)
        self.SharedDocumentVersion = APIObject('SharedDocumentVersion', 'string', r'([$]LATEST|[$]DEFAULT|[$]ALL)', None, 8)
        self.add_api_object('SharedDocumentVersion', self.SharedDocumentVersion)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$', 36, 36)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.SourceId = APIObject('SourceId', 'string', r'^[a-zA-Z0-9:_-]*$', 0, 128)
        self.add_api_object('SourceId', self.SourceId)
        self.StringDateTime = APIObject('StringDateTime', 'string', r'^([\-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24\:?00)([\.,]\d(?!:))?)?(\17[0-5]\d([\.,]\d)?)?([zZ]|([\-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$', None, None)
        self.add_api_object('StringDateTime', self.StringDateTime)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TargetKey = APIObject('TargetKey', 'string', r'^[\p{L}\p{Z}\p{N}_.:/=\-@]*$|resource-groups:ResourceTypeFilters|resource-groups:Name', 1, 163)
        self.add_api_object('TargetKey', self.TargetKey)
        self.TargetType = APIObject('TargetType', 'string', r'^\/[\w\.\-\:\/]*$', None, 200)
        self.add_api_object('TargetType', self.TargetType)
        self.UUID = APIObject('UUID', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', None, None)
        self.add_api_object('UUID', self.UUID)
        self.Version = APIObject('Version', 'string', r'^[0-9]{1,6}(\.[0-9]{1,6}){2,3}$', None, None)
        self.add_api_object('Version', self.Version)

class SsoAdmin(Service):
    def __init__(self):
        super().__init__('SsoAdmin')
        self.AccessControlAttributeKey = APIObject('AccessControlAttributeKey', 'string', r'^[\p{L}\p{Z}\p{N}_.:\/=+\-@]+$', 1, 128)
        self.add_api_object('AccessControlAttributeKey', self.AccessControlAttributeKey)
        self.AccessControlAttributeValueSource = APIObject('AccessControlAttributeValueSource', 'string', r'^[\p{L}\p{Z}\p{N}_.:\/=+\-@\[\]\{\}\$\\"]*$', 0, 256)
        self.add_api_object('AccessControlAttributeValueSource', self.AccessControlAttributeValueSource)
        self.AccountId = APIObject('AccountId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16}$', 10, 1224)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.ApplicationProviderArn = APIObject('ApplicationProviderArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::aws:applicationProvider/[a-zA-Z0-9-/]+$', 10, 1224)
        self.add_api_object('ApplicationProviderArn', self.ApplicationProviderArn)
        self.ApplicationUrl = APIObject('ApplicationUrl', 'string', r'^http(s)?:\/\/[-a-zA-Z0-9+&@#\/%?=~_|!:,.;]*[-a-zA-Z0-9+&bb@#\/%?=~_|]$', 1, 512)
        self.add_api_object('ApplicationUrl', self.ApplicationUrl)
        self.ClaimAttributePath = APIObject('ClaimAttributePath', 'string', r'^\p{L}+(?:(\.|\_)\p{L}+){0,2}$', 1, 255)
        self.add_api_object('ClaimAttributePath', self.ClaimAttributePath)
        self.ClientToken = APIObject('ClientToken', 'string', r'^[!-~]+$', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.Duration = APIObject('Duration', 'string', r'^(-?)P(?=\d|T\d)(?:(\d+)Y)?(?:(\d+)M)?(?:(\d+)([DW]))?(?:T(?:(\d+)H)?(?:(\d+)M)?(?:(\d+(?:\.\d+)?)S)?)?$', 1, 100)
        self.add_api_object('Duration', self.Duration)
        self.IconUrl = APIObject('IconUrl', 'string', r'^(http|https):\/\/.*$', 1, 768)
        self.add_api_object('IconUrl', self.IconUrl)
        self.Id = APIObject('Id', 'string', r'^[a-zA-Z0-9-]*$', 1, 64)
        self.add_api_object('Id', self.Id)
        self.InstanceArn = APIObject('InstanceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso:::instance/(sso)?ins-[a-zA-Z0-9-.]{16}$', 10, 1224)
        self.add_api_object('InstanceArn', self.InstanceArn)
        self.JMESPath = APIObject('JMESPath', 'string', r'^\p{L}+(?:\.\p{L}+){0,2}$', 1, 255)
        self.add_api_object('JMESPath', self.JMESPath)
        self.ManagedPolicyArn = APIObject('ManagedPolicyArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):iam::aws:policy/[\p{L}\p{M}\p{Z}\p{S}\p{N}\p{P}]+$', 20, 2048)
        self.add_api_object('ManagedPolicyArn', self.ManagedPolicyArn)
        self.ManagedPolicyName = APIObject('ManagedPolicyName', 'string', r'^[\w+=,.@-]+$', 1, 128)
        self.add_api_object('ManagedPolicyName', self.ManagedPolicyName)
        self.ManagedPolicyPath = APIObject('ManagedPolicyPath', 'string', r'^((/[A-Za-z0-9\.,\+@=_-]+)*)/$', 1, 512)
        self.add_api_object('ManagedPolicyPath', self.ManagedPolicyPath)
        self.NameType = APIObject('NameType', 'string', r'^[\w+=,.@-]+$', 0, 255)
        self.add_api_object('NameType', self.NameType)
        self.PermissionSetArn = APIObject('PermissionSetArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso:::permissionSet/(sso)?ins-[a-zA-Z0-9-.]{16}/ps-[a-zA-Z0-9-./]{16}$', 10, 1224)
        self.add_api_object('PermissionSetArn', self.PermissionSetArn)
        self.PermissionSetDescription = APIObject('PermissionSetDescription', 'string', r'^[\u0009\u000A\u000D\u0020-\u007E\u00A1-\u00FF]*$', 1, 700)
        self.add_api_object('PermissionSetDescription', self.PermissionSetDescription)
        self.PermissionSetName = APIObject('PermissionSetName', 'string', r'^[\w+=,.@-]+$', 1, 32)
        self.add_api_object('PermissionSetName', self.PermissionSetName)
        self.PermissionSetPolicyDocument = APIObject('PermissionSetPolicyDocument', 'string', r'^[\u0009\u000A\u000D\u0020-\u00FF]+$', 1, 32768)
        self.add_api_object('PermissionSetPolicyDocument', self.PermissionSetPolicyDocument)
        self.PrincipalId = APIObject('PrincipalId', 'string', r'^([0-9a-f]{10}-|)[A-Fa-f0-9]{8}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{4}-[A-Fa-f0-9]{12}$', 1, 47)
        self.add_api_object('PrincipalId', self.PrincipalId)
        self.Reason = APIObject('Reason', 'string', r'^[\p{L}\p{M}\p{Z}\p{S}\p{N}\p{P}]*$', None, None)
        self.add_api_object('Reason', self.Reason)
        self.RelayState = APIObject('RelayState', 'string', r'^[a-zA-Z0-9&$@#\\\/%?=~\-_\'"|!:,.;*+\[\]\ \(\)\{\}]+$', 1, 240)
        self.add_api_object('RelayState', self.RelayState)
        self.ResourceServerScope = APIObject('ResourceServerScope', 'string', r'^[^:=\-\.\s][0-9a-zA-Z_:\-\.]+$', 1, 80)
        self.add_api_object('ResourceServerScope', self.ResourceServerScope)
        self.Scope = APIObject('Scope', 'string', r'^([A-Za-z0-9_]{1,50})(:[A-Za-z0-9_]{1,50}){0,1}(:[A-Za-z0-9_]{1,50}){0,1}$', None, None)
        self.add_api_object('Scope', self.Scope)
        self.ScopeTarget = APIObject('ScopeTarget', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::(\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16}|:instance/(sso)?ins-[a-zA-Z0-9-.]{16})$', 1, 100)
        self.add_api_object('ScopeTarget', self.ScopeTarget)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TaggableResourceArn = APIObject('TaggableResourceArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::((:instance/(sso)?ins-[a-zA-Z0-9-.]{16})|(:permissionSet/(sso)?ins-[a-zA-Z0-9-.]{16}/ps-[a-zA-Z0-9-./]{16})|(\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16})|(\d{12}:trustedTokenIssuer/(sso)?ins-[a-zA-Z0-9-.]{16}/tti-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}))$', 10, 2048)
        self.add_api_object('TaggableResourceArn', self.TaggableResourceArn)
        self.TargetId = APIObject('TargetId', 'string', r'^\d{12}$', 12, 12)
        self.add_api_object('TargetId', self.TargetId)
        self.Token = APIObject('Token', 'string', r'^[-a-zA-Z0-9+=/_]*$', 0, 2048)
        self.add_api_object('Token', self.Token)
        self.TrustedTokenIssuerArn = APIObject('TrustedTokenIssuerArn', 'string', r'^arn:(aws|aws-us-gov|aws-cn|aws-iso|aws-iso-b):sso::\d{12}:trustedTokenIssuer/(sso)?ins-[a-zA-Z0-9-.]{16}/tti-[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', 10, 1224)
        self.add_api_object('TrustedTokenIssuerArn', self.TrustedTokenIssuerArn)
        self.TrustedTokenIssuerName = APIObject('TrustedTokenIssuerName', 'string', r'^[\w+=,.@-]+$', 1, 255)
        self.add_api_object('TrustedTokenIssuerName', self.TrustedTokenIssuerName)
        self.TrustedTokenIssuerUrl = APIObject('TrustedTokenIssuerUrl', 'string', r'^https?:\/\/[-a-zA-Z0-9+&@\/%=~_|!:,.;]*[-a-zA-Z0-9+&@\/%=~_|]$', 1, 512)
        self.add_api_object('TrustedTokenIssuerUrl', self.TrustedTokenIssuerUrl)
        self.UUId = APIObject('UUId', 'string', r'^\b[0-9a-f]{8}\b-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-\b[0-9a-f]{12}\b$', 36, 36)
        self.add_api_object('UUId', self.UUId)

class SsoOidc(Service):
    def __init__(self):
        super().__init__('SsoOidc')

class Sso(Service):
    def __init__(self):
        super().__init__('Sso')

class Stepfunctions(Service):
    def __init__(self):
        super().__init__('Stepfunctions')
        self.CharacterRestrictedName = APIObject('CharacterRestrictedName', 'string', r'^(?=.*[a-zA-Z_\-\.])[a-zA-Z0-9_\-\.]+$', 1, 80)
        self.add_api_object('CharacterRestrictedName', self.CharacterRestrictedName)
        self.ClientToken = APIObject('ClientToken', 'string', r'[!-~]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.TraceHeader = APIObject('TraceHeader', 'string', r'\p{ASCII}*', 0, 256)
        self.add_api_object('TraceHeader', self.TraceHeader)

class Storagegateway(Service):
    def __init__(self):
        super().__init__('Storagegateway')
        self.DNSHostName = APIObject('DNSHostName', 'string', r'^(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])$', 1, 255)
        self.add_api_object('DNSHostName', self.DNSHostName)
        self.DomainName = APIObject('DomainName', 'string', r'^([a-zA-Z0-9]+[\\.-])+([a-zA-Z0-9])+$', 1, 1024)
        self.add_api_object('DomainName', self.DomainName)
        self.DomainUserName = APIObject('DomainUserName', 'string', r'^\w[\w\.\- ]*$', 1, 1024)
        self.add_api_object('DomainUserName', self.DomainUserName)
        self.DomainUserPassword = APIObject('DomainUserPassword', 'string', r'^[ -~]+$', 1, 1024)
        self.add_api_object('DomainUserPassword', self.DomainUserPassword)
        self.GatewayName = APIObject('GatewayName', 'string', r'^[ -\.0-\[\]-~]*[!-\.0-\[\]-~][ -\.0-\[\]-~]*$', 2, 255)
        self.add_api_object('GatewayName', self.GatewayName)
        self.Host = APIObject('Host', 'string', r'^(([a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9\-]*[A-Za-z0-9])(:(\d+))?$', 6, 1024)
        self.add_api_object('Host', self.Host)
        self.IPV4Address = APIObject('IPV4Address', 'string', r'^((25[0-5]|(2[0-4]|1[0-9]|[1-9]|)[0-9])(\.(?!$)|$)){4}', 7, 15)
        self.add_api_object('IPV4Address', self.IPV4Address)
        self.IPV4AddressCIDR = APIObject('IPV4AddressCIDR', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(\/([0-9]|[1-2][0-9]|3[0-2]))?$', None, None)
        self.add_api_object('IPV4AddressCIDR', self.IPV4AddressCIDR)
        self.IqnName = APIObject('IqnName', 'string', r'[0-9a-z:.-]+', 1, 255)
        self.add_api_object('IqnName', self.IqnName)
        self.KMSKey = APIObject('KMSKey', 'string', r'(^arn:(aws(|-cn|-us-gov|-iso[A-Za-z0-9_-]*)):kms:([a-zA-Z0-9-]+):([0-9]+):(key|alias)/(\S+)$)|(^alias/(\S+)$)', 7, 2048)
        self.add_api_object('KMSKey', self.KMSKey)
        self.LocalConsolePassword = APIObject('LocalConsolePassword', 'string', r'^[ -~]+$', 6, 512)
        self.add_api_object('LocalConsolePassword', self.LocalConsolePassword)
        self.NetworkInterfaceId = APIObject('NetworkInterfaceId', 'string', r'\A(25[0-5]|2[0-4]\d|[0-1]?\d?\d)(\.(25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}\z', None, None)
        self.add_api_object('NetworkInterfaceId', self.NetworkInterfaceId)
        self.NotificationPolicy = APIObject('NotificationPolicy', 'string', r'^\{[\w\s:\{\}\[\]"]*}$', 2, 100)
        self.add_api_object('NotificationPolicy', self.NotificationPolicy)
        self.PermissionMode = APIObject('PermissionMode', 'string', r'^[0-7]{4}$', 1, 4)
        self.add_api_object('PermissionMode', self.PermissionMode)
        self.PoolName = APIObject('PoolName', 'string', r'^[ -\.0-\[\]-~]*[!-\.0-\[\]-~][ -\.0-\[\]-~]*$', 1, 100)
        self.add_api_object('PoolName', self.PoolName)
        self.Role = APIObject('Role', 'string', r'^arn:(aws(|-cn|-us-gov|-iso[A-Za-z0-9_-]*)):iam::([0-9]+):role/(\S+)$', 20, 2048)
        self.add_api_object('Role', self.Role)
        self.SMBGuestPassword = APIObject('SMBGuestPassword', 'string', r'^[ -~]+$', 6, 512)
        self.add_api_object('SMBGuestPassword', self.SMBGuestPassword)
        self.SnapshotId = APIObject('SnapshotId', 'string', r'\Asnap-([0-9A-Fa-f]{8}|[0-9A-Fa-f]{17})\z', None, None)
        self.add_api_object('SnapshotId', self.SnapshotId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TapeARN = APIObject('TapeARN', 'string', r'arn:(aws(|-cn|-us-gov|-iso[A-Za-z0-9_-]*)):storagegateway:[a-z\-0-9]+:[0-9]+:tape\/[0-9A-Z]{5,16}$', 50, 500)
        self.add_api_object('TapeARN', self.TapeARN)
        self.TapeBarcode = APIObject('TapeBarcode', 'string', r'^[A-Z0-9]*$', 5, 16)
        self.add_api_object('TapeBarcode', self.TapeBarcode)
        self.TapeBarcodePrefix = APIObject('TapeBarcodePrefix', 'string', r'^[A-Z]*$', 1, 4)
        self.add_api_object('TapeBarcodePrefix', self.TapeBarcodePrefix)
        self.TargetName = APIObject('TargetName', 'string', r'^[-\.;a-z0-9]+$', 1, 200)
        self.add_api_object('TargetName', self.TargetName)

class Sts(Service):
    def __init__(self):
        super().__init__('Sts')
        self.accessKeyIdType = APIObject('accessKeyIdType', 'string', r'[\w]*', 16, 128)
        self.add_api_object('accessKeyIdType', self.accessKeyIdType)
        self.arnType = APIObject('arnType', 'string', r'[\u0009\u000A\u000D\u0020-\u007E\u0085\u00A0-\uD7FF\uE000-\uFFFD\u10000-\u10FFFF]+', 20, 2048)
        self.add_api_object('arnType', self.arnType)
        self.assumedRoleIdType = APIObject('assumedRoleIdType', 'string', r'[\w+=,.@:-]*', 2, 193)
        self.add_api_object('assumedRoleIdType', self.assumedRoleIdType)
        self.externalIdType = APIObject('externalIdType', 'string', r'[\w+=,.@:\/-]*', 2, 1224)
        self.add_api_object('externalIdType', self.externalIdType)
        self.federatedIdType = APIObject('federatedIdType', 'string', r'[\w+=,.@\:-]*', 2, 193)
        self.add_api_object('federatedIdType', self.federatedIdType)
        self.roleSessionNameType = APIObject('roleSessionNameType', 'string', r'[\w+=,.@-]*', 2, 64)
        self.add_api_object('roleSessionNameType', self.roleSessionNameType)
        self.serialNumberType = APIObject('serialNumberType', 'string', r'[\w+=/:,.@-]*', 9, 256)
        self.add_api_object('serialNumberType', self.serialNumberType)
        self.sessionPolicyDocumentType = APIObject('sessionPolicyDocumentType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, 2048)
        self.add_api_object('sessionPolicyDocumentType', self.sessionPolicyDocumentType)
        self.sourceIdentityType = APIObject('sourceIdentityType', 'string', r'[\w+=,.@-]*', 2, 64)
        self.add_api_object('sourceIdentityType', self.sourceIdentityType)
        self.tagKeyType = APIObject('tagKeyType', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]+', 1, 128)
        self.add_api_object('tagKeyType', self.tagKeyType)
        self.tagValueType = APIObject('tagValueType', 'string', r'[\p{L}\p{Z}\p{N}_.:/=+\-@]*', 0, 256)
        self.add_api_object('tagValueType', self.tagValueType)
        self.tokenCodeType = APIObject('tokenCodeType', 'string', r'[\d]*', 6, 6)
        self.add_api_object('tokenCodeType', self.tokenCodeType)
        self.unrestrictedSessionPolicyDocumentType = APIObject('unrestrictedSessionPolicyDocumentType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]+', 1, None)
        self.add_api_object('unrestrictedSessionPolicyDocumentType', self.unrestrictedSessionPolicyDocumentType)
        self.userNameType = APIObject('userNameType', 'string', r'[\w+=,.@-]*', 2, 32)
        self.add_api_object('userNameType', self.userNameType)

class Supplychain(Service):
    def __init__(self):
        super().__init__('Supplychain')
        self.ConfigurationS3Uri = APIObject('ConfigurationS3Uri', 'string', r'[sS]3://[a-z0-9][a-z0-9.-]{1,61}[a-z0-9]/.+', 10, None)
        self.add_api_object('ConfigurationS3Uri', self.ConfigurationS3Uri)
        self.UUID = APIObject('UUID', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 36, 36)
        self.add_api_object('UUID', self.UUID)

class SupportApp(Service):
    def __init__(self):
        super().__init__('SupportApp')
        self.awsAccountAlias = APIObject('awsAccountAlias', 'string', r'^[\w\- ]+$', 1, 30)
        self.add_api_object('awsAccountAlias', self.awsAccountAlias)
        self.channelId = APIObject('channelId', 'string', r'^\S+$', 1, 256)
        self.add_api_object('channelId', self.channelId)
        self.channelName = APIObject('channelName', 'string', r'^.+$', 1, 256)
        self.add_api_object('channelName', self.channelName)
        self.paginationToken = APIObject('paginationToken', 'string', r'^\S+$', 1, 256)
        self.add_api_object('paginationToken', self.paginationToken)
        self.roleArn = APIObject('roleArn', 'string', r'^arn:aws:iam::[0-9]{12}:role/(.+)$', 31, 2048)
        self.add_api_object('roleArn', self.roleArn)
        self.teamId = APIObject('teamId', 'string', r'^\S+$', 1, 256)
        self.add_api_object('teamId', self.teamId)
        self.teamName = APIObject('teamName', 'string', r'^.+$', 1, 256)
        self.add_api_object('teamName', self.teamName)

class Support(Service):
    def __init__(self):
        super().__init__('Support')

class Swf(Service):
    def __init__(self):
        super().__init__('Swf')

class Synthetics(Service):
    def __init__(self):
        super().__init__('Synthetics')
        self.BaseScreenshotConfigIgnoreCoordinate = APIObject('BaseScreenshotConfigIgnoreCoordinate', 'string', r'^(-?\d{1,5}\.?\d{0,2},){3}(-?\d{1,5}\.?\d{0,2}){1}$', None, None)
        self.add_api_object('BaseScreenshotConfigIgnoreCoordinate', self.BaseScreenshotConfigIgnoreCoordinate)
        self.CanaryArn = APIObject('CanaryArn', 'string', r'arn:(aws[a-zA-Z-]*)?:synthetics:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:canary:[0-9a-z_\-]{1,21}', 1, 2048)
        self.add_api_object('CanaryArn', self.CanaryArn)
        self.CanaryName = APIObject('CanaryName', 'string', r'^[0-9a-z_\-]+$', 1, 21)
        self.add_api_object('CanaryName', self.CanaryName)
        self.CodeHandler = APIObject('CodeHandler', 'string', r'^([0-9a-zA-Z_-]+\/)*[0-9A-Za-z_\\-]+\.[A-Za-z_][A-Za-z0-9_]*$', 1, 128)
        self.add_api_object('CodeHandler', self.CodeHandler)
        self.EnvironmentVariableName = APIObject('EnvironmentVariableName', 'string', r'[a-zA-Z]([a-zA-Z0-9_])+', None, None)
        self.add_api_object('EnvironmentVariableName', self.EnvironmentVariableName)
        self.FunctionArn = APIObject('FunctionArn', 'string', r'arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(:(\$LATEST|[a-zA-Z0-9-_]+))?', 1, 2048)
        self.add_api_object('FunctionArn', self.FunctionArn)
        self.GroupArn = APIObject('GroupArn', 'string', r'arn:(aws[a-zA-Z-]*)?:synthetics:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:group:[0-9a-z]+', 1, 128)
        self.add_api_object('GroupArn', self.GroupArn)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:(aws[a-zA-Z-]*)?:kms:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:key/[\w\-\/]+', 1, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^.+$', 1, 512)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:(aws[a-zA-Z-]*)?:synthetics:[a-z]{2}((-gov)|(-iso(b?)))?-[a-z]+-\d{1}:\d{12}:(canary|group):[0-9a-z_\-]+', 1, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:(aws[a-zA-Z-]*)?:iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', 1, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.UUID = APIObject('UUID', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('UUID', self.UUID)

class Textract(Service):
    def __init__(self):
        super().__init__('Textract')
        self.AdapterDescription = APIObject('AdapterDescription', 'string', r'^[a-zA-Z0-9\s!"\#\$%\'&\(\)\*\+\,\-\./:;=\?@\[\\\]\^_`\{\|\}~><]+$', 1, 256)
        self.add_api_object('AdapterDescription', self.AdapterDescription)
        self.AdapterName = APIObject('AdapterName', 'string', r'[a-zA-Z0-9-_]+', 1, 128)
        self.add_api_object('AdapterName', self.AdapterName)
        self.AdapterPage = APIObject('AdapterPage', 'string', r'^[0-9\*\-]+$', 1, 9)
        self.add_api_object('AdapterPage', self.AdapterPage)
        self.AdapterVersionStatusMessage = APIObject('AdapterVersionStatusMessage', 'string', r'^[a-zA-Z0-9\s!"\#\$%\'&\(\)\*\+\,\-\./:;=\?@\[\\\]\^_`\{\|\}~><]+$', 1, 256)
        self.add_api_object('AdapterVersionStatusMessage', self.AdapterVersionStatusMessage)
        self.ClientRequestToken = APIObject('ClientRequestToken', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientRequestToken', self.ClientRequestToken)
        self.HumanLoopName = APIObject('HumanLoopName', 'string', r'^[a-z0-9](-*[a-z0-9])*', 1, 63)
        self.add_api_object('HumanLoopName', self.HumanLoopName)
        self.JobId = APIObject('JobId', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('JobId', self.JobId)
        self.JobTag = APIObject('JobTag', 'string', r'[a-zA-Z0-9_.\-:]+', 1, 64)
        self.add_api_object('JobTag', self.JobTag)
        self.KMSKeyId = APIObject('KMSKeyId', 'string', r'^[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,2048}$', 1, 2048)
        self.add_api_object('KMSKeyId', self.KMSKeyId)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', None, None)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.QueryInput = APIObject('QueryInput', 'string', r'^[a-zA-Z0-9\s!"\#\$%\'&\(\)\*\+\,\-\./:;=\?@\[\\\]\^_`\{\|\}~><]+$', 1, 200)
        self.add_api_object('QueryInput', self.QueryInput)
        self.QueryPage = APIObject('QueryPage', 'string', r'^[0-9\*\-]+$', 1, 9)
        self.add_api_object('QueryPage', self.QueryPage)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:([a-z\d-]+):iam::\d{12}:role/?[a-zA-Z_0-9+=,.@\-_/]+', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[0-9A-Za-z\.\-_]*', 3, 255)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3ObjectName = APIObject('S3ObjectName', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('S3ObjectName', self.S3ObjectName)
        self.S3ObjectVersion = APIObject('S3ObjectVersion', 'string', r'.*\S.*', 1, 1024)
        self.add_api_object('S3ObjectVersion', self.S3ObjectVersion)
        self.SNSTopicArn = APIObject('SNSTopicArn', 'string', r'(^arn:([a-z\d-]+):sns:[a-zA-Z\d-]{1,20}:\w{12}:.+$)', 20, 1024)
        self.add_api_object('SNSTopicArn', self.SNSTopicArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[\p{L}\p{Z}\p{N}_.:/=+\-@]*$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class TimestreamInfluxdb(Service):
    def __init__(self):
        super().__init__('TimestreamInfluxdb')
        self.Arn = APIObject('Arn', 'string', r'arn:aws[a-z\-]*:timestream\-influxdb:[a-z0-9\-]+:[0-9]{12}:(db\-instance|db\-parameter\-group)/[a-zA-Z0-9]{3,64}', 1, 1011)
        self.add_api_object('Arn', self.Arn)
        self.Bucket = APIObject('Bucket', 'string', r'[^_][^"]*', 2, 64)
        self.add_api_object('Bucket', self.Bucket)
        self.DbInstanceId = APIObject('DbInstanceId', 'string', r'[a-zA-Z0-9]+', 3, 64)
        self.add_api_object('DbInstanceId', self.DbInstanceId)
        self.DbInstanceIdentifier = APIObject('DbInstanceIdentifier', 'string', r'[a-zA-Z0-9]+', 3, 64)
        self.add_api_object('DbInstanceIdentifier', self.DbInstanceIdentifier)
        self.DbInstanceName = APIObject('DbInstanceName', 'string', r'[a-zA-z][a-zA-Z0-9]*(-[a-zA-Z0-9]+)*', 3, 40)
        self.add_api_object('DbInstanceName', self.DbInstanceName)
        self.DbParameterGroupId = APIObject('DbParameterGroupId', 'string', r'[a-zA-Z0-9]+', 3, 64)
        self.add_api_object('DbParameterGroupId', self.DbParameterGroupId)
        self.DbParameterGroupIdentifier = APIObject('DbParameterGroupIdentifier', 'string', r'[a-zA-Z0-9]+', 3, 64)
        self.add_api_object('DbParameterGroupIdentifier', self.DbParameterGroupIdentifier)
        self.DbParameterGroupName = APIObject('DbParameterGroupName', 'string', r'[a-zA-z][a-zA-Z0-9]*(-[a-zA-Z0-9]+)*', 3, 64)
        self.add_api_object('DbParameterGroupName', self.DbParameterGroupName)
        self.Password = APIObject('Password', 'string', r'[a-zA-Z0-9]+', 8, 64)
        self.add_api_object('Password', self.Password)
        self.S3ConfigurationBucketNameString = APIObject('S3ConfigurationBucketNameString', 'string', r'[0-9a-z]+[0-9a-z\.\-]*[0-9a-z]+', 3, 63)
        self.add_api_object('S3ConfigurationBucketNameString', self.S3ConfigurationBucketNameString)
        self.VpcSecurityGroupId = APIObject('VpcSecurityGroupId', 'string', r'sg-[a-z0-9]+', 0, 64)
        self.add_api_object('VpcSecurityGroupId', self.VpcSecurityGroupId)
        self.VpcSubnetId = APIObject('VpcSubnetId', 'string', r'subnet-[a-z0-9]+', 0, 64)
        self.add_api_object('VpcSubnetId', self.VpcSubnetId)

class TimestreamQuery(Service):
    def __init__(self):
        super().__init__('TimestreamQuery')
        self.QueryId = APIObject('QueryId', 'string', r'[a-zA-Z0-9]+', 1, 64)
        self.add_api_object('QueryId', self.QueryId)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectKeyPrefix = APIObject('S3ObjectKeyPrefix', 'string', r'[a-zA-Z0-9|!\-_*\'\(\)]([a-zA-Z0-9]|[!\-_*\'\(\)\/.])+', 1, 896)
        self.add_api_object('S3ObjectKeyPrefix', self.S3ObjectKeyPrefix)
        self.ScheduledQueryName = APIObject('ScheduledQueryName', 'string', r'[a-zA-Z0-9|!\-_*\'\(\)]([a-zA-Z0-9]|[!\-_*\'\(\)\/.])+', 1, 64)
        self.add_api_object('ScheduledQueryName', self.ScheduledQueryName)

class TimestreamWrite(Service):
    def __init__(self):
        super().__init__('TimestreamWrite')
        self.BatchLoadTaskId = APIObject('BatchLoadTaskId', 'string', r'[A-Z0-9]+', 3, 32)
        self.add_api_object('BatchLoadTaskId', self.BatchLoadTaskId)
        self.ResourceCreateAPIName = APIObject('ResourceCreateAPIName', 'string', r'[a-zA-Z0-9_.-]+', None, None)
        self.add_api_object('ResourceCreateAPIName', self.ResourceCreateAPIName)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'[a-zA-Z0-9|!\-_*\'\(\)]([a-zA-Z0-9]|[!\-_*\'\(\)\/.])+', 1, 1024)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.S3ObjectKeyPrefix = APIObject('S3ObjectKeyPrefix', 'string', r'[a-zA-Z0-9|!\-_*\'\(\)]([a-zA-Z0-9]|[!\-_*\'\(\)\/.])+', 1, 928)
        self.add_api_object('S3ObjectKeyPrefix', self.S3ObjectKeyPrefix)

class Tnb(Service):
    def __init__(self):
        super().__init__('Tnb')
        self.NsInstanceArn = APIObject('NsInstanceArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-b|aws-us-gov):tnb:([a-z]{2}(-(gov|isob|iso))?-(east|west|north|south|central){1,2}-[0-9]):\d{12}:(network-instance/ni-[a-f0-9]{17})$', None, None)
        self.add_api_object('NsInstanceArn', self.NsInstanceArn)
        self.NsInstanceId = APIObject('NsInstanceId', 'string', r'^ni-[a-f0-9]{17}$', None, None)
        self.add_api_object('NsInstanceId', self.NsInstanceId)
        self.NsLcmOpOccArn = APIObject('NsLcmOpOccArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-b|aws-us-gov):tnb:([a-z]{2}(-(gov|isob|iso))?-(east|west|north|south|central){1,2}-[0-9]):\d{12}:(network-operation/no-[a-f0-9]{17})$', None, None)
        self.add_api_object('NsLcmOpOccArn', self.NsLcmOpOccArn)
        self.NsLcmOpOccId = APIObject('NsLcmOpOccId', 'string', r'^no-[a-f0-9]{17}$', None, None)
        self.add_api_object('NsLcmOpOccId', self.NsLcmOpOccId)
        self.NsdId = APIObject('NsdId', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('NsdId', self.NsdId)
        self.NsdInfoArn = APIObject('NsdInfoArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-b|aws-us-gov):tnb:([a-z]{2}(-(gov|isob|iso))?-(east|west|north|south|central){1,2}-[0-9]):\d{12}:(network-package/np-[a-f0-9]{17})$', None, None)
        self.add_api_object('NsdInfoArn', self.NsdInfoArn)
        self.NsdInfoId = APIObject('NsdInfoId', 'string', r'^np-[a-f0-9]{17}$', None, None)
        self.add_api_object('NsdInfoId', self.NsdInfoId)
        self.TNBResourceArn = APIObject('TNBResourceArn', 'string', r'^arn:aws:tnb:[a-z0-9-]+:[^:]*:.*$', None, None)
        self.add_api_object('TNBResourceArn', self.TNBResourceArn)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:).{1,128}$', None, None)
        self.add_api_object('TagKey', self.TagKey)
        self.VnfInstanceArn = APIObject('VnfInstanceArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-b|aws-us-gov):tnb:([a-z]{2}(-(gov|isob|iso))?-(east|west|north|south|central){1,2}-[0-9]):\d{12}:(function-instance/fi-[a-f0-9]{17})$', None, None)
        self.add_api_object('VnfInstanceArn', self.VnfInstanceArn)
        self.VnfInstanceId = APIObject('VnfInstanceId', 'string', r'^fi-[a-f0-9]{17}$', None, None)
        self.add_api_object('VnfInstanceId', self.VnfInstanceId)
        self.VnfPkgArn = APIObject('VnfPkgArn', 'string', r'^arn:(aws|aws-cn|aws-iso|aws-iso-b|aws-us-gov):tnb:([a-z]{2}(-(gov|isob|iso))?-(east|west|north|south|central){1,2}-[0-9]):\d{12}:(function-package/fp-[a-f0-9]{17})$', None, None)
        self.add_api_object('VnfPkgArn', self.VnfPkgArn)
        self.VnfPkgId = APIObject('VnfPkgId', 'string', r'^fp-[a-f0-9]{17}$', None, None)
        self.add_api_object('VnfPkgId', self.VnfPkgId)
        self.VnfdId = APIObject('VnfdId', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('VnfdId', self.VnfdId)

class Transcribe(Service):
    def __init__(self):
        super().__init__('Transcribe')
        self.CallAnalyticsJobName = APIObject('CallAnalyticsJobName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('CallAnalyticsJobName', self.CallAnalyticsJobName)
        self.CategoryName = APIObject('CategoryName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('CategoryName', self.CategoryName)
        self.DataAccessRoleArn = APIObject('DataAccessRoleArn', 'string', r'^arn:(aws|aws-cn|aws-us-gov|aws-iso-{0,1}[a-z]{0,1}):iam::[0-9]{0,63}:role/[A-Za-z0-9:_/+=,@.-]{0,1024}$', 20, 2048)
        self.add_api_object('DataAccessRoleArn', self.DataAccessRoleArn)
        self.KMSKeyId = APIObject('KMSKeyId', 'string', r'^[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,2048}$', 1, 2048)
        self.add_api_object('KMSKeyId', self.KMSKeyId)
        self.ModelName = APIObject('ModelName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('ModelName', self.ModelName)
        self.NextToken = APIObject('NextToken', 'string', r'.+', None, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.NonEmptyString = APIObject('NonEmptyString', 'string', r'.*\S.*', 1, 2000)
        self.add_api_object('NonEmptyString', self.NonEmptyString)
        self.OutputBucketName = APIObject('OutputBucketName', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', None, 64)
        self.add_api_object('OutputBucketName', self.OutputBucketName)
        self.OutputKey = APIObject('OutputKey', 'string', r'[a-zA-Z0-9-_.!*\'()/]{1,1024}$', 1, 1024)
        self.add_api_object('OutputKey', self.OutputKey)
        self.Phrase = APIObject('Phrase', 'string', r'.+', 0, 256)
        self.add_api_object('Phrase', self.Phrase)
        self.TranscribeArn = APIObject('TranscribeArn', 'string', r'arn:aws(-[^:]+)?:transcribe:[a-zA-Z0-9-]*:[0-9]{12}:[a-zA-Z-]*/[0-9a-zA-Z._-]+', 1, 1011)
        self.add_api_object('TranscribeArn', self.TranscribeArn)
        self.TranscriptionJobName = APIObject('TranscriptionJobName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('TranscriptionJobName', self.TranscriptionJobName)
        self.Uri = APIObject('Uri', 'string', r'(s3://|http(s*)://).+', 1, 2000)
        self.add_api_object('Uri', self.Uri)
        self.VocabularyFilterName = APIObject('VocabularyFilterName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('VocabularyFilterName', self.VocabularyFilterName)
        self.VocabularyName = APIObject('VocabularyName', 'string', r'^[0-9a-zA-Z._-]+', 1, 200)
        self.add_api_object('VocabularyName', self.VocabularyName)

class Transfer(Service):
    def __init__(self):
        super().__init__('Transfer')
        self.AgreementId = APIObject('AgreementId', 'string', r'a-([0-9a-f]{17})', 19, 19)
        self.add_api_object('AgreementId', self.AgreementId)
        self.Arn = APIObject('Arn', 'string', r'arn:\S+', 20, 1600)
        self.add_api_object('Arn', self.Arn)
        self.As2Id = APIObject('As2Id', 'string', r'[\p{Print}\s]*', 1, 128)
        self.add_api_object('As2Id', self.As2Id)
        self.CallbackToken = APIObject('CallbackToken', 'string', r'\w+', 1, 64)
        self.add_api_object('CallbackToken', self.CallbackToken)
        self.CertSerial = APIObject('CertSerial', 'string', r'[\p{XDigit}{2}:?]*', 0, 48)
        self.add_api_object('CertSerial', self.CertSerial)
        self.CertificateBodyType = APIObject('CertificateBodyType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]*', 1, 16384)
        self.add_api_object('CertificateBodyType', self.CertificateBodyType)
        self.CertificateChainType = APIObject('CertificateChainType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]*', 1, 2097152)
        self.add_api_object('CertificateChainType', self.CertificateChainType)
        self.CertificateId = APIObject('CertificateId', 'string', r'cert-([0-9a-f]{17})', 22, 22)
        self.add_api_object('CertificateId', self.CertificateId)
        self.ConnectorId = APIObject('ConnectorId', 'string', r'c-([0-9a-f]{17})', 19, 19)
        self.add_api_object('ConnectorId', self.ConnectorId)
        self.ConnectorSecurityPolicyName = APIObject('ConnectorSecurityPolicyName', 'string', r'TransferSFTPConnectorSecurityPolicy-[A-Za-z0-9-]+', 0, 100)
        self.add_api_object('ConnectorSecurityPolicyName', self.ConnectorSecurityPolicyName)
        self.CustomStepTarget = APIObject('CustomStepTarget', 'string', r'arn:[a-z-]+:lambda:.*', 0, 170)
        self.add_api_object('CustomStepTarget', self.CustomStepTarget)
        self.Description = APIObject('Description', 'string', r'[\p{Graph}]+', 1, 200)
        self.add_api_object('Description', self.Description)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'd-[0-9a-f]{10}', 12, 12)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.EfsFileSystemId = APIObject('EfsFileSystemId', 'string', r'(arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:(access-point/fsap|file-system/fs)-[0-9a-f]{8,40}|fs(ap)?-[0-9a-f]{8,40})', 0, 128)
        self.add_api_object('EfsFileSystemId', self.EfsFileSystemId)
        self.EfsPath = APIObject('EfsPath', 'string', r'[^\x00]+', 1, 65536)
        self.add_api_object('EfsPath', self.EfsPath)
        self.ExecutionId = APIObject('ExecutionId', 'string', r'[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}', 36, 36)
        self.add_api_object('ExecutionId', self.ExecutionId)
        self.ExternalId = APIObject('ExternalId', 'string', r'S-1-[\d-]+', 1, 256)
        self.add_api_object('ExternalId', self.ExternalId)
        self.FilePath = APIObject('FilePath', 'string', r'(.)+', 1, 1024)
        self.add_api_object('FilePath', self.FilePath)
        self.Function = APIObject('Function', 'string', r'arn:[a-z-]+:lambda:.*', 1, 170)
        self.add_api_object('Function', self.Function)
        self.HomeDirectory = APIObject('HomeDirectory', 'string', r'(|/.*)', 0, 1024)
        self.add_api_object('HomeDirectory', self.HomeDirectory)
        self.HostKeyDescription = APIObject('HostKeyDescription', 'string', r'[\p{Print}]*', 0, 200)
        self.add_api_object('HostKeyDescription', self.HostKeyDescription)
        self.HostKeyId = APIObject('HostKeyId', 'string', r'hostkey-[0-9a-f]{17}', 25, 25)
        self.add_api_object('HostKeyId', self.HostKeyId)
        self.ListingId = APIObject('ListingId', 'string', r'[0-9a-zA-Z./-]+', 1, 512)
        self.add_api_object('ListingId', self.ListingId)
        self.LogGroupName = APIObject('LogGroupName', 'string', r'[\.\-_/#A-Za-z0-9]*', 1, 512)
        self.add_api_object('LogGroupName', self.LogGroupName)
        self.MapEntry = APIObject('MapEntry', 'string', r'/.*', 0, 1024)
        self.add_api_object('MapEntry', self.MapEntry)
        self.MapTarget = APIObject('MapTarget', 'string', r'/.*', 0, 1024)
        self.add_api_object('MapTarget', self.MapTarget)
        self.MessageSubject = APIObject('MessageSubject', 'string', r'[\p{Print}\p{Blank}]+', 1, 1024)
        self.add_api_object('MessageSubject', self.MessageSubject)
        self.NullableRole = APIObject('NullableRole', 'string', r'(|arn:.*role/\S+)', 0, 2048)
        self.add_api_object('NullableRole', self.NullableRole)
        self.OutputFileName = APIObject('OutputFileName', 'string', r'c-([0-9a-f]{17})-[0-9a-zA-Z./-]+.json', 26, 537)
        self.add_api_object('OutputFileName', self.OutputFileName)
        self.PostAuthenticationLoginBanner = APIObject('PostAuthenticationLoginBanner', 'string', r'[\x09-\x0D\x20-\x7E]*', 0, 4096)
        self.add_api_object('PostAuthenticationLoginBanner', self.PostAuthenticationLoginBanner)
        self.PreAuthenticationLoginBanner = APIObject('PreAuthenticationLoginBanner', 'string', r'[\x09-\x0D\x20-\x7E]*', 0, 4096)
        self.add_api_object('PreAuthenticationLoginBanner', self.PreAuthenticationLoginBanner)
        self.PrivateKeyType = APIObject('PrivateKeyType', 'string', r'[\u0009\u000A\u000D\u0020-\u00FF]*', 1, 16384)
        self.add_api_object('PrivateKeyType', self.PrivateKeyType)
        self.ProfileId = APIObject('ProfileId', 'string', r'p-([0-9a-f]{17})', 19, 19)
        self.add_api_object('ProfileId', self.ProfileId)
        self.Role = APIObject('Role', 'string', r'arn:.*role/\S+', 20, 2048)
        self.add_api_object('Role', self.Role)
        self.S3Bucket = APIObject('S3Bucket', 'string', r'[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9]', 3, 63)
        self.add_api_object('S3Bucket', self.S3Bucket)
        self.S3Etag = APIObject('S3Etag', 'string', r'.+', 1, 65536)
        self.add_api_object('S3Etag', self.S3Etag)
        self.S3Key = APIObject('S3Key', 'string', r'[\P{M}\p{M}]*', 0, 1024)
        self.add_api_object('S3Key', self.S3Key)
        self.S3TagKey = APIObject('S3TagKey', 'string', r'([\p{L}\p{Z}\p{N}_.:/=+\-@]*)', 1, 128)
        self.add_api_object('S3TagKey', self.S3TagKey)
        self.S3TagValue = APIObject('S3TagValue', 'string', r'([\p{L}\p{Z}\p{N}_.:/=+\-@]*)', 0, 256)
        self.add_api_object('S3TagValue', self.S3TagValue)
        self.S3VersionId = APIObject('S3VersionId', 'string', r'.+', 1, 1024)
        self.add_api_object('S3VersionId', self.S3VersionId)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'sg-[0-9a-f]{8,17}', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SecurityPolicyName = APIObject('SecurityPolicyName', 'string', r'Transfer[A-Za-z0-9]*SecurityPolicy-[A-Za-z0-9-]+', 0, 100)
        self.add_api_object('SecurityPolicyName', self.SecurityPolicyName)
        self.ServerId = APIObject('ServerId', 'string', r's-([0-9a-f]{17})', 19, 19)
        self.add_api_object('ServerId', self.ServerId)
        self.ServiceManagedEgressIpAddress = APIObject('ServiceManagedEgressIpAddress', 'string', r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', None, None)
        self.add_api_object('ServiceManagedEgressIpAddress', self.ServiceManagedEgressIpAddress)
        self.SessionId = APIObject('SessionId', 'string', r'[\w-]*', 3, 32)
        self.add_api_object('SessionId', self.SessionId)
        self.SourceFileLocation = APIObject('SourceFileLocation', 'string', r'\$\{(\w+.)+\w+\}', 0, 256)
        self.add_api_object('SourceFileLocation', self.SourceFileLocation)
        self.SourceIp = APIObject('SourceIp', 'string', r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', 0, 32)
        self.add_api_object('SourceIp', self.SourceIp)
        self.SshPublicKeyId = APIObject('SshPublicKeyId', 'string', r'key-[0-9a-f]{17}', 21, 21)
        self.add_api_object('SshPublicKeyId', self.SshPublicKeyId)
        self.TransferId = APIObject('TransferId', 'string', r'[0-9a-zA-Z./-]+', 1, 512)
        self.add_api_object('TransferId', self.TransferId)
        self.UserName = APIObject('UserName', 'string', r'[\w][\w@.-]{2,99}', 3, 100)
        self.add_api_object('UserName', self.UserName)
        self.VpcEndpointId = APIObject('VpcEndpointId', 'string', r'vpce-[0-9a-f]{17}', 22, 22)
        self.add_api_object('VpcEndpointId', self.VpcEndpointId)
        self.WorkflowDescription = APIObject('WorkflowDescription', 'string', r'[\w- ]*', 0, 256)
        self.add_api_object('WorkflowDescription', self.WorkflowDescription)
        self.WorkflowId = APIObject('WorkflowId', 'string', r'w-([a-z0-9]{17})', 19, 19)
        self.add_api_object('WorkflowId', self.WorkflowId)
        self.WorkflowStepName = APIObject('WorkflowStepName', 'string', r'[\w-]*', 0, 30)
        self.add_api_object('WorkflowStepName', self.WorkflowStepName)

class Translate(Service):
    def __init__(self):
        super().__init__('Translate')
        self.BoundedLengthString = APIObject('BoundedLengthString', 'string', r'[\P{M}\p{M}]{1,10000}', 1, 10000)
        self.add_api_object('BoundedLengthString', self.BoundedLengthString)
        self.ClientTokenString = APIObject('ClientTokenString', 'string', r'^[a-zA-Z0-9-]+$', 1, 64)
        self.add_api_object('ClientTokenString', self.ClientTokenString)
        self.ContentType = APIObject('ContentType', 'string', r'^[-\w.]+\/[-\w.+]+$', None, 256)
        self.add_api_object('ContentType', self.ContentType)
        self.Description = APIObject('Description', 'string', r'[\P{M}\p{M}]{0,256}', None, 256)
        self.add_api_object('Description', self.Description)
        self.EncryptionKeyID = APIObject('EncryptionKeyID', 'string', r'(arn:aws((-us-gov)|(-iso)|(-iso-b)|(-cn))?:kms:)?([a-z]{2}-[a-z]+(-[a-z]+)?-\d:)?(\d{12}:)?(((key/)?[a-zA-Z0-9-_]+)|(alias/[a-zA-Z0-9:/_-]+))', 1, 400)
        self.add_api_object('EncryptionKeyID', self.EncryptionKeyID)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.JobId = APIObject('JobId', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 32)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 256)
        self.add_api_object('JobName', self.JobName)
        self.NextToken = APIObject('NextToken', 'string', r'\p{ASCII}{0,8192}', None, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.ResourceName = APIObject('ResourceName', 'string', r'^([A-Za-z0-9-]_?)+$', 1, 256)
        self.add_api_object('ResourceName', self.ResourceName)
        self.S3Uri = APIObject('S3Uri', 'string', r's3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?', None, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.String = APIObject('String', 'string', r'[\P{M}\p{M}]{0,10000}', None, 10000)
        self.add_api_object('String', self.String)
        self.TranslatedTextString = APIObject('TranslatedTextString', 'string', r'[\P{M}\p{M}]{0,20000}', None, 20000)
        self.add_api_object('TranslatedTextString', self.TranslatedTextString)

class Trustedadvisor(Service):
    def __init__(self):
        super().__init__('Trustedadvisor')
        self.AccountId = APIObject('AccountId', 'string', r'^\d+$', 12, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.AccountRecommendationArn = APIObject('AccountRecommendationArn', 'string', r'^arn:[\w-]+:trustedadvisor::\d{12}:recommendation\/[\w-]+$', 20, 2048)
        self.add_api_object('AccountRecommendationArn', self.AccountRecommendationArn)
        self.AccountRecommendationIdentifier = APIObject('AccountRecommendationIdentifier', 'string', r'^arn:[\w-]+:trustedadvisor::\d{12}:recommendation\/[\w-]+$', 20, 200)
        self.add_api_object('AccountRecommendationIdentifier', self.AccountRecommendationIdentifier)
        self.CheckArn = APIObject('CheckArn', 'string', r'^arn:[\w-]+:trustedadvisor:::check\/[\w-]+$', 20, 2048)
        self.add_api_object('CheckArn', self.CheckArn)
        self.CheckIdentifier = APIObject('CheckIdentifier', 'string', r'^arn:[\w-]+:trustedadvisor:::check\/[\w-]+$', 20, 64)
        self.add_api_object('CheckIdentifier', self.CheckIdentifier)
        self.OrganizationRecommendationArn = APIObject('OrganizationRecommendationArn', 'string', r'^arn:[\w-]+:trustedadvisor:::organization-recommendation\/[\w-]+$', 20, 2048)
        self.add_api_object('OrganizationRecommendationArn', self.OrganizationRecommendationArn)
        self.OrganizationRecommendationIdentifier = APIObject('OrganizationRecommendationIdentifier', 'string', r'^arn:[\w-]+:trustedadvisor:::organization-recommendation\/[\w-]+$', 20, 200)
        self.add_api_object('OrganizationRecommendationIdentifier', self.OrganizationRecommendationIdentifier)
        self.RecommendationResourceArn = APIObject('RecommendationResourceArn', 'string', r'^arn:[\w-]+:trustedadvisor::\d{12}:recommendation-resource\/[\w-]+\/[\w-]+$', 20, 2048)
        self.add_api_object('RecommendationResourceArn', self.RecommendationResourceArn)
        self.RecommendationUpdateReason = APIObject('RecommendationUpdateReason', 'string', r'^[\s\S]*$', 10, 4096)
        self.add_api_object('RecommendationUpdateReason', self.RecommendationUpdateReason)

class Verifiedpermissions(Service):
    def __init__(self):
        super().__init__('Verifiedpermissions')
        self.ActionId = APIObject('ActionId', 'string', r'.*', 1, 200)
        self.add_api_object('ActionId', self.ActionId)
        self.ActionType = APIObject('ActionType', 'string', r'Action$|^.+::Action', 1, 200)
        self.add_api_object('ActionType', self.ActionType)
        self.ClientId = APIObject('ClientId', 'string', r'.*', 1, 255)
        self.add_api_object('ClientId', self.ClientId)
        self.DiscoveryUrl = APIObject('DiscoveryUrl', 'string', r'https://.*', 1, 2048)
        self.add_api_object('DiscoveryUrl', self.DiscoveryUrl)
        self.EntityId = APIObject('EntityId', 'string', r'.*', 1, 200)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityType = APIObject('EntityType', 'string', r'.*', 1, 200)
        self.add_api_object('EntityType', self.EntityType)
        self.GroupEntityType = APIObject('GroupEntityType', 'string', r'([_a-zA-Z][_a-zA-Z0-9]*::)*[_a-zA-Z][_a-zA-Z0-9]*', 1, 200)
        self.add_api_object('GroupEntityType', self.GroupEntityType)
        self.IdempotencyToken = APIObject('IdempotencyToken', 'string', r'[a-zA-Z0-9-]*', 1, 64)
        self.add_api_object('IdempotencyToken', self.IdempotencyToken)
        self.IdentitySourceId = APIObject('IdentitySourceId', 'string', r'[a-zA-Z0-9-]*', 1, 200)
        self.add_api_object('IdentitySourceId', self.IdentitySourceId)
        self.Issuer = APIObject('Issuer', 'string', r'https://.*', 1, 2048)
        self.add_api_object('Issuer', self.Issuer)
        self.Namespace = APIObject('Namespace', 'string', r'.*', 1, 100)
        self.add_api_object('Namespace', self.Namespace)
        self.NextToken = APIObject('NextToken', 'string', r'[A-Za-z0-9-_=+/\.]*', 1, 8000)
        self.add_api_object('NextToken', self.NextToken)
        self.PolicyId = APIObject('PolicyId', 'string', r'[a-zA-Z0-9-]*', 1, 200)
        self.add_api_object('PolicyId', self.PolicyId)
        self.PolicyStoreId = APIObject('PolicyStoreId', 'string', r'[a-zA-Z0-9-]*', 1, 200)
        self.add_api_object('PolicyStoreId', self.PolicyStoreId)
        self.PolicyTemplateId = APIObject('PolicyTemplateId', 'string', r'[a-zA-Z0-9-]*', 1, 200)
        self.add_api_object('PolicyTemplateId', self.PolicyTemplateId)
        self.PrincipalEntityType = APIObject('PrincipalEntityType', 'string', r'.*', 1, 200)
        self.add_api_object('PrincipalEntityType', self.PrincipalEntityType)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:[^:]*:[^:]*:[^:]*:[^:]*:.*', 1, 2500)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.Token = APIObject('Token', 'string', r'[A-Za-z0-9-_=]+.[A-Za-z0-9-_=]+.[A-Za-z0-9-_=]+', 1, 131072)
        self.add_api_object('Token', self.Token)
        self.UserPoolArn = APIObject('UserPoolArn', 'string', r'arn:[a-zA-Z0-9-]+:cognito-idp:(([a-zA-Z0-9-]+:\d{12}:userpool/[\w-]+_[0-9a-zA-Z]+))', 1, 255)
        self.add_api_object('UserPoolArn', self.UserPoolArn)

class VoiceId(Service):
    def __init__(self):
        super().__init__('VoiceId')
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'^arn:aws(-[^:]+)?:voiceid.+:[0-9]{12}:domain/[a-zA-Z0-9]{22}$', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.Arn = APIObject('Arn', 'string', r'^arn:aws(-[^:]+)?:voiceid.+:[0-9]{12}:domain/[a-zA-Z0-9]{22}$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ClientTokenString = APIObject('ClientTokenString', 'string', r'^[a-zA-Z0-9-_]+$', 1, 64)
        self.add_api_object('ClientTokenString', self.ClientTokenString)
        self.CustomerSpeakerId = APIObject('CustomerSpeakerId', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_-]*$', 1, 256)
        self.add_api_object('CustomerSpeakerId', self.CustomerSpeakerId)
        self.Description = APIObject('Description', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 1024)
        self.add_api_object('Description', self.Description)
        self.DomainId = APIObject('DomainId', 'string', r'^[a-zA-Z0-9]{22}$', 22, 22)
        self.add_api_object('DomainId', self.DomainId)
        self.DomainName = APIObject('DomainName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_-]*$', 1, 256)
        self.add_api_object('DomainName', self.DomainName)
        self.FraudsterId = APIObject('FraudsterId', 'string', r'^id#[a-zA-Z0-9]{22}$', 25, 25)
        self.add_api_object('FraudsterId', self.FraudsterId)
        self.GeneratedFraudsterId = APIObject('GeneratedFraudsterId', 'string', r'^id#[a-zA-Z0-9]{22}$', 25, 25)
        self.add_api_object('GeneratedFraudsterId', self.GeneratedFraudsterId)
        self.GeneratedSpeakerId = APIObject('GeneratedSpeakerId', 'string', r'^id#[a-zA-Z0-9]{22}$', 25, 25)
        self.add_api_object('GeneratedSpeakerId', self.GeneratedSpeakerId)
        self.IamRoleArn = APIObject('IamRoleArn', 'string', r'^arn:aws(-[^:]+)?:iam::[0-9]{12}:role/.+$', 20, 2048)
        self.add_api_object('IamRoleArn', self.IamRoleArn)
        self.JobId = APIObject('JobId', 'string', r'^[a-zA-Z0-9]{22}$', 22, 22)
        self.add_api_object('JobId', self.JobId)
        self.JobName = APIObject('JobName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_-]*$', 1, 256)
        self.add_api_object('JobName', self.JobName)
        self.NextToken = APIObject('NextToken', 'string', r'^\p{ASCII}{0,8192}$', 0, 8192)
        self.add_api_object('NextToken', self.NextToken)
        self.S3Uri = APIObject('S3Uri', 'string', r'^s3://[a-z0-9][\.\-a-z0-9]{1,61}[a-z0-9](/.*)?$', 0, 1024)
        self.add_api_object('S3Uri', self.S3Uri)
        self.SessionId = APIObject('SessionId', 'string', r'^id#[a-zA-Z0-9]{22}$', 25, 25)
        self.add_api_object('SessionId', self.SessionId)
        self.SessionName = APIObject('SessionName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_-]*$', 1, 36)
        self.add_api_object('SessionName', self.SessionName)
        self.SessionNameOrId = APIObject('SessionNameOrId', 'string', r'^(id#[a-zA-Z0-9]{22}|[a-zA-Z0-9][a-zA-Z0-9_-]*)$', 1, 36)
        self.add_api_object('SessionNameOrId', self.SessionNameOrId)
        self.SpeakerId = APIObject('SpeakerId', 'string', r'^(id#[a-zA-Z0-9]{22}|[a-zA-Z0-9][a-zA-Z0-9_-]*)$', 1, 256)
        self.add_api_object('SpeakerId', self.SpeakerId)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.UniqueIdLarge = APIObject('UniqueIdLarge', 'string', r'^[a-zA-Z0-9]{22}$', 22, 22)
        self.add_api_object('UniqueIdLarge', self.UniqueIdLarge)
        self.WatchlistDescription = APIObject('WatchlistDescription', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-%@]*)$', 1, 1024)
        self.add_api_object('WatchlistDescription', self.WatchlistDescription)
        self.WatchlistId = APIObject('WatchlistId', 'string', r'^[a-zA-Z0-9]{22}$', 22, 22)
        self.add_api_object('WatchlistId', self.WatchlistId)
        self.WatchlistName = APIObject('WatchlistName', 'string', r'^[a-zA-Z0-9][a-zA-Z0-9_-]*$', 1, 256)
        self.add_api_object('WatchlistName', self.WatchlistName)

class VpcLattice(Service):
    def __init__(self):
        super().__init__('VpcLattice')
        self.AccessLogDestinationArn = APIObject('AccessLogDestinationArn', 'string', r'^arn(:[a-z0-9]+([.-][a-z0-9]+)*){2}(:([a-z0-9]+([.-][a-z0-9]+)*)?){2}:([^/].*)?$', 20, 2048)
        self.add_api_object('AccessLogDestinationArn', self.AccessLogDestinationArn)
        self.AccessLogSubscriptionArn = APIObject('AccessLogSubscriptionArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:accesslogsubscription/als-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('AccessLogSubscriptionArn', self.AccessLogSubscriptionArn)
        self.AccessLogSubscriptionId = APIObject('AccessLogSubscriptionId', 'string', r'^als-[0-9a-z]{17}$', 21, 21)
        self.add_api_object('AccessLogSubscriptionId', self.AccessLogSubscriptionId)
        self.AccessLogSubscriptionIdentifier = APIObject('AccessLogSubscriptionIdentifier', 'string', r'^((als-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:accesslogsubscription/als-[0-9a-z]{17}))$', 17, 2048)
        self.add_api_object('AccessLogSubscriptionIdentifier', self.AccessLogSubscriptionIdentifier)
        self.AccountId = APIObject('AccountId', 'string', r'^[0-9]{12}$', 1, 12)
        self.add_api_object('AccountId', self.AccountId)
        self.Arn = APIObject('Arn', 'string', r'^arn:[a-z0-9][-.a-z0-9]{0,62}:vpc-lattice:([a-z0-9][-.a-z0-9]{0,62})?:\d{12}?:[^/].{0,1023}$', 0, 1224)
        self.add_api_object('Arn', self.Arn)
        self.CertificateArn = APIObject('CertificateArn', 'string', r'^(arn(:[a-z0-9]+([.-][a-z0-9]+)*){2}(:([a-z0-9]+([.-][a-z0-9]+)*)?){2}:certificate/[0-9a-z-]+)?$', 0, 2048)
        self.add_api_object('CertificateArn', self.CertificateArn)
        self.ClientToken = APIObject('ClientToken', 'string', r'[!-~]+', 1, 64)
        self.add_api_object('ClientToken', self.ClientToken)
        self.HealthCheckPath = APIObject('HealthCheckPath', 'string', r'(^/[a-zA-Z0-9@:%_+.~#?&/=-]*$|(^$))', 0, 2048)
        self.add_api_object('HealthCheckPath', self.HealthCheckPath)
        self.HttpCodeMatcher = APIObject('HttpCodeMatcher', 'string', r'(^[0-9-,]+$|(^$))', 0, 2000)
        self.add_api_object('HttpCodeMatcher', self.HttpCodeMatcher)
        self.ListenerArn = APIObject('ListenerArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}/listener/listener-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('ListenerArn', self.ListenerArn)
        self.ListenerId = APIObject('ListenerId', 'string', r'^listener-[0-9a-z]{17}$', 26, 26)
        self.add_api_object('ListenerId', self.ListenerId)
        self.ListenerIdentifier = APIObject('ListenerIdentifier', 'string', r'^((listener-[0-9a-z]{17})|(^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}/listener/listener-[0-9a-z]{17}$))$', 20, 2048)
        self.add_api_object('ListenerIdentifier', self.ListenerIdentifier)
        self.ListenerName = APIObject('ListenerName', 'string', r'^(?!listener-)(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$', 3, 63)
        self.add_api_object('ListenerName', self.ListenerName)
        self.PathMatchExact = APIObject('PathMatchExact', 'string', r'^/[a-zA-Z0-9@:%_+.~#?&/=-]*$', 1, 200)
        self.add_api_object('PathMatchExact', self.PathMatchExact)
        self.PathMatchPrefix = APIObject('PathMatchPrefix', 'string', r'^/[a-zA-Z0-9@:%_+.~#?&/=-]*$', 1, 200)
        self.add_api_object('PathMatchPrefix', self.PathMatchPrefix)
        self.PolicyString = APIObject('PolicyString', 'string', r'^.*\S.*$', 1, 10000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'^arn(:[a-z0-9]+([.-][a-z0-9]+)*){2}(:([a-z0-9]+([.-][a-z0-9]+)*)?){2}:((servicenetwork/sn)|(service/svc))-[0-9a-z]{17}$', 20, 200)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'^((sn)|(svc))-[0-9a-z]{17}$', 20, 50)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceIdentifier = APIObject('ResourceIdentifier', 'string', r'^((((sn)|(svc))-[0-9a-z]{17})|(arn(:[a-z0-9]+([.-][a-z0-9]+)*){2}(:([a-z0-9]+([.-][a-z0-9]+)*)?){2}:((servicenetwork/sn)|(service/svc))-[0-9a-z]{17}))$', 17, 200)
        self.add_api_object('ResourceIdentifier', self.ResourceIdentifier)
        self.RuleArn = APIObject('RuleArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}/listener/listener-[0-9a-z]{17}/rule/rule-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('RuleArn', self.RuleArn)
        self.RuleId = APIObject('RuleId', 'string', r'^rule-[0-9a-z]{17}$', 5, 22)
        self.add_api_object('RuleId', self.RuleId)
        self.RuleIdentifier = APIObject('RuleIdentifier', 'string', r'^((rule-[0-9a-z]{17})|(^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}/listener/listener-[0-9a-z]{17}/rule/rule-[0-9a-z]{17}$))$', 20, 2048)
        self.add_api_object('RuleIdentifier', self.RuleIdentifier)
        self.RuleName = APIObject('RuleName', 'string', r'^(?!rule-)(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$', 3, 63)
        self.add_api_object('RuleName', self.RuleName)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-(([0-9a-z]{8})|([0-9a-z]{17}))$', 5, 200)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.ServiceArn = APIObject('ServiceArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('ServiceArn', self.ServiceArn)
        self.ServiceId = APIObject('ServiceId', 'string', r'^svc-[0-9a-z]{17}$', 21, 21)
        self.add_api_object('ServiceId', self.ServiceId)
        self.ServiceIdentifier = APIObject('ServiceIdentifier', 'string', r'^((svc-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:service/svc-[0-9a-z]{17}))$', 17, 2048)
        self.add_api_object('ServiceIdentifier', self.ServiceIdentifier)
        self.ServiceName = APIObject('ServiceName', 'string', r'^(?!svc-)(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$', 3, 40)
        self.add_api_object('ServiceName', self.ServiceName)
        self.ServiceNetworkArn = APIObject('ServiceNetworkArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetwork/sn-[0-9a-z]{17}$', 32, 2048)
        self.add_api_object('ServiceNetworkArn', self.ServiceNetworkArn)
        self.ServiceNetworkId = APIObject('ServiceNetworkId', 'string', r'^sn-[0-9a-z]{17}$', 32, 32)
        self.add_api_object('ServiceNetworkId', self.ServiceNetworkId)
        self.ServiceNetworkIdentifier = APIObject('ServiceNetworkIdentifier', 'string', r'^((sn-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetwork/sn-[0-9a-z]{17}))$', 3, 2048)
        self.add_api_object('ServiceNetworkIdentifier', self.ServiceNetworkIdentifier)
        self.ServiceNetworkName = APIObject('ServiceNetworkName', 'string', r'^(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$', 3, 63)
        self.add_api_object('ServiceNetworkName', self.ServiceNetworkName)
        self.ServiceNetworkServiceAssociationArn = APIObject('ServiceNetworkServiceAssociationArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetworkserviceassociation/snsa-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('ServiceNetworkServiceAssociationArn', self.ServiceNetworkServiceAssociationArn)
        self.ServiceNetworkServiceAssociationIdentifier = APIObject('ServiceNetworkServiceAssociationIdentifier', 'string', r'^((snsa-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetworkserviceassociation/snsa-[0-9a-z]{17}))$', 17, 2048)
        self.add_api_object('ServiceNetworkServiceAssociationIdentifier', self.ServiceNetworkServiceAssociationIdentifier)
        self.ServiceNetworkVpcAssociationArn = APIObject('ServiceNetworkVpcAssociationArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetworkvpcassociation/snva-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('ServiceNetworkVpcAssociationArn', self.ServiceNetworkVpcAssociationArn)
        self.ServiceNetworkVpcAssociationId = APIObject('ServiceNetworkVpcAssociationId', 'string', r'^snva-[0-9a-z]{17}$', 22, 22)
        self.add_api_object('ServiceNetworkVpcAssociationId', self.ServiceNetworkVpcAssociationId)
        self.ServiceNetworkVpcAssociationIdentifier = APIObject('ServiceNetworkVpcAssociationIdentifier', 'string', r'^((snva-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:servicenetworkvpcassociation/snva-[0-9a-z]{17}))$', 17, 2048)
        self.add_api_object('ServiceNetworkVpcAssociationIdentifier', self.ServiceNetworkVpcAssociationIdentifier)
        self.TargetGroupArn = APIObject('TargetGroupArn', 'string', r'^arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:targetgroup/tg-[0-9a-z]{17}$', 20, 2048)
        self.add_api_object('TargetGroupArn', self.TargetGroupArn)
        self.TargetGroupId = APIObject('TargetGroupId', 'string', r'^tg-[0-9a-z]{17}$', 20, 20)
        self.add_api_object('TargetGroupId', self.TargetGroupId)
        self.TargetGroupIdentifier = APIObject('TargetGroupIdentifier', 'string', r'^((tg-[0-9a-z]{17})|(arn:[a-z0-9\-]+:vpc-lattice:[a-zA-Z0-9\-]+:\d{12}:targetgroup/tg-[0-9a-z]{17}))$', 17, 2048)
        self.add_api_object('TargetGroupIdentifier', self.TargetGroupIdentifier)
        self.TargetGroupName = APIObject('TargetGroupName', 'string', r'^(?!tg-)(?![-])(?!.*[-]$)(?!.*[-]{2})[a-z0-9-]+$', 3, 128)
        self.add_api_object('TargetGroupName', self.TargetGroupName)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-(([0-9a-z]{8})|([0-9a-z]{17}))$', 5, 50)
        self.add_api_object('VpcId', self.VpcId)

class WafRegional(Service):
    def __init__(self):
        super().__init__('WafRegional')
        self.ChangeToken = APIObject('ChangeToken', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ChangeToken', self.ChangeToken)
        self.IPSetDescriptorValue = APIObject('IPSetDescriptorValue', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('IPSetDescriptorValue', self.IPSetDescriptorValue)
        self.MatchFieldData = APIObject('MatchFieldData', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('MatchFieldData', self.MatchFieldData)
        self.MetricName = APIObject('MetricName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('MetricName', self.MetricName)
        self.NextMarker = APIObject('NextMarker', 'string', r'.*\S.*', 1, 1224)
        self.add_api_object('NextMarker', self.NextMarker)
        self.PolicyString = APIObject('PolicyString', 'string', r'.*\S.*', 1, 395000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.RegexPatternString = APIObject('RegexPatternString', 'string', r'.*', 1, 512)
        self.add_api_object('RegexPatternString', self.RegexPatternString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'.*\S.*', 1, 1224)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ResourceName', self.ResourceName)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^aws-waf-migration-[0-9A-Za-z\.\-_]*', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.TagKey = APIObject('TagKey', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Waf(Service):
    def __init__(self):
        super().__init__('Waf')
        self.ChangeToken = APIObject('ChangeToken', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ChangeToken', self.ChangeToken)
        self.IPSetDescriptorValue = APIObject('IPSetDescriptorValue', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('IPSetDescriptorValue', self.IPSetDescriptorValue)
        self.MatchFieldData = APIObject('MatchFieldData', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('MatchFieldData', self.MatchFieldData)
        self.MetricName = APIObject('MetricName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('MetricName', self.MetricName)
        self.NextMarker = APIObject('NextMarker', 'string', r'.*\S.*', 1, 1224)
        self.add_api_object('NextMarker', self.NextMarker)
        self.PolicyString = APIObject('PolicyString', 'string', r'.*\S.*', 1, 395000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.RegexPatternString = APIObject('RegexPatternString', 'string', r'.*', 1, 512)
        self.add_api_object('RegexPatternString', self.RegexPatternString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'.*\S.*', 1, 1224)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResourceId = APIObject('ResourceId', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ResourceName', self.ResourceName)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'^aws-waf-migration-[0-9A-Za-z\.\-_]*', 3, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.TagKey = APIObject('TagKey', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'.*', 0, 256)
        self.add_api_object('TagValue', self.TagValue)

class Wafv2(Service):
    def __init__(self):
        super().__init__('Wafv2')
        self.APIKey = APIObject('APIKey', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('APIKey', self.APIKey)
        self.CreationPathString = APIObject('CreationPathString', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('CreationPathString', self.CreationPathString)
        self.CustomHTTPHeaderName = APIObject('CustomHTTPHeaderName', 'string', r'^[a-zA-Z0-9._$-]+$', 1, 64)
        self.add_api_object('CustomHTTPHeaderName', self.CustomHTTPHeaderName)
        self.CustomHTTPHeaderValue = APIObject('CustomHTTPHeaderValue', 'string', r'.*', 1, 255)
        self.add_api_object('CustomHTTPHeaderValue', self.CustomHTTPHeaderValue)
        self.EntityDescription = APIObject('EntityDescription', 'string', r'^[\w+=:#@/\-,\.][\w+=:#@/\-,\.\s]+[\w+=:#@/\-,\.]$', 1, 256)
        self.add_api_object('EntityDescription', self.EntityDescription)
        self.EntityId = APIObject('EntityId', 'string', r'^[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}$', 1, 36)
        self.add_api_object('EntityId', self.EntityId)
        self.EntityName = APIObject('EntityName', 'string', r'^[\w\-]+$', 1, 128)
        self.add_api_object('EntityName', self.EntityName)
        self.FailureValue = APIObject('FailureValue', 'string', r'.*\S.*', 1, 100)
        self.add_api_object('FailureValue', self.FailureValue)
        self.FieldIdentifier = APIObject('FieldIdentifier', 'string', r'.*\S.*', 1, 512)
        self.add_api_object('FieldIdentifier', self.FieldIdentifier)
        self.FieldToMatchData = APIObject('FieldToMatchData', 'string', r'.*\S.*', 1, 64)
        self.add_api_object('FieldToMatchData', self.FieldToMatchData)
        self.ForwardedIPHeaderName = APIObject('ForwardedIPHeaderName', 'string', r'^[a-zA-Z0-9-]+$', 1, 255)
        self.add_api_object('ForwardedIPHeaderName', self.ForwardedIPHeaderName)
        self.IPAddress = APIObject('IPAddress', 'string', r'.*\S.*', 1, 50)
        self.add_api_object('IPAddress', self.IPAddress)
        self.JsonPointerPath = APIObject('JsonPointerPath', 'string', r'([/])|([/](([^~])|(~[01]))+)', 1, 512)
        self.add_api_object('JsonPointerPath', self.JsonPointerPath)
        self.LabelMatchKey = APIObject('LabelMatchKey', 'string', r'^[0-9A-Za-z_\-:]+$', 1, 1024)
        self.add_api_object('LabelMatchKey', self.LabelMatchKey)
        self.LabelName = APIObject('LabelName', 'string', r'^[0-9A-Za-z_\-:]+$', 1, 1024)
        self.add_api_object('LabelName', self.LabelName)
        self.LabelNamespace = APIObject('LabelNamespace', 'string', r'^[0-9A-Za-z_\-:]+:$', 1, 1024)
        self.add_api_object('LabelNamespace', self.LabelNamespace)
        self.LockToken = APIObject('LockToken', 'string', r'^[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}$', 1, 36)
        self.add_api_object('LockToken', self.LockToken)
        self.LoginPathString = APIObject('LoginPathString', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('LoginPathString', self.LoginPathString)
        self.MetricName = APIObject('MetricName', 'string', r'^[\w#:\.\-/]+$', 1, 255)
        self.add_api_object('MetricName', self.MetricName)
        self.NextMarker = APIObject('NextMarker', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('NextMarker', self.NextMarker)
        self.PolicyString = APIObject('PolicyString', 'string', r'.*\S.*', 1, 395000)
        self.add_api_object('PolicyString', self.PolicyString)
        self.ProductDescription = APIObject('ProductDescription', 'string', r'.*\S.*', 1, None)
        self.add_api_object('ProductDescription', self.ProductDescription)
        self.ProductId = APIObject('ProductId', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('ProductId', self.ProductId)
        self.ProductLink = APIObject('ProductLink', 'string', r'.*\S.*', 1, 2048)
        self.add_api_object('ProductLink', self.ProductLink)
        self.ProductTitle = APIObject('ProductTitle', 'string', r'.*\S.*', 1, None)
        self.add_api_object('ProductTitle', self.ProductTitle)
        self.RegexPatternString = APIObject('RegexPatternString', 'string', r'.*', 1, 512)
        self.add_api_object('RegexPatternString', self.RegexPatternString)
        self.RegistrationPagePathString = APIObject('RegistrationPagePathString', 'string', r'.*\S.*', 1, 256)
        self.add_api_object('RegistrationPagePathString', self.RegistrationPagePathString)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'.*\S.*', 20, 2048)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ResponseContent = APIObject('ResponseContent', 'string', r'[\s\S]*', 1, 10240)
        self.add_api_object('ResponseContent', self.ResponseContent)
        self.ResponseInspectionHeaderName = APIObject('ResponseInspectionHeaderName', 'string', r'.*\S.*', 1, 200)
        self.add_api_object('ResponseInspectionHeaderName', self.ResponseInspectionHeaderName)
        self.SingleCookieName = APIObject('SingleCookieName', 'string', r'.*\S.*', 1, 60)
        self.add_api_object('SingleCookieName', self.SingleCookieName)
        self.SuccessValue = APIObject('SuccessValue', 'string', r'.*\S.*', 1, 100)
        self.add_api_object('SuccessValue', self.SuccessValue)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.TokenDomain = APIObject('TokenDomain', 'string', r'^[\w\.\-/]+$', 1, 253)
        self.add_api_object('TokenDomain', self.TokenDomain)
        self.VendorName = APIObject('VendorName', 'string', r'.*\S.*', 1, 128)
        self.add_api_object('VendorName', self.VendorName)
        self.VersionKeyString = APIObject('VersionKeyString', 'string', r'^[\w#:\.\-/]+$', 1, 64)
        self.add_api_object('VersionKeyString', self.VersionKeyString)

class Wellarchitected(Service):
    def __init__(self):
        super().__init__('Wellarchitected')
        self.ApplicationArn = APIObject('ApplicationArn', 'string', r'arn:aws[-a-z]*:servicecatalog:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:/applications/[a-z0-9]+', None, 2084)
        self.add_api_object('ApplicationArn', self.ApplicationArn)
        self.AwsAccountId = APIObject('AwsAccountId', 'string', r'[0-9]{12}', 12, 12)
        self.add_api_object('AwsAccountId', self.AwsAccountId)
        self.JiraProjectKey = APIObject('JiraProjectKey', 'string', r'^[A-Z][A-Z0-9_]*$', 1, 100)
        self.add_api_object('JiraProjectKey', self.JiraProjectKey)
        self.ProfileArn = APIObject('ProfileArn', 'string', r'arn:aws[-a-z]*:wellarchitected:[a-z]{2}(-gov)?-[a-z]+-\d:\d{12}:profile/[a-z0-9]+', None, 2084)
        self.add_api_object('ProfileArn', self.ProfileArn)
        self.ProfileVersion = APIObject('ProfileVersion', 'string', r'^[A-Za-z0-9-]+$', 1, 32)
        self.add_api_object('ProfileVersion', self.ProfileVersion)
        self.ResourceArn = APIObject('ResourceArn', 'string', r'arn:aws(-us-gov|-iso(-[a-z])?|-cn)?:wellarchitected:[a-z]{2}(-gov|-iso([a-z])?)?-[a-z]+-\d:\d{12}:(review-template)/[a-f0-9]{32}', 50, 250)
        self.add_api_object('ResourceArn', self.ResourceArn)
        self.ShareId = APIObject('ShareId', 'string', r'[0-9a-f]{32}', None, None)
        self.add_api_object('ShareId', self.ShareId)
        self.ShareInvitationId = APIObject('ShareInvitationId', 'string', r'[0-9a-f]{32}', None, None)
        self.add_api_object('ShareInvitationId', self.ShareInvitationId)
        self.TemplateArn = APIObject('TemplateArn', 'string', r'arn:aws(-us-gov|-iso(-[a-z])?|-cn)?:wellarchitected:[a-z]{2}(-gov|-iso([a-z])?)?-[a-z]+-\d:\d{12}:(review-template)/[a-f0-9]{32}', 50, 250)
        self.add_api_object('TemplateArn', self.TemplateArn)
        self.TemplateDescription = APIObject('TemplateDescription', 'string', r'^[A-Za-z0-9-_.,:/()@!&?#+\'’\s]+$', 3, 250)
        self.add_api_object('TemplateDescription', self.TemplateDescription)
        self.TemplateName = APIObject('TemplateName', 'string', r'^[A-Za-z0-9-_.,:/()@!&?#+\'’\s]+$', 3, 100)
        self.add_api_object('TemplateName', self.TemplateName)
        self.TemplateNamePrefix = APIObject('TemplateNamePrefix', 'string', r'^[A-Za-z0-9-_.,:/()@!&?#+\'’\s]+$', None, 100)
        self.add_api_object('TemplateNamePrefix', self.TemplateNamePrefix)
        self.WorkloadArchitecturalDesign = APIObject('WorkloadArchitecturalDesign', 'string', r'^(|(https?|ftp):\/\/[^\s/$.?#].[^\s]*)$', None, 2048)
        self.add_api_object('WorkloadArchitecturalDesign', self.WorkloadArchitecturalDesign)
        self.WorkloadId = APIObject('WorkloadId', 'string', r'[0-9a-f]{32}', 32, 32)
        self.add_api_object('WorkloadId', self.WorkloadId)

class Wisdom(Service):
    def __init__(self):
        super().__init__('Wisdom')
        self.Arn = APIObject('Arn', 'string', r'^arn:[a-z-]*?:wisdom:[a-z0-9-]*?:[0-9]{12}:[a-z-]*?/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}(?:/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})?$', None, None)
        self.add_api_object('Arn', self.Arn)
        self.ContentType = APIObject('ContentType', 'string', r'^(text/(plain|html|csv))|(application/(pdf|vnd\.openxmlformats-officedocument\.wordprocessingml\.document))|(application/x\.wisdom-json;source=(salesforce|servicenow|zendesk))$', None, None)
        self.add_api_object('ContentType', self.ContentType)
        self.Description = APIObject('Description', 'string', r'^[a-zA-Z0-9\s_.,-]+', 1, 255)
        self.add_api_object('Description', self.Description)
        self.GenericArn = APIObject('GenericArn', 'string', r'^arn:[a-z-]+?:[a-z-]+?:[a-z0-9-]*?:([0-9]{12})?:[a-zA-Z0-9-:/]+$', 1, 2048)
        self.add_api_object('GenericArn', self.GenericArn)
        self.Name = APIObject('Name', 'string', r'^[a-zA-Z0-9\s_.,-]+', 1, 255)
        self.add_api_object('Name', self.Name)
        self.QuickResponseType = APIObject('QuickResponseType', 'string', r'^(application/x\.quickresponse;format=(plain|markdown))$', None, None)
        self.add_api_object('QuickResponseType', self.QuickResponseType)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.Uuid = APIObject('Uuid', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$', None, None)
        self.add_api_object('Uuid', self.Uuid)
        self.UuidOrArn = APIObject('UuidOrArn', 'string', r'^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$|^arn:[a-z-]*?:wisdom:[a-z0-9-]*?:[0-9]{12}:[a-z-]*?/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}(?:/[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12})?$', None, None)
        self.add_api_object('UuidOrArn', self.UuidOrArn)

class Workdocs(Service):
    def __init__(self):
        super().__init__('Workdocs')
        self.ActivityNamesFilterType = APIObject('ActivityNamesFilterType', 'string', r'[\w,]+', 1, 1024)
        self.add_api_object('ActivityNamesFilterType', self.ActivityNamesFilterType)
        self.CommentIdType = APIObject('CommentIdType', 'string', r'[\w+-.@]+', 1, 128)
        self.add_api_object('CommentIdType', self.CommentIdType)
        self.CustomMetadataKeyType = APIObject('CustomMetadataKeyType', 'string', r'[a-zA-Z0-9._+-/=][a-zA-Z0-9 ._+-/=]*', 1, 56)
        self.add_api_object('CustomMetadataKeyType', self.CustomMetadataKeyType)
        self.CustomMetadataValueType = APIObject('CustomMetadataValueType', 'string', r'[a-zA-Z0-9._+-/=][a-zA-Z0-9 ._+-/=]*', 1, 256)
        self.add_api_object('CustomMetadataValueType', self.CustomMetadataValueType)
        self.DocumentVersionIdType = APIObject('DocumentVersionIdType', 'string', r'[\w+-.@]+', 1, 128)
        self.add_api_object('DocumentVersionIdType', self.DocumentVersionIdType)
        self.EmailAddressType = APIObject('EmailAddressType', 'string', r'[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}', 1, 256)
        self.add_api_object('EmailAddressType', self.EmailAddressType)
        self.FieldNamesType = APIObject('FieldNamesType', 'string', r'[\w,]+', 1, 256)
        self.add_api_object('FieldNamesType', self.FieldNamesType)
        self.HashType = APIObject('HashType', 'string', r'[&\w+-.@]+', 0, 128)
        self.add_api_object('HashType', self.HashType)
        self.HeaderNameType = APIObject('HeaderNameType', 'string', r'[\w-]+', 1, 256)
        self.add_api_object('HeaderNameType', self.HeaderNameType)
        self.IdType = APIObject('IdType', 'string', r'[&\w+-.@]+', 1, 256)
        self.add_api_object('IdType', self.IdType)
        self.MarkerType = APIObject('MarkerType', 'string', r'[\u0000-\u00FF]+', 1, 2048)
        self.add_api_object('MarkerType', self.MarkerType)
        self.NextMarkerType = APIObject('NextMarkerType', 'string', r'[\d]+', 1, 2048)
        self.add_api_object('NextMarkerType', self.NextMarkerType)
        self.PasswordType = APIObject('PasswordType', 'string', r'[\u0020-\u00FF]+', 4, 32)
        self.add_api_object('PasswordType', self.PasswordType)
        self.ResourceIdType = APIObject('ResourceIdType', 'string', r'[\w+-.@]+', 1, 128)
        self.add_api_object('ResourceIdType', self.ResourceIdType)
        self.ResourceNameType = APIObject('ResourceNameType', 'string', r'[\u0020-\u202D\u202F-\uFFFF]+', 1, 255)
        self.add_api_object('ResourceNameType', self.ResourceNameType)
        self.ResponseItemWebUrl = APIObject('ResponseItemWebUrl', 'string', r'[\u0020-\uFFFF]+', 1, 512)
        self.add_api_object('ResponseItemWebUrl', self.ResponseItemWebUrl)
        self.SearchMarkerType = APIObject('SearchMarkerType', 'string', r'[\u0000-\u00FF]+', 1, 12288)
        self.add_api_object('SearchMarkerType', self.SearchMarkerType)
        self.SearchQueryType = APIObject('SearchQueryType', 'string', r'[\u0020-\uFFFF]+', 1, 512)
        self.add_api_object('SearchQueryType', self.SearchQueryType)
        self.SharedLabel = APIObject('SharedLabel', 'string', r'[a-zA-Z0-9._+-/=][a-zA-Z0-9 ._+-/=]*', 1, 32)
        self.add_api_object('SharedLabel', self.SharedLabel)
        self.UserIdsType = APIObject('UserIdsType', 'string', r'[&\w+-.@, ]+', 1, 2000)
        self.add_api_object('UserIdsType', self.UserIdsType)
        self.UsernameType = APIObject('UsernameType', 'string', r'[\w\-+.]+(@[a-zA-Z0-9.\-]+\.[a-zA-Z]+)?', 1, 256)
        self.add_api_object('UsernameType', self.UsernameType)

class Worklink(Service):
    def __init__(self):
        super().__init__('Worklink')
        self.AcmCertificateArn = APIObject('AcmCertificateArn', 'string', r'arn:[\w+=/,.@-]+:[\w+=/,.@-]+:[\w+=/,.@-]*:[0-9]+:[\w+=,.@-]+(/[\w+=/,.@-]+)*', None, None)
        self.add_api_object('AcmCertificateArn', self.AcmCertificateArn)
        self.AuditStreamArn = APIObject('AuditStreamArn', 'string', r'^arn:aws:kinesis:.+:[0-9]{12}:stream/AmazonWorkLink-.*$', None, None)
        self.add_api_object('AuditStreamArn', self.AuditStreamArn)
        self.Certificate = APIObject('Certificate', 'string', r'-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}(\u000D?\u000A)?', 1, 8192)
        self.add_api_object('Certificate', self.Certificate)
        self.CertificateChain = APIObject('CertificateChain', 'string', r'(-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}\u000D?\u000A)*-{5}BEGIN CERTIFICATE-{5}\u000D?\u000A([A-Za-z0-9/+]{64}\u000D?\u000A)*[A-Za-z0-9/+]{1,64}={0,2}\u000D?\u000A-{5}END CERTIFICATE-{5}(\u000D?\u000A)?', 1, 32768)
        self.add_api_object('CertificateChain', self.CertificateChain)
        self.DomainName = APIObject('DomainName', 'string', r'^[a-zA-Z0-9]?((?!-)([A-Za-z0-9-]*[A-Za-z0-9])\.)+[a-zA-Z0-9]+$', 1, 253)
        self.add_api_object('DomainName', self.DomainName)
        self.FleetName = APIObject('FleetName', 'string', r'^[a-z0-9](?:[a-z0-9\-]{0,46}[a-z0-9])?$', 1, 48)
        self.add_api_object('FleetName', self.FleetName)
        self.NextToken = APIObject('NextToken', 'string', r'[\w\-]+', 1, 4096)
        self.add_api_object('NextToken', self.NextToken)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^sg-([0-9a-f]{8}|[0-9a-f]{17})$', None, None)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-([0-9a-f]{8}|[0-9a-f]{17})$', None, None)
        self.add_api_object('SubnetId', self.SubnetId)
        self.TagKey = APIObject('TagKey', 'string', r'^(?!aws:)[a-zA-Z+-=._:/]+$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-([0-9a-f]{8}|[0-9a-f]{17})$', None, None)
        self.add_api_object('VpcId', self.VpcId)

class Workmail(Service):
    def __init__(self):
        super().__init__('Workmail')
        self.AccessControlRuleAction = APIObject('AccessControlRuleAction', 'string', r'[a-zA-Z]+', 1, 64)
        self.add_api_object('AccessControlRuleAction', self.AccessControlRuleAction)
        self.AccessControlRuleDescription = APIObject('AccessControlRuleDescription', 'string', r'[\u0020-\u00FF]+', 0, 255)
        self.add_api_object('AccessControlRuleDescription', self.AccessControlRuleDescription)
        self.AccessControlRuleName = APIObject('AccessControlRuleName', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('AccessControlRuleName', self.AccessControlRuleName)
        self.AmazonResourceName = APIObject('AmazonResourceName', 'string', r'arn:aws:workmail:[a-z0-9-]*:[a-z0-9-]+:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}', 1, 1011)
        self.add_api_object('AmazonResourceName', self.AmazonResourceName)
        self.Description = APIObject('Description', 'string', r'[\S\s]*', 0, 1023)
        self.add_api_object('Description', self.Description)
        self.DeviceId = APIObject('DeviceId', 'string', r'[A-Za-z0-9]+', 1, 32)
        self.add_api_object('DeviceId', self.DeviceId)
        self.DeviceModel = APIObject('DeviceModel', 'string', r'[\u0020-\u00FF]+', 1, 256)
        self.add_api_object('DeviceModel', self.DeviceModel)
        self.DeviceOperatingSystem = APIObject('DeviceOperatingSystem', 'string', r'[\u0020-\u00FF]+', 1, 256)
        self.add_api_object('DeviceOperatingSystem', self.DeviceOperatingSystem)
        self.DeviceType = APIObject('DeviceType', 'string', r'[\u0020-\u00FF]+', 1, 256)
        self.add_api_object('DeviceType', self.DeviceType)
        self.DeviceUserAgent = APIObject('DeviceUserAgent', 'string', r'[\u0020-\u00FF]+', 1, 256)
        self.add_api_object('DeviceUserAgent', self.DeviceUserAgent)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{10}$', 12, 12)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.DomainName = APIObject('DomainName', 'string', r'[a-zA-Z0-9.-]+', 3, 255)
        self.add_api_object('DomainName', self.DomainName)
        self.EmailAddress = APIObject('EmailAddress', 'string', r'[a-zA-Z0-9._%+-]{1,64}@[a-zA-Z0-9.-]+\.[a-zA-Z-]{2,}', 1, 254)
        self.add_api_object('EmailAddress', self.EmailAddress)
        self.EntityIdentifier = APIObject('EntityIdentifier', 'string', r'[a-zA-Z0-9._%+@-]+', 1, 256)
        self.add_api_object('EntityIdentifier', self.EntityIdentifier)
        self.ExternalUserName = APIObject('ExternalUserName', 'string', r'[\u0020-\u00FF]+', None, 256)
        self.add_api_object('ExternalUserName', self.ExternalUserName)
        self.GroupName = APIObject('GroupName', 'string', r'[\u0020-\u00FF]+', 1, 256)
        self.add_api_object('GroupName', self.GroupName)
        self.HostedZoneId = APIObject('HostedZoneId', 'string', r'[^/\\]*', 1, 32)
        self.add_api_object('HostedZoneId', self.HostedZoneId)
        self.IdempotencyClientToken = APIObject('IdempotencyClientToken', 'string', r'[\x21-\x7e]+', 1, 128)
        self.add_api_object('IdempotencyClientToken', self.IdempotencyClientToken)
        self.ImpersonationRoleDescription = APIObject('ImpersonationRoleDescription', 'string', r'[^\x00-\x09\x0B\x0C\x0E-\x1F\x7F\x3C\x3E\x5C]+', 1, 256)
        self.add_api_object('ImpersonationRoleDescription', self.ImpersonationRoleDescription)
        self.ImpersonationRoleId = APIObject('ImpersonationRoleId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('ImpersonationRoleId', self.ImpersonationRoleId)
        self.ImpersonationRoleName = APIObject('ImpersonationRoleName', 'string', r'[^\x00-\x1F\x7F\x3C\x3E\x5C]+', 1, 64)
        self.add_api_object('ImpersonationRoleName', self.ImpersonationRoleName)
        self.ImpersonationRuleDescription = APIObject('ImpersonationRuleDescription', 'string', r'[^\x00-\x09\x0B\x0C\x0E-\x1F\x7F\x3C\x3E\x5C]+', 1, 256)
        self.add_api_object('ImpersonationRuleDescription', self.ImpersonationRuleDescription)
        self.ImpersonationRuleId = APIObject('ImpersonationRuleId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('ImpersonationRuleId', self.ImpersonationRuleId)
        self.ImpersonationRuleName = APIObject('ImpersonationRuleName', 'string', r'[^\x00-\x1F\x7F\x3C\x3E\x5C]+', 1, 64)
        self.add_api_object('ImpersonationRuleName', self.ImpersonationRuleName)
        self.ImpersonationToken = APIObject('ImpersonationToken', 'string', r'[\x21-\x7e]+', 1, 256)
        self.add_api_object('ImpersonationToken', self.ImpersonationToken)
        self.IpAddress = APIObject('IpAddress', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$', 1, 15)
        self.add_api_object('IpAddress', self.IpAddress)
        self.IpRange = APIObject('IpRange', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])/([0-9]|[12][0-9]|3[0-2])$', 1, 18)
        self.add_api_object('IpRange', self.IpRange)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:aws:kms:[a-z0-9-]*:[a-z0-9-]+:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.LambdaArn = APIObject('LambdaArn', 'string', r'arn:aws:lambda:[a-z]{2}-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9\-_\.]+(:(\$LATEST|[a-zA-Z0-9\-_]+))?', 49, 256)
        self.add_api_object('LambdaArn', self.LambdaArn)
        self.LogGroupArn = APIObject('LogGroupArn', 'string', r'arn:aws:logs:[a-z\-0-9]*:[0-9]{12}:log-group:([\.\-_/#A-Za-z0-9]+):\*$', 47, 562)
        self.add_api_object('LogGroupArn', self.LogGroupArn)
        self.MailboxExportErrorInfo = APIObject('MailboxExportErrorInfo', 'string', r'[\S\s]*', 1, 1024)
        self.add_api_object('MailboxExportErrorInfo', self.MailboxExportErrorInfo)
        self.MailboxExportJobId = APIObject('MailboxExportJobId', 'string', r'[A-Za-z0-9-]+', 1, 63)
        self.add_api_object('MailboxExportJobId', self.MailboxExportJobId)
        self.MobileDeviceAccessRuleDescription = APIObject('MobileDeviceAccessRuleDescription', 'string', r'[\S\s]+', 1, 256)
        self.add_api_object('MobileDeviceAccessRuleDescription', self.MobileDeviceAccessRuleDescription)
        self.MobileDeviceAccessRuleId = APIObject('MobileDeviceAccessRuleId', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('MobileDeviceAccessRuleId', self.MobileDeviceAccessRuleId)
        self.MobileDeviceAccessRuleName = APIObject('MobileDeviceAccessRuleName', 'string', r'[\S\s]+', 1, 64)
        self.add_api_object('MobileDeviceAccessRuleName', self.MobileDeviceAccessRuleName)
        self.NextToken = APIObject('NextToken', 'string', r'[\S\s]*|[a-zA-Z0-9/+=]{1,1024}', 1, 1024)
        self.add_api_object('NextToken', self.NextToken)
        self.OrganizationId = APIObject('OrganizationId', 'string', r'^m-[0-9a-f]{32}$', 34, 34)
        self.add_api_object('OrganizationId', self.OrganizationId)
        self.OrganizationName = APIObject('OrganizationName', 'string', r'^(?!d-)([\da-zA-Z]+)([-][\da-zA-Z]+)*', 1, 62)
        self.add_api_object('OrganizationName', self.OrganizationName)
        self.Password = APIObject('Password', 'string', r'[\u0020-\u00FF]+', None, 256)
        self.add_api_object('Password', self.Password)
        self.PolicyDescription = APIObject('PolicyDescription', 'string', r'[\w\d\s\S\-!?=,.;:\'_]+', None, 256)
        self.add_api_object('PolicyDescription', self.PolicyDescription)
        self.ResourceId = APIObject('ResourceId', 'string', r'^r-[0-9a-f]{32}$', 34, 34)
        self.add_api_object('ResourceId', self.ResourceId)
        self.ResourceName = APIObject('ResourceName', 'string', r'[\w\-.]+(@[a-zA-Z0-9.\-]+\.[a-zA-Z0-9-]{2,})?', 1, 20)
        self.add_api_object('ResourceName', self.ResourceName)
        self.RoleArn = APIObject('RoleArn', 'string', r'arn:aws:iam:[a-z0-9-]*:[a-z0-9-]+:[A-Za-z0-9][A-Za-z0-9:_/+=,@.-]{0,1023}', 20, 2048)
        self.add_api_object('RoleArn', self.RoleArn)
        self.S3BucketName = APIObject('S3BucketName', 'string', r'[A-Za-z0-9.-]+', 1, 63)
        self.add_api_object('S3BucketName', self.S3BucketName)
        self.S3ObjectKey = APIObject('S3ObjectKey', 'string', r'[A-Za-z0-9!_.*\'()/-]+', 1, 1023)
        self.add_api_object('S3ObjectKey', self.S3ObjectKey)
        self.ShortString = APIObject('ShortString', 'string', r'[a-zA-Z0-9_-]+', 1, 64)
        self.add_api_object('ShortString', self.ShortString)
        self.Url = APIObject('Url', 'string', r'https?://[A-Za-z0-9.-]+(:[0-9]+)?/.*', None, 256)
        self.add_api_object('Url', self.Url)
        self.UserName = APIObject('UserName', 'string', r'[\w\-.]+(@[a-zA-Z0-9.\-]+\.[a-zA-Z0-9-]{2,})?', 1, 64)
        self.add_api_object('UserName', self.UserName)
        self.WorkMailDomainName = APIObject('WorkMailDomainName', 'string', r'[a-zA-Z0-9.-]+', 3, 209)
        self.add_api_object('WorkMailDomainName', self.WorkMailDomainName)

class Workmailmessageflow(Service):
    def __init__(self):
        super().__init__('Workmailmessageflow')
        self.messageIdType = APIObject('messageIdType', 'string', r'[a-z0-9\-]*', 1, 120)
        self.add_api_object('messageIdType', self.messageIdType)
        self.s3BucketIdType = APIObject('s3BucketIdType', 'string', r'^[a-z0-9][a-z0-9\-]*', 3, 63)
        self.add_api_object('s3BucketIdType', self.s3BucketIdType)
        self.s3KeyIdType = APIObject('s3KeyIdType', 'string', r'[a-zA-Z0-9\-/]*', 1, 1024)
        self.add_api_object('s3KeyIdType', self.s3KeyIdType)
        self.s3VersionType = APIObject('s3VersionType', 'string', r'.+', 1, 1024)
        self.add_api_object('s3VersionType', self.s3VersionType)

class WorkspacesThinClient(Service):
    def __init__(self):
        super().__init__('WorkspacesThinClient')
        self.ActivationCode = APIObject('ActivationCode', 'string', r'[a-z]{2}[a-z0-9]{6}', None, None)
        self.add_api_object('ActivationCode', self.ActivationCode)
        self.Arn = APIObject('Arn', 'string', r'arn:[\w+=\/,.@-]+:[a-zA-Z0-9\-]+:[a-zA-Z0-9\-]*:[0-9]{0,12}:[a-zA-Z0-9\-\/\._]+', 20, 2048)
        self.add_api_object('Arn', self.Arn)
        self.DesktopEndpoint = APIObject('DesktopEndpoint', 'string', r'(https:\/\/)[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,32}(:[0-9]{1,5})?(\/.*)?', 1, 1024)
        self.add_api_object('DesktopEndpoint', self.DesktopEndpoint)
        self.DeviceId = APIObject('DeviceId', 'string', r'[a-zA-Z0-9]{24}', None, None)
        self.add_api_object('DeviceId', self.DeviceId)
        self.DeviceName = APIObject('DeviceName', 'string', r'[0-9\p{IsAlphabetic}+:,.@\'" -]{1,64}', None, None)
        self.add_api_object('DeviceName', self.DeviceName)
        self.EnvironmentId = APIObject('EnvironmentId', 'string', r'[a-z0-9]{9}', None, None)
        self.add_api_object('EnvironmentId', self.EnvironmentId)
        self.EnvironmentName = APIObject('EnvironmentName', 'string', r'[0-9\p{IsAlphabetic}+:,.@\'" -][0-9\p{IsAlphabetic}+=:,.@\'" -]{0,63}', None, None)
        self.add_api_object('EnvironmentName', self.EnvironmentName)
        self.KmsKeyArn = APIObject('KmsKeyArn', 'string', r'arn:[\w+=\/,.@-]+:kms:[a-zA-Z0-9\-]*:[0-9]{0,12}:key\/[a-zA-Z0-9-]+', 20, 2048)
        self.add_api_object('KmsKeyArn', self.KmsKeyArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'\S*', 0, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.SoftwareSetId = APIObject('SoftwareSetId', 'string', r'[0-9]{1,9}', None, None)
        self.add_api_object('SoftwareSetId', self.SoftwareSetId)
        self.SoftwareSetIdOrEmptyString = APIObject('SoftwareSetIdOrEmptyString', 'string', r'[0-9]{0,9}', None, None)
        self.add_api_object('SoftwareSetIdOrEmptyString', self.SoftwareSetIdOrEmptyString)

class WorkspacesWeb(Service):
    def __init__(self):
        super().__init__('WorkspacesWeb')
        self.ARN = APIObject('ARN', 'string', r'^arn:[\w+=\/,.@-]+:[a-zA-Z0-9\-]+:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:[a-zA-Z]+(\/[a-fA-F0-9\-]{36})+$', 20, 2048)
        self.add_api_object('ARN', self.ARN)
        self.BrowserPolicy = APIObject('BrowserPolicy', 'string', r'\{[\S\s]*\}\s*', 2, 131072)
        self.add_api_object('BrowserPolicy', self.BrowserPolicy)
        self.CertificatePrincipal = APIObject('CertificatePrincipal', 'string', r'^\S+$', 1, 256)
        self.add_api_object('CertificatePrincipal', self.CertificatePrincipal)
        self.CertificateThumbprint = APIObject('CertificateThumbprint', 'string', r'^[A-Fa-f0-9]{64}$', 64, 64)
        self.add_api_object('CertificateThumbprint', self.CertificateThumbprint)
        self.CookieDomain = APIObject('CookieDomain', 'string', r'^(\.?)(?:[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?\.)*[a-z0-9][a-z0-9-]{0,61}[a-z0-9]$', 0, 253)
        self.add_api_object('CookieDomain', self.CookieDomain)
        self.CookiePath = APIObject('CookiePath', 'string', r'^/(\S)*$', 0, 2000)
        self.add_api_object('CookiePath', self.CookiePath)
        self.Description = APIObject('Description', 'string', r'^.+$', 1, 256)
        self.add_api_object('Description', self.Description)
        self.DisplayName = APIObject('DisplayName', 'string', r'^.+$', 1, 64)
        self.add_api_object('DisplayName', self.DisplayName)
        self.IdentityProviderName = APIObject('IdentityProviderName', 'string', r'^[^_][\p{L}\p{M}\p{S}\p{N}\p{P}][^_]+$', 1, 32)
        self.add_api_object('IdentityProviderName', self.IdentityProviderName)
        self.IpRange = APIObject('IpRange', 'string', r'^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}(?:/([0-9]|[12][0-9]|3[0-2])|)$', None, None)
        self.add_api_object('IpRange', self.IpRange)
        self.KinesisStreamArn = APIObject('KinesisStreamArn', 'string', r'arn:[\w+=/,.@-]+:kinesis:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:stream/.+', 20, 2048)
        self.add_api_object('KinesisStreamArn', self.KinesisStreamArn)
        self.PaginationToken = APIObject('PaginationToken', 'string', r'^\S+$', 1, 2048)
        self.add_api_object('PaginationToken', self.PaginationToken)
        self.PortalEndpoint = APIObject('PortalEndpoint', 'string', r'^[a-zA-Z0-9]?((?!-)([A-Za-z0-9-]*[A-Za-z0-9])\.)+[a-zA-Z0-9]+$', 1, 253)
        self.add_api_object('PortalEndpoint', self.PortalEndpoint)
        self.SamlMetadata = APIObject('SamlMetadata', 'string', r'^.+$', 1, 204800)
        self.add_api_object('SamlMetadata', self.SamlMetadata)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^[\w+\-]+$', 1, 128)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.StatusReason = APIObject('StatusReason', 'string', r'.*', 1, 1024)
        self.add_api_object('StatusReason', self.StatusReason)
        self.StringType = APIObject('StringType', 'string', r'^[\s\S]*$', 0, 131072)
        self.add_api_object('StringType', self.StringType)
        self.SubnetId = APIObject('SubnetId', 'string', r'^subnet-([0-9a-f]{8}|[0-9a-f]{17})$', 1, 32)
        self.add_api_object('SubnetId', self.SubnetId)
        self.SubresourceARN = APIObject('SubresourceARN', 'string', r'^arn:[\w+=\/,.@-]+:[a-zA-Z0-9\-]+:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:[a-zA-Z]+(\/[a-fA-F0-9\-]{36}){2,}$', 20, 2048)
        self.add_api_object('SubresourceARN', self.SubresourceARN)
        self.TagKey = APIObject('TagKey', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 1, 128)
        self.add_api_object('TagKey', self.TagKey)
        self.TagValue = APIObject('TagValue', 'string', r'^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$', 0, 256)
        self.add_api_object('TagValue', self.TagValue)
        self.VpcId = APIObject('VpcId', 'string', r'^vpc-[0-9a-z]*$', 1, 255)
        self.add_api_object('VpcId', self.VpcId)
        self.keyArn = APIObject('keyArn', 'string', r'^arn:[\w+=\/,.@-]+:kms:[a-zA-Z0-9\-]*:[a-zA-Z0-9]{1,12}:key\/[a-zA-Z0-9-]+$', 20, 2048)
        self.add_api_object('keyArn', self.keyArn)

class Workspaces(Service):
    def __init__(self):
        super().__init__('Workspaces')
        self.ARN = APIObject('ARN', 'string', r'^arn:aws:[A-Za-z0-9][A-za-z0-9_/.-]{0,62}:[A-za-z0-9_/.-]{0,63}:[A-za-z0-9_/.-]{0,63}:[A-Za-z0-9][A-za-z0-9_/.-]{0,127}$', None, None)
        self.add_api_object('ARN', self.ARN)
        self.AddInName = APIObject('AddInName', 'string', r'^.*$', 1, 64)
        self.add_api_object('AddInName', self.AddInName)
        self.AddInUrl = APIObject('AddInUrl', 'string', r'^(http|https)\://\S+', 1, 1024)
        self.add_api_object('AddInUrl', self.AddInUrl)
        self.AmazonUuid = APIObject('AmazonUuid', 'string', r'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}', 36, 36)
        self.add_api_object('AmazonUuid', self.AmazonUuid)
        self.AwsAccount = APIObject('AwsAccount', 'string', r'^\d{12}$', None, None)
        self.add_api_object('AwsAccount', self.AwsAccount)
        self.BundleId = APIObject('BundleId', 'string', r'^wsb-[0-9a-z]{8,63}$', None, None)
        self.add_api_object('BundleId', self.BundleId)
        self.CertificateAuthorityArn = APIObject('CertificateAuthorityArn', 'string', r'arn:[\w+=/,.@-]+:[\w+=/,.@-]+:[\w+=/,.@-]*:[0-9]*:[\w+=,.@-]+(/[\w+=,.@-]+)*', 5, 200)
        self.add_api_object('CertificateAuthorityArn', self.CertificateAuthorityArn)
        self.ClientEmail = APIObject('ClientEmail', 'string', r'^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}$', 6, 64)
        self.add_api_object('ClientEmail', self.ClientEmail)
        self.ClientLocale = APIObject('ClientLocale', 'string', r'^[a-z]{2}_[A-Z]{2}$', 5, 5)
        self.add_api_object('ClientLocale', self.ClientLocale)
        self.ClientLoginMessage = APIObject('ClientLoginMessage', 'string', r'^.*$', 0, 2000)
        self.add_api_object('ClientLoginMessage', self.ClientLoginMessage)
        self.ClientToken = APIObject('ClientToken', 'string', r'^.{1,64}$', None, None)
        self.add_api_object('ClientToken', self.ClientToken)
        self.ClientUrl = APIObject('ClientUrl', 'string', r'^(http|https)\://\S+', 1, 200)
        self.add_api_object('ClientUrl', self.ClientUrl)
        self.ConnectionAliasId = APIObject('ConnectionAliasId', 'string', r'^wsca-[0-9a-z]{8,63}$', 13, 68)
        self.add_api_object('ConnectionAliasId', self.ConnectionAliasId)
        self.ConnectionIdentifier = APIObject('ConnectionIdentifier', 'string', r'^[a-zA-Z0-9]+$', 1, 20)
        self.add_api_object('ConnectionIdentifier', self.ConnectionIdentifier)
        self.ConnectionString = APIObject('ConnectionString', 'string', r'^[.0-9a-zA-Z\-]{1,255}$', 1, 255)
        self.add_api_object('ConnectionString', self.ConnectionString)
        self.DedicatedTenancyManagementCidrRange = APIObject('DedicatedTenancyManagementCidrRange', 'string', r'(^([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.0\.0)(\/(16$))$', None, None)
        self.add_api_object('DedicatedTenancyManagementCidrRange', self.DedicatedTenancyManagementCidrRange)
        self.DirectoryId = APIObject('DirectoryId', 'string', r'^d-[0-9a-f]{8,63}$', 10, 65)
        self.add_api_object('DirectoryId', self.DirectoryId)
        self.Ec2ImageId = APIObject('Ec2ImageId', 'string', r'^ami\-([a-f0-9]{8}|[a-f0-9]{17})$', None, None)
        self.add_api_object('Ec2ImageId', self.Ec2ImageId)
        self.IpGroupId = APIObject('IpGroupId', 'string', r'wsipg-[0-9a-z]{8,63}$', None, None)
        self.add_api_object('IpGroupId', self.IpGroupId)
        self.LinkId = APIObject('LinkId', 'string', r'^link-.{8,24}$', None, None)
        self.add_api_object('LinkId', self.LinkId)
        self.ManagementCidrRangeConstraint = APIObject('ManagementCidrRangeConstraint', 'string', r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(\/(3[0-2]|[1-2][0-9]|[0-9]))$', None, None)
        self.add_api_object('ManagementCidrRangeConstraint', self.ManagementCidrRangeConstraint)
        self.Region = APIObject('Region', 'string', r'^[-0-9a-z]{1,31}$', 1, 31)
        self.add_api_object('Region', self.Region)
        self.SamlUserAccessUrl = APIObject('SamlUserAccessUrl', 'string', r'^(http|https)\://\S+$', 8, 200)
        self.add_api_object('SamlUserAccessUrl', self.SamlUserAccessUrl)
        self.SecurityGroupId = APIObject('SecurityGroupId', 'string', r'^(sg-([0-9a-f]{8}|[0-9a-f]{17}))$', 11, 20)
        self.add_api_object('SecurityGroupId', self.SecurityGroupId)
        self.SubnetId = APIObject('SubnetId', 'string', r'^(subnet-([0-9a-f]{8}|[0-9a-f]{17}))$', 15, 24)
        self.add_api_object('SubnetId', self.SubnetId)
        self.UpdateDescription = APIObject('UpdateDescription', 'string', r'^[a-zA-Z0-9_./() -]+$', 1, 255)
        self.add_api_object('UpdateDescription', self.UpdateDescription)
        self.WorkSpaceApplicationId = APIObject('WorkSpaceApplicationId', 'string', r'^wsa-[0-9a-z]{8,63}$', None, None)
        self.add_api_object('WorkSpaceApplicationId', self.WorkSpaceApplicationId)
        self.WorkSpaceApplicationOwner = APIObject('WorkSpaceApplicationOwner', 'string', r'^\d{12}|AMAZON$', None, None)
        self.add_api_object('WorkSpaceApplicationOwner', self.WorkSpaceApplicationOwner)
        self.WorkspaceBundleDescription = APIObject('WorkspaceBundleDescription', 'string', r'^[a-zA-Z0-9_./() -]+$', 1, 255)
        self.add_api_object('WorkspaceBundleDescription', self.WorkspaceBundleDescription)
        self.WorkspaceBundleName = APIObject('WorkspaceBundleName', 'string', r'^[a-zA-Z0-9_./()\\-]+$', 1, 64)
        self.add_api_object('WorkspaceBundleName', self.WorkspaceBundleName)
        self.WorkspaceId = APIObject('WorkspaceId', 'string', r'^ws-[0-9a-z]{8,63}$', None, None)
        self.add_api_object('WorkspaceId', self.WorkspaceId)
        self.WorkspaceImageDescription = APIObject('WorkspaceImageDescription', 'string', r'^[a-zA-Z0-9_./() -]+$', 1, 256)
        self.add_api_object('WorkspaceImageDescription', self.WorkspaceImageDescription)
        self.WorkspaceImageId = APIObject('WorkspaceImageId', 'string', r'wsi-[0-9a-z]{9,63}$', None, None)
        self.add_api_object('WorkspaceImageId', self.WorkspaceImageId)
        self.WorkspaceImageName = APIObject('WorkspaceImageName', 'string', r'^[a-zA-Z0-9_./()\\-]+$', 1, 64)
        self.add_api_object('WorkspaceImageName', self.WorkspaceImageName)
        self.WorkspaceName = APIObject('WorkspaceName', 'string', r'^[a-zA-Z0-9_()][a-zA-Z0-9_.()-]{1,63}$', None, None)
        self.add_api_object('WorkspaceName', self.WorkspaceName)

class Xray(Service):
    def __init__(self):
        super().__init__('Xray')
        self.InsightId = APIObject('InsightId', 'string', r'[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}', None, None)
        self.add_api_object('InsightId', self.InsightId)
        self.PolicyName = APIObject('PolicyName', 'string', r'[\w+=,.@-]+', 1, 128)
        self.add_api_object('PolicyName', self.PolicyName)

class_registry = APIRegistry()
accessanalyzer = Accessanalyzer()
class_registry.add_service(accessanalyzer)
account = Account()
class_registry.add_service(account)
acmpca = AcmPca()
class_registry.add_service(acmpca)
acm = Acm()
class_registry.add_service(acm)
alexaforbusiness = Alexaforbusiness()
class_registry.add_service(alexaforbusiness)
amp = Amp()
class_registry.add_service(amp)
amplify = Amplify()
class_registry.add_service(amplify)
amplifybackend = Amplifybackend()
class_registry.add_service(amplifybackend)
amplifyuibuilder = Amplifyuibuilder()
class_registry.add_service(amplifyuibuilder)
apigateway = Apigateway()
class_registry.add_service(apigateway)
apigatewaymanagementapi = Apigatewaymanagementapi()
class_registry.add_service(apigatewaymanagementapi)
apigatewayv2 = Apigatewayv2()
class_registry.add_service(apigatewayv2)
appconfig = Appconfig()
class_registry.add_service(appconfig)
appconfigdata = Appconfigdata()
class_registry.add_service(appconfigdata)
appfabric = Appfabric()
class_registry.add_service(appfabric)
appflow = Appflow()
class_registry.add_service(appflow)
appintegrations = Appintegrations()
class_registry.add_service(appintegrations)
applicationautoscaling = ApplicationAutoscaling()
class_registry.add_service(applicationautoscaling)
applicationinsights = ApplicationInsights()
class_registry.add_service(applicationinsights)
applicationcostprofiler = Applicationcostprofiler()
class_registry.add_service(applicationcostprofiler)
appmesh = Appmesh()
class_registry.add_service(appmesh)
apprunner = Apprunner()
class_registry.add_service(apprunner)
appstream = Appstream()
class_registry.add_service(appstream)
appsync = Appsync()
class_registry.add_service(appsync)
arczonalshift = ArcZonalShift()
class_registry.add_service(arczonalshift)
artifact = Artifact()
class_registry.add_service(artifact)
athena = Athena()
class_registry.add_service(athena)
auditmanager = Auditmanager()
class_registry.add_service(auditmanager)
autoscalingplans = AutoscalingPlans()
class_registry.add_service(autoscalingplans)
autoscaling = Autoscaling()
class_registry.add_service(autoscaling)
b2bi = B2bi()
class_registry.add_service(b2bi)
backupgateway = BackupGateway()
class_registry.add_service(backupgateway)
backup = Backup()
class_registry.add_service(backup)
backupstorage = Backupstorage()
class_registry.add_service(backupstorage)
batch = Batch()
class_registry.add_service(batch)
bcmdataexports = BcmDataExports()
class_registry.add_service(bcmdataexports)
bedrockagentruntime = BedrockAgentRuntime()
class_registry.add_service(bedrockagentruntime)
bedrockagent = BedrockAgent()
class_registry.add_service(bedrockagent)
bedrockruntime = BedrockRuntime()
class_registry.add_service(bedrockruntime)
bedrock = Bedrock()
class_registry.add_service(bedrock)
billingconductor = Billingconductor()
class_registry.add_service(billingconductor)
braket = Braket()
class_registry.add_service(braket)
budgets = Budgets()
class_registry.add_service(budgets)
ce = Ce()
class_registry.add_service(ce)
chatbot = Chatbot()
class_registry.add_service(chatbot)
chimesdkidentity = ChimeSdkIdentity()
class_registry.add_service(chimesdkidentity)
chimesdkmediapipelines = ChimeSdkMediaPipelines()
class_registry.add_service(chimesdkmediapipelines)
chimesdkmeetings = ChimeSdkMeetings()
class_registry.add_service(chimesdkmeetings)
chimesdkmessaging = ChimeSdkMessaging()
class_registry.add_service(chimesdkmessaging)
chimesdkvoice = ChimeSdkVoice()
class_registry.add_service(chimesdkvoice)
chime = Chime()
class_registry.add_service(chime)
cleanrooms = Cleanrooms()
class_registry.add_service(cleanrooms)
cleanroomsml = Cleanroomsml()
class_registry.add_service(cleanroomsml)
cloud9 = Cloud9()
class_registry.add_service(cloud9)
cloudcontrol = Cloudcontrol()
class_registry.add_service(cloudcontrol)
clouddirectory = Clouddirectory()
class_registry.add_service(clouddirectory)
cloudformation = Cloudformation()
class_registry.add_service(cloudformation)
cloudfrontkeyvaluestore = CloudfrontKeyvaluestore()
class_registry.add_service(cloudfrontkeyvaluestore)
cloudfront = Cloudfront()
class_registry.add_service(cloudfront)
cloudhsm = Cloudhsm()
class_registry.add_service(cloudhsm)
cloudhsmv2 = Cloudhsmv2()
class_registry.add_service(cloudhsmv2)
cloudsearch = Cloudsearch()
class_registry.add_service(cloudsearch)
cloudsearchdomain = Cloudsearchdomain()
class_registry.add_service(cloudsearchdomain)
cloudtraildata = CloudtrailData()
class_registry.add_service(cloudtraildata)
cloudtrail = Cloudtrail()
class_registry.add_service(cloudtrail)
cloudwatch = Cloudwatch()
class_registry.add_service(cloudwatch)
codeartifact = Codeartifact()
class_registry.add_service(codeartifact)
codebuild = Codebuild()
class_registry.add_service(codebuild)
codecatalyst = Codecatalyst()
class_registry.add_service(codecatalyst)
codecommit = Codecommit()
class_registry.add_service(codecommit)
codeconnections = Codeconnections()
class_registry.add_service(codeconnections)
codedeploy = Codedeploy()
class_registry.add_service(codedeploy)
codegurureviewer = CodeguruReviewer()
class_registry.add_service(codegurureviewer)
codegurusecurity = CodeguruSecurity()
class_registry.add_service(codegurusecurity)
codeguruprofiler = Codeguruprofiler()
class_registry.add_service(codeguruprofiler)
codepipeline = Codepipeline()
class_registry.add_service(codepipeline)
codestarconnections = CodestarConnections()
class_registry.add_service(codestarconnections)
codestarnotifications = CodestarNotifications()
class_registry.add_service(codestarnotifications)
codestar = Codestar()
class_registry.add_service(codestar)
cognitoidentity = CognitoIdentity()
class_registry.add_service(cognitoidentity)
cognitoidp = CognitoIdp()
class_registry.add_service(cognitoidp)
cognitosync = CognitoSync()
class_registry.add_service(cognitosync)
comprehend = Comprehend()
class_registry.add_service(comprehend)
comprehendmedical = Comprehendmedical()
class_registry.add_service(comprehendmedical)
computeoptimizer = ComputeOptimizer()
class_registry.add_service(computeoptimizer)
config = Config()
class_registry.add_service(config)
connectcontactlens = ConnectContactLens()
class_registry.add_service(connectcontactlens)
connect = Connect()
class_registry.add_service(connect)
connectcampaigns = Connectcampaigns()
class_registry.add_service(connectcampaigns)
connectcases = Connectcases()
class_registry.add_service(connectcases)
connectparticipant = Connectparticipant()
class_registry.add_service(connectparticipant)
controlcatalog = Controlcatalog()
class_registry.add_service(controlcatalog)
controltower = Controltower()
class_registry.add_service(controltower)
costoptimizationhub = CostOptimizationHub()
class_registry.add_service(costoptimizationhub)
cur = Cur()
class_registry.add_service(cur)
customerprofiles = CustomerProfiles()
class_registry.add_service(customerprofiles)
databrew = Databrew()
class_registry.add_service(databrew)
dataexchange = Dataexchange()
class_registry.add_service(dataexchange)
datapipeline = Datapipeline()
class_registry.add_service(datapipeline)
datasync = Datasync()
class_registry.add_service(datasync)
datazone = Datazone()
class_registry.add_service(datazone)
dax = Dax()
class_registry.add_service(dax)
deadline = Deadline()
class_registry.add_service(deadline)
detective = Detective()
class_registry.add_service(detective)
devicefarm = Devicefarm()
class_registry.add_service(devicefarm)
devopsguru = DevopsGuru()
class_registry.add_service(devopsguru)
directconnect = Directconnect()
class_registry.add_service(directconnect)
discovery = Discovery()
class_registry.add_service(discovery)
dlm = Dlm()
class_registry.add_service(dlm)
dms = Dms()
class_registry.add_service(dms)
docdbelastic = DocdbElastic()
class_registry.add_service(docdbelastic)
docdb = Docdb()
class_registry.add_service(docdb)
drs = Drs()
class_registry.add_service(drs)
ds = Ds()
class_registry.add_service(ds)
dynamodb = Dynamodb()
class_registry.add_service(dynamodb)
dynamodbstreams = Dynamodbstreams()
class_registry.add_service(dynamodbstreams)
ebs = Ebs()
class_registry.add_service(ebs)
ec2instanceconnect = Ec2InstanceConnect()
class_registry.add_service(ec2instanceconnect)
ec2 = Ec2()
class_registry.add_service(ec2)
ecrpublic = EcrPublic()
class_registry.add_service(ecrpublic)
ecr = Ecr()
class_registry.add_service(ecr)
ecs = Ecs()
class_registry.add_service(ecs)
efs = Efs()
class_registry.add_service(efs)
eksauth = EksAuth()
class_registry.add_service(eksauth)
eks = Eks()
class_registry.add_service(eks)
elasticinference = ElasticInference()
class_registry.add_service(elasticinference)
elasticache = Elasticache()
class_registry.add_service(elasticache)
elasticbeanstalk = Elasticbeanstalk()
class_registry.add_service(elasticbeanstalk)
elastictranscoder = Elastictranscoder()
class_registry.add_service(elastictranscoder)
elb = Elb()
class_registry.add_service(elb)
elbv2 = Elbv2()
class_registry.add_service(elbv2)
emrcontainers = EmrContainers()
class_registry.add_service(emrcontainers)
emrserverless = EmrServerless()
class_registry.add_service(emrserverless)
emr = Emr()
class_registry.add_service(emr)
entityresolution = Entityresolution()
class_registry.add_service(entityresolution)
es = Es()
class_registry.add_service(es)
events = Events()
class_registry.add_service(events)
evidently = Evidently()
class_registry.add_service(evidently)
finspacedata = FinspaceData()
class_registry.add_service(finspacedata)
finspace = Finspace()
class_registry.add_service(finspace)
firehose = Firehose()
class_registry.add_service(firehose)
fis = Fis()
class_registry.add_service(fis)
fms = Fms()
class_registry.add_service(fms)
forecast = Forecast()
class_registry.add_service(forecast)
forecastquery = Forecastquery()
class_registry.add_service(forecastquery)
frauddetector = Frauddetector()
class_registry.add_service(frauddetector)
freetier = Freetier()
class_registry.add_service(freetier)
fsx = Fsx()
class_registry.add_service(fsx)
gamelift = Gamelift()
class_registry.add_service(gamelift)
glacier = Glacier()
class_registry.add_service(glacier)
globalaccelerator = Globalaccelerator()
class_registry.add_service(globalaccelerator)
glue = Glue()
class_registry.add_service(glue)
grafana = Grafana()
class_registry.add_service(grafana)
greengrass = Greengrass()
class_registry.add_service(greengrass)
greengrassv2 = Greengrassv2()
class_registry.add_service(greengrassv2)
groundstation = Groundstation()
class_registry.add_service(groundstation)
guardduty = Guardduty()
class_registry.add_service(guardduty)
health = Health()
class_registry.add_service(health)
healthlake = Healthlake()
class_registry.add_service(healthlake)
honeycode = Honeycode()
class_registry.add_service(honeycode)
iam = Iam()
class_registry.add_service(iam)
identitystore = Identitystore()
class_registry.add_service(identitystore)
imagebuilder = Imagebuilder()
class_registry.add_service(imagebuilder)
importexport = Importexport()
class_registry.add_service(importexport)
inspectorscan = InspectorScan()
class_registry.add_service(inspectorscan)
inspector = Inspector()
class_registry.add_service(inspector)
inspector2 = Inspector2()
class_registry.add_service(inspector2)
internetmonitor = Internetmonitor()
class_registry.add_service(internetmonitor)
iotdata = IotData()
class_registry.add_service(iotdata)
iotjobsdata = IotJobsData()
class_registry.add_service(iotjobsdata)
iot = Iot()
class_registry.add_service(iot)
iot1clickdevices = Iot1clickDevices()
class_registry.add_service(iot1clickdevices)
iot1clickprojects = Iot1clickProjects()
class_registry.add_service(iot1clickprojects)
iotanalytics = Iotanalytics()
class_registry.add_service(iotanalytics)
iotdeviceadvisor = Iotdeviceadvisor()
class_registry.add_service(iotdeviceadvisor)
ioteventsdata = IoteventsData()
class_registry.add_service(ioteventsdata)
iotevents = Iotevents()
class_registry.add_service(iotevents)
iotfleethub = Iotfleethub()
class_registry.add_service(iotfleethub)
iotfleetwise = Iotfleetwise()
class_registry.add_service(iotfleetwise)
iotsecuretunneling = Iotsecuretunneling()
class_registry.add_service(iotsecuretunneling)
iotsitewise = Iotsitewise()
class_registry.add_service(iotsitewise)
iotthingsgraph = Iotthingsgraph()
class_registry.add_service(iotthingsgraph)
iottwinmaker = Iottwinmaker()
class_registry.add_service(iottwinmaker)
iotwireless = Iotwireless()
class_registry.add_service(iotwireless)
ivsrealtime = IvsRealtime()
class_registry.add_service(ivsrealtime)
ivs = Ivs()
class_registry.add_service(ivs)
ivschat = Ivschat()
class_registry.add_service(ivschat)
kafka = Kafka()
class_registry.add_service(kafka)
kafkaconnect = Kafkaconnect()
class_registry.add_service(kafkaconnect)
kendraranking = KendraRanking()
class_registry.add_service(kendraranking)
kendra = Kendra()
class_registry.add_service(kendra)
keyspaces = Keyspaces()
class_registry.add_service(keyspaces)
kinesisvideoarchivedmedia = KinesisVideoArchivedMedia()
class_registry.add_service(kinesisvideoarchivedmedia)
kinesisvideomedia = KinesisVideoMedia()
class_registry.add_service(kinesisvideomedia)
kinesisvideosignaling = KinesisVideoSignaling()
class_registry.add_service(kinesisvideosignaling)
kinesisvideowebrtcstorage = KinesisVideoWebrtcStorage()
class_registry.add_service(kinesisvideowebrtcstorage)
kinesis = Kinesis()
class_registry.add_service(kinesis)
kinesisanalytics = Kinesisanalytics()
class_registry.add_service(kinesisanalytics)
kinesisanalyticsv2 = Kinesisanalyticsv2()
class_registry.add_service(kinesisanalyticsv2)
kinesisvideo = Kinesisvideo()
class_registry.add_service(kinesisvideo)
kms = Kms()
class_registry.add_service(kms)
lakeformation = Lakeformation()
class_registry.add_service(lakeformation)
lambda_ = Lambda_()
class_registry.add_service(lambda_)
launchwizard = LaunchWizard()
class_registry.add_service(launchwizard)
lexmodels = LexModels()
class_registry.add_service(lexmodels)
lexruntime = LexRuntime()
class_registry.add_service(lexruntime)
lexv2models = Lexv2Models()
class_registry.add_service(lexv2models)
lexv2runtime = Lexv2Runtime()
class_registry.add_service(lexv2runtime)
licensemanagerlinuxsubscriptions = LicenseManagerLinuxSubscriptions()
class_registry.add_service(licensemanagerlinuxsubscriptions)
licensemanagerusersubscriptions = LicenseManagerUserSubscriptions()
class_registry.add_service(licensemanagerusersubscriptions)
licensemanager = LicenseManager()
class_registry.add_service(licensemanager)
lightsail = Lightsail()
class_registry.add_service(lightsail)
location = Location()
class_registry.add_service(location)
logs = Logs()
class_registry.add_service(logs)
lookoutequipment = Lookoutequipment()
class_registry.add_service(lookoutequipment)
lookoutmetrics = Lookoutmetrics()
class_registry.add_service(lookoutmetrics)
lookoutvision = Lookoutvision()
class_registry.add_service(lookoutvision)
m2 = M2()
class_registry.add_service(m2)
machinelearning = Machinelearning()
class_registry.add_service(machinelearning)
macie2 = Macie2()
class_registry.add_service(macie2)
managedblockchainquery = ManagedblockchainQuery()
class_registry.add_service(managedblockchainquery)
managedblockchain = Managedblockchain()
class_registry.add_service(managedblockchain)
marketplaceagreement = MarketplaceAgreement()
class_registry.add_service(marketplaceagreement)
marketplacecatalog = MarketplaceCatalog()
class_registry.add_service(marketplacecatalog)
marketplacedeployment = MarketplaceDeployment()
class_registry.add_service(marketplacedeployment)
marketplaceentitlement = MarketplaceEntitlement()
class_registry.add_service(marketplaceentitlement)
marketplacecommerceanalytics = Marketplacecommerceanalytics()
class_registry.add_service(marketplacecommerceanalytics)
mediaconnect = Mediaconnect()
class_registry.add_service(mediaconnect)
mediaconvert = Mediaconvert()
class_registry.add_service(mediaconvert)
medialive = Medialive()
class_registry.add_service(medialive)
mediapackagevod = MediapackageVod()
class_registry.add_service(mediapackagevod)
mediapackage = Mediapackage()
class_registry.add_service(mediapackage)
mediapackagev2 = Mediapackagev2()
class_registry.add_service(mediapackagev2)
mediastoredata = MediastoreData()
class_registry.add_service(mediastoredata)
mediastore = Mediastore()
class_registry.add_service(mediastore)
mediatailor = Mediatailor()
class_registry.add_service(mediatailor)
medicalimaging = MedicalImaging()
class_registry.add_service(medicalimaging)
memorydb = Memorydb()
class_registry.add_service(memorydb)
meteringmarketplace = Meteringmarketplace()
class_registry.add_service(meteringmarketplace)
mgh = Mgh()
class_registry.add_service(mgh)
mgn = Mgn()
class_registry.add_service(mgn)
migrationhubrefactorspaces = MigrationHubRefactorSpaces()
class_registry.add_service(migrationhubrefactorspaces)
migrationhubconfig = MigrationhubConfig()
class_registry.add_service(migrationhubconfig)
migrationhuborchestrator = Migrationhuborchestrator()
class_registry.add_service(migrationhuborchestrator)
migrationhubstrategy = Migrationhubstrategy()
class_registry.add_service(migrationhubstrategy)
mobile = Mobile()
class_registry.add_service(mobile)
mq = Mq()
class_registry.add_service(mq)
mturk = Mturk()
class_registry.add_service(mturk)
mwaa = Mwaa()
class_registry.add_service(mwaa)
neptunegraph = NeptuneGraph()
class_registry.add_service(neptunegraph)
neptune = Neptune()
class_registry.add_service(neptune)
neptunedata = Neptunedata()
class_registry.add_service(neptunedata)
networkfirewall = NetworkFirewall()
class_registry.add_service(networkfirewall)
networkmanager = Networkmanager()
class_registry.add_service(networkmanager)
networkmonitor = Networkmonitor()
class_registry.add_service(networkmonitor)
nimble = Nimble()
class_registry.add_service(nimble)
oam = Oam()
class_registry.add_service(oam)
omics = Omics()
class_registry.add_service(omics)
opensearch = Opensearch()
class_registry.add_service(opensearch)
opensearchserverless = Opensearchserverless()
class_registry.add_service(opensearchserverless)
opsworks = Opsworks()
class_registry.add_service(opsworks)
opsworkscm = Opsworkscm()
class_registry.add_service(opsworkscm)
organizations = Organizations()
class_registry.add_service(organizations)
osis = Osis()
class_registry.add_service(osis)
outposts = Outposts()
class_registry.add_service(outposts)
panorama = Panorama()
class_registry.add_service(panorama)
paymentcryptographydata = PaymentCryptographyData()
class_registry.add_service(paymentcryptographydata)
paymentcryptography = PaymentCryptography()
class_registry.add_service(paymentcryptography)
pcaconnectorad = PcaConnectorAd()
class_registry.add_service(pcaconnectorad)
personalizeevents = PersonalizeEvents()
class_registry.add_service(personalizeevents)
personalizeruntime = PersonalizeRuntime()
class_registry.add_service(personalizeruntime)
personalize = Personalize()
class_registry.add_service(personalize)
pi = Pi()
class_registry.add_service(pi)
pinpointemail = PinpointEmail()
class_registry.add_service(pinpointemail)
pinpointsmsvoicev2 = PinpointSmsVoiceV2()
class_registry.add_service(pinpointsmsvoicev2)
pinpointsmsvoice = PinpointSmsVoice()
class_registry.add_service(pinpointsmsvoice)
pinpoint = Pinpoint()
class_registry.add_service(pinpoint)
pipes = Pipes()
class_registry.add_service(pipes)
polly = Polly()
class_registry.add_service(polly)
pricing = Pricing()
class_registry.add_service(pricing)
privatenetworks = Privatenetworks()
class_registry.add_service(privatenetworks)
proton = Proton()
class_registry.add_service(proton)
qbusiness = Qbusiness()
class_registry.add_service(qbusiness)
qconnect = Qconnect()
class_registry.add_service(qconnect)
qldbsession = QldbSession()
class_registry.add_service(qldbsession)
qldb = Qldb()
class_registry.add_service(qldb)
ram = Ram()
class_registry.add_service(ram)
rbin = Rbin()
class_registry.add_service(rbin)
rdsdata = RdsData()
class_registry.add_service(rdsdata)
rds = Rds()
class_registry.add_service(rds)
redshiftdata = RedshiftData()
class_registry.add_service(redshiftdata)
redshiftserverless = RedshiftServerless()
class_registry.add_service(redshiftserverless)
redshift = Redshift()
class_registry.add_service(redshift)
rekognition = Rekognition()
class_registry.add_service(rekognition)
repostspace = Repostspace()
class_registry.add_service(repostspace)
resiliencehub = Resiliencehub()
class_registry.add_service(resiliencehub)
resourceexplorer2 = ResourceExplorer2()
class_registry.add_service(resourceexplorer2)
resourcegroups = ResourceGroups()
class_registry.add_service(resourcegroups)
resourcegroupstaggingapi = Resourcegroupstaggingapi()
class_registry.add_service(resourcegroupstaggingapi)
robomaker = Robomaker()
class_registry.add_service(robomaker)
rolesanywhere = Rolesanywhere()
class_registry.add_service(rolesanywhere)
route53recoverycluster = Route53RecoveryCluster()
class_registry.add_service(route53recoverycluster)
route53recoverycontrolconfig = Route53RecoveryControlConfig()
class_registry.add_service(route53recoverycontrolconfig)
route53recoveryreadiness = Route53RecoveryReadiness()
class_registry.add_service(route53recoveryreadiness)
route53 = Route53()
class_registry.add_service(route53)
route53domains = Route53domains()
class_registry.add_service(route53domains)
route53profiles = Route53profiles()
class_registry.add_service(route53profiles)
route53resolver = Route53resolver()
class_registry.add_service(route53resolver)
rum = Rum()
class_registry.add_service(rum)
s3 = S3()
class_registry.add_service(s3)
s3control = S3control()
class_registry.add_service(s3control)
s3outposts = S3outposts()
class_registry.add_service(s3outposts)
sagemakera2iruntime = SagemakerA2iRuntime()
class_registry.add_service(sagemakera2iruntime)
sagemakeredge = SagemakerEdge()
class_registry.add_service(sagemakeredge)
sagemakerfeaturestoreruntime = SagemakerFeaturestoreRuntime()
class_registry.add_service(sagemakerfeaturestoreruntime)
sagemakergeospatial = SagemakerGeospatial()
class_registry.add_service(sagemakergeospatial)
sagemakermetrics = SagemakerMetrics()
class_registry.add_service(sagemakermetrics)
sagemakerruntime = SagemakerRuntime()
class_registry.add_service(sagemakerruntime)
savingsplans = Savingsplans()
class_registry.add_service(savingsplans)
scheduler = Scheduler()
class_registry.add_service(scheduler)
schemas = Schemas()
class_registry.add_service(schemas)
sdb = Sdb()
class_registry.add_service(sdb)
secretsmanager = Secretsmanager()
class_registry.add_service(secretsmanager)
securitylake = Securitylake()
class_registry.add_service(securitylake)
serverlessrepo = Serverlessrepo()
class_registry.add_service(serverlessrepo)
servicequotas = ServiceQuotas()
class_registry.add_service(servicequotas)
servicecatalogappregistry = ServicecatalogAppregistry()
class_registry.add_service(servicecatalogappregistry)
servicecatalog = Servicecatalog()
class_registry.add_service(servicecatalog)
servicediscovery = Servicediscovery()
class_registry.add_service(servicediscovery)
ses = Ses()
class_registry.add_service(ses)
sesv2 = Sesv2()
class_registry.add_service(sesv2)
shield = Shield()
class_registry.add_service(shield)
signer = Signer()
class_registry.add_service(signer)
simspaceweaver = Simspaceweaver()
class_registry.add_service(simspaceweaver)
smsvoice = SmsVoice()
class_registry.add_service(smsvoice)
sms = Sms()
class_registry.add_service(sms)
snowdevicemanagement = SnowDeviceManagement()
class_registry.add_service(snowdevicemanagement)
snowball = Snowball()
class_registry.add_service(snowball)
sns = Sns()
class_registry.add_service(sns)
sqs = Sqs()
class_registry.add_service(sqs)
ssmcontacts = SsmContacts()
class_registry.add_service(ssmcontacts)
ssmincidents = SsmIncidents()
class_registry.add_service(ssmincidents)
ssmsap = SsmSap()
class_registry.add_service(ssmsap)
ssm = Ssm()
class_registry.add_service(ssm)
ssoadmin = SsoAdmin()
class_registry.add_service(ssoadmin)
ssooidc = SsoOidc()
class_registry.add_service(ssooidc)
sso = Sso()
class_registry.add_service(sso)
stepfunctions = Stepfunctions()
class_registry.add_service(stepfunctions)
storagegateway = Storagegateway()
class_registry.add_service(storagegateway)
sts = Sts()
class_registry.add_service(sts)
supplychain = Supplychain()
class_registry.add_service(supplychain)
supportapp = SupportApp()
class_registry.add_service(supportapp)
support = Support()
class_registry.add_service(support)
swf = Swf()
class_registry.add_service(swf)
synthetics = Synthetics()
class_registry.add_service(synthetics)
textract = Textract()
class_registry.add_service(textract)
timestreaminfluxdb = TimestreamInfluxdb()
class_registry.add_service(timestreaminfluxdb)
timestreamquery = TimestreamQuery()
class_registry.add_service(timestreamquery)
timestreamwrite = TimestreamWrite()
class_registry.add_service(timestreamwrite)
tnb = Tnb()
class_registry.add_service(tnb)
transcribe = Transcribe()
class_registry.add_service(transcribe)
transfer = Transfer()
class_registry.add_service(transfer)
translate = Translate()
class_registry.add_service(translate)
trustedadvisor = Trustedadvisor()
class_registry.add_service(trustedadvisor)
verifiedpermissions = Verifiedpermissions()
class_registry.add_service(verifiedpermissions)
voiceid = VoiceId()
class_registry.add_service(voiceid)
vpclattice = VpcLattice()
class_registry.add_service(vpclattice)
wafregional = WafRegional()
class_registry.add_service(wafregional)
waf = Waf()
class_registry.add_service(waf)
wafv2 = Wafv2()
class_registry.add_service(wafv2)
wellarchitected = Wellarchitected()
class_registry.add_service(wellarchitected)
wisdom = Wisdom()
class_registry.add_service(wisdom)
workdocs = Workdocs()
class_registry.add_service(workdocs)
worklink = Worklink()
class_registry.add_service(worklink)
workmail = Workmail()
class_registry.add_service(workmail)
workmailmessageflow = Workmailmessageflow()
class_registry.add_service(workmailmessageflow)
workspacesthinclient = WorkspacesThinClient()
class_registry.add_service(workspacesthinclient)
workspacesweb = WorkspacesWeb()
class_registry.add_service(workspacesweb)
workspaces = Workspaces()
class_registry.add_service(workspaces)
xray = Xray()
class_registry.add_service(xray)
